(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1925254,      32138]
NotebookOptionsPosition[   1920946,      32001]
NotebookOutlinePosition[   1921283,      32016]
CellTagsIndexPosition[   1921240,      32013]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Main functions", "Subsection",
 CellChangeTimes->{{3.470830740832885*^9, 3.470830751751577*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"importResolutionsFromImage", "[", 
   RowBox[{"img_", ",", "gridw_", ",", "gridh_"}], "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"0.3", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"ListQ", "@", "#"}], ",", 
           RowBox[{"First", "@", "#"}], ",", "#"}], "]"}]}], ")"}], "*", 
       "0.7"}]}], "&"}], ",", 
    RowBox[{"ImageData", "@", 
     RowBox[{"ImageResize", "[", 
      RowBox[{
       RowBox[{"ColorConvert", "[", 
        RowBox[{"img", ",", "\"\<GrayScale\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"gridw", ",", "gridh"}], "}"}]}], "]"}]}], ",", 
    RowBox[{"{", "2", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.47079258157441*^9, 3.470792585243581*^9}, {
   3.470792638426224*^9, 3.470792641336386*^9}, {3.47082482122731*^9, 
   3.470824824663075*^9}, 3.470825698963144*^9, {3.470827558085828*^9, 
   3.470827563089484*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"given", " ", "a", " ", "resolution", " ", "value"}], ",", " ", 
    RowBox[{
    "create", " ", "a", " ", "small", " ", "graph", " ", "representing", " ", 
     "a", " ", "grid", " ", "in", " ", "that", " ", "resolution"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"createGraphForResolutionCell", "[", 
    RowBox[{"resolution_", ",", "minNodeName_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pixels", ",", "table", ",", "counterFromWH"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"counterFromWH", "[", 
        RowBox[{"w_", ",", "h_", ",", "maxw_"}], "]"}], ":=", 
       RowBox[{"w", "+", 
        RowBox[{"h", "*", "maxw"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"pixels", "=", 
       RowBox[{"Floor", "[", 
        RowBox[{"resolution", "*", "10"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"table", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"minNodeName", "+", 
            RowBox[{"counterFromWH", "[", 
             RowBox[{"w", ",", "h", ",", "pixels"}], "]"}], "-", "1"}], ")"}],
           "\[Rule]", 
          RowBox[{"(", 
           RowBox[{"minNodeName", "+", 
            RowBox[{"counterFromWH", "[", 
             RowBox[{
              RowBox[{"w", "+", "1"}], ",", "h", ",", "pixels"}], "]"}], "-", 
            "1"}], ")"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"w", ",", 
           RowBox[{"pixels", "-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"h", ",", "pixels"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"table", "=", 
       RowBox[{"Join", "[", 
        RowBox[{"table", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"minNodeName", "+", 
              RowBox[{"counterFromWH", "[", 
               RowBox[{"w", ",", "h", ",", "pixels"}], "]"}], "-", "1"}], 
             ")"}], "\[Rule]", 
            RowBox[{"(", 
             RowBox[{"minNodeName", "+", 
              RowBox[{"counterFromWH", "[", 
               RowBox[{"w", ",", 
                RowBox[{"h", "+", "1"}], ",", "pixels"}], "]"}], "-", "1"}], 
             ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"w", ",", "pixels"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"h", ",", 
             RowBox[{"pixels", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Flatten", "@", "table"}]}]}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.467930266991764*^9, 3.467930287431575*^9}, {
  3.470825761981407*^9, 3.470825783559429*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "given", " ", "a", " ", "graph", " ", "like", " ", "the", " ", "one", " ",
      "built", " ", "by", " ", "createGraphForResolutionCell"}], ",", 
    RowBox[{
    "return", " ", "a", " ", "specific", " ", "side", " ", "of", " ", "such", 
     " ", "graph"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"getSide", "[", 
    RowBox[{"grid_", ",", "whichSide_"}], "]"}], ":=", "\[IndentingNewLine]", 
   
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nums", ",", "min", ",", "max", ",", "w"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"nums", "=", 
       RowBox[{"Union", "@", 
        RowBox[{"Flatten", "[", 
         RowBox[{"List", "@@@", "grid"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"min", "=", 
       RowBox[{"Min", "[", "nums", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"max", "=", 
       RowBox[{"Max", "[", "nums", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"w", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "+", "max", "-", "min"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"whichSide", "===", "\"\<Left\>\""}], ",", 
        RowBox[{"Return", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"min", "+", 
            RowBox[{"(", 
             RowBox[{"w", "*", 
              RowBox[{"(", 
               RowBox[{"#", "-", "1"}], ")"}]}], ")"}]}], "&"}], "/@", 
          RowBox[{"Range", "[", "w", "]"}]}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"whichSide", "===", "\"\<Right\>\""}], ",", 
        RowBox[{"Return", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"min", "+", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"w", "*", 
               RowBox[{"(", 
                RowBox[{"#", "-", "1"}], ")"}]}], "+", "w", "-", "1"}], 
             ")"}]}], "&"}], "/@", 
          RowBox[{"Range", "[", "w", "]"}]}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"whichSide", "===", "\"\<Top\>\""}], ",", 
        RowBox[{"Return", "[", 
         RowBox[{"Take", "[", 
          RowBox[{"nums", ",", "w"}], "]"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Take", "[", 
       RowBox[{"nums", ",", 
        RowBox[{"-", "w"}]}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.467930300089826*^9, 3.46793031054517*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"getLeftSide", "[", "grid_", "]"}], ":=", 
  RowBox[{"getSide", "[", 
   RowBox[{"grid", ",", "\"\<Left\>\""}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getRightSide", "[", "grid_", "]"}], ":=", 
  RowBox[{"getSide", "[", 
   RowBox[{"grid", ",", "\"\<Right\>\""}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getTopSide", "[", "grid_", "]"}], ":=", 
  RowBox[{"getSide", "[", 
   RowBox[{"grid", ",", "\"\<Top\>\""}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getBottomSide", "[", "grid_", "]"}], ":=", 
  RowBox[{"getSide", "[", 
   RowBox[{"grid", ",", "\"\<Bottom\>\""}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"connectPoints", "[", 
   RowBox[{"pointsA_", ",", "pointsB_"}], "]"}], ":=", "\[IndentingNewLine]", 
  
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pA", ",", "pB", ",", "dist", ",", "pa2", ",", "idx", ",", "idxpre"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "@", "pointsA"}], ">", 
        RowBox[{"Length", "@", "pointsB"}]}], ",", 
       RowBox[{
        RowBox[{"pA", "=", "pointsA"}], ";", 
        RowBox[{"pB", "=", "pointsB"}]}], ",", 
       RowBox[{
        RowBox[{"pB", "=", "pointsA"}], ";", 
        RowBox[{"pA", "=", "pointsB"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"dist", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Length", "@", "pB"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"Length", "@", "pA"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"idx", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"pa2", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"idxpre", "=", "idx"}], ";", 
           RowBox[{"idx", "=", 
            RowBox[{"idx", "+", "dist"}]}], ";", 
           RowBox[{"pB", "[", 
            RowBox[{"[", 
             RowBox[{"Floor", "[", "idxpre", "]"}], "]"}], "]"}]}], ")"}]}], 
        "&"}], "/@", "pA"}]}], ";", "\[IndentingNewLine]", "pa2"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.467930337914637*^9, 3.467930350854337*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"returns", " ", 
     RowBox[{"{", 
      RowBox[{"graph", ",", "graphgrid"}], "}"}]}], ",", 
    RowBox[{
    "graph", " ", "is", " ", "the", " ", "full", " ", "graph", " ", "with", 
     " ", "interconnectors", " ", "included"}], ",", " ", 
    RowBox[{
    "graphgrid", " ", "is", " ", "the", " ", "grid", " ", "of", " ", 
     "subgraphs", " ", "that", " ", "compose", " ", "the", " ", "graph", " ", 
     "without", " ", "the", " ", "connectors"}]}], "*)"}], 
  RowBox[{
   RowBox[{"createGraphFromResolutionGrid", "[", "resolutionGrid_", "]"}], ":=",
    "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "gridw", ",", "gridh", ",", "graphgrid", ",", "last", ",", "minNode", 
       ",", "wConnectors", ",", "hConnectors", ",", "fullgraph"}], "}"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gridw", "=", 
       RowBox[{"Length", "@", 
        RowBox[{"resolutionGrid", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gridh", "=", 
       RowBox[{"Length", "@", "resolutionGrid"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"minNode", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"graphgrid", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"last", "=", 
             RowBox[{"createGraphForResolutionCell", "[", 
              RowBox[{"#", ",", "minNode"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"minNode", "=", 
             RowBox[{"Max", "@", 
              RowBox[{"Flatten", "[", 
               RowBox[{"List", "@@@", "last"}], "]"}]}]}], ";", "last"}], 
           ")"}], "&"}], ",", "resolutionGrid", ",", 
         RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"wConnectors", "=", 
       RowBox[{"Flatten", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"connectPoints", "[", 
           RowBox[{
            RowBox[{"getRightSide", "[", 
             RowBox[{
              RowBox[{"graphgrid", "[", 
               RowBox[{"[", "h", "]"}], "]"}], "[", 
              RowBox[{"[", "w", "]"}], "]"}], "]"}], ",", 
            RowBox[{"getLeftSide", "[", 
             RowBox[{
              RowBox[{"graphgrid", "[", 
               RowBox[{"[", "h", "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"w", "+", "1"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"w", ",", 
            RowBox[{"gridw", "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"h", ",", "gridh"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"hConnectors", "=", 
       RowBox[{"Flatten", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"connectPoints", "[", 
           RowBox[{
            RowBox[{"getBottomSide", "[", 
             RowBox[{
              RowBox[{"graphgrid", "[", 
               RowBox[{"[", "h", "]"}], "]"}], "[", 
              RowBox[{"[", "w", "]"}], "]"}], "]"}], ",", 
            RowBox[{"getTopSide", "[", 
             RowBox[{
              RowBox[{"graphgrid", "[", 
               RowBox[{"[", 
                RowBox[{"h", "+", "1"}], "]"}], "]"}], "[", 
              RowBox[{"[", "w", "]"}], "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"w", ",", "gridw"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"h", ",", 
            RowBox[{"gridh", "-", "1"}]}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"fullgraph", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Flatten", "@", "graphgrid"}], ",", "wConnectors", ",", 
         "hConnectors"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"fullgraph", ",", "graphgrid"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.467930366724322*^9, 3.467930372864495*^9}, {
  3.470824771287435*^9, 3.470824786743111*^9}, {3.470825354483326*^9, 
  3.470825380404792*^9}, {3.470826930352913*^9, 3.470826947072204*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"squareCellNumToXY", "[", 
   RowBox[{"num_", ",", "min_", ",", "gridw_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{"(*", "x", "*)"}], 
   RowBox[{
    RowBox[{"Mod", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"num", "-", "min"}], ")"}], ",", "gridw"}], "]"}], ",", 
    RowBox[{"(*", "y", "*)"}], 
    RowBox[{"Floor", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"num", "-", "min"}], ")"}], "/", "gridw"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{
  3.467930382278127*^9, {3.470827293592242*^9, 3.470827300423328*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"squareCellToSpace", "[", 
   RowBox[{
   "grid_", ",", "x_", ",", "y_", ",", "w_", ",", "h_", ",", "mindist_"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"nums", ",", "min", ",", "max", ",", "cellw", ",", "numcoord"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"nums", "=", 
      RowBox[{"Union", "@", 
       RowBox[{"Flatten", "[", 
        RowBox[{"List", "@@@", "grid"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"min", "=", 
      RowBox[{"Min", "[", "nums", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"max", "=", 
      RowBox[{"Max", "[", "nums", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"cellw", "=", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", "max", "-", "min"}], "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"cells", " ", "are", " ", "square"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"numcoord", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Rule]", 
         RowBox[{"squareCellNumToXY", "[", 
          RowBox[{"#", ",", "min", ",", "cellw"}], "]"}]}], "&"}], "/@", 
       "nums"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"numcoord", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "+", "mindist", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"w", "-", 
               RowBox[{"2", " ", "mindist"}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "1"}], "]"}], "]"}], "/", 
              RowBox[{"(", 
               RowBox[{"cellw", "-", "1"}], ")"}]}]}]}], ",", 
           RowBox[{"y", "+", "mindist", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"h", "-", 
               RowBox[{"2", " ", "mindist"}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "2"}], "]"}], "]"}], "/", 
              RowBox[{"(", 
               RowBox[{"cellw", "-", "1"}], ")"}]}]}]}]}], "}"}]}], "&"}], "/@",
        "numcoord"}]}], ";", "\[IndentingNewLine]", "numcoord"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.467930392869233*^9, 3.467930398130646*^9}, {
   3.470827144729225*^9, 3.470827205658784*^9}, 3.470827340541436*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "generate", " ", "coordinates", " ", "for", " ", "all", " ", "vertices", 
    " ", "of", " ", "a", " ", "megagrid", " ", "generated", " ", "by", " ", 
    "createGraphFromResolutionGrid", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"it", "'"}], "s", " ", "called", " ", "megagrid", " ", 
      "because", " ", 
      RowBox[{"it", "'"}], "s", " ", "a", " ", "grid", " ", "of", " ", 
      "grids"}], ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"computeXYForFullMegaGrid", "[", 
    RowBox[{
    "graphgrid_", ",", "x_", ",", "y_", ",", "w_", ",", "h_", ",", 
     "mindist_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "gridsxy", ",", "gridw", ",", "gridh", ",", "graphxy", ",", "maxy"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gridw", "=", 
       RowBox[{"Length", "@", 
        RowBox[{"graphgrid", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gridh", "=", 
       RowBox[{"Length", "@", "graphgrid"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gridsxy", "=", 
       RowBox[{"MapIndexed", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"squareCellToSpace", "[", 
           RowBox[{"#", ",", 
            RowBox[{"x", "+", 
             RowBox[{
              RowBox[{"#2", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "*", 
              RowBox[{"w", "/", "gridw"}]}]}], ",", 
            RowBox[{"y", "+", 
             RowBox[{
              RowBox[{"#2", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "*", 
              RowBox[{"h", "/", "gridh"}]}]}], ",", 
            RowBox[{"w", "/", "gridw"}], ",", 
            RowBox[{"h", "/", "gridh"}], ",", "mindist"}], "]"}], "&"}], ",", 
         "graphgrid", ",", 
         RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"graphxy", "=", 
       RowBox[{"Flatten", "@", "gridsxy"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"maxy", "=", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "2"}], "]"}], "]"}], "&"}], "/@", 
         RowBox[{"Flatten", "[", "graphxy", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"graphxy", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{"maxy", "-", 
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], "}"}]}], "&"}], "/@",
         "graphxy"}]}], ";", 
      RowBox[{"(*", 
       RowBox[{"invert", " ", "y", " ", "coordinate"}], "*)"}], 
      "\[IndentingNewLine]", "graphxy"}]}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.467930404627018*^9, 3.467930411820557*^9}, {
   3.470826442539023*^9, 3.470826501059427*^9}, {3.470826640489897*^9, 
   3.47082665194406*^9}, {3.470827019565609*^9, 3.470827026456098*^9}, 
   3.470827059313522*^9, {3.470827368202587*^9, 3.470827389601109*^9}, {
   3.470827550386369*^9, 3.470827552708228*^9}, {3.470838125174374*^9, 
   3.470838159721356*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "generates", " ", "a", " ", "maze", " ", "from", " ", "any", " ", "kind",
       " ", "of", " ", "graph", "\[IndentingNewLine]", "maxdepth", " ", "is", 
      " ", "the", " ", "maximum", " ", "depth", " ", "for", " ", "the", " ", 
      "dfs", " ", "algorithm"}], ";", " ", 
     RowBox[{
     "it", " ", "can", " ", "be", " ", "infinity", " ", "for", " ", "small", 
      " ", "images"}]}], ",", " ", 
    RowBox[{
     RowBox[{
     "bigger", " ", "images", " ", "need", " ", "an", " ", "integer", " ", 
      "value"}], ";", " ", 
     RowBox[{
     "if", " ", "maxdeep", " ", "is", " ", "too", " ", "small", " ", "some", 
      " ", "parts", " ", "of", " ", "the", " ", "images", " ", "will", " ", 
      "be", " ", "white"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"generateMazeFromGraph", "[", 
    RowBox[{"graph_", ",", "entrance_", ",", "exit_", ",", 
     RowBox[{"maxdeep_:", "Infinity"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "generateMazeFromCell", ",", "visited", ",", "lim", ",", "maze"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"generateMazeFromCell", "[", 
        RowBox[{"parent_", ",", "cell_", ",", "maxdeepvalue_"}], "]"}], ":=", 
       "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"neighbours", ",", 
           RowBox[{"newgraphs", "=", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"newgraphs2", "=", 
            RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"MemberQ", "[", 
             RowBox[{"visited", ",", "cell"}], "]"}], ",", 
            RowBox[{"Return", "@", 
             RowBox[{"{", "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"maxdeepvalue", "\[Equal]", "0"}], ",", 
            RowBox[{"Return", "@", 
             RowBox[{"{", "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"parent", "=!=", "None"}], ",", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"newgraphs", ",", 
              RowBox[{"parent", "\[Rule]", "cell"}]}], "]"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"visited", "=", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"visited", ",", "cell"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"neighbours", "=", 
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"Union", "@", 
              RowBox[{"Flatten", "[", 
               RowBox[{"List", "@@@", 
                RowBox[{"Select", "[", 
                 RowBox[{"graph", ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "cell"}], "||", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "cell"}]}], 
                   "&"}]}], "]"}]}], "]"}]}], ",", "visited"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"neighbours", "=", 
             RowBox[{"RandomSample", "[", 
              RowBox[{"neighbours", ",", 
               RowBox[{"Ceiling", "[", 
                RowBox[{
                 RowBox[{"Random", "[", "]"}], "*", 
                 RowBox[{"Length", "@", "neighbours"}]}], "]"}]}], "]"}]}], 
            ";"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"neighbours", "=", 
           RowBox[{"RandomSample", "[", "neighbours", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"!", 
               RowBox[{"MemberQ", "[", 
                RowBox[{"visited", ",", "#"}], "]"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"newgraphs2", ",", 
                RowBox[{"generateMazeFromCell", "[", 
                 RowBox[{"cell", ",", "#", ",", 
                  RowBox[{"maxdeepvalue", "-", "1"}]}], "]"}]}], "]"}]}], 
             "]"}], "&"}], "/@", "neighbours"}], ";", "\[IndentingNewLine]", 
          RowBox[{"Flatten", "@", 
           RowBox[{"Append", "[", 
            RowBox[{"newgraphs2", ",", "newgraphs"}], "]"}]}]}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"visited", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"lim", "=", "$RecursionLimit"}], ";", "\[IndentingNewLine]", 
      RowBox[{"$RecursionLimit", "=", "Infinity"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"maze", "=", 
       RowBox[{"generateMazeFromCell", "[", 
        RowBox[{"None", ",", "entrance", ",", "maxdeep"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"$RecursionLimit", "=", "lim"}], ";", "\[IndentingNewLine]", 
      "maze"}]}], "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.467930422983644*^9, 3.467930443868853*^9}, {
   3.470656989363226*^9, 3.470657026012592*^9}, {3.470657056580154*^9, 
   3.470657090463068*^9}, {3.47065712046308*^9, 3.470657136879695*^9}, {
   3.47065734326164*^9, 3.470657346935506*^9}, {3.470657422852585*^9, 
   3.470657434323194*^9}, 3.47065754574952*^9, {3.470657592453017*^9, 
   3.470657592852497*^9}, 3.470657717365706*^9, {3.470845994210696*^9, 
   3.470846015071162*^9}, 3.470846118492688*^9, {3.47084624845558*^9, 
   3.47084627897452*^9}, {3.470846319152812*^9, 3.470846430298995*^9}, {
   3.470867674680986*^9, 3.470867676550481*^9}, {3.470867743593587*^9, 
   3.470867752640825*^9}, {3.470912522900355*^9, 3.470912592500109*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateMazeFromImage", "[", 
   RowBox[{"img_", ",", "resolutionX_", ",", "resolutionY_", ",", 
    RowBox[{"maxPathLength_:", "Infinity"}], ",", 
    RowBox[{"showBackgroundGrids_:", " ", "False"}], ",", 
    RowBox[{"showBackgroundGridsOnly_:", "False"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "entrance", ",", "exit", ",", "resolutions", ",", "fullgraph", ",", 
      "graphgrid", ",", "graphxy", ",", "fullgraph2", ",", "maze", ",", 
      "mazegfx", ",", "graphic"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"resolutions", "=", 
      RowBox[{"importResolutionsFromImage", "[", 
       RowBox[{"img", ",", "resolutionX", ",", "resolutionY"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"fullgraph", ",", "graphgrid"}], "}"}], "=", 
      RowBox[{"createGraphFromResolutionGrid", "[", "resolutions", "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"graphxy", "=", 
      RowBox[{"computeXYForFullMegaGrid", "[", 
       RowBox[{"graphgrid", ",", "0", ",", "0", ",", 
        RowBox[{"10", " ", "resolutionX"}], ",", 
        RowBox[{"10", " ", "resolutionY"}], ",", "1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"entrance", "=", 
      RowBox[{"Min", "@", 
       RowBox[{"Flatten", "[", 
        RowBox[{"List", "@@@", "fullgraph"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"exit", "=", 
      RowBox[{"Max", "@", 
       RowBox[{"Flatten", "[", 
        RowBox[{"List", "@@@", "fullgraph"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", "showBackgroundGridsOnly"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"maze", "=", 
         RowBox[{"generateMazeFromGraph", "[", 
          RowBox[{
          "fullgraph", ",", "entrance", ",", "exit", ",", "maxPathLength"}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"maze", "=", 
         RowBox[{"Rule", "@@@", 
          RowBox[{"(", 
           RowBox[{"Sort", "/@", 
            RowBox[{"List", "@@@", "maze"}]}], ")"}]}]}], ";", 
        RowBox[{"(*", "sort", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"mazegfx", "=", 
         RowBox[{"ReplaceAll", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], "&"}], "/@", 
            "maze"}], ",", "graphxy"}], "]"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"fullgraph", "=", 
      RowBox[{"Rule", "@@@", 
       RowBox[{"(", 
        RowBox[{"Sort", "/@", 
         RowBox[{"List", "@@@", "fullgraph"}]}], ")"}]}]}], ";", 
     RowBox[{"(*", "sort", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"fullgraph2", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"showBackgroundGrids", "||", "showBackgroundGridsOnly"}], ",",
         "fullgraph", ",", 
        RowBox[{"{", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fullgraph2", "=", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], "&"}], "/@", 
         "fullgraph2"}], ",", "graphxy"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", "showBackgroundGridsOnly"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fullgraph2", "=", 
         RowBox[{"Complement", "[", 
          RowBox[{"fullgraph2", ",", "mazegfx"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"graphic", "=", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Gray", ",", 
             RowBox[{"AbsoluteThickness", "[", "3", "]"}], ",", 
             "fullgraph2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"AbsoluteThickness", "[", "5", "]"}], ",", "mazegfx"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Green", ",", 
             RowBox[{"Disk", "[", 
              RowBox[{"entrance", "/.", "graphxy"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Disk", "[", 
              RowBox[{"exit", "/.", "graphxy"}], "]"}]}], "}"}]}], "]"}]}], 
        ";"}], "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"graphic", "=", 
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"AbsoluteThickness", "[", "5", "]"}], ",", "fullgraph2"}], 
          "}"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{"graphic", ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"resolutionX", "*", 
         RowBox[{"1500", "/", "16"}]}]}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.467930463721863*^9, 3.467930472124222*^9}, {
   3.470657219650711*^9, 3.470657262217841*^9}, {3.47065761869213*^9, 
   3.470657625861727*^9}, {3.470657723033334*^9, 3.470657724258048*^9}, {
   3.470792536145582*^9, 3.470792563015903*^9}, {3.470824332948887*^9, 
   3.470824361808349*^9}, {3.470825952598976*^9, 3.470825956378899*^9}, {
   3.470826547730533*^9, 3.470826559729378*^9}, {3.47082679388932*^9, 
   3.470826801582972*^9}, {3.470826980112565*^9, 3.470826983479406*^9}, {
   3.470827572998093*^9, 3.47082758863044*^9}, {3.470827710977398*^9, 
   3.470827721353032*^9}, {3.47082777152026*^9, 3.470827773744006*^9}, {
   3.470827807352099*^9, 3.470827844355348*^9}, {3.470828546526092*^9, 
   3.470828591331301*^9}, {3.470829374883118*^9, 3.470829386123183*^9}, {
   3.470829496099672*^9, 3.470829538749545*^9}, {3.470838139041827*^9, 
   3.470838146586596*^9}, {3.470838325108125*^9, 3.470838443496021*^9}, {
   3.470838599092958*^9, 3.470838600487915*^9}, {3.470838703539838*^9, 
   3.47083870376303*^9}, 3.47083879586215*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate a big test maze", "Subsection",
 CellChangeTimes->{{3.470830769312381*^9, 3.470830774387702*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.470782924438041*^9, 3.470782936650239*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"img", " ", "by", " ", "Larry", " ", "Ewing"}], ",", " ", 
   RowBox[{
    RowBox[{"see", "  ", 
     RowBox[{"http", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"www", ".", "isc", ".", "tamu", ".", "edu"}], "/", 
        RowBox[{"~", "lewing"}]}], "/", "linux"}], "/", " ", "for"}], " ", 
     "details"}]}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.467930949128257*^9, 3.467930973615503*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"img", "=", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJzsved/W9eZMHiAe4GLDhAkWERSkmXZsuMax7Gd13HGk2RSx5k0J3mTyWRK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      "], {{0, 303}, {258, 0}}, {
      0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", ImageSize -> Automatic, Interleaving -> 
      True, Magnification -> Automatic],
     Selectable->False],
    BaseStyle->"ImageGraphics",
    ImageSize->Automatic,
    ImageSizeRaw->{258, 303},
    PlotRange->{{0, 258}, {0, 303}},
    ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], ";"}]], "Input",
 CellChangeTimes->{{3.46793093396174*^9, 3.46793093489837*^9}, 
   3.467931118184213*^9, {3.470830154845313*^9, 3.470830172799497*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"resx", ",", "resy"}], "}"}], "=", 
  RowBox[{"ImageDimensions", "@", "img"}]}]], "Input",
 CellChangeTimes->{{3.470792064049328*^9, 3.470792070550447*^9}, 
   3.470792210561783*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"258", ",", "303"}], "}"}]], "Output",
 CellChangeTimes->{
  3.470792211330247*^9, 3.47079227999782*^9, {3.470792599364072*^9, 
   3.4707926203487*^9}, 3.470792717273318*^9, 3.470824376532374*^9, {
   3.47082483384715*^9, 3.470824851580734*^9}, 3.470825407860038*^9, 
   3.470826230412859*^9, {3.470827605355497*^9, 3.470827623979812*^9}, 
   3.470828596413012*^9, 3.470828777035585*^9, 3.470829390426154*^9, 
   3.470829543944549*^9, 3.470829810531096*^9, 3.47083019544462*^9, 
   3.470830240333574*^9, 3.470830288727123*^9, 3.470834124563404*^9, 
   3.470839891583025*^9, 3.4708460484201*^9, 3.470846491181906*^9, 
   3.470850725356513*^9, 3.470867695125254*^9, 3.470867854841147*^9, 
   3.470871189092112*^9, 3.470875030778156*^9, 3.470878954551593*^9, 
   3.470881916317064*^9, 3.470908844721686*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"resx2", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"resx", "/", "10"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resy2", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"resy", "/", "10"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"resx2", ",", "resy2"}], "}"}]}], "Input",
 CellChangeTimes->{{3.470792053870682*^9, 3.470792095711456*^9}, {
   3.470792263342236*^9, 3.470792289968931*^9}, {3.470792321599549*^9, 
   3.47079233260008*^9}, 3.470827642379828*^9, {3.470828767568868*^9, 
   3.470828771284418*^9}, 3.470829804132568*^9, {3.47083019980315*^9, 
   3.470830234587145*^9}, {3.470830280664652*^9, 3.470830281788411*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"26", ",", "30"}], "}"}]], "Output",
 CellChangeTimes->{
  3.470792096429687*^9, 3.470792178031667*^9, {3.470792271624257*^9, 
   3.470792290452822*^9}, {3.470792322494061*^9, 3.470792332988711*^9}, {
   3.470792600147009*^9, 3.470792620499532*^9}, 3.470792717359884*^9, 
   3.470824376597356*^9, {3.470824833861037*^9, 3.470824851598713*^9}, 
   3.470825407947444*^9, 3.470826230489527*^9, {3.470827605417113*^9, 
   3.470827624051125*^9}, 3.470828596483813*^9, 3.470828777112381*^9, 
   3.470829390438539*^9, 3.470829544033717*^9, 3.47082981059731*^9, {
   3.470830197712385*^9, 3.470830240345824*^9}, 3.470830288738582*^9, 
   3.47083412464676*^9, 3.470839891702989*^9, 3.470846049358347*^9, 
   3.470846491253403*^9, 3.470850726122737*^9, 3.470867695982844*^9, 
   3.470867854906299*^9, 3.470871189104262*^9, 3.47087503087789*^9, 
   3.470878954565859*^9, 3.470881916330136*^9, 3.470908844835314*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageResize", "[", 
  RowBox[{
   RowBox[{"ColorConvert", "[", 
    RowBox[{"img", ",", "\"\<GrayScale\>\""}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"resx2", ",", "resy2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.470782896403226*^9, 3.470782898054505*^9}, {
  3.470791821456185*^9, 3.470791823014758*^9}, {3.470792131400814*^9, 
  3.47079214555564*^9}, {3.470792293792995*^9, 3.470792295127934*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmJiYGCQA2IpIP4PA48KZZl4rJZ/+48O3oSyANXJ6nX9QpdZwwmU
YLTVlz6JLtPAyMjAwMrGyFj+D02m3KaAV3ziDEUG3x9oMi1ZU63CZ84rZLT8
iCYzxTeouCrAvoHJ9B2azGT/eTu2LC1zZlR5hCazJHHbnh2rp8XwiJ9Ak1kr
ndTU1j4lxjK8GNVHPxvK3aNj573YKiktfRxZ4t9W13vr0vf9/v89noEx+AOS
zF2r3n///oBYW3lYuToRXnofw7EGynxmKi8qvA4eDmv11C7BzJ0vZM9m/gzK
+x7B3/IHpuqFsZE6+xIo54yE7DW4yX9SJN0Yw75D2M3yPkgR1sHhzyR/A8y8
ZGhUgBT0Czi9mdg3gJkTODxqkXyw2yWGi3kRJMhsvfYh9HyZLi/Dy7UNxPy6
Z3tb7GWY1L9VqWwMrH7XgSnj9oLpe3blme38DZH5PXe1u1zgqpV//jdN79+6
Z89GB5kpkCD+PXvn5pXbdhZc/5+0ZQ8ITJfUegyWeVKyCcSfUno8bgFYZldR
Cyj+/14Md10D4u/e3BSxDiyzZ3115ebDG+rVVH1AenYum7Iyedaa7SCZnWHW
nLxsjAz2vlv37F5QOPXGn1t7ZjXW9SzdMsM8IqempqYqXbV3dXvGcbBL/36+
sTDC0WHVp7/gqEqQ1Qq+DfIdAPWvOho=
    "], {{0, 30}, {26, 0}}, {0, 255},
    ColorFunction->GrayLevel],
   BoxForm`ImageTag["Byte", ColorSpace -> "Grayscale", Interleaving -> None],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{26, 30},
  PlotRange->{{0, 26}, {0, 30}}]], "Output",
 CellChangeTimes->{{3.470782898708857*^9, 3.470782907702497*^9}, 
   3.470792120448023*^9, 3.47079217813485*^9, 3.470792295750112*^9, 
   3.470792333903975*^9, {3.470792600965297*^9, 3.470792620609993*^9}, 
   3.470792717587886*^9, 3.470824376760464*^9, 3.470824796098679*^9, {
   3.470824833973279*^9, 3.470824851744135*^9}, 3.470825408130943*^9, 
   3.470825605310376*^9, 3.47082623060008*^9, 3.470826524675999*^9, {
   3.470827605511421*^9, 3.470827624124649*^9}, 3.470828596562029*^9, 
   3.470828777225346*^9, 3.470829390465806*^9, 3.470829544161145*^9, 
   3.470829810684106*^9, 3.470830240432857*^9, 3.470830288810031*^9, 
   3.470834124754778*^9, 3.470839891806026*^9, 3.470846491336998*^9, 
   3.470867697539817*^9, 3.470867855037335*^9, 3.470871189141472*^9, 
   3.470875030977641*^9, 3.47087895463056*^9, 3.470881916354023*^9, 
   3.470908844970836*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"gfx", "=", 
   RowBox[{"generateMazeFromImage", "[", 
    RowBox[{"img", ",", "resx2", ",", "resy2", ",", "3200"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.467931129972965*^9, 3.467931146489971*^9}, {
   3.470650459883169*^9, 3.470650463266504*^9}, {3.470651496238227*^9, 
   3.470651498024194*^9}, {3.470652232862829*^9, 3.470652233952507*^9}, {
   3.470653051026667*^9, 3.470653100838387*^9}, {3.470654355486056*^9, 
   3.470654358121651*^9}, {3.470657167926679*^9, 3.470657168576924*^9}, 
   3.470657209358678*^9, {3.470657266780783*^9, 3.470657277982328*^9}, {
   3.470657745714665*^9, 3.470657745882454*^9}, {3.470658120491398*^9, 
   3.470658120847952*^9}, {3.470658926177442*^9, 3.470658927723673*^9}, {
   3.470660533183363*^9, 3.470660534353454*^9}, {3.470663693189845*^9, 
   3.470663695296426*^9}, {3.47066733529509*^9, 3.470667335527758*^9}, {
   3.470782746257042*^9, 3.470782752300564*^9}, {3.470785070051505*^9, 
   3.470785099226503*^9}, {3.47078645182379*^9, 3.470786456501622*^9}, {
   3.470791473124259*^9, 3.470791476154891*^9}, {3.470792151816185*^9, 
   3.470792153920448*^9}, {3.470792298378308*^9, 3.470792299467718*^9}, {
   3.470834076802851*^9, 3.470834079962361*^9}, 3.470838727406957*^9, {
   3.470875010165985*^9, 3.470875010253314*^9}, {3.470878937211145*^9, 
   3.47087894894236*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gfx", ">>", "\"\<data/maze.m\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.470782939549479*^9, 3.47078294794397*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"imggfx", "=", 
   RowBox[{"Image", "[", "gfx", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.470838194550921*^9, 3.470838202289166*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<data/mazebig.jpg\>\"", ",", "imggfx"}], "]"}], ";"}]], "Input",\

 CellChangeTimes->{{3.470830471110922*^9, 3.470830475447548*^9}, {
  3.470830556147491*^9, 3.470830565103016*^9}, {3.470830621187729*^9, 
  3.470830624452654*^9}, {3.470838188891791*^9, 3.470838191974976*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"smallimg", "=", 
  RowBox[{"ImageResize", "[", 
   RowBox[{"imggfx", ",", "400"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.467931149249021*^9, 3.467931162037558*^9}, {
  3.470658107700803*^9, 3.470658115449865*^9}, {3.470830576997634*^9, 
  3.470830579843411*^9}, {3.470838209665373*^9, 3.470838210736727*^9}, {
  3.470871176711799*^9, 3.470871176935693*^9}, {3.470874978421589*^9, 
  3.470874995722459*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs3fvXXlV1N/x2vH9Af3h+a8do+/ZgK4RTTpwPgigiBQ+tWkpFRVqpAoqK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    "], {{0, 458}, {400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{400, 458},
  PlotRange->{{0, 400}, {0, 458}}]], "Output",
 CellChangeTimes->{3.470652020013327*^9, 3.470654880905491*^9, 
  3.470657179105771*^9, 3.470657704684233*^9, 3.470657981069219*^9, 
  3.47065865486565*^9, 3.470659882012956*^9, 3.470663111301825*^9, 
  3.470666493952267*^9, 3.47079262703444*^9, 3.470792745675778*^9, 
  3.470824385357232*^9, 3.470824802707044*^9, 3.470824836702518*^9, 
  3.470824878021669*^9, 3.470825434927348*^9, 3.470825609541033*^9, 
  3.47082623380783*^9, 3.470826570323481*^9, 3.470827605900163*^9, 
  3.470827655760687*^9, 3.47082776019328*^9, 3.470828809963512*^9, 
  3.470829424728812*^9, 3.47082957788761*^9, 3.470830274001766*^9, 
  3.470832994140635*^9, 3.470837414944106*^9, 3.470842990890227*^9, 
  3.470849662332996*^9, 3.470871115179608*^9, 3.470874456241613*^9, 
  3.470878247845619*^9, 3.470881789940838*^9, 3.470912078743905*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<data/mazesmall.jpg\>\"", ",", "smallimg"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.470830585113434*^9, 3.470830614586866*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageResize", "[", 
  RowBox[{"imggfx", ",", 
   RowBox[{"resx2", "*", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.470837838066102*^9, 3.470837859575949*^9}, {
  3.470838215346609*^9, 3.470838216379458*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3fnTX0WVx3Gr5i+Zf2nKIpgEJ5CFIGskGCWCQJRFIogDjgvKbgBlEWST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    "], {{0, 119}, {104, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{104, 119},
  PlotRange->{{0, 104}, {0, 119}}]], "Output",
 CellChangeTimes->{{3.470837854673227*^9, 3.470837876416222*^9}, 
   3.470842991747776*^9, 3.470849663030256*^9, 3.470871115851839*^9, 
   3.470874457011192*^9, 3.470878248521981*^9, 3.470881790770596*^9, 
   3.470912079244779*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageResize", "[", 
  RowBox[{"imggfx", ",", "resx2"}], "]"}]], "Input",
 CellChangeTimes->{{3.470834759432662*^9, 3.470834772910511*^9}, {
  3.470838220898501*^9, 3.470838221835835*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJxN1tlOVkkUBWCTfou+6KRfqR/Ba9NciGMUFSdAcTY4i4oMIqIM2qCiIuA8
MamJcUD4QUQTNX3fX58VT9wJlTpVtVetvdfe9fPn8qq/lv+2bNmyP/z97u//
+dd/v85V5hYWFmZnZ+fm5ubn500+fvyYz+fPnw8ODv5T2O3bt1++fGnLeg4Y
nfeZ+ffv3yuVyosXL6ampqanp1+9emWcmJjwaYRz6NChtWvXrlq1avXq1XV1
dS0tLTDtjo+PGycnJ43cfZqDXVxcNPHpXmhGOFbu3Lmzb9++6urqvwtbt27d
1q1bd+3adfz48UePHjng3kCZhwBiSIYYnHIdeG9v77Zt21CqqqpasWIFtM2b
N9fU1OzcuVPUz549Cz2OJrxMFgqbLCw4T58+NXHg8uXLe/bs2b9///r169es
WSPkEydOQNu4cWNHR0dwWOLCkBdi0pjF5K3MxpUrV44dO9be3r53714hX7p0
yQpMgM3NzdwJlDAFNVUYYlIHHPPXr1/nomyR4NSpU82FnT171gj89OnTsid1
zk//tNwOExpuE4WVDCPEjRs3IFy8eHFgYEAOcQOFp0gPHz4cpaQFPTQiByia
JupoFEwrN2/ePHfuHJy7d+/SV+a7u7tFSguY9+7di0uYBG1paSmRptISo11b
IiXByZMnu7q64CAJWYyNjY1NTU3Xrl3jFUFLWb98+YJeBI2USUUq5MyZM8gc
OXLE5OrVq/fv379w4cL27dtVjkX0yqQlKGHiliQkA8EUJgmGhoZ6enpASV0q
R9T0VYQAZfJXWVNv0KxEI1cI2RkiStrDhw+fPHny+PFju7lRF6iZLVu20AKs
W0oFeUH79OmTSakmYhLV0NDAK92XMXXIUZ+q6k2bNtXW1kogtmkiNPJiBEqY
VhyWE6rJc6LIXSlRaNi6SKQKz6gvHEg7BG28MOetIOatUGlyXnZuYFPYfIeH
h9Grr6+niHjVT8hTwbuUSx2GcPToUTf29fXJVaCS6kDl3rGxMVrjtmPHDoA6
OjmXN89IoBgQb44yGxkZyUqSnwNlNVJHHYKSEE+KHqGO9fnCnETgwYMHqkL+
7TpfZt5WeV1W0JYuaOL1CNDC7UFLvaUxsZK08+fPCzm+2cqL8esLqQ7rC1Mt
2nZ0dNTi58+fy/dNbj3UesfJtCGV455gzSOHuMi0YcMGT5864cI3fYqeOkce
vuLp7+9XtwAVbRokIafdmHVNJzpoK1euFKymkKVE+v79exoJE46Gwsqr6LA2
F28JlYfCBDGl6B04ePDggQMHdC5HRSIV+Y0DTk1vjsUgC0SSdahaTXEmb0bc
cu9gYar9+vXr3IWmdJEkkAYfK4w66AFsKoy4SRczAa43W1tbXc19pDCAMiOi
Dx8+QOvs7ORufbQwaGDtWr9165Z4gVjEXKeIToUHLYCyjZ4aplq4+UyYfHOj
WPSj2hM1rZWrJlJdu3fvtihGZ7igMVCYe9++fSu9XkK7smG0PvTTSI+J7oDQ
WJjKV5N+boQGxyjn7kVSVVBhZmZGIC7iHkx6IdPW1kYF8VLQebtuh8BdkwpW
ISFvMb81NPKL9e3bt9nCNOy7d++Av3nzRhkoSAeyzvKvi4mKwkRmHKC1Gsv/
OfOVyo+lpf8AhlXjAg==
    "], {{0, 30}, {26, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{26, 30},
  PlotRange->{{0, 26}, {0, 30}}]], "Output",
 CellChangeTimes->{{3.470837430787326*^9, 3.470837447205792*^9}, 
   3.470842992091921*^9, 3.470849663451185*^9, 3.470871116275503*^9, 
   3.470874457334903*^9, 3.470878248954754*^9, 3.470881791091896*^9, 
   3.470912079665847*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sample images for article", "Subsection",
 CellChangeTimes->{{3.470830830032405*^9, 3.47083083937941*^9}, {
  3.47083846035079*^9, 3.470838466942134*^9}}],

Cell[CellGroupData[{

Cell["small resolution tux", "Subsubsection",
 CellChangeTimes->{{3.470839080843019*^9, 3.470839083495122*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"resx3", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"resx", "/", "40"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"resy3", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"resy", "/", "40"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"resx3", ",", "resy3"}], "}"}]}], "Input",
 CellChangeTimes->{{3.470838491611935*^9, 3.470838499432628*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "8"}], "}"}]], "Output",
 CellChangeTimes->{
  3.470838499868163*^9, 3.470842992138802*^9, {3.470846031445641*^9, 
   3.470846057134328*^9}, 3.470846130317572*^9, 3.470849663492747*^9, 
   3.470867703804198*^9, 3.470867780759123*^9, 3.470874457371904*^9, 
   3.470878248994496*^9, 3.470881791134382*^9, 3.470912079685808*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateMazeFromImage", "[", 
  RowBox[{
  "img", ",", "resx3", ",", "resy3", ",", "Infinity", ",", "True", ",", 
   "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.470838479497769*^9, 3.470838558557734*^9}, {
   3.470838646151735*^9, 3.470838646395149*^9}, 3.470838994070406*^9, {
   3.470839775290068*^9, 3.470839776212894*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], LineBox[{{11, 78}, {15, 78}}], 
   LineBox[{{11, 74}, {15, 74}}], LineBox[{{11, 70}, {15, 70}}], 
   LineBox[{{15, 78}, {19, 78}}], LineBox[{{15, 74}, {19, 74}}], 
   LineBox[{{15, 70}, {19, 70}}], LineBox[{{11, 78}, {11, 74}}], 
   LineBox[{{11, 74}, {11, 70}}], LineBox[{{15, 78}, {15, 74}}], 
   LineBox[{{15, 74}, {15, 70}}], LineBox[{{19, 78}, {19, 74}}], 
   LineBox[{{19, 74}, {19, 70}}], LineBox[{{21, 78}, {25, 78}}], 
   LineBox[{{21, 74}, {25, 74}}], LineBox[{{21, 70}, {25, 70}}], 
   LineBox[{{25, 78}, {29, 78}}], LineBox[{{25, 74}, {29, 74}}], 
   LineBox[{{25, 70}, {29, 70}}], LineBox[{{21, 78}, {21, 74}}], 
   LineBox[{{21, 74}, {21, 70}}], LineBox[{{25, 78}, {25, 74}}], 
   LineBox[{{25, 74}, {25, 70}}], LineBox[{{29, 78}, {29, 74}}], 
   LineBox[{{29, 74}, {29, 70}}], 
   LineBox[NCache[{{31, 78}, {Rational[225, 7], 78}}, {{31, 78}, {
      32.142857142857146`, 78}}]], 
   LineBox[NCache[{{31, Rational[538, 7]}, {
      Rational[225, 7], Rational[538, 7]}}, {{31, 76.85714285714286}, {
      32.142857142857146`, 76.85714285714286}}]], 
   LineBox[NCache[{{31, Rational[530, 7]}, {
      Rational[225, 7], Rational[530, 7]}}, {{31, 75.71428571428571}, {
      32.142857142857146`, 75.71428571428571}}]], 
   LineBox[NCache[{{31, Rational[522, 7]}, {
      Rational[225, 7], Rational[522, 7]}}, {{31, 74.57142857142857}, {
      32.142857142857146`, 74.57142857142857}}]], 
   LineBox[NCache[{{31, Rational[514, 7]}, {
      Rational[225, 7], Rational[514, 7]}}, {{31, 73.42857142857143}, {
      32.142857142857146`, 73.42857142857143}}]], 
   LineBox[NCache[{{31, Rational[506, 7]}, {
      Rational[225, 7], Rational[506, 7]}}, {{31, 72.28571428571429}, {
      32.142857142857146`, 72.28571428571429}}]], 
   LineBox[NCache[{{31, Rational[498, 7]}, {
      Rational[225, 7], Rational[498, 7]}}, {{31, 71.14285714285714}, {
      32.142857142857146`, 71.14285714285714}}]], 
   LineBox[NCache[{{31, 70}, {Rational[225, 7], 70}}, {{31, 70}, {
      32.142857142857146`, 70}}]], 
   LineBox[NCache[{{Rational[225, 7], 78}, {Rational[233, 7], 78}}, {{
      32.142857142857146`, 78}, {33.285714285714285`, 78}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[538, 7]}, {
      Rational[233, 7], Rational[538, 7]}}, {{32.142857142857146`, 
     76.85714285714286}, {33.285714285714285`, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[530, 7]}, {
      Rational[233, 7], Rational[530, 7]}}, {{32.142857142857146`, 
     75.71428571428571}, {33.285714285714285`, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[522, 7]}, {
      Rational[233, 7], Rational[522, 7]}}, {{32.142857142857146`, 
     74.57142857142857}, {33.285714285714285`, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[514, 7]}, {
      Rational[233, 7], Rational[514, 7]}}, {{32.142857142857146`, 
     73.42857142857143}, {33.285714285714285`, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[506, 7]}, {
      Rational[233, 7], Rational[506, 7]}}, {{32.142857142857146`, 
     72.28571428571429}, {33.285714285714285`, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[498, 7]}, {
      Rational[233, 7], Rational[498, 7]}}, {{32.142857142857146`, 
     71.14285714285714}, {33.285714285714285`, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[225, 7], 70}, {Rational[233, 7], 70}}, {{
      32.142857142857146`, 70}, {33.285714285714285`, 70}}]], 
   LineBox[NCache[{{Rational[233, 7], 78}, {Rational[241, 7], 78}}, {{
      33.285714285714285`, 78}, {34.42857142857143, 78}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[538, 7]}, {
      Rational[241, 7], Rational[538, 7]}}, {{33.285714285714285`, 
     76.85714285714286}, {34.42857142857143, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[530, 7]}, {
      Rational[241, 7], Rational[530, 7]}}, {{33.285714285714285`, 
     75.71428571428571}, {34.42857142857143, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[522, 7]}, {
      Rational[241, 7], Rational[522, 7]}}, {{33.285714285714285`, 
     74.57142857142857}, {34.42857142857143, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[514, 7]}, {
      Rational[241, 7], Rational[514, 7]}}, {{33.285714285714285`, 
     73.42857142857143}, {34.42857142857143, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[506, 7]}, {
      Rational[241, 7], Rational[506, 7]}}, {{33.285714285714285`, 
     72.28571428571429}, {34.42857142857143, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[498, 7]}, {
      Rational[241, 7], Rational[498, 7]}}, {{33.285714285714285`, 
     71.14285714285714}, {34.42857142857143, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[233, 7], 70}, {Rational[241, 7], 70}}, {{
      33.285714285714285`, 70}, {34.42857142857143, 70}}]], 
   LineBox[NCache[{{Rational[241, 7], 78}, {Rational[249, 7], 78}}, {{
      34.42857142857143, 78}, {35.57142857142857, 78}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[538, 7]}, {
      Rational[249, 7], Rational[538, 7]}}, {{34.42857142857143, 
     76.85714285714286}, {35.57142857142857, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[530, 7]}, {
      Rational[249, 7], Rational[530, 7]}}, {{34.42857142857143, 
     75.71428571428571}, {35.57142857142857, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[522, 7]}, {
      Rational[249, 7], Rational[522, 7]}}, {{34.42857142857143, 
     74.57142857142857}, {35.57142857142857, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[514, 7]}, {
      Rational[249, 7], Rational[514, 7]}}, {{34.42857142857143, 
     73.42857142857143}, {35.57142857142857, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[506, 7]}, {
      Rational[249, 7], Rational[506, 7]}}, {{34.42857142857143, 
     72.28571428571429}, {35.57142857142857, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[498, 7]}, {
      Rational[249, 7], Rational[498, 7]}}, {{34.42857142857143, 
     71.14285714285714}, {35.57142857142857, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[241, 7], 70}, {Rational[249, 7], 70}}, {{
      34.42857142857143, 70}, {35.57142857142857, 70}}]], 
   LineBox[NCache[{{Rational[249, 7], 78}, {Rational[257, 7], 78}}, {{
      35.57142857142857, 78}, {36.714285714285715`, 78}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[538, 7]}, {
      Rational[257, 7], Rational[538, 7]}}, {{35.57142857142857, 
     76.85714285714286}, {36.714285714285715`, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[530, 7]}, {
      Rational[257, 7], Rational[530, 7]}}, {{35.57142857142857, 
     75.71428571428571}, {36.714285714285715`, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[522, 7]}, {
      Rational[257, 7], Rational[522, 7]}}, {{35.57142857142857, 
     74.57142857142857}, {36.714285714285715`, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[514, 7]}, {
      Rational[257, 7], Rational[514, 7]}}, {{35.57142857142857, 
     73.42857142857143}, {36.714285714285715`, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[506, 7]}, {
      Rational[257, 7], Rational[506, 7]}}, {{35.57142857142857, 
     72.28571428571429}, {36.714285714285715`, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[498, 7]}, {
      Rational[257, 7], Rational[498, 7]}}, {{35.57142857142857, 
     71.14285714285714}, {36.714285714285715`, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[249, 7], 70}, {Rational[257, 7], 70}}, {{
      35.57142857142857, 70}, {36.714285714285715`, 70}}]], 
   LineBox[NCache[{{Rational[257, 7], 78}, {Rational[265, 7], 78}}, {{
      36.714285714285715`, 78}, {37.857142857142854`, 78}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[538, 7]}, {
      Rational[265, 7], Rational[538, 7]}}, {{36.714285714285715`, 
     76.85714285714286}, {37.857142857142854`, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[530, 7]}, {
      Rational[265, 7], Rational[530, 7]}}, {{36.714285714285715`, 
     75.71428571428571}, {37.857142857142854`, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[522, 7]}, {
      Rational[265, 7], Rational[522, 7]}}, {{36.714285714285715`, 
     74.57142857142857}, {37.857142857142854`, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[514, 7]}, {
      Rational[265, 7], Rational[514, 7]}}, {{36.714285714285715`, 
     73.42857142857143}, {37.857142857142854`, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[506, 7]}, {
      Rational[265, 7], Rational[506, 7]}}, {{36.714285714285715`, 
     72.28571428571429}, {37.857142857142854`, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[498, 7]}, {
      Rational[265, 7], Rational[498, 7]}}, {{36.714285714285715`, 
     71.14285714285714}, {37.857142857142854`, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[257, 7], 70}, {Rational[265, 7], 70}}, {{
      36.714285714285715`, 70}, {37.857142857142854`, 70}}]], 
   LineBox[NCache[{{Rational[265, 7], 78}, {39, 78}}, {{
      37.857142857142854`, 78}, {39, 78}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[538, 7]}, {
      39, Rational[538, 7]}}, {{37.857142857142854`, 76.85714285714286}, {
      39, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[530, 7]}, {
      39, Rational[530, 7]}}, {{37.857142857142854`, 75.71428571428571}, {
      39, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[522, 7]}, {
      39, Rational[522, 7]}}, {{37.857142857142854`, 74.57142857142857}, {
      39, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[514, 7]}, {
      39, Rational[514, 7]}}, {{37.857142857142854`, 73.42857142857143}, {
      39, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[506, 7]}, {
      39, Rational[506, 7]}}, {{37.857142857142854`, 72.28571428571429}, {
      39, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[498, 7]}, {
      39, Rational[498, 7]}}, {{37.857142857142854`, 71.14285714285714}, {
      39, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[265, 7], 70}, {39, 70}}, {{
      37.857142857142854`, 70}, {39, 70}}]], 
   LineBox[NCache[{{31, 78}, {31, Rational[538, 7]}}, {{31, 78}, {
      31, 76.85714285714286}}]], 
   LineBox[NCache[{{31, Rational[538, 7]}, {31, Rational[530, 7]}}, {{
      31, 76.85714285714286}, {31, 75.71428571428571}}]], 
   LineBox[NCache[{{31, Rational[530, 7]}, {31, Rational[522, 7]}}, {{
      31, 75.71428571428571}, {31, 74.57142857142857}}]], 
   LineBox[NCache[{{31, Rational[522, 7]}, {31, Rational[514, 7]}}, {{
      31, 74.57142857142857}, {31, 73.42857142857143}}]], 
   LineBox[NCache[{{31, Rational[514, 7]}, {31, Rational[506, 7]}}, {{
      31, 73.42857142857143}, {31, 72.28571428571429}}]], 
   LineBox[NCache[{{31, Rational[506, 7]}, {31, Rational[498, 7]}}, {{
      31, 72.28571428571429}, {31, 71.14285714285714}}]], 
   LineBox[NCache[{{31, Rational[498, 7]}, {31, 70}}, {{
      31, 71.14285714285714}, {31, 70}}]], 
   LineBox[NCache[{{Rational[225, 7], 78}, {
      Rational[225, 7], Rational[538, 7]}}, {{32.142857142857146`, 78}, {
      32.142857142857146`, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[538, 7]}, {
      Rational[225, 7], Rational[530, 7]}}, {{32.142857142857146`, 
     76.85714285714286}, {32.142857142857146`, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[530, 7]}, {
      Rational[225, 7], Rational[522, 7]}}, {{32.142857142857146`, 
     75.71428571428571}, {32.142857142857146`, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[522, 7]}, {
      Rational[225, 7], Rational[514, 7]}}, {{32.142857142857146`, 
     74.57142857142857}, {32.142857142857146`, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[514, 7]}, {
      Rational[225, 7], Rational[506, 7]}}, {{32.142857142857146`, 
     73.42857142857143}, {32.142857142857146`, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[506, 7]}, {
      Rational[225, 7], Rational[498, 7]}}, {{32.142857142857146`, 
     72.28571428571429}, {32.142857142857146`, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[225, 7], Rational[498, 7]}, {
      Rational[225, 7], 70}}, {{32.142857142857146`, 71.14285714285714}, {
      32.142857142857146`, 70}}]], 
   LineBox[NCache[{{Rational[233, 7], 78}, {
      Rational[233, 7], Rational[538, 7]}}, {{33.285714285714285`, 78}, {
      33.285714285714285`, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[538, 7]}, {
      Rational[233, 7], Rational[530, 7]}}, {{33.285714285714285`, 
     76.85714285714286}, {33.285714285714285`, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[530, 7]}, {
      Rational[233, 7], Rational[522, 7]}}, {{33.285714285714285`, 
     75.71428571428571}, {33.285714285714285`, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[522, 7]}, {
      Rational[233, 7], Rational[514, 7]}}, {{33.285714285714285`, 
     74.57142857142857}, {33.285714285714285`, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[514, 7]}, {
      Rational[233, 7], Rational[506, 7]}}, {{33.285714285714285`, 
     73.42857142857143}, {33.285714285714285`, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[506, 7]}, {
      Rational[233, 7], Rational[498, 7]}}, {{33.285714285714285`, 
     72.28571428571429}, {33.285714285714285`, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[233, 7], Rational[498, 7]}, {
      Rational[233, 7], 70}}, {{33.285714285714285`, 71.14285714285714}, {
      33.285714285714285`, 70}}]], 
   LineBox[NCache[{{Rational[241, 7], 78}, {
      Rational[241, 7], Rational[538, 7]}}, {{34.42857142857143, 78}, {
      34.42857142857143, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[538, 7]}, {
      Rational[241, 7], Rational[530, 7]}}, {{34.42857142857143, 
     76.85714285714286}, {34.42857142857143, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[530, 7]}, {
      Rational[241, 7], Rational[522, 7]}}, {{34.42857142857143, 
     75.71428571428571}, {34.42857142857143, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[522, 7]}, {
      Rational[241, 7], Rational[514, 7]}}, {{34.42857142857143, 
     74.57142857142857}, {34.42857142857143, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[514, 7]}, {
      Rational[241, 7], Rational[506, 7]}}, {{34.42857142857143, 
     73.42857142857143}, {34.42857142857143, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[506, 7]}, {
      Rational[241, 7], Rational[498, 7]}}, {{34.42857142857143, 
     72.28571428571429}, {34.42857142857143, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[241, 7], Rational[498, 7]}, {
      Rational[241, 7], 70}}, {{34.42857142857143, 71.14285714285714}, {
      34.42857142857143, 70}}]], 
   LineBox[NCache[{{Rational[249, 7], 78}, {
      Rational[249, 7], Rational[538, 7]}}, {{35.57142857142857, 78}, {
      35.57142857142857, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[538, 7]}, {
      Rational[249, 7], Rational[530, 7]}}, {{35.57142857142857, 
     76.85714285714286}, {35.57142857142857, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[530, 7]}, {
      Rational[249, 7], Rational[522, 7]}}, {{35.57142857142857, 
     75.71428571428571}, {35.57142857142857, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[522, 7]}, {
      Rational[249, 7], Rational[514, 7]}}, {{35.57142857142857, 
     74.57142857142857}, {35.57142857142857, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[514, 7]}, {
      Rational[249, 7], Rational[506, 7]}}, {{35.57142857142857, 
     73.42857142857143}, {35.57142857142857, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[506, 7]}, {
      Rational[249, 7], Rational[498, 7]}}, {{35.57142857142857, 
     72.28571428571429}, {35.57142857142857, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[249, 7], Rational[498, 7]}, {
      Rational[249, 7], 70}}, {{35.57142857142857, 71.14285714285714}, {
      35.57142857142857, 70}}]], 
   LineBox[NCache[{{Rational[257, 7], 78}, {
      Rational[257, 7], Rational[538, 7]}}, {{36.714285714285715`, 78}, {
      36.714285714285715`, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[538, 7]}, {
      Rational[257, 7], Rational[530, 7]}}, {{36.714285714285715`, 
     76.85714285714286}, {36.714285714285715`, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[530, 7]}, {
      Rational[257, 7], Rational[522, 7]}}, {{36.714285714285715`, 
     75.71428571428571}, {36.714285714285715`, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[522, 7]}, {
      Rational[257, 7], Rational[514, 7]}}, {{36.714285714285715`, 
     74.57142857142857}, {36.714285714285715`, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[514, 7]}, {
      Rational[257, 7], Rational[506, 7]}}, {{36.714285714285715`, 
     73.42857142857143}, {36.714285714285715`, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[506, 7]}, {
      Rational[257, 7], Rational[498, 7]}}, {{36.714285714285715`, 
     72.28571428571429}, {36.714285714285715`, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[257, 7], Rational[498, 7]}, {
      Rational[257, 7], 70}}, {{36.714285714285715`, 71.14285714285714}, {
      36.714285714285715`, 70}}]], 
   LineBox[NCache[{{Rational[265, 7], 78}, {
      Rational[265, 7], Rational[538, 7]}}, {{37.857142857142854`, 78}, {
      37.857142857142854`, 76.85714285714286}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[538, 7]}, {
      Rational[265, 7], Rational[530, 7]}}, {{37.857142857142854`, 
     76.85714285714286}, {37.857142857142854`, 75.71428571428571}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[530, 7]}, {
      Rational[265, 7], Rational[522, 7]}}, {{37.857142857142854`, 
     75.71428571428571}, {37.857142857142854`, 74.57142857142857}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[522, 7]}, {
      Rational[265, 7], Rational[514, 7]}}, {{37.857142857142854`, 
     74.57142857142857}, {37.857142857142854`, 73.42857142857143}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[514, 7]}, {
      Rational[265, 7], Rational[506, 7]}}, {{37.857142857142854`, 
     73.42857142857143}, {37.857142857142854`, 72.28571428571429}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[506, 7]}, {
      Rational[265, 7], Rational[498, 7]}}, {{37.857142857142854`, 
     72.28571428571429}, {37.857142857142854`, 71.14285714285714}}]], 
   LineBox[NCache[{{Rational[265, 7], Rational[498, 7]}, {
      Rational[265, 7], 70}}, {{37.857142857142854`, 71.14285714285714}, {
      37.857142857142854`, 70}}]], 
   LineBox[NCache[{{39, 78}, {39, Rational[538, 7]}}, {{39, 78}, {
      39, 76.85714285714286}}]], 
   LineBox[NCache[{{39, Rational[538, 7]}, {39, Rational[530, 7]}}, {{
      39, 76.85714285714286}, {39, 75.71428571428571}}]], 
   LineBox[NCache[{{39, Rational[530, 7]}, {39, Rational[522, 7]}}, {{
      39, 75.71428571428571}, {39, 74.57142857142857}}]], 
   LineBox[NCache[{{39, Rational[522, 7]}, {39, Rational[514, 7]}}, {{
      39, 74.57142857142857}, {39, 73.42857142857143}}]], 
   LineBox[NCache[{{39, Rational[514, 7]}, {39, Rational[506, 7]}}, {{
      39, 73.42857142857143}, {39, 72.28571428571429}}]], 
   LineBox[NCache[{{39, Rational[506, 7]}, {39, Rational[498, 7]}}, {{
      39, 72.28571428571429}, {39, 71.14285714285714}}]], 
   LineBox[NCache[{{39, Rational[498, 7]}, {39, 70}}, {{
      39, 71.14285714285714}, {39, 70}}]], 
   LineBox[NCache[{{41, 78}, {Rational[127, 3], 78}}, {{41, 78}, {
      42.333333333333336`, 78}}]], 
   LineBox[NCache[{{41, Rational[230, 3]}, {
      Rational[127, 3], Rational[230, 3]}}, {{41, 76.66666666666667}, {
      42.333333333333336`, 76.66666666666667}}]], 
   LineBox[NCache[{{41, Rational[226, 3]}, {
      Rational[127, 3], Rational[226, 3]}}, {{41, 75.33333333333333}, {
      42.333333333333336`, 75.33333333333333}}]], 
   LineBox[NCache[{{41, 74}, {Rational[127, 3], 74}}, {{41, 74}, {
      42.333333333333336`, 74}}]], 
   LineBox[NCache[{{41, Rational[218, 3]}, {
      Rational[127, 3], Rational[218, 3]}}, {{41, 72.66666666666667}, {
      42.333333333333336`, 72.66666666666667}}]], 
   LineBox[NCache[{{41, Rational[214, 3]}, {
      Rational[127, 3], Rational[214, 3]}}, {{41, 71.33333333333333}, {
      42.333333333333336`, 71.33333333333333}}]], 
   LineBox[NCache[{{41, 70}, {Rational[127, 3], 70}}, {{41, 70}, {
      42.333333333333336`, 70}}]], 
   LineBox[NCache[{{Rational[127, 3], 78}, {Rational[131, 3], 78}}, {{
      42.333333333333336`, 78}, {43.666666666666664`, 78}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[230, 3]}, {
      Rational[131, 3], Rational[230, 3]}}, {{42.333333333333336`, 
     76.66666666666667}, {43.666666666666664`, 76.66666666666667}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[226, 3]}, {
      Rational[131, 3], Rational[226, 3]}}, {{42.333333333333336`, 
     75.33333333333333}, {43.666666666666664`, 75.33333333333333}}]], 
   LineBox[NCache[{{Rational[127, 3], 74}, {Rational[131, 3], 74}}, {{
      42.333333333333336`, 74}, {43.666666666666664`, 74}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[218, 3]}, {
      Rational[131, 3], Rational[218, 3]}}, {{42.333333333333336`, 
     72.66666666666667}, {43.666666666666664`, 72.66666666666667}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[214, 3]}, {
      Rational[131, 3], Rational[214, 3]}}, {{42.333333333333336`, 
     71.33333333333333}, {43.666666666666664`, 71.33333333333333}}]], 
   LineBox[NCache[{{Rational[127, 3], 70}, {Rational[131, 3], 70}}, {{
      42.333333333333336`, 70}, {43.666666666666664`, 70}}]], 
   LineBox[NCache[{{Rational[131, 3], 78}, {45, 78}}, {{
      43.666666666666664`, 78}, {45, 78}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[230, 3]}, {
      45, Rational[230, 3]}}, {{43.666666666666664`, 76.66666666666667}, {
      45, 76.66666666666667}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[226, 3]}, {
      45, Rational[226, 3]}}, {{43.666666666666664`, 75.33333333333333}, {
      45, 75.33333333333333}}]], 
   LineBox[NCache[{{Rational[131, 3], 74}, {45, 74}}, {{
      43.666666666666664`, 74}, {45, 74}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[218, 3]}, {
      45, Rational[218, 3]}}, {{43.666666666666664`, 72.66666666666667}, {
      45, 72.66666666666667}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[214, 3]}, {
      45, Rational[214, 3]}}, {{43.666666666666664`, 71.33333333333333}, {
      45, 71.33333333333333}}]], 
   LineBox[NCache[{{Rational[131, 3], 70}, {45, 70}}, {{
      43.666666666666664`, 70}, {45, 70}}]], 
   LineBox[NCache[{{45, 78}, {Rational[139, 3], 78}}, {{45, 78}, {
      46.333333333333336`, 78}}]], 
   LineBox[NCache[{{45, Rational[230, 3]}, {
      Rational[139, 3], Rational[230, 3]}}, {{45, 76.66666666666667}, {
      46.333333333333336`, 76.66666666666667}}]], 
   LineBox[NCache[{{45, Rational[226, 3]}, {
      Rational[139, 3], Rational[226, 3]}}, {{45, 75.33333333333333}, {
      46.333333333333336`, 75.33333333333333}}]], 
   LineBox[NCache[{{45, 74}, {Rational[139, 3], 74}}, {{45, 74}, {
      46.333333333333336`, 74}}]], 
   LineBox[NCache[{{45, Rational[218, 3]}, {
      Rational[139, 3], Rational[218, 3]}}, {{45, 72.66666666666667}, {
      46.333333333333336`, 72.66666666666667}}]], 
   LineBox[NCache[{{45, Rational[214, 3]}, {
      Rational[139, 3], Rational[214, 3]}}, {{45, 71.33333333333333}, {
      46.333333333333336`, 71.33333333333333}}]], 
   LineBox[NCache[{{45, 70}, {Rational[139, 3], 70}}, {{45, 70}, {
      46.333333333333336`, 70}}]], 
   LineBox[NCache[{{Rational[139, 3], 78}, {Rational[143, 3], 78}}, {{
      46.333333333333336`, 78}, {47.666666666666664`, 78}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[230, 3]}, {
      Rational[143, 3], Rational[230, 3]}}, {{46.333333333333336`, 
     76.66666666666667}, {47.666666666666664`, 76.66666666666667}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[226, 3]}, {
      Rational[143, 3], Rational[226, 3]}}, {{46.333333333333336`, 
     75.33333333333333}, {47.666666666666664`, 75.33333333333333}}]], 
   LineBox[
    NCache[{{Rational[139, 3], 74}, {Rational[143, 3], 74}}, {{
      46.333333333333336`, 74}, {47.666666666666664`, 74}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[218, 3]}, {
      Rational[143, 3], Rational[218, 3]}}, {{46.333333333333336`, 
     72.66666666666667}, {47.666666666666664`, 72.66666666666667}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[214, 3]}, {
      Rational[143, 3], Rational[214, 3]}}, {{46.333333333333336`, 
     71.33333333333333}, {47.666666666666664`, 71.33333333333333}}]], 
   LineBox[NCache[{{Rational[139, 3], 70}, {Rational[143, 3], 70}}, {{
      46.333333333333336`, 70}, {47.666666666666664`, 70}}]], 
   LineBox[NCache[{{Rational[143, 3], 78}, {49, 78}}, {{
      47.666666666666664`, 78}, {49, 78}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[230, 3]}, {
      49, Rational[230, 3]}}, {{47.666666666666664`, 76.66666666666667}, {
      49, 76.66666666666667}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[226, 3]}, {
      49, Rational[226, 3]}}, {{47.666666666666664`, 75.33333333333333}, {
      49, 75.33333333333333}}]], 
   LineBox[NCache[{{Rational[143, 3], 74}, {49, 74}}, {{
      47.666666666666664`, 74}, {49, 74}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[218, 3]}, {
      49, Rational[218, 3]}}, {{47.666666666666664`, 72.66666666666667}, {
      49, 72.66666666666667}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[214, 3]}, {
      49, Rational[214, 3]}}, {{47.666666666666664`, 71.33333333333333}, {
      49, 71.33333333333333}}]], 
   LineBox[NCache[{{Rational[143, 3], 70}, {49, 70}}, {{
      47.666666666666664`, 70}, {49, 70}}]], 
   LineBox[NCache[{{41, 78}, {41, Rational[230, 3]}}, {{41, 78}, {
      41, 76.66666666666667}}]], 
   LineBox[NCache[{{41, Rational[230, 3]}, {41, Rational[226, 3]}}, {{
      41, 76.66666666666667}, {41, 75.33333333333333}}]], 
   LineBox[NCache[{{41, Rational[226, 3]}, {41, 74}}, {{
      41, 75.33333333333333}, {41, 74}}]], 
   LineBox[NCache[{{41, 74}, {41, Rational[218, 3]}}, {{41, 74}, {
      41, 72.66666666666667}}]], 
   LineBox[
    NCache[{{41, Rational[218, 3]}, {41, Rational[214, 3]}}, {{
      41, 72.66666666666667}, {41, 71.33333333333333}}]], 
   LineBox[NCache[{{41, Rational[214, 3]}, {41, 70}}, {{
      41, 71.33333333333333}, {41, 70}}]], 
   LineBox[NCache[{{Rational[127, 3], 78}, {
      Rational[127, 3], Rational[230, 3]}}, {{42.333333333333336`, 78}, {
      42.333333333333336`, 76.66666666666667}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[230, 3]}, {
      Rational[127, 3], Rational[226, 3]}}, {{42.333333333333336`, 
     76.66666666666667}, {42.333333333333336`, 75.33333333333333}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[226, 3]}, {
      Rational[127, 3], 74}}, {{42.333333333333336`, 75.33333333333333}, {
      42.333333333333336`, 74}}]], 
   LineBox[NCache[{{Rational[127, 3], 74}, {
      Rational[127, 3], Rational[218, 3]}}, {{42.333333333333336`, 74}, {
      42.333333333333336`, 72.66666666666667}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[218, 3]}, {
      Rational[127, 3], Rational[214, 3]}}, {{42.333333333333336`, 
     72.66666666666667}, {42.333333333333336`, 71.33333333333333}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[214, 3]}, {
      Rational[127, 3], 70}}, {{42.333333333333336`, 71.33333333333333}, {
      42.333333333333336`, 70}}]], 
   LineBox[NCache[{{Rational[131, 3], 78}, {
      Rational[131, 3], Rational[230, 3]}}, {{43.666666666666664`, 78}, {
      43.666666666666664`, 76.66666666666667}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[230, 3]}, {
      Rational[131, 3], Rational[226, 3]}}, {{43.666666666666664`, 
     76.66666666666667}, {43.666666666666664`, 75.33333333333333}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[226, 3]}, {
      Rational[131, 3], 74}}, {{43.666666666666664`, 75.33333333333333}, {
      43.666666666666664`, 74}}]], 
   LineBox[NCache[{{Rational[131, 3], 74}, {
      Rational[131, 3], Rational[218, 3]}}, {{43.666666666666664`, 74}, {
      43.666666666666664`, 72.66666666666667}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[218, 3]}, {
      Rational[131, 3], Rational[214, 3]}}, {{43.666666666666664`, 
     72.66666666666667}, {43.666666666666664`, 71.33333333333333}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[214, 3]}, {
      Rational[131, 3], 70}}, {{43.666666666666664`, 71.33333333333333}, {
      43.666666666666664`, 70}}]], 
   LineBox[NCache[{{45, 78}, {45, Rational[230, 3]}}, {{45, 78}, {
      45, 76.66666666666667}}]], 
   LineBox[NCache[{{45, Rational[230, 3]}, {45, Rational[226, 3]}}, {{
      45, 76.66666666666667}, {45, 75.33333333333333}}]], 
   LineBox[NCache[{{45, Rational[226, 3]}, {45, 74}}, {{
      45, 75.33333333333333}, {45, 74}}]], 
   LineBox[NCache[{{45, 74}, {45, Rational[218, 3]}}, {{45, 74}, {
      45, 72.66666666666667}}]], 
   LineBox[NCache[{{45, Rational[218, 3]}, {45, Rational[214, 3]}}, {{
      45, 72.66666666666667}, {45, 71.33333333333333}}]], 
   LineBox[NCache[{{45, Rational[214, 3]}, {45, 70}}, {{
      45, 71.33333333333333}, {45, 70}}]], 
   LineBox[NCache[{{Rational[139, 3], 78}, {
      Rational[139, 3], Rational[230, 3]}}, {{46.333333333333336`, 78}, {
      46.333333333333336`, 76.66666666666667}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[230, 3]}, {
      Rational[139, 3], Rational[226, 3]}}, {{46.333333333333336`, 
     76.66666666666667}, {46.333333333333336`, 75.33333333333333}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[226, 3]}, {
      Rational[139, 3], 74}}, {{46.333333333333336`, 75.33333333333333}, {
      46.333333333333336`, 74}}]], 
   LineBox[NCache[{{Rational[139, 3], 74}, {
      Rational[139, 3], Rational[218, 3]}}, {{46.333333333333336`, 74}, {
      46.333333333333336`, 72.66666666666667}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[218, 3]}, {
      Rational[139, 3], Rational[214, 3]}}, {{46.333333333333336`, 
     72.66666666666667}, {46.333333333333336`, 71.33333333333333}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[214, 3]}, {
      Rational[139, 3], 70}}, {{46.333333333333336`, 71.33333333333333}, {
      46.333333333333336`, 70}}]], 
   LineBox[
    NCache[{{Rational[143, 3], 78}, {Rational[143, 3], Rational[230, 3]}}, {{
      47.666666666666664`, 78}, {47.666666666666664`, 76.66666666666667}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[230, 3]}, {
      Rational[143, 3], Rational[226, 3]}}, {{47.666666666666664`, 
     76.66666666666667}, {47.666666666666664`, 75.33333333333333}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[226, 3]}, {
      Rational[143, 3], 74}}, {{47.666666666666664`, 75.33333333333333}, {
      47.666666666666664`, 74}}]], 
   LineBox[NCache[{{Rational[143, 3], 74}, {
      Rational[143, 3], Rational[218, 3]}}, {{47.666666666666664`, 74}, {
      47.666666666666664`, 72.66666666666667}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[218, 3]}, {
      Rational[143, 3], Rational[214, 3]}}, {{47.666666666666664`, 
     72.66666666666667}, {47.666666666666664`, 71.33333333333333}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[214, 3]}, {
      Rational[143, 3], 70}}, {{47.666666666666664`, 71.33333333333333}, {
      47.666666666666664`, 70}}]], 
   LineBox[NCache[{{49, 78}, {49, Rational[230, 3]}}, {{49, 78}, {
      49, 76.66666666666667}}]], 
   LineBox[NCache[{{49, Rational[230, 3]}, {49, Rational[226, 3]}}, {{
      49, 76.66666666666667}, {49, 75.33333333333333}}]], 
   LineBox[NCache[{{49, Rational[226, 3]}, {49, 74}}, {{
      49, 75.33333333333333}, {49, 74}}]], 
   LineBox[NCache[{{49, 74}, {49, Rational[218, 3]}}, {{49, 74}, {
      49, 72.66666666666667}}]], 
   LineBox[NCache[{{49, Rational[218, 3]}, {49, Rational[214, 3]}}, {{
      49, 72.66666666666667}, {49, 71.33333333333333}}]], 
   LineBox[NCache[{{49, Rational[214, 3]}, {49, 70}}, {{
      49, 71.33333333333333}, {49, 70}}]], LineBox[{{51, 78}, {55, 78}}], 
   LineBox[{{51, 74}, {55, 74}}], LineBox[{{51, 70}, {55, 70}}], 
   LineBox[{{55, 78}, {59, 78}}], LineBox[{{55, 74}, {59, 74}}], 
   LineBox[{{55, 70}, {59, 70}}], LineBox[{{51, 78}, {51, 74}}], 
   LineBox[{{51, 74}, {51, 70}}], LineBox[{{55, 78}, {55, 74}}], 
   LineBox[{{55, 74}, {55, 70}}], LineBox[{{59, 78}, {59, 74}}], 
   LineBox[{{59, 74}, {59, 70}}], LineBox[{{61, 78}, {65, 78}}], 
   LineBox[{{61, 74}, {65, 74}}], LineBox[{{61, 70}, {65, 70}}], 
   LineBox[{{65, 78}, {69, 78}}], LineBox[{{65, 74}, {69, 74}}], 
   LineBox[{{65, 70}, {69, 70}}], LineBox[{{61, 78}, {61, 74}}], 
   LineBox[{{61, 74}, {61, 70}}], LineBox[{{65, 78}, {65, 74}}], 
   LineBox[{{65, 74}, {65, 70}}], LineBox[{{69, 78}, {69, 74}}], 
   LineBox[{{69, 74}, {69, 70}}], LineBox[{{11, 68}, {15, 68}}], 
   LineBox[{{11, 64}, {15, 64}}], LineBox[{{11, 60}, {15, 60}}], 
   LineBox[{{15, 68}, {19, 68}}], LineBox[{{15, 64}, {19, 64}}], 
   LineBox[{{15, 60}, {19, 60}}], LineBox[{{11, 68}, {11, 64}}], 
   LineBox[{{11, 64}, {11, 60}}], LineBox[{{15, 68}, {15, 64}}], 
   LineBox[{{15, 64}, {15, 60}}], LineBox[{{19, 68}, {19, 64}}], 
   LineBox[{{19, 64}, {19, 60}}], LineBox[{{21, 68}, {25, 68}}], 
   LineBox[{{21, 64}, {25, 64}}], LineBox[{{21, 60}, {25, 60}}], 
   LineBox[{{25, 68}, {29, 68}}], LineBox[{{25, 64}, {29, 64}}], 
   LineBox[{{25, 60}, {29, 60}}], LineBox[{{21, 68}, {21, 64}}], 
   LineBox[{{21, 64}, {21, 60}}], LineBox[{{25, 68}, {25, 64}}], 
   LineBox[{{25, 64}, {25, 60}}], LineBox[{{29, 68}, {29, 64}}], 
   LineBox[{{29, 64}, {29, 60}}], 
   LineBox[NCache[{{31, 68}, {Rational[97, 3], 68}}, {{31, 68}, {
      32.333333333333336`, 68}}]], 
   LineBox[NCache[{{31, Rational[200, 3]}, {
      Rational[97, 3], Rational[200, 3]}}, {{31, 66.66666666666667}, {
      32.333333333333336`, 66.66666666666667}}]], 
   LineBox[NCache[{{31, Rational[196, 3]}, {
      Rational[97, 3], Rational[196, 3]}}, {{31, 65.33333333333333}, {
      32.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{31, 64}, {Rational[97, 3], 64}}, {{31, 64}, {
      32.333333333333336`, 64}}]], 
   LineBox[NCache[{{31, Rational[188, 3]}, {
      Rational[97, 3], Rational[188, 3]}}, {{31, 62.666666666666664`}, {
      32.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{31, Rational[184, 3]}, {
      Rational[97, 3], Rational[184, 3]}}, {{31, 61.333333333333336`}, {
      32.333333333333336`, 61.333333333333336`}}]], 
   LineBox[NCache[{{31, 60}, {Rational[97, 3], 60}}, {{31, 60}, {
      32.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[97, 3], 68}, {Rational[101, 3], 68}}, {{
      32.333333333333336`, 68}, {33.666666666666664`, 68}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[200, 3]}, {
      Rational[101, 3], Rational[200, 3]}}, {{32.333333333333336`, 
     66.66666666666667}, {33.666666666666664`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[196, 3]}, {
      Rational[101, 3], Rational[196, 3]}}, {{32.333333333333336`, 
     65.33333333333333}, {33.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[97, 3], 64}, {Rational[101, 3], 64}}, {{
      32.333333333333336`, 64}, {33.666666666666664`, 64}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[188, 3]}, {
      Rational[101, 3], Rational[188, 3]}}, {{32.333333333333336`, 
     62.666666666666664`}, {33.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[184, 3]}, {
      Rational[101, 3], Rational[184, 3]}}, {{32.333333333333336`, 
     61.333333333333336`}, {33.666666666666664`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[97, 3], 60}, {Rational[101, 3], 60}}, {{
      32.333333333333336`, 60}, {33.666666666666664`, 60}}]], 
   LineBox[NCache[{{Rational[101, 3], 68}, {35, 68}}, {{
      33.666666666666664`, 68}, {35, 68}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[200, 3]}, {
      35, Rational[200, 3]}}, {{33.666666666666664`, 66.66666666666667}, {
      35, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[196, 3]}, {
      35, Rational[196, 3]}}, {{33.666666666666664`, 65.33333333333333}, {
      35, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[101, 3], 64}, {35, 64}}, {{
      33.666666666666664`, 64}, {35, 64}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[188, 3]}, {
      35, Rational[188, 3]}}, {{33.666666666666664`, 62.666666666666664`}, {
      35, 62.666666666666664`}}]], 
   LineBox[
    NCache[{{Rational[101, 3], Rational[184, 3]}, {35, Rational[184, 3]}}, {{
      33.666666666666664`, 61.333333333333336`}, {35, 61.333333333333336`}}]],
    LineBox[NCache[{{Rational[101, 3], 60}, {35, 60}}, {{
      33.666666666666664`, 60}, {35, 60}}]], 
   LineBox[NCache[{{35, 68}, {Rational[109, 3], 68}}, {{35, 68}, {
      36.333333333333336`, 68}}]], 
   LineBox[NCache[{{35, Rational[200, 3]}, {
      Rational[109, 3], Rational[200, 3]}}, {{35, 66.66666666666667}, {
      36.333333333333336`, 66.66666666666667}}]], 
   LineBox[NCache[{{35, Rational[196, 3]}, {
      Rational[109, 3], Rational[196, 3]}}, {{35, 65.33333333333333}, {
      36.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{35, 64}, {Rational[109, 3], 64}}, {{35, 64}, {
      36.333333333333336`, 64}}]], 
   LineBox[NCache[{{35, Rational[188, 3]}, {
      Rational[109, 3], Rational[188, 3]}}, {{35, 62.666666666666664`}, {
      36.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{35, Rational[184, 3]}, {
      Rational[109, 3], Rational[184, 3]}}, {{35, 61.333333333333336`}, {
      36.333333333333336`, 61.333333333333336`}}]], 
   LineBox[NCache[{{35, 60}, {Rational[109, 3], 60}}, {{35, 60}, {
      36.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[109, 3], 68}, {Rational[113, 3], 68}}, {{
      36.333333333333336`, 68}, {37.666666666666664`, 68}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[200, 3]}, {
      Rational[113, 3], Rational[200, 3]}}, {{36.333333333333336`, 
     66.66666666666667}, {37.666666666666664`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[196, 3]}, {
      Rational[113, 3], Rational[196, 3]}}, {{36.333333333333336`, 
     65.33333333333333}, {37.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[109, 3], 64}, {Rational[113, 3], 64}}, {{
      36.333333333333336`, 64}, {37.666666666666664`, 64}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[188, 3]}, {
      Rational[113, 3], Rational[188, 3]}}, {{36.333333333333336`, 
     62.666666666666664`}, {37.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[184, 3]}, {
      Rational[113, 3], Rational[184, 3]}}, {{36.333333333333336`, 
     61.333333333333336`}, {37.666666666666664`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[109, 3], 60}, {Rational[113, 3], 60}}, {{
      36.333333333333336`, 60}, {37.666666666666664`, 60}}]], 
   LineBox[NCache[{{Rational[113, 3], 68}, {39, 68}}, {{
      37.666666666666664`, 68}, {39, 68}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[200, 3]}, {
      39, Rational[200, 3]}}, {{37.666666666666664`, 66.66666666666667}, {
      39, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[196, 3]}, {
      39, Rational[196, 3]}}, {{37.666666666666664`, 65.33333333333333}, {
      39, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[113, 3], 64}, {39, 64}}, {{
      37.666666666666664`, 64}, {39, 64}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[188, 3]}, {
      39, Rational[188, 3]}}, {{37.666666666666664`, 62.666666666666664`}, {
      39, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[184, 3]}, {
      39, Rational[184, 3]}}, {{37.666666666666664`, 61.333333333333336`}, {
      39, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[113, 3], 60}, {39, 60}}, {{
      37.666666666666664`, 60}, {39, 60}}]], 
   LineBox[NCache[{{31, 68}, {31, Rational[200, 3]}}, {{31, 68}, {
      31, 66.66666666666667}}]], 
   LineBox[NCache[{{31, Rational[200, 3]}, {31, Rational[196, 3]}}, {{
      31, 66.66666666666667}, {31, 65.33333333333333}}]], 
   LineBox[NCache[{{31, Rational[196, 3]}, {31, 64}}, {{
      31, 65.33333333333333}, {31, 64}}]], 
   LineBox[NCache[{{31, 64}, {31, Rational[188, 3]}}, {{31, 64}, {
      31, 62.666666666666664`}}]], 
   LineBox[NCache[{{31, Rational[188, 3]}, {31, Rational[184, 3]}}, {{
      31, 62.666666666666664`}, {31, 61.333333333333336`}}]], 
   LineBox[NCache[{{31, Rational[184, 3]}, {31, 60}}, {{
      31, 61.333333333333336`}, {31, 60}}]], 
   LineBox[
    NCache[{{Rational[97, 3], 68}, {Rational[97, 3], Rational[200, 3]}}, {{
      32.333333333333336`, 68}, {32.333333333333336`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[200, 3]}, {
      Rational[97, 3], Rational[196, 3]}}, {{32.333333333333336`, 
     66.66666666666667}, {32.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[196, 3]}, {
      Rational[97, 3], 64}}, {{32.333333333333336`, 65.33333333333333}, {
      32.333333333333336`, 64}}]], 
   LineBox[NCache[{{Rational[97, 3], 64}, {
      Rational[97, 3], Rational[188, 3]}}, {{32.333333333333336`, 64}, {
      32.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[188, 3]}, {
      Rational[97, 3], Rational[184, 3]}}, {{32.333333333333336`, 
     62.666666666666664`}, {32.333333333333336`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[184, 3]}, {
      Rational[97, 3], 60}}, {{32.333333333333336`, 61.333333333333336`}, {
      32.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[101, 3], 68}, {
      Rational[101, 3], Rational[200, 3]}}, {{33.666666666666664`, 68}, {
      33.666666666666664`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[200, 3]}, {
      Rational[101, 3], Rational[196, 3]}}, {{33.666666666666664`, 
     66.66666666666667}, {33.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[196, 3]}, {
      Rational[101, 3], 64}}, {{33.666666666666664`, 65.33333333333333}, {
      33.666666666666664`, 64}}]], 
   LineBox[NCache[{{Rational[101, 3], 64}, {
      Rational[101, 3], Rational[188, 3]}}, {{33.666666666666664`, 64}, {
      33.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[188, 3]}, {
      Rational[101, 3], Rational[184, 3]}}, {{33.666666666666664`, 
     62.666666666666664`}, {33.666666666666664`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[184, 3]}, {
      Rational[101, 3], 60}}, {{33.666666666666664`, 61.333333333333336`}, {
      33.666666666666664`, 60}}]], 
   LineBox[NCache[{{35, 68}, {35, Rational[200, 3]}}, {{35, 68}, {
      35, 66.66666666666667}}]], 
   LineBox[NCache[{{35, Rational[200, 3]}, {35, Rational[196, 3]}}, {{
      35, 66.66666666666667}, {35, 65.33333333333333}}]], 
   LineBox[NCache[{{35, Rational[196, 3]}, {35, 64}}, {{
      35, 65.33333333333333}, {35, 64}}]], 
   LineBox[NCache[{{35, 64}, {35, Rational[188, 3]}}, {{35, 64}, {
      35, 62.666666666666664`}}]], 
   LineBox[NCache[{{35, Rational[188, 3]}, {35, Rational[184, 3]}}, {{
      35, 62.666666666666664`}, {35, 61.333333333333336`}}]], 
   LineBox[NCache[{{35, Rational[184, 3]}, {35, 60}}, {{
      35, 61.333333333333336`}, {35, 60}}]], 
   LineBox[NCache[{{Rational[109, 3], 68}, {
      Rational[109, 3], Rational[200, 3]}}, {{36.333333333333336`, 68}, {
      36.333333333333336`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[200, 3]}, {
      Rational[109, 3], Rational[196, 3]}}, {{36.333333333333336`, 
     66.66666666666667}, {36.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[196, 3]}, {
      Rational[109, 3], 64}}, {{36.333333333333336`, 65.33333333333333}, {
      36.333333333333336`, 64}}]], 
   LineBox[NCache[{{Rational[109, 3], 64}, {
      Rational[109, 3], Rational[188, 3]}}, {{36.333333333333336`, 64}, {
      36.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[188, 3]}, {
      Rational[109, 3], Rational[184, 3]}}, {{36.333333333333336`, 
     62.666666666666664`}, {36.333333333333336`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[184, 3]}, {
      Rational[109, 3], 60}}, {{36.333333333333336`, 61.333333333333336`}, {
      36.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[113, 3], 68}, {
      Rational[113, 3], Rational[200, 3]}}, {{37.666666666666664`, 68}, {
      37.666666666666664`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[200, 3]}, {
      Rational[113, 3], Rational[196, 3]}}, {{37.666666666666664`, 
     66.66666666666667}, {37.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[196, 3]}, {
      Rational[113, 3], 64}}, {{37.666666666666664`, 65.33333333333333}, {
      37.666666666666664`, 64}}]], 
   LineBox[NCache[{{Rational[113, 3], 64}, {
      Rational[113, 3], Rational[188, 3]}}, {{37.666666666666664`, 64}, {
      37.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[188, 3]}, {
      Rational[113, 3], Rational[184, 3]}}, {{37.666666666666664`, 
     62.666666666666664`}, {37.666666666666664`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[184, 3]}, {
      Rational[113, 3], 60}}, {{37.666666666666664`, 61.333333333333336`}, {
      37.666666666666664`, 60}}]], 
   LineBox[NCache[{{39, 68}, {39, Rational[200, 3]}}, {{39, 68}, {
      39, 66.66666666666667}}]], 
   LineBox[NCache[{{39, Rational[200, 3]}, {39, Rational[196, 3]}}, {{
      39, 66.66666666666667}, {39, 65.33333333333333}}]], 
   LineBox[NCache[{{39, Rational[196, 3]}, {39, 64}}, {{
      39, 65.33333333333333}, {39, 64}}]], 
   LineBox[NCache[{{39, 64}, {39, Rational[188, 3]}}, {{39, 64}, {
      39, 62.666666666666664`}}]], 
   LineBox[NCache[{{39, Rational[188, 3]}, {39, Rational[184, 3]}}, {{
      39, 62.666666666666664`}, {39, 61.333333333333336`}}]], 
   LineBox[NCache[{{39, Rational[184, 3]}, {39, 60}}, {{
      39, 61.333333333333336`}, {39, 60}}]], 
   LineBox[NCache[{{41, 68}, {Rational[127, 3], 68}}, {{41, 68}, {
      42.333333333333336`, 68}}]], 
   LineBox[NCache[{{41, Rational[200, 3]}, {
      Rational[127, 3], Rational[200, 3]}}, {{41, 66.66666666666667}, {
      42.333333333333336`, 66.66666666666667}}]], 
   LineBox[NCache[{{41, Rational[196, 3]}, {
      Rational[127, 3], Rational[196, 3]}}, {{41, 65.33333333333333}, {
      42.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{41, 64}, {Rational[127, 3], 64}}, {{41, 64}, {
      42.333333333333336`, 64}}]], 
   LineBox[NCache[{{41, Rational[188, 3]}, {
      Rational[127, 3], Rational[188, 3]}}, {{41, 62.666666666666664`}, {
      42.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{41, Rational[184, 3]}, {
      Rational[127, 3], Rational[184, 3]}}, {{41, 61.333333333333336`}, {
      42.333333333333336`, 61.333333333333336`}}]], 
   LineBox[NCache[{{41, 60}, {Rational[127, 3], 60}}, {{41, 60}, {
      42.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[127, 3], 68}, {Rational[131, 3], 68}}, {{
      42.333333333333336`, 68}, {43.666666666666664`, 68}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[200, 3]}, {
      Rational[131, 3], Rational[200, 3]}}, {{42.333333333333336`, 
     66.66666666666667}, {43.666666666666664`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[196, 3]}, {
      Rational[131, 3], Rational[196, 3]}}, {{42.333333333333336`, 
     65.33333333333333}, {43.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[127, 3], 64}, {Rational[131, 3], 64}}, {{
      42.333333333333336`, 64}, {43.666666666666664`, 64}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[188, 3]}, {
      Rational[131, 3], Rational[188, 3]}}, {{42.333333333333336`, 
     62.666666666666664`}, {43.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[184, 3]}, {
      Rational[131, 3], Rational[184, 3]}}, {{42.333333333333336`, 
     61.333333333333336`}, {43.666666666666664`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[127, 3], 60}, {Rational[131, 3], 60}}, {{
      42.333333333333336`, 60}, {43.666666666666664`, 60}}]], 
   LineBox[NCache[{{Rational[131, 3], 68}, {45, 68}}, {{
      43.666666666666664`, 68}, {45, 68}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[200, 3]}, {
      45, Rational[200, 3]}}, {{43.666666666666664`, 66.66666666666667}, {
      45, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[196, 3]}, {
      45, Rational[196, 3]}}, {{43.666666666666664`, 65.33333333333333}, {
      45, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[131, 3], 64}, {45, 64}}, {{
      43.666666666666664`, 64}, {45, 64}}]], 
   LineBox[
    NCache[{{Rational[131, 3], Rational[188, 3]}, {45, Rational[188, 3]}}, {{
      43.666666666666664`, 62.666666666666664`}, {45, 62.666666666666664`}}]],
    LineBox[NCache[{{Rational[131, 3], Rational[184, 3]}, {
      45, Rational[184, 3]}}, {{43.666666666666664`, 61.333333333333336`}, {
      45, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[131, 3], 60}, {45, 60}}, {{
      43.666666666666664`, 60}, {45, 60}}]], 
   LineBox[NCache[{{45, 68}, {Rational[139, 3], 68}}, {{45, 68}, {
      46.333333333333336`, 68}}]], 
   LineBox[NCache[{{45, Rational[200, 3]}, {
      Rational[139, 3], Rational[200, 3]}}, {{45, 66.66666666666667}, {
      46.333333333333336`, 66.66666666666667}}]], 
   LineBox[NCache[{{45, Rational[196, 3]}, {
      Rational[139, 3], Rational[196, 3]}}, {{45, 65.33333333333333}, {
      46.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{45, 64}, {Rational[139, 3], 64}}, {{45, 64}, {
      46.333333333333336`, 64}}]], 
   LineBox[NCache[{{45, Rational[188, 3]}, {
      Rational[139, 3], Rational[188, 3]}}, {{45, 62.666666666666664`}, {
      46.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{45, Rational[184, 3]}, {
      Rational[139, 3], Rational[184, 3]}}, {{45, 61.333333333333336`}, {
      46.333333333333336`, 61.333333333333336`}}]], 
   LineBox[NCache[{{45, 60}, {Rational[139, 3], 60}}, {{45, 60}, {
      46.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[139, 3], 68}, {Rational[143, 3], 68}}, {{
      46.333333333333336`, 68}, {47.666666666666664`, 68}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[200, 3]}, {
      Rational[143, 3], Rational[200, 3]}}, {{46.333333333333336`, 
     66.66666666666667}, {47.666666666666664`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[196, 3]}, {
      Rational[143, 3], Rational[196, 3]}}, {{46.333333333333336`, 
     65.33333333333333}, {47.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[139, 3], 64}, {Rational[143, 3], 64}}, {{
      46.333333333333336`, 64}, {47.666666666666664`, 64}}]], 
   LineBox[
    NCache[{{Rational[139, 3], Rational[188, 3]}, {
      Rational[143, 3], Rational[188, 3]}}, {{46.333333333333336`, 
     62.666666666666664`}, {47.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[184, 3]}, {
      Rational[143, 3], Rational[184, 3]}}, {{46.333333333333336`, 
     61.333333333333336`}, {47.666666666666664`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[139, 3], 60}, {Rational[143, 3], 60}}, {{
      46.333333333333336`, 60}, {47.666666666666664`, 60}}]], 
   LineBox[NCache[{{Rational[143, 3], 68}, {49, 68}}, {{
      47.666666666666664`, 68}, {49, 68}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[200, 3]}, {
      49, Rational[200, 3]}}, {{47.666666666666664`, 66.66666666666667}, {
      49, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[196, 3]}, {
      49, Rational[196, 3]}}, {{47.666666666666664`, 65.33333333333333}, {
      49, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[143, 3], 64}, {49, 64}}, {{
      47.666666666666664`, 64}, {49, 64}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[188, 3]}, {
      49, Rational[188, 3]}}, {{47.666666666666664`, 62.666666666666664`}, {
      49, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[184, 3]}, {
      49, Rational[184, 3]}}, {{47.666666666666664`, 61.333333333333336`}, {
      49, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[143, 3], 60}, {49, 60}}, {{
      47.666666666666664`, 60}, {49, 60}}]], 
   LineBox[NCache[{{41, 68}, {41, Rational[200, 3]}}, {{41, 68}, {
      41, 66.66666666666667}}]], 
   LineBox[NCache[{{41, Rational[200, 3]}, {41, Rational[196, 3]}}, {{
      41, 66.66666666666667}, {41, 65.33333333333333}}]], 
   LineBox[NCache[{{41, Rational[196, 3]}, {41, 64}}, {{
      41, 65.33333333333333}, {41, 64}}]], 
   LineBox[NCache[{{41, 64}, {41, Rational[188, 3]}}, {{41, 64}, {
      41, 62.666666666666664`}}]], 
   LineBox[NCache[{{41, Rational[188, 3]}, {41, Rational[184, 3]}}, {{
      41, 62.666666666666664`}, {41, 61.333333333333336`}}]], 
   LineBox[
    NCache[{{41, Rational[184, 3]}, {41, 60}}, {{41, 61.333333333333336`}, {
      41, 60}}]], 
   LineBox[NCache[{{Rational[127, 3], 68}, {
      Rational[127, 3], Rational[200, 3]}}, {{42.333333333333336`, 68}, {
      42.333333333333336`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[200, 3]}, {
      Rational[127, 3], Rational[196, 3]}}, {{42.333333333333336`, 
     66.66666666666667}, {42.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[196, 3]}, {
      Rational[127, 3], 64}}, {{42.333333333333336`, 65.33333333333333}, {
      42.333333333333336`, 64}}]], 
   LineBox[NCache[{{Rational[127, 3], 64}, {
      Rational[127, 3], Rational[188, 3]}}, {{42.333333333333336`, 64}, {
      42.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[188, 3]}, {
      Rational[127, 3], Rational[184, 3]}}, {{42.333333333333336`, 
     62.666666666666664`}, {42.333333333333336`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[127, 3], Rational[184, 3]}, {
      Rational[127, 3], 60}}, {{42.333333333333336`, 61.333333333333336`}, {
      42.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[131, 3], 68}, {
      Rational[131, 3], Rational[200, 3]}}, {{43.666666666666664`, 68}, {
      43.666666666666664`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[200, 3]}, {
      Rational[131, 3], Rational[196, 3]}}, {{43.666666666666664`, 
     66.66666666666667}, {43.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[196, 3]}, {
      Rational[131, 3], 64}}, {{43.666666666666664`, 65.33333333333333}, {
      43.666666666666664`, 64}}]], 
   LineBox[NCache[{{Rational[131, 3], 64}, {
      Rational[131, 3], Rational[188, 3]}}, {{43.666666666666664`, 64}, {
      43.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[188, 3]}, {
      Rational[131, 3], Rational[184, 3]}}, {{43.666666666666664`, 
     62.666666666666664`}, {43.666666666666664`, 61.333333333333336`}}]], 
   LineBox[
    NCache[{{Rational[131, 3], Rational[184, 3]}, {Rational[131, 3], 60}}, {{
      43.666666666666664`, 61.333333333333336`}, {43.666666666666664`, 60}}]],
    LineBox[NCache[{{45, 68}, {45, Rational[200, 3]}}, {{45, 68}, {
      45, 66.66666666666667}}]], 
   LineBox[NCache[{{45, Rational[200, 3]}, {45, Rational[196, 3]}}, {{
      45, 66.66666666666667}, {45, 65.33333333333333}}]], 
   LineBox[NCache[{{45, Rational[196, 3]}, {45, 64}}, {{
      45, 65.33333333333333}, {45, 64}}]], 
   LineBox[NCache[{{45, 64}, {45, Rational[188, 3]}}, {{45, 64}, {
      45, 62.666666666666664`}}]], 
   LineBox[NCache[{{45, Rational[188, 3]}, {45, Rational[184, 3]}}, {{
      45, 62.666666666666664`}, {45, 61.333333333333336`}}]], 
   LineBox[NCache[{{45, Rational[184, 3]}, {45, 60}}, {{
      45, 61.333333333333336`}, {45, 60}}]], 
   LineBox[NCache[{{Rational[139, 3], 68}, {
      Rational[139, 3], Rational[200, 3]}}, {{46.333333333333336`, 68}, {
      46.333333333333336`, 66.66666666666667}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[200, 3]}, {
      Rational[139, 3], Rational[196, 3]}}, {{46.333333333333336`, 
     66.66666666666667}, {46.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[196, 3]}, {
      Rational[139, 3], 64}}, {{46.333333333333336`, 65.33333333333333}, {
      46.333333333333336`, 64}}]], 
   LineBox[NCache[{{Rational[139, 3], 64}, {
      Rational[139, 3], Rational[188, 3]}}, {{46.333333333333336`, 64}, {
      46.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[188, 3]}, {
      Rational[139, 3], Rational[184, 3]}}, {{46.333333333333336`, 
     62.666666666666664`}, {46.333333333333336`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[184, 3]}, {
      Rational[139, 3], 60}}, {{46.333333333333336`, 61.333333333333336`}, {
      46.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[143, 3], 68}, {
      Rational[143, 3], Rational[200, 3]}}, {{47.666666666666664`, 68}, {
      47.666666666666664`, 66.66666666666667}}]], 
   LineBox[
    NCache[{{Rational[143, 3], Rational[200, 3]}, {
      Rational[143, 3], Rational[196, 3]}}, {{47.666666666666664`, 
     66.66666666666667}, {47.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[196, 3]}, {
      Rational[143, 3], 64}}, {{47.666666666666664`, 65.33333333333333}, {
      47.666666666666664`, 64}}]], 
   LineBox[NCache[{{Rational[143, 3], 64}, {
      Rational[143, 3], Rational[188, 3]}}, {{47.666666666666664`, 64}, {
      47.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[188, 3]}, {
      Rational[143, 3], Rational[184, 3]}}, {{47.666666666666664`, 
     62.666666666666664`}, {47.666666666666664`, 61.333333333333336`}}]], 
   LineBox[NCache[{{Rational[143, 3], Rational[184, 3]}, {
      Rational[143, 3], 60}}, {{47.666666666666664`, 61.333333333333336`}, {
      47.666666666666664`, 60}}]], 
   LineBox[NCache[{{49, 68}, {49, Rational[200, 3]}}, {{49, 68}, {
      49, 66.66666666666667}}]], 
   LineBox[NCache[{{49, Rational[200, 3]}, {49, Rational[196, 3]}}, {{
      49, 66.66666666666667}, {49, 65.33333333333333}}]], 
   LineBox[NCache[{{49, Rational[196, 3]}, {49, 64}}, {{
      49, 65.33333333333333}, {49, 64}}]], 
   LineBox[NCache[{{49, 64}, {49, Rational[188, 3]}}, {{49, 64}, {
      49, 62.666666666666664`}}]], 
   LineBox[NCache[{{49, Rational[188, 3]}, {49, Rational[184, 3]}}, {{
      49, 62.666666666666664`}, {49, 61.333333333333336`}}]], 
   LineBox[NCache[{{49, Rational[184, 3]}, {49, 60}}, {{
      49, 61.333333333333336`}, {49, 60}}]], 
   LineBox[NCache[{{51, 68}, {Rational[161, 3], 68}}, {{51, 68}, {
      53.666666666666664`, 68}}]], 
   LineBox[NCache[{{51, Rational[196, 3]}, {
      Rational[161, 3], Rational[196, 3]}}, {{51, 65.33333333333333}, {
      53.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{51, Rational[188, 3]}, {
      Rational[161, 3], Rational[188, 3]}}, {{51, 62.666666666666664`}, {
      53.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{51, 60}, {Rational[161, 3], 60}}, {{51, 60}, {
      53.666666666666664`, 60}}]], 
   LineBox[NCache[{{Rational[161, 3], 68}, {Rational[169, 3], 68}}, {{
      53.666666666666664`, 68}, {56.333333333333336`, 68}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[196, 3]}, {
      Rational[169, 3], Rational[196, 3]}}, {{53.666666666666664`, 
     65.33333333333333}, {56.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[188, 3]}, {
      Rational[169, 3], Rational[188, 3]}}, {{53.666666666666664`, 
     62.666666666666664`}, {56.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[161, 3], 60}, {Rational[169, 3], 60}}, {{
      53.666666666666664`, 60}, {56.333333333333336`, 60}}]], 
   LineBox[NCache[{{Rational[169, 3], 68}, {59, 68}}, {{
      56.333333333333336`, 68}, {59, 68}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[196, 3]}, {
      59, Rational[196, 3]}}, {{56.333333333333336`, 65.33333333333333}, {
      59, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[188, 3]}, {
      59, Rational[188, 3]}}, {{56.333333333333336`, 62.666666666666664`}, {
      59, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], 60}, {59, 60}}, {{
      56.333333333333336`, 60}, {59, 60}}]], 
   LineBox[NCache[{{51, 68}, {51, Rational[196, 3]}}, {{51, 68}, {
      51, 65.33333333333333}}]], 
   LineBox[NCache[{{51, Rational[196, 3]}, {51, Rational[188, 3]}}, {{
      51, 65.33333333333333}, {51, 62.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[188, 3]}, {51, 60}}, {{
      51, 62.666666666666664`}, {51, 60}}]], 
   LineBox[NCache[{{Rational[161, 3], 68}, {
      Rational[161, 3], Rational[196, 3]}}, {{53.666666666666664`, 68}, {
      53.666666666666664`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[196, 3]}, {
      Rational[161, 3], Rational[188, 3]}}, {{53.666666666666664`, 
     65.33333333333333}, {53.666666666666664`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[188, 3]}, {
      Rational[161, 3], 60}}, {{53.666666666666664`, 62.666666666666664`}, {
      53.666666666666664`, 60}}]], 
   LineBox[NCache[{{Rational[169, 3], 68}, {
      Rational[169, 3], Rational[196, 3]}}, {{56.333333333333336`, 68}, {
      56.333333333333336`, 65.33333333333333}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[196, 3]}, {
      Rational[169, 3], Rational[188, 3]}}, {{56.333333333333336`, 
     65.33333333333333}, {56.333333333333336`, 62.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[188, 3]}, {
      Rational[169, 3], 60}}, {{56.333333333333336`, 62.666666666666664`}, {
      56.333333333333336`, 60}}]], 
   LineBox[NCache[{{59, 68}, {59, Rational[196, 3]}}, {{59, 68}, {
      59, 65.33333333333333}}]], 
   LineBox[NCache[{{59, Rational[196, 3]}, {59, Rational[188, 3]}}, {{
      59, 65.33333333333333}, {59, 62.666666666666664`}}]], 
   LineBox[NCache[{{59, Rational[188, 3]}, {59, 60}}, {{
      59, 62.666666666666664`}, {59, 60}}]], LineBox[{{61, 68}, {65, 68}}], 
   LineBox[{{61, 64}, {65, 64}}], LineBox[{{61, 60}, {65, 60}}], 
   LineBox[{{65, 68}, {69, 68}}], LineBox[{{65, 64}, {69, 64}}], 
   LineBox[{{65, 60}, {69, 60}}], LineBox[{{61, 68}, {61, 64}}], 
   LineBox[{{61, 64}, {61, 60}}], LineBox[{{65, 68}, {65, 64}}], 
   LineBox[{{65, 64}, {65, 60}}], LineBox[{{69, 68}, {69, 64}}], 
   LineBox[{{69, 64}, {69, 60}}], LineBox[{{11, 58}, {15, 58}}], 
   LineBox[{{11, 54}, {15, 54}}], LineBox[{{11, 50}, {15, 50}}], 
   LineBox[{{15, 58}, {19, 58}}], LineBox[{{15, 54}, {19, 54}}], 
   LineBox[{{15, 50}, {19, 50}}], LineBox[{{11, 58}, {11, 54}}], 
   LineBox[{{11, 54}, {11, 50}}], LineBox[{{15, 58}, {15, 54}}], 
   LineBox[{{15, 54}, {15, 50}}], LineBox[{{19, 58}, {19, 54}}], 
   LineBox[{{19, 54}, {19, 50}}], LineBox[{{21, 58}, {25, 58}}], 
   LineBox[{{21, 54}, {25, 54}}], LineBox[{{21, 50}, {25, 50}}], 
   LineBox[{{25, 58}, {29, 58}}], LineBox[{{25, 54}, {29, 54}}], 
   LineBox[{{25, 50}, {29, 50}}], LineBox[{{21, 58}, {21, 54}}], 
   LineBox[{{21, 54}, {21, 50}}], LineBox[{{25, 58}, {25, 54}}], 
   LineBox[{{25, 54}, {25, 50}}], LineBox[{{29, 58}, {29, 54}}], 
   LineBox[{{29, 54}, {29, 50}}], 
   LineBox[NCache[{{31, 58}, {Rational[163, 5], 58}}, {{31, 58}, {
      32.6, 58}}]], 
   LineBox[NCache[{{31, Rational[282, 5]}, {
      Rational[163, 5], Rational[282, 5]}}, {{31, 56.4}, {32.6, 56.4}}]], 
   LineBox[NCache[{{31, Rational[274, 5]}, {
      Rational[163, 5], Rational[274, 5]}}, {{31, 54.8}, {32.6, 54.8}}]], 
   LineBox[NCache[{{31, Rational[266, 5]}, {
      Rational[163, 5], Rational[266, 5]}}, {{31, 53.2}, {32.6, 53.2}}]], 
   LineBox[NCache[{{31, Rational[258, 5]}, {
      Rational[163, 5], Rational[258, 5]}}, {{31, 51.6}, {32.6, 51.6}}]], 
   LineBox[NCache[{{31, 50}, {Rational[163, 5], 50}}, {{31, 50}, {
      32.6, 50}}]], 
   LineBox[NCache[{{Rational[163, 5], 58}, {Rational[171, 5], 58}}, {{
      32.6, 58}, {34.2, 58}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[282, 5]}, {
      Rational[171, 5], Rational[282, 5]}}, {{32.6, 56.4}, {34.2, 56.4}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[274, 5]}, {
      Rational[171, 5], Rational[274, 5]}}, {{32.6, 54.8}, {34.2, 54.8}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[266, 5]}, {
      Rational[171, 5], Rational[266, 5]}}, {{32.6, 53.2}, {34.2, 53.2}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[258, 5]}, {
      Rational[171, 5], Rational[258, 5]}}, {{32.6, 51.6}, {34.2, 51.6}}]], 
   LineBox[NCache[{{Rational[163, 5], 50}, {Rational[171, 5], 50}}, {{
      32.6, 50}, {34.2, 50}}]], 
   LineBox[NCache[{{Rational[171, 5], 58}, {Rational[179, 5], 58}}, {{
      34.2, 58}, {35.8, 58}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[282, 5]}, {
      Rational[179, 5], Rational[282, 5]}}, {{34.2, 56.4}, {35.8, 56.4}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[274, 5]}, {
      Rational[179, 5], Rational[274, 5]}}, {{34.2, 54.8}, {35.8, 54.8}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[266, 5]}, {
      Rational[179, 5], Rational[266, 5]}}, {{34.2, 53.2}, {35.8, 53.2}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[258, 5]}, {
      Rational[179, 5], Rational[258, 5]}}, {{34.2, 51.6}, {35.8, 51.6}}]], 
   LineBox[
    NCache[{{Rational[171, 5], 50}, {Rational[179, 5], 50}}, {{34.2, 50}, {
      35.8, 50}}]], 
   LineBox[NCache[{{Rational[179, 5], 58}, {Rational[187, 5], 58}}, {{
      35.8, 58}, {37.4, 58}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[282, 5]}, {
      Rational[187, 5], Rational[282, 5]}}, {{35.8, 56.4}, {37.4, 56.4}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[274, 5]}, {
      Rational[187, 5], Rational[274, 5]}}, {{35.8, 54.8}, {37.4, 54.8}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[266, 5]}, {
      Rational[187, 5], Rational[266, 5]}}, {{35.8, 53.2}, {37.4, 53.2}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[258, 5]}, {
      Rational[187, 5], Rational[258, 5]}}, {{35.8, 51.6}, {37.4, 51.6}}]], 
   LineBox[NCache[{{Rational[179, 5], 50}, {Rational[187, 5], 50}}, {{
      35.8, 50}, {37.4, 50}}]], 
   LineBox[NCache[{{Rational[187, 5], 58}, {39, 58}}, {{37.4, 58}, {39, 
      58}}]], LineBox[
    NCache[{{Rational[187, 5], Rational[282, 5]}, {39, Rational[282, 5]}}, {{
      37.4, 56.4}, {39, 56.4}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[274, 5]}, {
      39, Rational[274, 5]}}, {{37.4, 54.8}, {39, 54.8}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[266, 5]}, {
      39, Rational[266, 5]}}, {{37.4, 53.2}, {39, 53.2}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[258, 5]}, {
      39, Rational[258, 5]}}, {{37.4, 51.6}, {39, 51.6}}]], 
   LineBox[NCache[{{Rational[187, 5], 50}, {39, 50}}, {{37.4, 50}, {39, 
      50}}]], LineBox[
    NCache[{{31, 58}, {31, Rational[282, 5]}}, {{31, 58}, {31, 56.4}}]], 
   LineBox[NCache[{{31, Rational[282, 5]}, {31, Rational[274, 5]}}, {{
      31, 56.4}, {31, 54.8}}]], 
   LineBox[NCache[{{31, Rational[274, 5]}, {31, Rational[266, 5]}}, {{
      31, 54.8}, {31, 53.2}}]], 
   LineBox[NCache[{{31, Rational[266, 5]}, {31, Rational[258, 5]}}, {{
      31, 53.2}, {31, 51.6}}]], 
   LineBox[NCache[{{31, Rational[258, 5]}, {31, 50}}, {{31, 51.6}, {31, 
      50}}]], LineBox[
    NCache[{{Rational[163, 5], 58}, {Rational[163, 5], Rational[282, 5]}}, {{
      32.6, 58}, {32.6, 56.4}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[282, 5]}, {
      Rational[163, 5], Rational[274, 5]}}, {{32.6, 56.4}, {32.6, 54.8}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[274, 5]}, {
      Rational[163, 5], Rational[266, 5]}}, {{32.6, 54.8}, {32.6, 53.2}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[266, 5]}, {
      Rational[163, 5], Rational[258, 5]}}, {{32.6, 53.2}, {32.6, 51.6}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[258, 5]}, {
      Rational[163, 5], 50}}, {{32.6, 51.6}, {32.6, 50}}]], 
   LineBox[NCache[{{Rational[171, 5], 58}, {
      Rational[171, 5], Rational[282, 5]}}, {{34.2, 58}, {34.2, 56.4}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[282, 5]}, {
      Rational[171, 5], Rational[274, 5]}}, {{34.2, 56.4}, {34.2, 54.8}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[274, 5]}, {
      Rational[171, 5], Rational[266, 5]}}, {{34.2, 54.8}, {34.2, 53.2}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[266, 5]}, {
      Rational[171, 5], Rational[258, 5]}}, {{34.2, 53.2}, {34.2, 51.6}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[258, 5]}, {
      Rational[171, 5], 50}}, {{34.2, 51.6}, {34.2, 50}}]], 
   LineBox[NCache[{{Rational[179, 5], 58}, {
      Rational[179, 5], Rational[282, 5]}}, {{35.8, 58}, {35.8, 56.4}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[282, 5]}, {
      Rational[179, 5], Rational[274, 5]}}, {{35.8, 56.4}, {35.8, 54.8}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[274, 5]}, {
      Rational[179, 5], Rational[266, 5]}}, {{35.8, 54.8}, {35.8, 53.2}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[266, 5]}, {
      Rational[179, 5], Rational[258, 5]}}, {{35.8, 53.2}, {35.8, 51.6}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[258, 5]}, {
      Rational[179, 5], 50}}, {{35.8, 51.6}, {35.8, 50}}]], 
   LineBox[NCache[{{Rational[187, 5], 58}, {
      Rational[187, 5], Rational[282, 5]}}, {{37.4, 58}, {37.4, 56.4}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[282, 5]}, {
      Rational[187, 5], Rational[274, 5]}}, {{37.4, 56.4}, {37.4, 54.8}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[274, 5]}, {
      Rational[187, 5], Rational[266, 5]}}, {{37.4, 54.8}, {37.4, 53.2}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[266, 5]}, {
      Rational[187, 5], Rational[258, 5]}}, {{37.4, 53.2}, {37.4, 51.6}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[258, 5]}, {
      Rational[187, 5], 50}}, {{37.4, 51.6}, {37.4, 50}}]], 
   LineBox[NCache[{{39, 58}, {39, Rational[282, 5]}}, {{39, 58}, {
      39, 56.4}}]], 
   LineBox[NCache[{{39, Rational[282, 5]}, {39, Rational[274, 5]}}, {{
      39, 56.4}, {39, 54.8}}]], 
   LineBox[NCache[{{39, Rational[274, 5]}, {39, Rational[266, 5]}}, {{
      39, 54.8}, {39, 53.2}}]], 
   LineBox[NCache[{{39, Rational[266, 5]}, {39, Rational[258, 5]}}, {{
      39, 53.2}, {39, 51.6}}]], 
   LineBox[NCache[{{39, Rational[258, 5]}, {39, 50}}, {{39, 51.6}, {39, 
      50}}]], LineBox[
    NCache[{{41, 58}, {Rational[213, 5], 58}}, {{41, 58}, {42.6, 58}}]], 
   LineBox[NCache[{{41, Rational[282, 5]}, {
      Rational[213, 5], Rational[282, 5]}}, {{41, 56.4}, {42.6, 56.4}}]], 
   LineBox[NCache[{{41, Rational[274, 5]}, {
      Rational[213, 5], Rational[274, 5]}}, {{41, 54.8}, {42.6, 54.8}}]], 
   LineBox[NCache[{{41, Rational[266, 5]}, {
      Rational[213, 5], Rational[266, 5]}}, {{41, 53.2}, {42.6, 53.2}}]], 
   LineBox[NCache[{{41, Rational[258, 5]}, {
      Rational[213, 5], Rational[258, 5]}}, {{41, 51.6}, {42.6, 51.6}}]], 
   LineBox[NCache[{{41, 50}, {Rational[213, 5], 50}}, {{41, 50}, {
      42.6, 50}}]], 
   LineBox[NCache[{{Rational[213, 5], 58}, {Rational[221, 5], 58}}, {{
      42.6, 58}, {44.2, 58}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[282, 5]}, {
      Rational[221, 5], Rational[282, 5]}}, {{42.6, 56.4}, {44.2, 56.4}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[274, 5]}, {
      Rational[221, 5], Rational[274, 5]}}, {{42.6, 54.8}, {44.2, 54.8}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[266, 5]}, {
      Rational[221, 5], Rational[266, 5]}}, {{42.6, 53.2}, {44.2, 53.2}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[258, 5]}, {
      Rational[221, 5], Rational[258, 5]}}, {{42.6, 51.6}, {44.2, 51.6}}]], 
   LineBox[NCache[{{Rational[213, 5], 50}, {Rational[221, 5], 50}}, {{
      42.6, 50}, {44.2, 50}}]], 
   LineBox[NCache[{{Rational[221, 5], 58}, {Rational[229, 5], 58}}, {{
      44.2, 58}, {45.8, 58}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[282, 5]}, {
      Rational[229, 5], Rational[282, 5]}}, {{44.2, 56.4}, {45.8, 56.4}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[274, 5]}, {
      Rational[229, 5], Rational[274, 5]}}, {{44.2, 54.8}, {45.8, 54.8}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[266, 5]}, {
      Rational[229, 5], Rational[266, 5]}}, {{44.2, 53.2}, {45.8, 53.2}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[258, 5]}, {
      Rational[229, 5], Rational[258, 5]}}, {{44.2, 51.6}, {45.8, 51.6}}]], 
   LineBox[NCache[{{Rational[221, 5], 50}, {Rational[229, 5], 50}}, {{
      44.2, 50}, {45.8, 50}}]], 
   LineBox[NCache[{{Rational[229, 5], 58}, {Rational[237, 5], 58}}, {{
      45.8, 58}, {47.4, 58}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[282, 5]}, {
      Rational[237, 5], Rational[282, 5]}}, {{45.8, 56.4}, {47.4, 56.4}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[274, 5]}, {
      Rational[237, 5], Rational[274, 5]}}, {{45.8, 54.8}, {47.4, 54.8}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[266, 5]}, {
      Rational[237, 5], Rational[266, 5]}}, {{45.8, 53.2}, {47.4, 53.2}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[258, 5]}, {
      Rational[237, 5], Rational[258, 5]}}, {{45.8, 51.6}, {47.4, 51.6}}]], 
   LineBox[NCache[{{Rational[229, 5], 50}, {Rational[237, 5], 50}}, {{
      45.8, 50}, {47.4, 50}}]], 
   LineBox[NCache[{{Rational[237, 5], 58}, {49, 58}}, {{47.4, 58}, {49, 
      58}}]], LineBox[
    NCache[{{Rational[237, 5], Rational[282, 5]}, {49, Rational[282, 5]}}, {{
      47.4, 56.4}, {49, 56.4}}]], 
   LineBox[
    NCache[{{Rational[237, 5], Rational[274, 5]}, {49, Rational[274, 5]}}, {{
      47.4, 54.8}, {49, 54.8}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[266, 5]}, {
      49, Rational[266, 5]}}, {{47.4, 53.2}, {49, 53.2}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[258, 5]}, {
      49, Rational[258, 5]}}, {{47.4, 51.6}, {49, 51.6}}]], 
   LineBox[NCache[{{Rational[237, 5], 50}, {49, 50}}, {{47.4, 50}, {49, 
      50}}]], LineBox[
    NCache[{{41, 58}, {41, Rational[282, 5]}}, {{41, 58}, {41, 56.4}}]], 
   LineBox[NCache[{{41, Rational[282, 5]}, {41, Rational[274, 5]}}, {{
      41, 56.4}, {41, 54.8}}]], 
   LineBox[NCache[{{41, Rational[274, 5]}, {41, Rational[266, 5]}}, {{
      41, 54.8}, {41, 53.2}}]], 
   LineBox[NCache[{{41, Rational[266, 5]}, {41, Rational[258, 5]}}, {{
      41, 53.2}, {41, 51.6}}]], 
   LineBox[NCache[{{41, Rational[258, 5]}, {41, 50}}, {{41, 51.6}, {41, 
      50}}]], LineBox[
    NCache[{{Rational[213, 5], 58}, {Rational[213, 5], Rational[282, 5]}}, {{
      42.6, 58}, {42.6, 56.4}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[282, 5]}, {
      Rational[213, 5], Rational[274, 5]}}, {{42.6, 56.4}, {42.6, 54.8}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[274, 5]}, {
      Rational[213, 5], Rational[266, 5]}}, {{42.6, 54.8}, {42.6, 53.2}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[266, 5]}, {
      Rational[213, 5], Rational[258, 5]}}, {{42.6, 53.2}, {42.6, 51.6}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[258, 5]}, {
      Rational[213, 5], 50}}, {{42.6, 51.6}, {42.6, 50}}]], 
   LineBox[NCache[{{Rational[221, 5], 58}, {
      Rational[221, 5], Rational[282, 5]}}, {{44.2, 58}, {44.2, 56.4}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[282, 5]}, {
      Rational[221, 5], Rational[274, 5]}}, {{44.2, 56.4}, {44.2, 54.8}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[274, 5]}, {
      Rational[221, 5], Rational[266, 5]}}, {{44.2, 54.8}, {44.2, 53.2}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[266, 5]}, {
      Rational[221, 5], Rational[258, 5]}}, {{44.2, 53.2}, {44.2, 51.6}}]], 
   LineBox[
    NCache[{{Rational[221, 5], Rational[258, 5]}, {Rational[221, 5], 50}}, {{
      44.2, 51.6}, {44.2, 50}}]], 
   LineBox[NCache[{{Rational[229, 5], 58}, {
      Rational[229, 5], Rational[282, 5]}}, {{45.8, 58}, {45.8, 56.4}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[282, 5]}, {
      Rational[229, 5], Rational[274, 5]}}, {{45.8, 56.4}, {45.8, 54.8}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[274, 5]}, {
      Rational[229, 5], Rational[266, 5]}}, {{45.8, 54.8}, {45.8, 53.2}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[266, 5]}, {
      Rational[229, 5], Rational[258, 5]}}, {{45.8, 53.2}, {45.8, 51.6}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[258, 5]}, {
      Rational[229, 5], 50}}, {{45.8, 51.6}, {45.8, 50}}]], 
   LineBox[NCache[{{Rational[237, 5], 58}, {
      Rational[237, 5], Rational[282, 5]}}, {{47.4, 58}, {47.4, 56.4}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[282, 5]}, {
      Rational[237, 5], Rational[274, 5]}}, {{47.4, 56.4}, {47.4, 54.8}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[274, 5]}, {
      Rational[237, 5], Rational[266, 5]}}, {{47.4, 54.8}, {47.4, 53.2}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[266, 5]}, {
      Rational[237, 5], Rational[258, 5]}}, {{47.4, 53.2}, {47.4, 51.6}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[258, 5]}, {
      Rational[237, 5], 50}}, {{47.4, 51.6}, {47.4, 50}}]], 
   LineBox[NCache[{{49, 58}, {49, Rational[282, 5]}}, {{49, 58}, {
      49, 56.4}}]], 
   LineBox[NCache[{{49, Rational[282, 5]}, {49, Rational[274, 5]}}, {{
      49, 56.4}, {49, 54.8}}]], 
   LineBox[NCache[{{49, Rational[274, 5]}, {49, Rational[266, 5]}}, {{
      49, 54.8}, {49, 53.2}}]], 
   LineBox[NCache[{{49, Rational[266, 5]}, {49, Rational[258, 5]}}, {{
      49, 53.2}, {49, 51.6}}]], 
   LineBox[NCache[{{49, Rational[258, 5]}, {49, 50}}, {{49, 51.6}, {49, 
      50}}]], LineBox[{{51, 58}, {53, 58}}], LineBox[{{51, 56}, {53, 56}}], 
   LineBox[{{51, 54}, {53, 54}}], LineBox[{{51, 52}, {53, 52}}], 
   LineBox[{{51, 50}, {53, 50}}], LineBox[{{53, 58}, {55, 58}}], 
   LineBox[{{53, 56}, {55, 56}}], LineBox[{{53, 54}, {55, 54}}], 
   LineBox[{{53, 52}, {55, 52}}], LineBox[{{53, 50}, {55, 50}}], 
   LineBox[{{55, 58}, {57, 58}}], LineBox[{{55, 56}, {57, 56}}], 
   LineBox[{{55, 54}, {57, 54}}], LineBox[{{55, 52}, {57, 52}}], 
   LineBox[{{55, 50}, {57, 50}}], LineBox[{{57, 58}, {59, 58}}], 
   LineBox[{{57, 56}, {59, 56}}], LineBox[{{57, 54}, {59, 54}}], 
   LineBox[{{57, 52}, {59, 52}}], LineBox[{{57, 50}, {59, 50}}], 
   LineBox[{{51, 58}, {51, 56}}], LineBox[{{51, 56}, {51, 54}}], 
   LineBox[{{51, 54}, {51, 52}}], LineBox[{{51, 52}, {51, 50}}], 
   LineBox[{{53, 58}, {53, 56}}], LineBox[{{53, 56}, {53, 54}}], 
   LineBox[{{53, 54}, {53, 52}}], LineBox[{{53, 52}, {53, 50}}], 
   LineBox[{{55, 58}, {55, 56}}], LineBox[{{55, 56}, {55, 54}}], 
   LineBox[{{55, 54}, {55, 52}}], LineBox[{{55, 52}, {55, 50}}], 
   LineBox[{{57, 58}, {57, 56}}], LineBox[{{57, 56}, {57, 54}}], 
   LineBox[{{57, 54}, {57, 52}}], LineBox[{{57, 52}, {57, 50}}], 
   LineBox[{{59, 58}, {59, 56}}], LineBox[{{59, 56}, {59, 54}}], 
   LineBox[{{59, 54}, {59, 52}}], LineBox[{{59, 52}, {59, 50}}], 
   LineBox[{{61, 58}, {65, 58}}], LineBox[{{61, 54}, {65, 54}}], 
   LineBox[{{61, 50}, {65, 50}}], LineBox[{{65, 58}, {69, 58}}], 
   LineBox[{{65, 54}, {69, 54}}], LineBox[{{65, 50}, {69, 50}}], 
   LineBox[{{61, 58}, {61, 54}}], LineBox[{{61, 54}, {61, 50}}], 
   LineBox[{{65, 58}, {65, 54}}], LineBox[{{65, 54}, {65, 50}}], 
   LineBox[{{69, 58}, {69, 54}}], LineBox[{{69, 54}, {69, 50}}], 
   LineBox[{{11, 48}, {15, 48}}], LineBox[{{11, 44}, {15, 44}}], 
   LineBox[{{11, 40}, {15, 40}}], LineBox[{{15, 48}, {19, 48}}], 
   LineBox[{{15, 44}, {19, 44}}], LineBox[{{15, 40}, {19, 40}}], 
   LineBox[{{11, 48}, {11, 44}}], LineBox[{{11, 44}, {11, 40}}], 
   LineBox[{{15, 48}, {15, 44}}], LineBox[{{15, 44}, {15, 40}}], 
   LineBox[{{19, 48}, {19, 44}}], LineBox[{{19, 44}, {19, 40}}], 
   LineBox[{{21, 48}, {23, 48}}], LineBox[{{21, 46}, {23, 46}}], 
   LineBox[{{21, 44}, {23, 44}}], LineBox[{{21, 42}, {23, 42}}], 
   LineBox[{{21, 40}, {23, 40}}], LineBox[{{23, 48}, {25, 48}}], 
   LineBox[{{23, 46}, {25, 46}}], LineBox[{{23, 44}, {25, 44}}], 
   LineBox[{{23, 42}, {25, 42}}], LineBox[{{23, 40}, {25, 40}}], 
   LineBox[{{25, 48}, {27, 48}}], LineBox[{{25, 46}, {27, 46}}], 
   LineBox[{{25, 44}, {27, 44}}], LineBox[{{25, 42}, {27, 42}}], 
   LineBox[{{25, 40}, {27, 40}}], LineBox[{{27, 48}, {29, 48}}], 
   LineBox[{{27, 46}, {29, 46}}], LineBox[{{27, 44}, {29, 44}}], 
   LineBox[{{27, 42}, {29, 42}}], LineBox[{{27, 40}, {29, 40}}], 
   LineBox[{{21, 48}, {21, 46}}], LineBox[{{21, 46}, {21, 44}}], 
   LineBox[{{21, 44}, {21, 42}}], LineBox[{{21, 42}, {21, 40}}], 
   LineBox[{{23, 48}, {23, 46}}], LineBox[{{23, 46}, {23, 44}}], 
   LineBox[{{23, 44}, {23, 42}}], LineBox[{{23, 42}, {23, 40}}], 
   LineBox[{{25, 48}, {25, 46}}], LineBox[{{25, 46}, {25, 44}}], 
   LineBox[{{25, 44}, {25, 42}}], LineBox[{{25, 42}, {25, 40}}], 
   LineBox[{{27, 48}, {27, 46}}], LineBox[{{27, 46}, {27, 44}}], 
   LineBox[{{27, 44}, {27, 42}}], LineBox[{{27, 42}, {27, 40}}], 
   LineBox[{{29, 48}, {29, 46}}], LineBox[{{29, 46}, {29, 44}}], 
   LineBox[{{29, 44}, {29, 42}}], LineBox[{{29, 42}, {29, 40}}], 
   LineBox[NCache[{{31, 48}, {Rational[101, 3], 48}}, {{31, 48}, {
      33.666666666666664`, 48}}]], 
   LineBox[NCache[{{31, Rational[136, 3]}, {
      Rational[101, 3], Rational[136, 3]}}, {{31, 45.333333333333336`}, {
      33.666666666666664`, 45.333333333333336`}}]], 
   LineBox[NCache[{{31, Rational[128, 3]}, {
      Rational[101, 3], Rational[128, 3]}}, {{31, 42.666666666666664`}, {
      33.666666666666664`, 42.666666666666664`}}]], 
   LineBox[NCache[{{31, 40}, {Rational[101, 3], 40}}, {{31, 40}, {
      33.666666666666664`, 40}}]], 
   LineBox[NCache[{{Rational[101, 3], 48}, {Rational[109, 3], 48}}, {{
      33.666666666666664`, 48}, {36.333333333333336`, 48}}]], 
   LineBox[
    NCache[{{Rational[101, 3], Rational[136, 3]}, {
      Rational[109, 3], Rational[136, 3]}}, {{33.666666666666664`, 
     45.333333333333336`}, {36.333333333333336`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[128, 3]}, {
      Rational[109, 3], Rational[128, 3]}}, {{33.666666666666664`, 
     42.666666666666664`}, {36.333333333333336`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[101, 3], 40}, {Rational[109, 3], 40}}, {{
      33.666666666666664`, 40}, {36.333333333333336`, 40}}]], 
   LineBox[NCache[{{Rational[109, 3], 48}, {39, 48}}, {{
      36.333333333333336`, 48}, {39, 48}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[136, 3]}, {
      39, Rational[136, 3]}}, {{36.333333333333336`, 45.333333333333336`}, {
      39, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[128, 3]}, {
      39, Rational[128, 3]}}, {{36.333333333333336`, 42.666666666666664`}, {
      39, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[109, 3], 40}, {39, 40}}, {{
      36.333333333333336`, 40}, {39, 40}}]], 
   LineBox[NCache[{{31, 48}, {31, Rational[136, 3]}}, {{31, 48}, {
      31, 45.333333333333336`}}]], 
   LineBox[NCache[{{31, Rational[136, 3]}, {31, Rational[128, 3]}}, {{
      31, 45.333333333333336`}, {31, 42.666666666666664`}}]], 
   LineBox[NCache[{{31, Rational[128, 3]}, {31, 40}}, {{
      31, 42.666666666666664`}, {31, 40}}]], 
   LineBox[NCache[{{Rational[101, 3], 48}, {
      Rational[101, 3], Rational[136, 3]}}, {{33.666666666666664`, 48}, {
      33.666666666666664`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[136, 3]}, {
      Rational[101, 3], Rational[128, 3]}}, {{33.666666666666664`, 
     45.333333333333336`}, {33.666666666666664`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[128, 3]}, {
      Rational[101, 3], 40}}, {{33.666666666666664`, 42.666666666666664`}, {
      33.666666666666664`, 40}}]], 
   LineBox[NCache[{{Rational[109, 3], 48}, {
      Rational[109, 3], Rational[136, 3]}}, {{36.333333333333336`, 48}, {
      36.333333333333336`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[136, 3]}, {
      Rational[109, 3], Rational[128, 3]}}, {{36.333333333333336`, 
     45.333333333333336`}, {36.333333333333336`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[128, 3]}, {
      Rational[109, 3], 40}}, {{36.333333333333336`, 42.666666666666664`}, {
      36.333333333333336`, 40}}]], 
   LineBox[NCache[{{39, 48}, {39, Rational[136, 3]}}, {{39, 48}, {
      39, 45.333333333333336`}}]], 
   LineBox[NCache[{{39, Rational[136, 3]}, {39, Rational[128, 3]}}, {{
      39, 45.333333333333336`}, {39, 42.666666666666664`}}]], 
   LineBox[NCache[{{39, Rational[128, 3]}, {39, 40}}, {{
      39, 42.666666666666664`}, {39, 40}}]], 
   LineBox[NCache[{{41, 48}, {Rational[131, 3], 48}}, {{41, 48}, {
      43.666666666666664`, 48}}]], 
   LineBox[NCache[{{41, Rational[136, 3]}, {
      Rational[131, 3], Rational[136, 3]}}, {{41, 45.333333333333336`}, {
      43.666666666666664`, 45.333333333333336`}}]], 
   LineBox[NCache[{{41, Rational[128, 3]}, {
      Rational[131, 3], Rational[128, 3]}}, {{41, 42.666666666666664`}, {
      43.666666666666664`, 42.666666666666664`}}]], 
   LineBox[NCache[{{41, 40}, {Rational[131, 3], 40}}, {{41, 40}, {
      43.666666666666664`, 40}}]], 
   LineBox[NCache[{{Rational[131, 3], 48}, {Rational[139, 3], 48}}, {{
      43.666666666666664`, 48}, {46.333333333333336`, 48}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[136, 3]}, {
      Rational[139, 3], Rational[136, 3]}}, {{43.666666666666664`, 
     45.333333333333336`}, {46.333333333333336`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[128, 3]}, {
      Rational[139, 3], Rational[128, 3]}}, {{43.666666666666664`, 
     42.666666666666664`}, {46.333333333333336`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[131, 3], 40}, {Rational[139, 3], 40}}, {{
      43.666666666666664`, 40}, {46.333333333333336`, 40}}]], 
   LineBox[NCache[{{Rational[139, 3], 48}, {49, 48}}, {{
      46.333333333333336`, 48}, {49, 48}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[136, 3]}, {
      49, Rational[136, 3]}}, {{46.333333333333336`, 45.333333333333336`}, {
      49, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[128, 3]}, {
      49, Rational[128, 3]}}, {{46.333333333333336`, 42.666666666666664`}, {
      49, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[139, 3], 40}, {49, 40}}, {{
      46.333333333333336`, 40}, {49, 40}}]], 
   LineBox[NCache[{{41, 48}, {41, Rational[136, 3]}}, {{41, 48}, {
      41, 45.333333333333336`}}]], 
   LineBox[NCache[{{41, Rational[136, 3]}, {41, Rational[128, 3]}}, {{
      41, 45.333333333333336`}, {41, 42.666666666666664`}}]], 
   LineBox[NCache[{{41, Rational[128, 3]}, {41, 40}}, {{
      41, 42.666666666666664`}, {41, 40}}]], 
   LineBox[NCache[{{Rational[131, 3], 48}, {
      Rational[131, 3], Rational[136, 3]}}, {{43.666666666666664`, 48}, {
      43.666666666666664`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[136, 3]}, {
      Rational[131, 3], Rational[128, 3]}}, {{43.666666666666664`, 
     45.333333333333336`}, {43.666666666666664`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[128, 3]}, {
      Rational[131, 3], 40}}, {{43.666666666666664`, 42.666666666666664`}, {
      43.666666666666664`, 40}}]], 
   LineBox[NCache[{{Rational[139, 3], 48}, {
      Rational[139, 3], Rational[136, 3]}}, {{46.333333333333336`, 48}, {
      46.333333333333336`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[136, 3]}, {
      Rational[139, 3], Rational[128, 3]}}, {{46.333333333333336`, 
     45.333333333333336`}, {46.333333333333336`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[128, 3]}, {
      Rational[139, 3], 40}}, {{46.333333333333336`, 42.666666666666664`}, {
      46.333333333333336`, 40}}]], 
   LineBox[NCache[{{49, 48}, {49, Rational[136, 3]}}, {{49, 48}, {
      49, 45.333333333333336`}}]], 
   LineBox[NCache[{{49, Rational[136, 3]}, {49, Rational[128, 3]}}, {{
      49, 45.333333333333336`}, {49, 42.666666666666664`}}]], 
   LineBox[NCache[{{49, Rational[128, 3]}, {49, 40}}, {{
      49, 42.666666666666664`}, {49, 40}}]], 
   LineBox[NCache[{{51, 48}, {Rational[157, 3], 48}}, {{51, 48}, {
      52.333333333333336`, 48}}]], 
   LineBox[NCache[{{51, Rational[140, 3]}, {
      Rational[157, 3], Rational[140, 3]}}, {{51, 46.666666666666664`}, {
      52.333333333333336`, 46.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[136, 3]}, {
      Rational[157, 3], Rational[136, 3]}}, {{51, 45.333333333333336`}, {
      52.333333333333336`, 45.333333333333336`}}]], 
   LineBox[NCache[{{51, 44}, {Rational[157, 3], 44}}, {{51, 44}, {
      52.333333333333336`, 44}}]], 
   LineBox[NCache[{{51, Rational[128, 3]}, {
      Rational[157, 3], Rational[128, 3]}}, {{51, 42.666666666666664`}, {
      52.333333333333336`, 42.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[124, 3]}, {
      Rational[157, 3], Rational[124, 3]}}, {{51, 41.333333333333336`}, {
      52.333333333333336`, 41.333333333333336`}}]], 
   LineBox[NCache[{{51, 40}, {Rational[157, 3], 40}}, {{51, 40}, {
      52.333333333333336`, 40}}]], 
   LineBox[NCache[{{Rational[157, 3], 48}, {Rational[161, 3], 48}}, {{
      52.333333333333336`, 48}, {53.666666666666664`, 48}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[140, 3]}, {
      Rational[161, 3], Rational[140, 3]}}, {{52.333333333333336`, 
     46.666666666666664`}, {53.666666666666664`, 46.666666666666664`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[136, 3]}, {
      Rational[161, 3], Rational[136, 3]}}, {{52.333333333333336`, 
     45.333333333333336`}, {53.666666666666664`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[157, 3], 44}, {Rational[161, 3], 44}}, {{
      52.333333333333336`, 44}, {53.666666666666664`, 44}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[128, 3]}, {
      Rational[161, 3], Rational[128, 3]}}, {{52.333333333333336`, 
     42.666666666666664`}, {53.666666666666664`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[124, 3]}, {
      Rational[161, 3], Rational[124, 3]}}, {{52.333333333333336`, 
     41.333333333333336`}, {53.666666666666664`, 41.333333333333336`}}]], 
   LineBox[NCache[{{Rational[157, 3], 40}, {Rational[161, 3], 40}}, {{
      52.333333333333336`, 40}, {53.666666666666664`, 40}}]], 
   LineBox[NCache[{{Rational[161, 3], 48}, {55, 48}}, {{
      53.666666666666664`, 48}, {55, 48}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[140, 3]}, {
      55, Rational[140, 3]}}, {{53.666666666666664`, 46.666666666666664`}, {
      55, 46.666666666666664`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[136, 3]}, {
      55, Rational[136, 3]}}, {{53.666666666666664`, 45.333333333333336`}, {
      55, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[161, 3], 44}, {55, 44}}, {{
      53.666666666666664`, 44}, {55, 44}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[128, 3]}, {
      55, Rational[128, 3]}}, {{53.666666666666664`, 42.666666666666664`}, {
      55, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[124, 3]}, {
      55, Rational[124, 3]}}, {{53.666666666666664`, 41.333333333333336`}, {
      55, 41.333333333333336`}}]], 
   LineBox[NCache[{{Rational[161, 3], 40}, {55, 40}}, {{
      53.666666666666664`, 40}, {55, 40}}]], 
   LineBox[NCache[{{55, 48}, {Rational[169, 3], 48}}, {{55, 48}, {
      56.333333333333336`, 48}}]], 
   LineBox[NCache[{{55, Rational[140, 3]}, {
      Rational[169, 3], Rational[140, 3]}}, {{55, 46.666666666666664`}, {
      56.333333333333336`, 46.666666666666664`}}]], 
   LineBox[NCache[{{55, Rational[136, 3]}, {
      Rational[169, 3], Rational[136, 3]}}, {{55, 45.333333333333336`}, {
      56.333333333333336`, 45.333333333333336`}}]], 
   LineBox[NCache[{{55, 44}, {Rational[169, 3], 44}}, {{55, 44}, {
      56.333333333333336`, 44}}]], 
   LineBox[NCache[{{55, Rational[128, 3]}, {
      Rational[169, 3], Rational[128, 3]}}, {{55, 42.666666666666664`}, {
      56.333333333333336`, 42.666666666666664`}}]], 
   LineBox[NCache[{{55, Rational[124, 3]}, {
      Rational[169, 3], Rational[124, 3]}}, {{55, 41.333333333333336`}, {
      56.333333333333336`, 41.333333333333336`}}]], 
   LineBox[NCache[{{55, 40}, {Rational[169, 3], 40}}, {{55, 40}, {
      56.333333333333336`, 40}}]], 
   LineBox[NCache[{{Rational[169, 3], 48}, {Rational[173, 3], 48}}, {{
      56.333333333333336`, 48}, {57.666666666666664`, 48}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[140, 3]}, {
      Rational[173, 3], Rational[140, 3]}}, {{56.333333333333336`, 
     46.666666666666664`}, {57.666666666666664`, 46.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[136, 3]}, {
      Rational[173, 3], Rational[136, 3]}}, {{56.333333333333336`, 
     45.333333333333336`}, {57.666666666666664`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[169, 3], 44}, {Rational[173, 3], 44}}, {{
      56.333333333333336`, 44}, {57.666666666666664`, 44}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[128, 3]}, {
      Rational[173, 3], Rational[128, 3]}}, {{56.333333333333336`, 
     42.666666666666664`}, {57.666666666666664`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[124, 3]}, {
      Rational[173, 3], Rational[124, 3]}}, {{56.333333333333336`, 
     41.333333333333336`}, {57.666666666666664`, 41.333333333333336`}}]], 
   LineBox[NCache[{{Rational[169, 3], 40}, {Rational[173, 3], 40}}, {{
      56.333333333333336`, 40}, {57.666666666666664`, 40}}]], 
   LineBox[NCache[{{Rational[173, 3], 48}, {59, 48}}, {{
      57.666666666666664`, 48}, {59, 48}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[140, 3]}, {
      59, Rational[140, 3]}}, {{57.666666666666664`, 46.666666666666664`}, {
      59, 46.666666666666664`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[136, 3]}, {
      59, Rational[136, 3]}}, {{57.666666666666664`, 45.333333333333336`}, {
      59, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[173, 3], 44}, {59, 44}}, {{
      57.666666666666664`, 44}, {59, 44}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[128, 3]}, {
      59, Rational[128, 3]}}, {{57.666666666666664`, 42.666666666666664`}, {
      59, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[124, 3]}, {
      59, Rational[124, 3]}}, {{57.666666666666664`, 41.333333333333336`}, {
      59, 41.333333333333336`}}]], 
   LineBox[NCache[{{Rational[173, 3], 40}, {59, 40}}, {{
      57.666666666666664`, 40}, {59, 40}}]], 
   LineBox[NCache[{{51, 48}, {51, Rational[140, 3]}}, {{51, 48}, {
      51, 46.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[140, 3]}, {51, Rational[136, 3]}}, {{
      51, 46.666666666666664`}, {51, 45.333333333333336`}}]], 
   LineBox[NCache[{{51, Rational[136, 3]}, {51, 44}}, {{
      51, 45.333333333333336`}, {51, 44}}]], 
   LineBox[NCache[{{51, 44}, {51, Rational[128, 3]}}, {{51, 44}, {
      51, 42.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[128, 3]}, {51, Rational[124, 3]}}, {{
      51, 42.666666666666664`}, {51, 41.333333333333336`}}]], 
   LineBox[NCache[{{51, Rational[124, 3]}, {51, 40}}, {{
      51, 41.333333333333336`}, {51, 40}}]], 
   LineBox[NCache[{{Rational[157, 3], 48}, {
      Rational[157, 3], Rational[140, 3]}}, {{52.333333333333336`, 48}, {
      52.333333333333336`, 46.666666666666664`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[140, 3]}, {
      Rational[157, 3], Rational[136, 3]}}, {{52.333333333333336`, 
     46.666666666666664`}, {52.333333333333336`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[136, 3]}, {
      Rational[157, 3], 44}}, {{52.333333333333336`, 45.333333333333336`}, {
      52.333333333333336`, 44}}]], 
   LineBox[NCache[{{Rational[157, 3], 44}, {
      Rational[157, 3], Rational[128, 3]}}, {{52.333333333333336`, 44}, {
      52.333333333333336`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[128, 3]}, {
      Rational[157, 3], Rational[124, 3]}}, {{52.333333333333336`, 
     42.666666666666664`}, {52.333333333333336`, 41.333333333333336`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[124, 3]}, {
      Rational[157, 3], 40}}, {{52.333333333333336`, 41.333333333333336`}, {
      52.333333333333336`, 40}}]], 
   LineBox[
    NCache[{{Rational[161, 3], 48}, {Rational[161, 3], Rational[140, 3]}}, {{
      53.666666666666664`, 48}, {53.666666666666664`, 46.666666666666664`}}]],
    LineBox[NCache[{{Rational[161, 3], Rational[140, 3]}, {
      Rational[161, 3], Rational[136, 3]}}, {{53.666666666666664`, 
     46.666666666666664`}, {53.666666666666664`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[136, 3]}, {
      Rational[161, 3], 44}}, {{53.666666666666664`, 45.333333333333336`}, {
      53.666666666666664`, 44}}]], 
   LineBox[NCache[{{Rational[161, 3], 44}, {
      Rational[161, 3], Rational[128, 3]}}, {{53.666666666666664`, 44}, {
      53.666666666666664`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[128, 3]}, {
      Rational[161, 3], Rational[124, 3]}}, {{53.666666666666664`, 
     42.666666666666664`}, {53.666666666666664`, 41.333333333333336`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[124, 3]}, {
      Rational[161, 3], 40}}, {{53.666666666666664`, 41.333333333333336`}, {
      53.666666666666664`, 40}}]], 
   LineBox[NCache[{{55, 48}, {55, Rational[140, 3]}}, {{55, 48}, {
      55, 46.666666666666664`}}]], 
   LineBox[NCache[{{55, Rational[140, 3]}, {55, Rational[136, 3]}}, {{
      55, 46.666666666666664`}, {55, 45.333333333333336`}}]], 
   LineBox[NCache[{{55, Rational[136, 3]}, {55, 44}}, {{
      55, 45.333333333333336`}, {55, 44}}]], 
   LineBox[NCache[{{55, 44}, {55, Rational[128, 3]}}, {{55, 44}, {
      55, 42.666666666666664`}}]], 
   LineBox[NCache[{{55, Rational[128, 3]}, {55, Rational[124, 3]}}, {{
      55, 42.666666666666664`}, {55, 41.333333333333336`}}]], 
   LineBox[NCache[{{55, Rational[124, 3]}, {55, 40}}, {{
      55, 41.333333333333336`}, {55, 40}}]], 
   LineBox[NCache[{{Rational[169, 3], 48}, {
      Rational[169, 3], Rational[140, 3]}}, {{56.333333333333336`, 48}, {
      56.333333333333336`, 46.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[140, 3]}, {
      Rational[169, 3], Rational[136, 3]}}, {{56.333333333333336`, 
     46.666666666666664`}, {56.333333333333336`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[136, 3]}, {
      Rational[169, 3], 44}}, {{56.333333333333336`, 45.333333333333336`}, {
      56.333333333333336`, 44}}]], 
   LineBox[NCache[{{Rational[169, 3], 44}, {
      Rational[169, 3], Rational[128, 3]}}, {{56.333333333333336`, 44}, {
      56.333333333333336`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[128, 3]}, {
      Rational[169, 3], Rational[124, 3]}}, {{56.333333333333336`, 
     42.666666666666664`}, {56.333333333333336`, 41.333333333333336`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[124, 3]}, {
      Rational[169, 3], 40}}, {{56.333333333333336`, 41.333333333333336`}, {
      56.333333333333336`, 40}}]], 
   LineBox[NCache[{{Rational[173, 3], 48}, {
      Rational[173, 3], Rational[140, 3]}}, {{57.666666666666664`, 48}, {
      57.666666666666664`, 46.666666666666664`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[140, 3]}, {
      Rational[173, 3], Rational[136, 3]}}, {{57.666666666666664`, 
     46.666666666666664`}, {57.666666666666664`, 45.333333333333336`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[136, 3]}, {
      Rational[173, 3], 44}}, {{57.666666666666664`, 45.333333333333336`}, {
      57.666666666666664`, 44}}]], 
   LineBox[NCache[{{Rational[173, 3], 44}, {
      Rational[173, 3], Rational[128, 3]}}, {{57.666666666666664`, 44}, {
      57.666666666666664`, 42.666666666666664`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[128, 3]}, {
      Rational[173, 3], Rational[124, 3]}}, {{57.666666666666664`, 
     42.666666666666664`}, {57.666666666666664`, 41.333333333333336`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[124, 3]}, {
      Rational[173, 3], 40}}, {{57.666666666666664`, 41.333333333333336`}, {
      57.666666666666664`, 40}}]], 
   LineBox[NCache[{{59, 48}, {59, Rational[140, 3]}}, {{59, 48}, {
      59, 46.666666666666664`}}]], 
   LineBox[NCache[{{59, Rational[140, 3]}, {59, Rational[136, 3]}}, {{
      59, 46.666666666666664`}, {59, 45.333333333333336`}}]], 
   LineBox[NCache[{{59, Rational[136, 3]}, {59, 44}}, {{
      59, 45.333333333333336`}, {59, 44}}]], 
   LineBox[NCache[{{59, 44}, {59, Rational[128, 3]}}, {{59, 44}, {
      59, 42.666666666666664`}}]], 
   LineBox[NCache[{{59, Rational[128, 3]}, {59, Rational[124, 3]}}, {{
      59, 42.666666666666664`}, {59, 41.333333333333336`}}]], 
   LineBox[NCache[{{59, Rational[124, 3]}, {59, 40}}, {{
      59, 41.333333333333336`}, {59, 40}}]], LineBox[{{61, 48}, {65, 48}}], 
   LineBox[{{61, 44}, {65, 44}}], LineBox[{{61, 40}, {65, 40}}], 
   LineBox[{{65, 48}, {69, 48}}], LineBox[{{65, 44}, {69, 44}}], 
   LineBox[{{65, 40}, {69, 40}}], LineBox[{{61, 48}, {61, 44}}], 
   LineBox[{{61, 44}, {61, 40}}], LineBox[{{65, 48}, {65, 44}}], 
   LineBox[{{65, 44}, {65, 40}}], LineBox[{{69, 48}, {69, 44}}], 
   LineBox[{{69, 44}, {69, 40}}], LineBox[{{11, 38}, {15, 38}}], 
   LineBox[{{11, 34}, {15, 34}}], LineBox[{{11, 30}, {15, 30}}], 
   LineBox[{{15, 38}, {19, 38}}], LineBox[{{15, 34}, {19, 34}}], 
   LineBox[{{15, 30}, {19, 30}}], LineBox[{{11, 38}, {11, 34}}], 
   LineBox[{{11, 34}, {11, 30}}], LineBox[{{15, 38}, {15, 34}}], 
   LineBox[{{15, 34}, {15, 30}}], LineBox[{{19, 38}, {19, 34}}], 
   LineBox[{{19, 34}, {19, 30}}], LineBox[{{21, 38}, {23, 38}}], 
   LineBox[{{21, 36}, {23, 36}}], LineBox[{{21, 34}, {23, 34}}], 
   LineBox[{{21, 32}, {23, 32}}], LineBox[{{21, 30}, {23, 30}}], 
   LineBox[{{23, 38}, {25, 38}}], LineBox[{{23, 36}, {25, 36}}], 
   LineBox[{{23, 34}, {25, 34}}], LineBox[{{23, 32}, {25, 32}}], 
   LineBox[{{23, 30}, {25, 30}}], LineBox[{{25, 38}, {27, 38}}], 
   LineBox[{{25, 36}, {27, 36}}], LineBox[{{25, 34}, {27, 34}}], 
   LineBox[{{25, 32}, {27, 32}}], LineBox[{{25, 30}, {27, 30}}], 
   LineBox[{{27, 38}, {29, 38}}], LineBox[{{27, 36}, {29, 36}}], 
   LineBox[{{27, 34}, {29, 34}}], LineBox[{{27, 32}, {29, 32}}], 
   LineBox[{{27, 30}, {29, 30}}], LineBox[{{21, 38}, {21, 36}}], 
   LineBox[{{21, 36}, {21, 34}}], LineBox[{{21, 34}, {21, 32}}], 
   LineBox[{{21, 32}, {21, 30}}], LineBox[{{23, 38}, {23, 36}}], 
   LineBox[{{23, 36}, {23, 34}}], LineBox[{{23, 34}, {23, 32}}], 
   LineBox[{{23, 32}, {23, 30}}], LineBox[{{25, 38}, {25, 36}}], 
   LineBox[{{25, 36}, {25, 34}}], LineBox[{{25, 34}, {25, 32}}], 
   LineBox[{{25, 32}, {25, 30}}], LineBox[{{27, 38}, {27, 36}}], 
   LineBox[{{27, 36}, {27, 34}}], LineBox[{{27, 34}, {27, 32}}], 
   LineBox[{{27, 32}, {27, 30}}], LineBox[{{29, 38}, {29, 36}}], 
   LineBox[{{29, 36}, {29, 34}}], LineBox[{{29, 34}, {29, 32}}], 
   LineBox[{{29, 32}, {29, 30}}], LineBox[{{31, 38}, {35, 38}}], 
   LineBox[{{31, 34}, {35, 34}}], LineBox[{{31, 30}, {35, 30}}], 
   LineBox[{{35, 38}, {39, 38}}], LineBox[{{35, 34}, {39, 34}}], 
   LineBox[{{35, 30}, {39, 30}}], LineBox[{{31, 38}, {31, 34}}], 
   LineBox[{{31, 34}, {31, 30}}], LineBox[{{35, 38}, {35, 34}}], 
   LineBox[{{35, 34}, {35, 30}}], LineBox[{{39, 38}, {39, 34}}], 
   LineBox[{{39, 34}, {39, 30}}], LineBox[{{41, 38}, {45, 38}}], 
   LineBox[{{41, 34}, {45, 34}}], LineBox[{{41, 30}, {45, 30}}], 
   LineBox[{{45, 38}, {49, 38}}], LineBox[{{45, 34}, {49, 34}}], 
   LineBox[{{45, 30}, {49, 30}}], LineBox[{{41, 38}, {41, 34}}], 
   LineBox[{{41, 34}, {41, 30}}], LineBox[{{45, 38}, {45, 34}}], 
   LineBox[{{45, 34}, {45, 30}}], LineBox[{{49, 38}, {49, 34}}], 
   LineBox[{{49, 34}, {49, 30}}], 
   LineBox[NCache[{{51, 38}, {Rational[157, 3], 38}}, {{51, 38}, {
      52.333333333333336`, 38}}]], 
   LineBox[NCache[{{51, Rational[110, 3]}, {
      Rational[157, 3], Rational[110, 3]}}, {{51, 36.666666666666664`}, {
      52.333333333333336`, 36.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[106, 3]}, {
      Rational[157, 3], Rational[106, 3]}}, {{51, 35.333333333333336`}, {
      52.333333333333336`, 35.333333333333336`}}]], 
   LineBox[NCache[{{51, 34}, {Rational[157, 3], 34}}, {{51, 34}, {
      52.333333333333336`, 34}}]], 
   LineBox[NCache[{{51, Rational[98, 3]}, {
      Rational[157, 3], Rational[98, 3]}}, {{51, 32.666666666666664`}, {
      52.333333333333336`, 32.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[94, 3]}, {
      Rational[157, 3], Rational[94, 3]}}, {{51, 31.333333333333332`}, {
      52.333333333333336`, 31.333333333333332`}}]], 
   LineBox[NCache[{{51, 30}, {Rational[157, 3], 30}}, {{51, 30}, {
      52.333333333333336`, 30}}]], 
   LineBox[NCache[{{Rational[157, 3], 38}, {Rational[161, 3], 38}}, {{
      52.333333333333336`, 38}, {53.666666666666664`, 38}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[110, 3]}, {
      Rational[161, 3], Rational[110, 3]}}, {{52.333333333333336`, 
     36.666666666666664`}, {53.666666666666664`, 36.666666666666664`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[106, 3]}, {
      Rational[161, 3], Rational[106, 3]}}, {{52.333333333333336`, 
     35.333333333333336`}, {53.666666666666664`, 35.333333333333336`}}]], 
   LineBox[NCache[{{Rational[157, 3], 34}, {Rational[161, 3], 34}}, {{
      52.333333333333336`, 34}, {53.666666666666664`, 34}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[98, 3]}, {
      Rational[161, 3], Rational[98, 3]}}, {{52.333333333333336`, 
     32.666666666666664`}, {53.666666666666664`, 32.666666666666664`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[94, 3]}, {
      Rational[161, 3], Rational[94, 3]}}, {{52.333333333333336`, 
     31.333333333333332`}, {53.666666666666664`, 31.333333333333332`}}]], 
   LineBox[NCache[{{Rational[157, 3], 30}, {Rational[161, 3], 30}}, {{
      52.333333333333336`, 30}, {53.666666666666664`, 30}}]], 
   LineBox[NCache[{{Rational[161, 3], 38}, {55, 38}}, {{
      53.666666666666664`, 38}, {55, 38}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[110, 3]}, {
      55, Rational[110, 3]}}, {{53.666666666666664`, 36.666666666666664`}, {
      55, 36.666666666666664`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[106, 3]}, {
      55, Rational[106, 3]}}, {{53.666666666666664`, 35.333333333333336`}, {
      55, 35.333333333333336`}}]], 
   LineBox[
    NCache[{{Rational[161, 3], 34}, {55, 34}}, {{53.666666666666664`, 34}, {
      55, 34}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[98, 3]}, {
      55, Rational[98, 3]}}, {{53.666666666666664`, 32.666666666666664`}, {
      55, 32.666666666666664`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[94, 3]}, {
      55, Rational[94, 3]}}, {{53.666666666666664`, 31.333333333333332`}, {
      55, 31.333333333333332`}}]], 
   LineBox[NCache[{{Rational[161, 3], 30}, {55, 30}}, {{
      53.666666666666664`, 30}, {55, 30}}]], 
   LineBox[NCache[{{55, 38}, {Rational[169, 3], 38}}, {{55, 38}, {
      56.333333333333336`, 38}}]], 
   LineBox[NCache[{{55, Rational[110, 3]}, {
      Rational[169, 3], Rational[110, 3]}}, {{55, 36.666666666666664`}, {
      56.333333333333336`, 36.666666666666664`}}]], 
   LineBox[NCache[{{55, Rational[106, 3]}, {
      Rational[169, 3], Rational[106, 3]}}, {{55, 35.333333333333336`}, {
      56.333333333333336`, 35.333333333333336`}}]], 
   LineBox[NCache[{{55, 34}, {Rational[169, 3], 34}}, {{55, 34}, {
      56.333333333333336`, 34}}]], 
   LineBox[NCache[{{55, Rational[98, 3]}, {
      Rational[169, 3], Rational[98, 3]}}, {{55, 32.666666666666664`}, {
      56.333333333333336`, 32.666666666666664`}}]], 
   LineBox[NCache[{{55, Rational[94, 3]}, {
      Rational[169, 3], Rational[94, 3]}}, {{55, 31.333333333333332`}, {
      56.333333333333336`, 31.333333333333332`}}]], 
   LineBox[NCache[{{55, 30}, {Rational[169, 3], 30}}, {{55, 30}, {
      56.333333333333336`, 30}}]], 
   LineBox[NCache[{{Rational[169, 3], 38}, {Rational[173, 3], 38}}, {{
      56.333333333333336`, 38}, {57.666666666666664`, 38}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[110, 3]}, {
      Rational[173, 3], Rational[110, 3]}}, {{56.333333333333336`, 
     36.666666666666664`}, {57.666666666666664`, 36.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[106, 3]}, {
      Rational[173, 3], Rational[106, 3]}}, {{56.333333333333336`, 
     35.333333333333336`}, {57.666666666666664`, 35.333333333333336`}}]], 
   LineBox[
    NCache[{{Rational[169, 3], 34}, {Rational[173, 3], 34}}, {{
      56.333333333333336`, 34}, {57.666666666666664`, 34}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[98, 3]}, {
      Rational[173, 3], Rational[98, 3]}}, {{56.333333333333336`, 
     32.666666666666664`}, {57.666666666666664`, 32.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[94, 3]}, {
      Rational[173, 3], Rational[94, 3]}}, {{56.333333333333336`, 
     31.333333333333332`}, {57.666666666666664`, 31.333333333333332`}}]], 
   LineBox[NCache[{{Rational[169, 3], 30}, {Rational[173, 3], 30}}, {{
      56.333333333333336`, 30}, {57.666666666666664`, 30}}]], 
   LineBox[NCache[{{Rational[173, 3], 38}, {59, 38}}, {{
      57.666666666666664`, 38}, {59, 38}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[110, 3]}, {
      59, Rational[110, 3]}}, {{57.666666666666664`, 36.666666666666664`}, {
      59, 36.666666666666664`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[106, 3]}, {
      59, Rational[106, 3]}}, {{57.666666666666664`, 35.333333333333336`}, {
      59, 35.333333333333336`}}]], 
   LineBox[NCache[{{Rational[173, 3], 34}, {59, 34}}, {{
      57.666666666666664`, 34}, {59, 34}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[98, 3]}, {
      59, Rational[98, 3]}}, {{57.666666666666664`, 32.666666666666664`}, {
      59, 32.666666666666664`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[94, 3]}, {
      59, Rational[94, 3]}}, {{57.666666666666664`, 31.333333333333332`}, {
      59, 31.333333333333332`}}]], 
   LineBox[NCache[{{Rational[173, 3], 30}, {59, 30}}, {{
      57.666666666666664`, 30}, {59, 30}}]], 
   LineBox[NCache[{{51, 38}, {51, Rational[110, 3]}}, {{51, 38}, {
      51, 36.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[110, 3]}, {51, Rational[106, 3]}}, {{
      51, 36.666666666666664`}, {51, 35.333333333333336`}}]], 
   LineBox[NCache[{{51, Rational[106, 3]}, {51, 34}}, {{
      51, 35.333333333333336`}, {51, 34}}]], 
   LineBox[NCache[{{51, 34}, {51, Rational[98, 3]}}, {{51, 34}, {
      51, 32.666666666666664`}}]], 
   LineBox[NCache[{{51, Rational[98, 3]}, {51, Rational[94, 3]}}, {{
      51, 32.666666666666664`}, {51, 31.333333333333332`}}]], 
   LineBox[NCache[{{51, Rational[94, 3]}, {51, 30}}, {{
      51, 31.333333333333332`}, {51, 30}}]], 
   LineBox[NCache[{{Rational[157, 3], 38}, {
      Rational[157, 3], Rational[110, 3]}}, {{52.333333333333336`, 38}, {
      52.333333333333336`, 36.666666666666664`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[110, 3]}, {
      Rational[157, 3], Rational[106, 3]}}, {{52.333333333333336`, 
     36.666666666666664`}, {52.333333333333336`, 35.333333333333336`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[106, 3]}, {
      Rational[157, 3], 34}}, {{52.333333333333336`, 35.333333333333336`}, {
      52.333333333333336`, 34}}]], 
   LineBox[NCache[{{Rational[157, 3], 34}, {
      Rational[157, 3], Rational[98, 3]}}, {{52.333333333333336`, 34}, {
      52.333333333333336`, 32.666666666666664`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[98, 3]}, {
      Rational[157, 3], Rational[94, 3]}}, {{52.333333333333336`, 
     32.666666666666664`}, {52.333333333333336`, 31.333333333333332`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[94, 3]}, {
      Rational[157, 3], 30}}, {{52.333333333333336`, 31.333333333333332`}, {
      52.333333333333336`, 30}}]], 
   LineBox[NCache[{{Rational[161, 3], 38}, {
      Rational[161, 3], Rational[110, 3]}}, {{53.666666666666664`, 38}, {
      53.666666666666664`, 36.666666666666664`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[110, 3]}, {
      Rational[161, 3], Rational[106, 3]}}, {{53.666666666666664`, 
     36.666666666666664`}, {53.666666666666664`, 35.333333333333336`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[106, 3]}, {
      Rational[161, 3], 34}}, {{53.666666666666664`, 35.333333333333336`}, {
      53.666666666666664`, 34}}]], 
   LineBox[NCache[{{Rational[161, 3], 34}, {
      Rational[161, 3], Rational[98, 3]}}, {{53.666666666666664`, 34}, {
      53.666666666666664`, 32.666666666666664`}}]], 
   LineBox[
    NCache[{{Rational[161, 3], Rational[98, 3]}, {
      Rational[161, 3], Rational[94, 3]}}, {{53.666666666666664`, 
     32.666666666666664`}, {53.666666666666664`, 31.333333333333332`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[94, 3]}, {
      Rational[161, 3], 30}}, {{53.666666666666664`, 31.333333333333332`}, {
      53.666666666666664`, 30}}]], 
   LineBox[NCache[{{55, 38}, {55, Rational[110, 3]}}, {{55, 38}, {
      55, 36.666666666666664`}}]], 
   LineBox[NCache[{{55, Rational[110, 3]}, {55, Rational[106, 3]}}, {{
      55, 36.666666666666664`}, {55, 35.333333333333336`}}]], 
   LineBox[NCache[{{55, Rational[106, 3]}, {55, 34}}, {{
      55, 35.333333333333336`}, {55, 34}}]], 
   LineBox[NCache[{{55, 34}, {55, Rational[98, 3]}}, {{55, 34}, {
      55, 32.666666666666664`}}]], 
   LineBox[NCache[{{55, Rational[98, 3]}, {55, Rational[94, 3]}}, {{
      55, 32.666666666666664`}, {55, 31.333333333333332`}}]], 
   LineBox[NCache[{{55, Rational[94, 3]}, {55, 30}}, {{
      55, 31.333333333333332`}, {55, 30}}]], 
   LineBox[NCache[{{Rational[169, 3], 38}, {
      Rational[169, 3], Rational[110, 3]}}, {{56.333333333333336`, 38}, {
      56.333333333333336`, 36.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[110, 3]}, {
      Rational[169, 3], Rational[106, 3]}}, {{56.333333333333336`, 
     36.666666666666664`}, {56.333333333333336`, 35.333333333333336`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[106, 3]}, {
      Rational[169, 3], 34}}, {{56.333333333333336`, 35.333333333333336`}, {
      56.333333333333336`, 34}}]], 
   LineBox[NCache[{{Rational[169, 3], 34}, {
      Rational[169, 3], Rational[98, 3]}}, {{56.333333333333336`, 34}, {
      56.333333333333336`, 32.666666666666664`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[98, 3]}, {
      Rational[169, 3], Rational[94, 3]}}, {{56.333333333333336`, 
     32.666666666666664`}, {56.333333333333336`, 31.333333333333332`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[94, 3]}, {
      Rational[169, 3], 30}}, {{56.333333333333336`, 31.333333333333332`}, {
      56.333333333333336`, 30}}]], 
   LineBox[NCache[{{Rational[173, 3], 38}, {
      Rational[173, 3], Rational[110, 3]}}, {{57.666666666666664`, 38}, {
      57.666666666666664`, 36.666666666666664`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[110, 3]}, {
      Rational[173, 3], Rational[106, 3]}}, {{57.666666666666664`, 
     36.666666666666664`}, {57.666666666666664`, 35.333333333333336`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[106, 3]}, {
      Rational[173, 3], 34}}, {{57.666666666666664`, 35.333333333333336`}, {
      57.666666666666664`, 34}}]], 
   LineBox[NCache[{{Rational[173, 3], 34}, {
      Rational[173, 3], Rational[98, 3]}}, {{57.666666666666664`, 34}, {
      57.666666666666664`, 32.666666666666664`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[98, 3]}, {
      Rational[173, 3], Rational[94, 3]}}, {{57.666666666666664`, 
     32.666666666666664`}, {57.666666666666664`, 31.333333333333332`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[94, 3]}, {
      Rational[173, 3], 30}}, {{57.666666666666664`, 31.333333333333332`}, {
      57.666666666666664`, 30}}]], 
   LineBox[NCache[{{59, 38}, {59, Rational[110, 3]}}, {{59, 38}, {
      59, 36.666666666666664`}}]], 
   LineBox[NCache[{{59, Rational[110, 3]}, {59, Rational[106, 3]}}, {{
      59, 36.666666666666664`}, {59, 35.333333333333336`}}]], 
   LineBox[NCache[{{59, Rational[106, 3]}, {59, 34}}, {{
      59, 35.333333333333336`}, {59, 34}}]], 
   LineBox[NCache[{{59, 34}, {59, Rational[98, 3]}}, {{59, 34}, {
      59, 32.666666666666664`}}]], 
   LineBox[NCache[{{59, Rational[98, 3]}, {59, Rational[94, 3]}}, {{
      59, 32.666666666666664`}, {59, 31.333333333333332`}}]], 
   LineBox[NCache[{{59, Rational[94, 3]}, {59, 30}}, {{
      59, 31.333333333333332`}, {59, 30}}]], LineBox[{{61, 38}, {63, 38}}], 
   LineBox[{{61, 36}, {63, 36}}], LineBox[{{61, 34}, {63, 34}}], 
   LineBox[{{61, 32}, {63, 32}}], LineBox[{{61, 30}, {63, 30}}], 
   LineBox[{{63, 38}, {65, 38}}], LineBox[{{63, 36}, {65, 36}}], 
   LineBox[{{63, 34}, {65, 34}}], LineBox[{{63, 32}, {65, 32}}], 
   LineBox[{{63, 30}, {65, 30}}], LineBox[{{65, 38}, {67, 38}}], 
   LineBox[{{65, 36}, {67, 36}}], LineBox[{{65, 34}, {67, 34}}], 
   LineBox[{{65, 32}, {67, 32}}], LineBox[{{65, 30}, {67, 30}}], 
   LineBox[{{67, 38}, {69, 38}}], LineBox[{{67, 36}, {69, 36}}], 
   LineBox[{{67, 34}, {69, 34}}], LineBox[{{67, 32}, {69, 32}}], 
   LineBox[{{67, 30}, {69, 30}}], LineBox[{{61, 38}, {61, 36}}], 
   LineBox[{{61, 36}, {61, 34}}], LineBox[{{61, 34}, {61, 32}}], 
   LineBox[{{61, 32}, {61, 30}}], LineBox[{{63, 38}, {63, 36}}], 
   LineBox[{{63, 36}, {63, 34}}], LineBox[{{63, 34}, {63, 32}}], 
   LineBox[{{63, 32}, {63, 30}}], LineBox[{{65, 38}, {65, 36}}], 
   LineBox[{{65, 36}, {65, 34}}], LineBox[{{65, 34}, {65, 32}}], 
   LineBox[{{65, 32}, {65, 30}}], LineBox[{{67, 38}, {67, 36}}], 
   LineBox[{{67, 36}, {67, 34}}], LineBox[{{67, 34}, {67, 32}}], 
   LineBox[{{67, 32}, {67, 30}}], LineBox[{{69, 38}, {69, 36}}], 
   LineBox[{{69, 36}, {69, 34}}], LineBox[{{69, 34}, {69, 32}}], 
   LineBox[{{69, 32}, {69, 30}}], 
   LineBox[NCache[{{11, 28}, {Rational[41, 3], 28}}, {{11, 28}, {
      13.666666666666666`, 28}}]], 
   LineBox[NCache[{{11, Rational[76, 3]}, {
      Rational[41, 3], Rational[76, 3]}}, {{11, 25.333333333333332`}, {
      13.666666666666666`, 25.333333333333332`}}]], 
   LineBox[NCache[{{11, Rational[68, 3]}, {
      Rational[41, 3], Rational[68, 3]}}, {{11, 22.666666666666668`}, {
      13.666666666666666`, 22.666666666666668`}}]], 
   LineBox[NCache[{{11, 20}, {Rational[41, 3], 20}}, {{11, 20}, {
      13.666666666666666`, 20}}]], 
   LineBox[NCache[{{Rational[41, 3], 28}, {Rational[49, 3], 28}}, {{
      13.666666666666666`, 28}, {16.333333333333332`, 28}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[76, 3]}, {
      Rational[49, 3], Rational[76, 3]}}, {{13.666666666666666`, 
     25.333333333333332`}, {16.333333333333332`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[68, 3]}, {
      Rational[49, 3], Rational[68, 3]}}, {{13.666666666666666`, 
     22.666666666666668`}, {16.333333333333332`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[41, 3], 20}, {Rational[49, 3], 20}}, {{
      13.666666666666666`, 20}, {16.333333333333332`, 20}}]], 
   LineBox[NCache[{{Rational[49, 3], 28}, {19, 28}}, {{
      16.333333333333332`, 28}, {19, 28}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[76, 3]}, {
      19, Rational[76, 3]}}, {{16.333333333333332`, 25.333333333333332`}, {
      19, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[68, 3]}, {
      19, Rational[68, 3]}}, {{16.333333333333332`, 22.666666666666668`}, {
      19, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[49, 3], 20}, {19, 20}}, {{
      16.333333333333332`, 20}, {19, 20}}]], 
   LineBox[NCache[{{11, 28}, {11, Rational[76, 3]}}, {{11, 28}, {
      11, 25.333333333333332`}}]], 
   LineBox[NCache[{{11, Rational[76, 3]}, {11, Rational[68, 3]}}, {{
      11, 25.333333333333332`}, {11, 22.666666666666668`}}]], 
   LineBox[NCache[{{11, Rational[68, 3]}, {11, 20}}, {{
      11, 22.666666666666668`}, {11, 20}}]], 
   LineBox[NCache[{{Rational[41, 3], 28}, {
      Rational[41, 3], Rational[76, 3]}}, {{13.666666666666666`, 28}, {
      13.666666666666666`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[76, 3]}, {
      Rational[41, 3], Rational[68, 3]}}, {{13.666666666666666`, 
     25.333333333333332`}, {13.666666666666666`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[68, 3]}, {
      Rational[41, 3], 20}}, {{13.666666666666666`, 22.666666666666668`}, {
      13.666666666666666`, 20}}]], 
   LineBox[NCache[{{Rational[49, 3], 28}, {
      Rational[49, 3], Rational[76, 3]}}, {{16.333333333333332`, 28}, {
      16.333333333333332`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[76, 3]}, {
      Rational[49, 3], Rational[68, 3]}}, {{16.333333333333332`, 
     25.333333333333332`}, {16.333333333333332`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[68, 3]}, {
      Rational[49, 3], 20}}, {{16.333333333333332`, 22.666666666666668`}, {
      16.333333333333332`, 20}}]], 
   LineBox[NCache[{{19, 28}, {19, Rational[76, 3]}}, {{19, 28}, {
      19, 25.333333333333332`}}]], 
   LineBox[NCache[{{19, Rational[76, 3]}, {19, Rational[68, 3]}}, {{
      19, 25.333333333333332`}, {19, 22.666666666666668`}}]], 
   LineBox[NCache[{{19, Rational[68, 3]}, {19, 20}}, {{
      19, 22.666666666666668`}, {19, 20}}]], LineBox[{{21, 28}, {23, 28}}], 
   LineBox[{{21, 26}, {23, 26}}], LineBox[{{21, 24}, {23, 24}}], 
   LineBox[{{21, 22}, {23, 22}}], LineBox[{{21, 20}, {23, 20}}], 
   LineBox[{{23, 28}, {25, 28}}], LineBox[{{23, 26}, {25, 26}}], 
   LineBox[{{23, 24}, {25, 24}}], LineBox[{{23, 22}, {25, 22}}], 
   LineBox[{{23, 20}, {25, 20}}], LineBox[{{25, 28}, {27, 28}}], 
   LineBox[{{25, 26}, {27, 26}}], LineBox[{{25, 24}, {27, 24}}], 
   LineBox[{{25, 22}, {27, 22}}], LineBox[{{25, 20}, {27, 20}}], 
   LineBox[{{27, 28}, {29, 28}}], LineBox[{{27, 26}, {29, 26}}], 
   LineBox[{{27, 24}, {29, 24}}], LineBox[{{27, 22}, {29, 22}}], 
   LineBox[{{27, 20}, {29, 20}}], LineBox[{{21, 28}, {21, 26}}], 
   LineBox[{{21, 26}, {21, 24}}], LineBox[{{21, 24}, {21, 22}}], 
   LineBox[{{21, 22}, {21, 20}}], LineBox[{{23, 28}, {23, 26}}], 
   LineBox[{{23, 26}, {23, 24}}], LineBox[{{23, 24}, {23, 22}}], 
   LineBox[{{23, 22}, {23, 20}}], LineBox[{{25, 28}, {25, 26}}], 
   LineBox[{{25, 26}, {25, 24}}], LineBox[{{25, 24}, {25, 22}}], 
   LineBox[{{25, 22}, {25, 20}}], LineBox[{{27, 28}, {27, 26}}], 
   LineBox[{{27, 26}, {27, 24}}], LineBox[{{27, 24}, {27, 22}}], 
   LineBox[{{27, 22}, {27, 20}}], LineBox[{{29, 28}, {29, 26}}], 
   LineBox[{{29, 26}, {29, 24}}], LineBox[{{29, 24}, {29, 22}}], 
   LineBox[{{29, 22}, {29, 20}}], LineBox[{{31, 28}, {35, 28}}], 
   LineBox[{{31, 24}, {35, 24}}], LineBox[{{31, 20}, {35, 20}}], 
   LineBox[{{35, 28}, {39, 28}}], LineBox[{{35, 24}, {39, 24}}], 
   LineBox[{{35, 20}, {39, 20}}], LineBox[{{31, 28}, {31, 24}}], 
   LineBox[{{31, 24}, {31, 20}}], LineBox[{{35, 28}, {35, 24}}], 
   LineBox[{{35, 24}, {35, 20}}], LineBox[{{39, 28}, {39, 24}}], 
   LineBox[{{39, 24}, {39, 20}}], LineBox[{{41, 28}, {45, 28}}], 
   LineBox[{{41, 24}, {45, 24}}], LineBox[{{41, 20}, {45, 20}}], 
   LineBox[{{45, 28}, {49, 28}}], LineBox[{{45, 24}, {49, 24}}], 
   LineBox[{{45, 20}, {49, 20}}], LineBox[{{41, 28}, {41, 24}}], 
   LineBox[{{41, 24}, {41, 20}}], LineBox[{{45, 28}, {45, 24}}], 
   LineBox[{{45, 24}, {45, 20}}], LineBox[{{49, 28}, {49, 24}}], 
   LineBox[{{49, 24}, {49, 20}}], 
   LineBox[NCache[{{51, 28}, {Rational[157, 3], 28}}, {{51, 28}, {
      52.333333333333336`, 28}}]], 
   LineBox[NCache[{{51, Rational[80, 3]}, {
      Rational[157, 3], Rational[80, 3]}}, {{51, 26.666666666666668`}, {
      52.333333333333336`, 26.666666666666668`}}]], 
   LineBox[NCache[{{51, Rational[76, 3]}, {
      Rational[157, 3], Rational[76, 3]}}, {{51, 25.333333333333332`}, {
      52.333333333333336`, 25.333333333333332`}}]], 
   LineBox[NCache[{{51, 24}, {Rational[157, 3], 24}}, {{51, 24}, {
      52.333333333333336`, 24}}]], 
   LineBox[NCache[{{51, Rational[68, 3]}, {
      Rational[157, 3], Rational[68, 3]}}, {{51, 22.666666666666668`}, {
      52.333333333333336`, 22.666666666666668`}}]], 
   LineBox[NCache[{{51, Rational[64, 3]}, {
      Rational[157, 3], Rational[64, 3]}}, {{51, 21.333333333333332`}, {
      52.333333333333336`, 21.333333333333332`}}]], 
   LineBox[NCache[{{51, 20}, {Rational[157, 3], 20}}, {{51, 20}, {
      52.333333333333336`, 20}}]], 
   LineBox[NCache[{{Rational[157, 3], 28}, {Rational[161, 3], 28}}, {{
      52.333333333333336`, 28}, {53.666666666666664`, 28}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[80, 3]}, {
      Rational[161, 3], Rational[80, 3]}}, {{52.333333333333336`, 
     26.666666666666668`}, {53.666666666666664`, 26.666666666666668`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[76, 3]}, {
      Rational[161, 3], Rational[76, 3]}}, {{52.333333333333336`, 
     25.333333333333332`}, {53.666666666666664`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[157, 3], 24}, {Rational[161, 3], 24}}, {{
      52.333333333333336`, 24}, {53.666666666666664`, 24}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[68, 3]}, {
      Rational[161, 3], Rational[68, 3]}}, {{52.333333333333336`, 
     22.666666666666668`}, {53.666666666666664`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[64, 3]}, {
      Rational[161, 3], Rational[64, 3]}}, {{52.333333333333336`, 
     21.333333333333332`}, {53.666666666666664`, 21.333333333333332`}}]], 
   LineBox[NCache[{{Rational[157, 3], 20}, {Rational[161, 3], 20}}, {{
      52.333333333333336`, 20}, {53.666666666666664`, 20}}]], 
   LineBox[NCache[{{Rational[161, 3], 28}, {55, 28}}, {{
      53.666666666666664`, 28}, {55, 28}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[80, 3]}, {
      55, Rational[80, 3]}}, {{53.666666666666664`, 26.666666666666668`}, {
      55, 26.666666666666668`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[76, 3]}, {
      55, Rational[76, 3]}}, {{53.666666666666664`, 25.333333333333332`}, {
      55, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[161, 3], 24}, {55, 24}}, {{
      53.666666666666664`, 24}, {55, 24}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[68, 3]}, {
      55, Rational[68, 3]}}, {{53.666666666666664`, 22.666666666666668`}, {
      55, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[64, 3]}, {
      55, Rational[64, 3]}}, {{53.666666666666664`, 21.333333333333332`}, {
      55, 21.333333333333332`}}]], 
   LineBox[NCache[{{Rational[161, 3], 20}, {55, 20}}, {{
      53.666666666666664`, 20}, {55, 20}}]], 
   LineBox[NCache[{{55, 28}, {Rational[169, 3], 28}}, {{55, 28}, {
      56.333333333333336`, 28}}]], 
   LineBox[NCache[{{55, Rational[80, 3]}, {
      Rational[169, 3], Rational[80, 3]}}, {{55, 26.666666666666668`}, {
      56.333333333333336`, 26.666666666666668`}}]], 
   LineBox[NCache[{{55, Rational[76, 3]}, {
      Rational[169, 3], Rational[76, 3]}}, {{55, 25.333333333333332`}, {
      56.333333333333336`, 25.333333333333332`}}]], 
   LineBox[NCache[{{55, 24}, {Rational[169, 3], 24}}, {{55, 24}, {
      56.333333333333336`, 24}}]], 
   LineBox[NCache[{{55, Rational[68, 3]}, {
      Rational[169, 3], Rational[68, 3]}}, {{55, 22.666666666666668`}, {
      56.333333333333336`, 22.666666666666668`}}]], 
   LineBox[NCache[{{55, Rational[64, 3]}, {
      Rational[169, 3], Rational[64, 3]}}, {{55, 21.333333333333332`}, {
      56.333333333333336`, 21.333333333333332`}}]], 
   LineBox[NCache[{{55, 20}, {Rational[169, 3], 20}}, {{55, 20}, {
      56.333333333333336`, 20}}]], 
   LineBox[NCache[{{Rational[169, 3], 28}, {Rational[173, 3], 28}}, {{
      56.333333333333336`, 28}, {57.666666666666664`, 28}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[80, 3]}, {
      Rational[173, 3], Rational[80, 3]}}, {{56.333333333333336`, 
     26.666666666666668`}, {57.666666666666664`, 26.666666666666668`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[76, 3]}, {
      Rational[173, 3], Rational[76, 3]}}, {{56.333333333333336`, 
     25.333333333333332`}, {57.666666666666664`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[169, 3], 24}, {Rational[173, 3], 24}}, {{
      56.333333333333336`, 24}, {57.666666666666664`, 24}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[68, 3]}, {
      Rational[173, 3], Rational[68, 3]}}, {{56.333333333333336`, 
     22.666666666666668`}, {57.666666666666664`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[64, 3]}, {
      Rational[173, 3], Rational[64, 3]}}, {{56.333333333333336`, 
     21.333333333333332`}, {57.666666666666664`, 21.333333333333332`}}]], 
   LineBox[NCache[{{Rational[169, 3], 20}, {Rational[173, 3], 20}}, {{
      56.333333333333336`, 20}, {57.666666666666664`, 20}}]], 
   LineBox[NCache[{{Rational[173, 3], 28}, {59, 28}}, {{
      57.666666666666664`, 28}, {59, 28}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[80, 3]}, {
      59, Rational[80, 3]}}, {{57.666666666666664`, 26.666666666666668`}, {
      59, 26.666666666666668`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[76, 3]}, {
      59, Rational[76, 3]}}, {{57.666666666666664`, 25.333333333333332`}, {
      59, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[173, 3], 24}, {59, 24}}, {{
      57.666666666666664`, 24}, {59, 24}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[68, 3]}, {
      59, Rational[68, 3]}}, {{57.666666666666664`, 22.666666666666668`}, {
      59, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[64, 3]}, {
      59, Rational[64, 3]}}, {{57.666666666666664`, 21.333333333333332`}, {
      59, 21.333333333333332`}}]], 
   LineBox[NCache[{{Rational[173, 3], 20}, {59, 20}}, {{
      57.666666666666664`, 20}, {59, 20}}]], 
   LineBox[NCache[{{51, 28}, {51, Rational[80, 3]}}, {{51, 28}, {
      51, 26.666666666666668`}}]], 
   LineBox[NCache[{{51, Rational[80, 3]}, {51, Rational[76, 3]}}, {{
      51, 26.666666666666668`}, {51, 25.333333333333332`}}]], 
   LineBox[NCache[{{51, Rational[76, 3]}, {51, 24}}, {{
      51, 25.333333333333332`}, {51, 24}}]], 
   LineBox[NCache[{{51, 24}, {51, Rational[68, 3]}}, {{51, 24}, {
      51, 22.666666666666668`}}]], 
   LineBox[NCache[{{51, Rational[68, 3]}, {51, Rational[64, 3]}}, {{
      51, 22.666666666666668`}, {51, 21.333333333333332`}}]], 
   LineBox[NCache[{{51, Rational[64, 3]}, {51, 20}}, {{
      51, 21.333333333333332`}, {51, 20}}]], 
   LineBox[NCache[{{Rational[157, 3], 28}, {
      Rational[157, 3], Rational[80, 3]}}, {{52.333333333333336`, 28}, {
      52.333333333333336`, 26.666666666666668`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[80, 3]}, {
      Rational[157, 3], Rational[76, 3]}}, {{52.333333333333336`, 
     26.666666666666668`}, {52.333333333333336`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[76, 3]}, {
      Rational[157, 3], 24}}, {{52.333333333333336`, 25.333333333333332`}, {
      52.333333333333336`, 24}}]], 
   LineBox[NCache[{{Rational[157, 3], 24}, {
      Rational[157, 3], Rational[68, 3]}}, {{52.333333333333336`, 24}, {
      52.333333333333336`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[68, 3]}, {
      Rational[157, 3], Rational[64, 3]}}, {{52.333333333333336`, 
     22.666666666666668`}, {52.333333333333336`, 21.333333333333332`}}]], 
   LineBox[NCache[{{Rational[157, 3], Rational[64, 3]}, {
      Rational[157, 3], 20}}, {{52.333333333333336`, 21.333333333333332`}, {
      52.333333333333336`, 20}}]], 
   LineBox[NCache[{{Rational[161, 3], 28}, {
      Rational[161, 3], Rational[80, 3]}}, {{53.666666666666664`, 28}, {
      53.666666666666664`, 26.666666666666668`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[80, 3]}, {
      Rational[161, 3], Rational[76, 3]}}, {{53.666666666666664`, 
     26.666666666666668`}, {53.666666666666664`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[76, 3]}, {
      Rational[161, 3], 24}}, {{53.666666666666664`, 25.333333333333332`}, {
      53.666666666666664`, 24}}]], 
   LineBox[NCache[{{Rational[161, 3], 24}, {
      Rational[161, 3], Rational[68, 3]}}, {{53.666666666666664`, 24}, {
      53.666666666666664`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[68, 3]}, {
      Rational[161, 3], Rational[64, 3]}}, {{53.666666666666664`, 
     22.666666666666668`}, {53.666666666666664`, 21.333333333333332`}}]], 
   LineBox[NCache[{{Rational[161, 3], Rational[64, 3]}, {
      Rational[161, 3], 20}}, {{53.666666666666664`, 21.333333333333332`}, {
      53.666666666666664`, 20}}]], 
   LineBox[NCache[{{55, 28}, {55, Rational[80, 3]}}, {{55, 28}, {
      55, 26.666666666666668`}}]], 
   LineBox[NCache[{{55, Rational[80, 3]}, {55, Rational[76, 3]}}, {{
      55, 26.666666666666668`}, {55, 25.333333333333332`}}]], 
   LineBox[NCache[{{55, Rational[76, 3]}, {55, 24}}, {{
      55, 25.333333333333332`}, {55, 24}}]], 
   LineBox[NCache[{{55, 24}, {55, Rational[68, 3]}}, {{55, 24}, {
      55, 22.666666666666668`}}]], 
   LineBox[NCache[{{55, Rational[68, 3]}, {55, Rational[64, 3]}}, {{
      55, 22.666666666666668`}, {55, 21.333333333333332`}}]], 
   LineBox[NCache[{{55, Rational[64, 3]}, {55, 20}}, {{
      55, 21.333333333333332`}, {55, 20}}]], 
   LineBox[NCache[{{Rational[169, 3], 28}, {
      Rational[169, 3], Rational[80, 3]}}, {{56.333333333333336`, 28}, {
      56.333333333333336`, 26.666666666666668`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[80, 3]}, {
      Rational[169, 3], Rational[76, 3]}}, {{56.333333333333336`, 
     26.666666666666668`}, {56.333333333333336`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[76, 3]}, {
      Rational[169, 3], 24}}, {{56.333333333333336`, 25.333333333333332`}, {
      56.333333333333336`, 24}}]], 
   LineBox[NCache[{{Rational[169, 3], 24}, {
      Rational[169, 3], Rational[68, 3]}}, {{56.333333333333336`, 24}, {
      56.333333333333336`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[68, 3]}, {
      Rational[169, 3], Rational[64, 3]}}, {{56.333333333333336`, 
     22.666666666666668`}, {56.333333333333336`, 21.333333333333332`}}]], 
   LineBox[NCache[{{Rational[169, 3], Rational[64, 3]}, {
      Rational[169, 3], 20}}, {{56.333333333333336`, 21.333333333333332`}, {
      56.333333333333336`, 20}}]], 
   LineBox[NCache[{{Rational[173, 3], 28}, {
      Rational[173, 3], Rational[80, 3]}}, {{57.666666666666664`, 28}, {
      57.666666666666664`, 26.666666666666668`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[80, 3]}, {
      Rational[173, 3], Rational[76, 3]}}, {{57.666666666666664`, 
     26.666666666666668`}, {57.666666666666664`, 25.333333333333332`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[76, 3]}, {
      Rational[173, 3], 24}}, {{57.666666666666664`, 25.333333333333332`}, {
      57.666666666666664`, 24}}]], 
   LineBox[NCache[{{Rational[173, 3], 24}, {
      Rational[173, 3], Rational[68, 3]}}, {{57.666666666666664`, 24}, {
      57.666666666666664`, 22.666666666666668`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[68, 3]}, {
      Rational[173, 3], Rational[64, 3]}}, {{57.666666666666664`, 
     22.666666666666668`}, {57.666666666666664`, 21.333333333333332`}}]], 
   LineBox[NCache[{{Rational[173, 3], Rational[64, 3]}, {
      Rational[173, 3], 20}}, {{57.666666666666664`, 21.333333333333332`}, {
      57.666666666666664`, 20}}]], 
   LineBox[
    NCache[{{59, 28}, {59, Rational[80, 3]}}, {{59, 28}, {
      59, 26.666666666666668`}}]], 
   LineBox[NCache[{{59, Rational[80, 3]}, {59, Rational[76, 3]}}, {{
      59, 26.666666666666668`}, {59, 25.333333333333332`}}]], 
   LineBox[NCache[{{59, Rational[76, 3]}, {59, 24}}, {{
      59, 25.333333333333332`}, {59, 24}}]], 
   LineBox[NCache[{{59, 24}, {59, Rational[68, 3]}}, {{59, 24}, {
      59, 22.666666666666668`}}]], 
   LineBox[NCache[{{59, Rational[68, 3]}, {59, Rational[64, 3]}}, {{
      59, 22.666666666666668`}, {59, 21.333333333333332`}}]], 
   LineBox[NCache[{{59, Rational[64, 3]}, {59, 20}}, {{
      59, 21.333333333333332`}, {59, 20}}]], LineBox[{{61, 28}, {63, 28}}], 
   LineBox[{{61, 26}, {63, 26}}], LineBox[{{61, 24}, {63, 24}}], 
   LineBox[{{61, 22}, {63, 22}}], LineBox[{{61, 20}, {63, 20}}], 
   LineBox[{{63, 28}, {65, 28}}], LineBox[{{63, 26}, {65, 26}}], 
   LineBox[{{63, 24}, {65, 24}}], LineBox[{{63, 22}, {65, 22}}], 
   LineBox[{{63, 20}, {65, 20}}], LineBox[{{65, 28}, {67, 28}}], 
   LineBox[{{65, 26}, {67, 26}}], LineBox[{{65, 24}, {67, 24}}], 
   LineBox[{{65, 22}, {67, 22}}], LineBox[{{65, 20}, {67, 20}}], 
   LineBox[{{67, 28}, {69, 28}}], LineBox[{{67, 26}, {69, 26}}], 
   LineBox[{{67, 24}, {69, 24}}], LineBox[{{67, 22}, {69, 22}}], 
   LineBox[{{67, 20}, {69, 20}}], LineBox[{{61, 28}, {61, 26}}], 
   LineBox[{{61, 26}, {61, 24}}], LineBox[{{61, 24}, {61, 22}}], 
   LineBox[{{61, 22}, {61, 20}}], LineBox[{{63, 28}, {63, 26}}], 
   LineBox[{{63, 26}, {63, 24}}], LineBox[{{63, 24}, {63, 22}}], 
   LineBox[{{63, 22}, {63, 20}}], LineBox[{{65, 28}, {65, 26}}], 
   LineBox[{{65, 26}, {65, 24}}], LineBox[{{65, 24}, {65, 22}}], 
   LineBox[{{65, 22}, {65, 20}}], LineBox[{{67, 28}, {67, 26}}], 
   LineBox[{{67, 26}, {67, 24}}], LineBox[{{67, 24}, {67, 22}}], 
   LineBox[{{67, 22}, {67, 20}}], LineBox[{{69, 28}, {69, 26}}], 
   LineBox[{{69, 26}, {69, 24}}], LineBox[{{69, 24}, {69, 22}}], 
   LineBox[{{69, 22}, {69, 20}}], LineBox[{{11, 18}, {13, 18}}], 
   LineBox[{{11, 16}, {13, 16}}], LineBox[{{11, 14}, {13, 14}}], 
   LineBox[{{11, 12}, {13, 12}}], LineBox[{{11, 10}, {13, 10}}], 
   LineBox[{{13, 18}, {15, 18}}], LineBox[{{13, 16}, {15, 16}}], 
   LineBox[{{13, 14}, {15, 14}}], LineBox[{{13, 12}, {15, 12}}], 
   LineBox[{{13, 10}, {15, 10}}], LineBox[{{15, 18}, {17, 18}}], 
   LineBox[{{15, 16}, {17, 16}}], LineBox[{{15, 14}, {17, 14}}], 
   LineBox[{{15, 12}, {17, 12}}], LineBox[{{15, 10}, {17, 10}}], 
   LineBox[{{17, 18}, {19, 18}}], LineBox[{{17, 16}, {19, 16}}], 
   LineBox[{{17, 14}, {19, 14}}], LineBox[{{17, 12}, {19, 12}}], 
   LineBox[{{17, 10}, {19, 10}}], LineBox[{{11, 18}, {11, 16}}], 
   LineBox[{{11, 16}, {11, 14}}], LineBox[{{11, 14}, {11, 12}}], 
   LineBox[{{11, 12}, {11, 10}}], LineBox[{{13, 18}, {13, 16}}], 
   LineBox[{{13, 16}, {13, 14}}], LineBox[{{13, 14}, {13, 12}}], 
   LineBox[{{13, 12}, {13, 10}}], LineBox[{{15, 18}, {15, 16}}], 
   LineBox[{{15, 16}, {15, 14}}], LineBox[{{15, 14}, {15, 12}}], 
   LineBox[{{15, 12}, {15, 10}}], LineBox[{{17, 18}, {17, 16}}], 
   LineBox[{{17, 16}, {17, 14}}], LineBox[{{17, 14}, {17, 12}}], 
   LineBox[{{17, 12}, {17, 10}}], LineBox[{{19, 18}, {19, 16}}], 
   LineBox[{{19, 16}, {19, 14}}], LineBox[{{19, 14}, {19, 12}}], 
   LineBox[{{19, 12}, {19, 10}}], LineBox[{{21, 18}, {23, 18}}], 
   LineBox[{{21, 16}, {23, 16}}], LineBox[{{21, 14}, {23, 14}}], 
   LineBox[{{21, 12}, {23, 12}}], LineBox[{{21, 10}, {23, 10}}], 
   LineBox[{{23, 18}, {25, 18}}], LineBox[{{23, 16}, {25, 16}}], 
   LineBox[{{23, 14}, {25, 14}}], LineBox[{{23, 12}, {25, 12}}], 
   LineBox[{{23, 10}, {25, 10}}], LineBox[{{25, 18}, {27, 18}}], 
   LineBox[{{25, 16}, {27, 16}}], LineBox[{{25, 14}, {27, 14}}], 
   LineBox[{{25, 12}, {27, 12}}], LineBox[{{25, 10}, {27, 10}}], 
   LineBox[{{27, 18}, {29, 18}}], LineBox[{{27, 16}, {29, 16}}], 
   LineBox[{{27, 14}, {29, 14}}], LineBox[{{27, 12}, {29, 12}}], 
   LineBox[{{27, 10}, {29, 10}}], LineBox[{{21, 18}, {21, 16}}], 
   LineBox[{{21, 16}, {21, 14}}], LineBox[{{21, 14}, {21, 12}}], 
   LineBox[{{21, 12}, {21, 10}}], LineBox[{{23, 18}, {23, 16}}], 
   LineBox[{{23, 16}, {23, 14}}], LineBox[{{23, 14}, {23, 12}}], 
   LineBox[{{23, 12}, {23, 10}}], LineBox[{{25, 18}, {25, 16}}], 
   LineBox[{{25, 16}, {25, 14}}], LineBox[{{25, 14}, {25, 12}}], 
   LineBox[{{25, 12}, {25, 10}}], LineBox[{{27, 18}, {27, 16}}], 
   LineBox[{{27, 16}, {27, 14}}], LineBox[{{27, 14}, {27, 12}}], 
   LineBox[{{27, 12}, {27, 10}}], LineBox[{{29, 18}, {29, 16}}], 
   LineBox[{{29, 16}, {29, 14}}], LineBox[{{29, 14}, {29, 12}}], 
   LineBox[{{29, 12}, {29, 10}}], 
   LineBox[NCache[{{31, 18}, {Rational[101, 3], 18}}, {{31, 18}, {
      33.666666666666664`, 18}}]], 
   LineBox[NCache[{{31, Rational[46, 3]}, {
      Rational[101, 3], Rational[46, 3]}}, {{31, 15.333333333333334`}, {
      33.666666666666664`, 15.333333333333334`}}]], 
   LineBox[NCache[{{31, Rational[38, 3]}, {
      Rational[101, 3], Rational[38, 3]}}, {{31, 12.666666666666666`}, {
      33.666666666666664`, 12.666666666666666`}}]], 
   LineBox[NCache[{{31, 10}, {Rational[101, 3], 10}}, {{31, 10}, {
      33.666666666666664`, 10}}]], 
   LineBox[NCache[{{Rational[101, 3], 18}, {Rational[109, 3], 18}}, {{
      33.666666666666664`, 18}, {36.333333333333336`, 18}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[46, 3]}, {
      Rational[109, 3], Rational[46, 3]}}, {{33.666666666666664`, 
     15.333333333333334`}, {36.333333333333336`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[38, 3]}, {
      Rational[109, 3], Rational[38, 3]}}, {{33.666666666666664`, 
     12.666666666666666`}, {36.333333333333336`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[101, 3], 10}, {Rational[109, 3], 10}}, {{
      33.666666666666664`, 10}, {36.333333333333336`, 10}}]], 
   LineBox[NCache[{{Rational[109, 3], 18}, {39, 18}}, {{
      36.333333333333336`, 18}, {39, 18}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[46, 3]}, {
      39, Rational[46, 3]}}, {{36.333333333333336`, 15.333333333333334`}, {
      39, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[38, 3]}, {
      39, Rational[38, 3]}}, {{36.333333333333336`, 12.666666666666666`}, {
      39, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[109, 3], 10}, {39, 10}}, {{
      36.333333333333336`, 10}, {39, 10}}]], 
   LineBox[NCache[{{31, 18}, {31, Rational[46, 3]}}, {{31, 18}, {
      31, 15.333333333333334`}}]], 
   LineBox[NCache[{{31, Rational[46, 3]}, {31, Rational[38, 3]}}, {{
      31, 15.333333333333334`}, {31, 12.666666666666666`}}]], 
   LineBox[NCache[{{31, Rational[38, 3]}, {31, 10}}, {{
      31, 12.666666666666666`}, {31, 10}}]], 
   LineBox[NCache[{{Rational[101, 3], 18}, {
      Rational[101, 3], Rational[46, 3]}}, {{33.666666666666664`, 18}, {
      33.666666666666664`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[46, 3]}, {
      Rational[101, 3], Rational[38, 3]}}, {{33.666666666666664`, 
     15.333333333333334`}, {33.666666666666664`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[38, 3]}, {
      Rational[101, 3], 10}}, {{33.666666666666664`, 12.666666666666666`}, {
      33.666666666666664`, 10}}]], 
   LineBox[NCache[{{Rational[109, 3], 18}, {
      Rational[109, 3], Rational[46, 3]}}, {{36.333333333333336`, 18}, {
      36.333333333333336`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[46, 3]}, {
      Rational[109, 3], Rational[38, 3]}}, {{36.333333333333336`, 
     15.333333333333334`}, {36.333333333333336`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[38, 3]}, {
      Rational[109, 3], 10}}, {{36.333333333333336`, 12.666666666666666`}, {
      36.333333333333336`, 10}}]], 
   LineBox[NCache[{{39, 18}, {39, Rational[46, 3]}}, {{39, 18}, {
      39, 15.333333333333334`}}]], 
   LineBox[NCache[{{39, Rational[46, 3]}, {39, Rational[38, 3]}}, {{
      39, 15.333333333333334`}, {39, 12.666666666666666`}}]], 
   LineBox[NCache[{{39, Rational[38, 3]}, {39, 10}}, {{
      39, 12.666666666666666`}, {39, 10}}]], 
   LineBox[
    NCache[{{41, 18}, {Rational[131, 3], 18}}, {{41, 18}, {
      43.666666666666664`, 18}}]], 
   LineBox[NCache[{{41, Rational[46, 3]}, {
      Rational[131, 3], Rational[46, 3]}}, {{41, 15.333333333333334`}, {
      43.666666666666664`, 15.333333333333334`}}]], 
   LineBox[NCache[{{41, Rational[38, 3]}, {
      Rational[131, 3], Rational[38, 3]}}, {{41, 12.666666666666666`}, {
      43.666666666666664`, 12.666666666666666`}}]], 
   LineBox[NCache[{{41, 10}, {Rational[131, 3], 10}}, {{41, 10}, {
      43.666666666666664`, 10}}]], 
   LineBox[NCache[{{Rational[131, 3], 18}, {Rational[139, 3], 18}}, {{
      43.666666666666664`, 18}, {46.333333333333336`, 18}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[46, 3]}, {
      Rational[139, 3], Rational[46, 3]}}, {{43.666666666666664`, 
     15.333333333333334`}, {46.333333333333336`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[38, 3]}, {
      Rational[139, 3], Rational[38, 3]}}, {{43.666666666666664`, 
     12.666666666666666`}, {46.333333333333336`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 3], 10}, {Rational[139, 3], 10}}, {{
      43.666666666666664`, 10}, {46.333333333333336`, 10}}]], 
   LineBox[NCache[{{Rational[139, 3], 18}, {49, 18}}, {{
      46.333333333333336`, 18}, {49, 18}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[46, 3]}, {
      49, Rational[46, 3]}}, {{46.333333333333336`, 15.333333333333334`}, {
      49, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[38, 3]}, {
      49, Rational[38, 3]}}, {{46.333333333333336`, 12.666666666666666`}, {
      49, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 3], 10}, {49, 10}}, {{
      46.333333333333336`, 10}, {49, 10}}]], 
   LineBox[NCache[{{41, 18}, {41, Rational[46, 3]}}, {{41, 18}, {
      41, 15.333333333333334`}}]], 
   LineBox[NCache[{{41, Rational[46, 3]}, {41, Rational[38, 3]}}, {{
      41, 15.333333333333334`}, {41, 12.666666666666666`}}]], 
   LineBox[NCache[{{41, Rational[38, 3]}, {41, 10}}, {{
      41, 12.666666666666666`}, {41, 10}}]], 
   LineBox[NCache[{{Rational[131, 3], 18}, {
      Rational[131, 3], Rational[46, 3]}}, {{43.666666666666664`, 18}, {
      43.666666666666664`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[46, 3]}, {
      Rational[131, 3], Rational[38, 3]}}, {{43.666666666666664`, 
     15.333333333333334`}, {43.666666666666664`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[38, 3]}, {
      Rational[131, 3], 10}}, {{43.666666666666664`, 12.666666666666666`}, {
      43.666666666666664`, 10}}]], 
   LineBox[NCache[{{Rational[139, 3], 18}, {
      Rational[139, 3], Rational[46, 3]}}, {{46.333333333333336`, 18}, {
      46.333333333333336`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[46, 3]}, {
      Rational[139, 3], Rational[38, 3]}}, {{46.333333333333336`, 
     15.333333333333334`}, {46.333333333333336`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[38, 3]}, {
      Rational[139, 3], 10}}, {{46.333333333333336`, 12.666666666666666`}, {
      46.333333333333336`, 10}}]], 
   LineBox[NCache[{{49, 18}, {49, Rational[46, 3]}}, {{49, 18}, {
      49, 15.333333333333334`}}]], 
   LineBox[NCache[{{49, Rational[46, 3]}, {49, Rational[38, 3]}}, {{
      49, 15.333333333333334`}, {49, 12.666666666666666`}}]], 
   LineBox[NCache[{{49, Rational[38, 3]}, {49, 10}}, {{
      49, 12.666666666666666`}, {49, 10}}]], LineBox[{{51, 18}, {53, 18}}], 
   LineBox[{{51, 16}, {53, 16}}], LineBox[{{51, 14}, {53, 14}}], 
   LineBox[{{51, 12}, {53, 12}}], LineBox[{{51, 10}, {53, 10}}], 
   LineBox[{{53, 18}, {55, 18}}], LineBox[{{53, 16}, {55, 16}}], 
   LineBox[{{53, 14}, {55, 14}}], LineBox[{{53, 12}, {55, 12}}], 
   LineBox[{{53, 10}, {55, 10}}], LineBox[{{55, 18}, {57, 18}}], 
   LineBox[{{55, 16}, {57, 16}}], LineBox[{{55, 14}, {57, 14}}], 
   LineBox[{{55, 12}, {57, 12}}], LineBox[{{55, 10}, {57, 10}}], 
   LineBox[{{57, 18}, {59, 18}}], LineBox[{{57, 16}, {59, 16}}], 
   LineBox[{{57, 14}, {59, 14}}], LineBox[{{57, 12}, {59, 12}}], 
   LineBox[{{57, 10}, {59, 10}}], LineBox[{{51, 18}, {51, 16}}], 
   LineBox[{{51, 16}, {51, 14}}], LineBox[{{51, 14}, {51, 12}}], 
   LineBox[{{51, 12}, {51, 10}}], LineBox[{{53, 18}, {53, 16}}], 
   LineBox[{{53, 16}, {53, 14}}], LineBox[{{53, 14}, {53, 12}}], 
   LineBox[{{53, 12}, {53, 10}}], LineBox[{{55, 18}, {55, 16}}], 
   LineBox[{{55, 16}, {55, 14}}], LineBox[{{55, 14}, {55, 12}}], 
   LineBox[{{55, 12}, {55, 10}}], LineBox[{{57, 18}, {57, 16}}], 
   LineBox[{{57, 16}, {57, 14}}], LineBox[{{57, 14}, {57, 12}}], 
   LineBox[{{57, 12}, {57, 10}}], LineBox[{{59, 18}, {59, 16}}], 
   LineBox[{{59, 16}, {59, 14}}], LineBox[{{59, 14}, {59, 12}}], 
   LineBox[{{59, 12}, {59, 10}}], LineBox[{{61, 18}, {63, 18}}], 
   LineBox[{{61, 16}, {63, 16}}], LineBox[{{61, 14}, {63, 14}}], 
   LineBox[{{61, 12}, {63, 12}}], LineBox[{{61, 10}, {63, 10}}], 
   LineBox[{{63, 18}, {65, 18}}], LineBox[{{63, 16}, {65, 16}}], 
   LineBox[{{63, 14}, {65, 14}}], LineBox[{{63, 12}, {65, 12}}], 
   LineBox[{{63, 10}, {65, 10}}], LineBox[{{65, 18}, {67, 18}}], 
   LineBox[{{65, 16}, {67, 16}}], LineBox[{{65, 14}, {67, 14}}], 
   LineBox[{{65, 12}, {67, 12}}], LineBox[{{65, 10}, {67, 10}}], 
   LineBox[{{67, 18}, {69, 18}}], LineBox[{{67, 16}, {69, 16}}], 
   LineBox[{{67, 14}, {69, 14}}], LineBox[{{67, 12}, {69, 12}}], 
   LineBox[{{67, 10}, {69, 10}}], LineBox[{{61, 18}, {61, 16}}], 
   LineBox[{{61, 16}, {61, 14}}], LineBox[{{61, 14}, {61, 12}}], 
   LineBox[{{61, 12}, {61, 10}}], LineBox[{{63, 18}, {63, 16}}], 
   LineBox[{{63, 16}, {63, 14}}], LineBox[{{63, 14}, {63, 12}}], 
   LineBox[{{63, 12}, {63, 10}}], LineBox[{{65, 18}, {65, 16}}], 
   LineBox[{{65, 16}, {65, 14}}], LineBox[{{65, 14}, {65, 12}}], 
   LineBox[{{65, 12}, {65, 10}}], LineBox[{{67, 18}, {67, 16}}], 
   LineBox[{{67, 16}, {67, 14}}], LineBox[{{67, 14}, {67, 12}}], 
   LineBox[{{67, 12}, {67, 10}}], LineBox[{{69, 18}, {69, 16}}], 
   LineBox[{{69, 16}, {69, 14}}], LineBox[{{69, 14}, {69, 12}}], 
   LineBox[{{69, 12}, {69, 10}}], LineBox[{{11, 8}, {13, 8}}], 
   LineBox[{{11, 6}, {13, 6}}], LineBox[{{11, 4}, {13, 4}}], 
   LineBox[{{11, 2}, {13, 2}}], LineBox[{{11, 0}, {13, 0}}], 
   LineBox[{{13, 8}, {15, 8}}], LineBox[{{13, 6}, {15, 6}}], 
   LineBox[{{13, 4}, {15, 4}}], LineBox[{{13, 2}, {15, 2}}], 
   LineBox[{{13, 0}, {15, 0}}], LineBox[{{15, 8}, {17, 8}}], 
   LineBox[{{15, 6}, {17, 6}}], LineBox[{{15, 4}, {17, 4}}], 
   LineBox[{{15, 2}, {17, 2}}], LineBox[{{15, 0}, {17, 0}}], 
   LineBox[{{17, 8}, {19, 8}}], LineBox[{{17, 6}, {19, 6}}], 
   LineBox[{{17, 4}, {19, 4}}], LineBox[{{17, 2}, {19, 2}}], 
   LineBox[{{17, 0}, {19, 0}}], LineBox[{{11, 8}, {11, 6}}], 
   LineBox[{{11, 6}, {11, 4}}], LineBox[{{11, 4}, {11, 2}}], 
   LineBox[{{11, 2}, {11, 0}}], LineBox[{{13, 8}, {13, 6}}], 
   LineBox[{{13, 6}, {13, 4}}], LineBox[{{13, 4}, {13, 2}}], 
   LineBox[{{13, 2}, {13, 0}}], LineBox[{{15, 8}, {15, 6}}], 
   LineBox[{{15, 6}, {15, 4}}], LineBox[{{15, 4}, {15, 2}}], 
   LineBox[{{15, 2}, {15, 0}}], LineBox[{{17, 8}, {17, 6}}], 
   LineBox[{{17, 6}, {17, 4}}], LineBox[{{17, 4}, {17, 2}}], 
   LineBox[{{17, 2}, {17, 0}}], LineBox[{{19, 8}, {19, 6}}], 
   LineBox[{{19, 6}, {19, 4}}], LineBox[{{19, 4}, {19, 2}}], 
   LineBox[{{19, 2}, {19, 0}}], LineBox[{{21, 8}, {23, 8}}], 
   LineBox[{{21, 6}, {23, 6}}], LineBox[{{21, 4}, {23, 4}}], 
   LineBox[{{21, 2}, {23, 2}}], LineBox[{{21, 0}, {23, 0}}], 
   LineBox[{{23, 8}, {25, 8}}], LineBox[{{23, 6}, {25, 6}}], 
   LineBox[{{23, 4}, {25, 4}}], LineBox[{{23, 2}, {25, 2}}], 
   LineBox[{{23, 0}, {25, 0}}], LineBox[{{25, 8}, {27, 8}}], 
   LineBox[{{25, 6}, {27, 6}}], LineBox[{{25, 4}, {27, 4}}], 
   LineBox[{{25, 2}, {27, 2}}], LineBox[{{25, 0}, {27, 0}}], 
   LineBox[{{27, 8}, {29, 8}}], LineBox[{{27, 6}, {29, 6}}], 
   LineBox[{{27, 4}, {29, 4}}], LineBox[{{27, 2}, {29, 2}}], 
   LineBox[{{27, 0}, {29, 0}}], LineBox[{{21, 8}, {21, 6}}], 
   LineBox[{{21, 6}, {21, 4}}], LineBox[{{21, 4}, {21, 2}}], 
   LineBox[{{21, 2}, {21, 0}}], LineBox[{{23, 8}, {23, 6}}], 
   LineBox[{{23, 6}, {23, 4}}], LineBox[{{23, 4}, {23, 2}}], 
   LineBox[{{23, 2}, {23, 0}}], LineBox[{{25, 8}, {25, 6}}], 
   LineBox[{{25, 6}, {25, 4}}], LineBox[{{25, 4}, {25, 2}}], 
   LineBox[{{25, 2}, {25, 0}}], LineBox[{{27, 8}, {27, 6}}], 
   LineBox[{{27, 6}, {27, 4}}], LineBox[{{27, 4}, {27, 2}}], 
   LineBox[{{27, 2}, {27, 0}}], LineBox[{{29, 8}, {29, 6}}], 
   LineBox[{{29, 6}, {29, 4}}], LineBox[{{29, 4}, {29, 2}}], 
   LineBox[{{29, 2}, {29, 0}}], 
   LineBox[NCache[{{31, 8}, {Rational[163, 5], 8}}, {{31, 8}, {32.6, 8}}]], 
   LineBox[NCache[{{31, Rational[32, 5]}, {
      Rational[163, 5], Rational[32, 5]}}, {{31, 6.4}, {32.6, 6.4}}]], 
   LineBox[NCache[{{31, Rational[24, 5]}, {
      Rational[163, 5], Rational[24, 5]}}, {{31, 4.8}, {32.6, 4.8}}]], 
   LineBox[NCache[{{31, Rational[16, 5]}, {
      Rational[163, 5], Rational[16, 5]}}, {{31, 3.2}, {32.6, 3.2}}]], 
   LineBox[NCache[{{31, Rational[8, 5]}, {
      Rational[163, 5], Rational[8, 5]}}, {{31, 1.6}, {32.6, 1.6}}]], 
   LineBox[NCache[{{31, 0}, {Rational[163, 5], 0}}, {{31, 0}, {32.6, 0}}]], 
   LineBox[NCache[{{Rational[163, 5], 8}, {Rational[171, 5], 8}}, {{
      32.6, 8}, {34.2, 8}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[32, 5]}, {
      Rational[171, 5], Rational[32, 5]}}, {{32.6, 6.4}, {34.2, 6.4}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[24, 5]}, {
      Rational[171, 5], Rational[24, 5]}}, {{32.6, 4.8}, {34.2, 4.8}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[16, 5]}, {
      Rational[171, 5], Rational[16, 5]}}, {{32.6, 3.2}, {34.2, 3.2}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[8, 5]}, {
      Rational[171, 5], Rational[8, 5]}}, {{32.6, 1.6}, {34.2, 1.6}}]], 
   LineBox[NCache[{{Rational[163, 5], 0}, {Rational[171, 5], 0}}, {{
      32.6, 0}, {34.2, 0}}]], 
   LineBox[NCache[{{Rational[171, 5], 8}, {Rational[179, 5], 8}}, {{
      34.2, 8}, {35.8, 8}}]], 
   LineBox[
    NCache[{{Rational[171, 5], Rational[32, 5]}, {
      Rational[179, 5], Rational[32, 5]}}, {{34.2, 6.4}, {35.8, 6.4}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[24, 5]}, {
      Rational[179, 5], Rational[24, 5]}}, {{34.2, 4.8}, {35.8, 4.8}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[16, 5]}, {
      Rational[179, 5], Rational[16, 5]}}, {{34.2, 3.2}, {35.8, 3.2}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[8, 5]}, {
      Rational[179, 5], Rational[8, 5]}}, {{34.2, 1.6}, {35.8, 1.6}}]], 
   LineBox[NCache[{{Rational[171, 5], 0}, {Rational[179, 5], 0}}, {{
      34.2, 0}, {35.8, 0}}]], 
   LineBox[NCache[{{Rational[179, 5], 8}, {Rational[187, 5], 8}}, {{
      35.8, 8}, {37.4, 8}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[32, 5]}, {
      Rational[187, 5], Rational[32, 5]}}, {{35.8, 6.4}, {37.4, 6.4}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[24, 5]}, {
      Rational[187, 5], Rational[24, 5]}}, {{35.8, 4.8}, {37.4, 4.8}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[16, 5]}, {
      Rational[187, 5], Rational[16, 5]}}, {{35.8, 3.2}, {37.4, 3.2}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[8, 5]}, {
      Rational[187, 5], Rational[8, 5]}}, {{35.8, 1.6}, {37.4, 1.6}}]], 
   LineBox[NCache[{{Rational[179, 5], 0}, {Rational[187, 5], 0}}, {{
      35.8, 0}, {37.4, 0}}]], 
   LineBox[NCache[{{Rational[187, 5], 8}, {39, 8}}, {{37.4, 8}, {39, 8}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[32, 5]}, {
      39, Rational[32, 5]}}, {{37.4, 6.4}, {39, 6.4}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[24, 5]}, {
      39, Rational[24, 5]}}, {{37.4, 4.8}, {39, 4.8}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[16, 5]}, {
      39, Rational[16, 5]}}, {{37.4, 3.2}, {39, 3.2}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[8, 5]}, {
      39, Rational[8, 5]}}, {{37.4, 1.6}, {39, 1.6}}]], 
   LineBox[NCache[{{Rational[187, 5], 0}, {39, 0}}, {{37.4, 0}, {39, 0}}]], 
   LineBox[NCache[{{31, 8}, {31, Rational[32, 5]}}, {{31, 8}, {31, 6.4}}]], 
   LineBox[
    NCache[{{31, Rational[32, 5]}, {31, Rational[24, 5]}}, {{31, 6.4}, {
      31, 4.8}}]], 
   LineBox[NCache[{{31, Rational[24, 5]}, {31, Rational[16, 5]}}, {{
      31, 4.8}, {31, 3.2}}]], 
   LineBox[NCache[{{31, Rational[16, 5]}, {31, Rational[8, 5]}}, {{31, 3.2}, {
      31, 1.6}}]], 
   LineBox[NCache[{{31, Rational[8, 5]}, {31, 0}}, {{31, 1.6}, {31, 0}}]], 
   LineBox[NCache[{{Rational[163, 5], 8}, {
      Rational[163, 5], Rational[32, 5]}}, {{32.6, 8}, {32.6, 6.4}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[32, 5]}, {
      Rational[163, 5], Rational[24, 5]}}, {{32.6, 6.4}, {32.6, 4.8}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[24, 5]}, {
      Rational[163, 5], Rational[16, 5]}}, {{32.6, 4.8}, {32.6, 3.2}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[16, 5]}, {
      Rational[163, 5], Rational[8, 5]}}, {{32.6, 3.2}, {32.6, 1.6}}]], 
   LineBox[NCache[{{Rational[163, 5], Rational[8, 5]}, {
      Rational[163, 5], 0}}, {{32.6, 1.6}, {32.6, 0}}]], 
   LineBox[NCache[{{Rational[171, 5], 8}, {
      Rational[171, 5], Rational[32, 5]}}, {{34.2, 8}, {34.2, 6.4}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[32, 5]}, {
      Rational[171, 5], Rational[24, 5]}}, {{34.2, 6.4}, {34.2, 4.8}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[24, 5]}, {
      Rational[171, 5], Rational[16, 5]}}, {{34.2, 4.8}, {34.2, 3.2}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[16, 5]}, {
      Rational[171, 5], Rational[8, 5]}}, {{34.2, 3.2}, {34.2, 1.6}}]], 
   LineBox[NCache[{{Rational[171, 5], Rational[8, 5]}, {
      Rational[171, 5], 0}}, {{34.2, 1.6}, {34.2, 0}}]], 
   LineBox[NCache[{{Rational[179, 5], 8}, {
      Rational[179, 5], Rational[32, 5]}}, {{35.8, 8}, {35.8, 6.4}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[32, 5]}, {
      Rational[179, 5], Rational[24, 5]}}, {{35.8, 6.4}, {35.8, 4.8}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[24, 5]}, {
      Rational[179, 5], Rational[16, 5]}}, {{35.8, 4.8}, {35.8, 3.2}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[16, 5]}, {
      Rational[179, 5], Rational[8, 5]}}, {{35.8, 3.2}, {35.8, 1.6}}]], 
   LineBox[NCache[{{Rational[179, 5], Rational[8, 5]}, {
      Rational[179, 5], 0}}, {{35.8, 1.6}, {35.8, 0}}]], 
   LineBox[NCache[{{Rational[187, 5], 8}, {
      Rational[187, 5], Rational[32, 5]}}, {{37.4, 8}, {37.4, 6.4}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[32, 5]}, {
      Rational[187, 5], Rational[24, 5]}}, {{37.4, 6.4}, {37.4, 4.8}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[24, 5]}, {
      Rational[187, 5], Rational[16, 5]}}, {{37.4, 4.8}, {37.4, 3.2}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[16, 5]}, {
      Rational[187, 5], Rational[8, 5]}}, {{37.4, 3.2}, {37.4, 1.6}}]], 
   LineBox[NCache[{{Rational[187, 5], Rational[8, 5]}, {
      Rational[187, 5], 0}}, {{37.4, 1.6}, {37.4, 0}}]], 
   LineBox[NCache[{{39, 8}, {39, Rational[32, 5]}}, {{39, 8}, {39, 6.4}}]], 
   LineBox[NCache[{{39, Rational[32, 5]}, {39, Rational[24, 5]}}, {{
      39, 6.4}, {39, 4.8}}]], 
   LineBox[NCache[{{39, Rational[24, 5]}, {39, Rational[16, 5]}}, {{
      39, 4.8}, {39, 3.2}}]], 
   LineBox[NCache[{{39, Rational[16, 5]}, {39, Rational[8, 5]}}, {{39, 3.2}, {
      39, 1.6}}]], 
   LineBox[NCache[{{39, Rational[8, 5]}, {39, 0}}, {{39, 1.6}, {39, 0}}]], 
   LineBox[NCache[{{41, 8}, {Rational[213, 5], 8}}, {{41, 8}, {42.6, 8}}]], 
   LineBox[NCache[{{41, Rational[32, 5]}, {
      Rational[213, 5], Rational[32, 5]}}, {{41, 6.4}, {42.6, 6.4}}]], 
   LineBox[NCache[{{41, Rational[24, 5]}, {
      Rational[213, 5], Rational[24, 5]}}, {{41, 4.8}, {42.6, 4.8}}]], 
   LineBox[NCache[{{41, Rational[16, 5]}, {
      Rational[213, 5], Rational[16, 5]}}, {{41, 3.2}, {42.6, 3.2}}]], 
   LineBox[NCache[{{41, Rational[8, 5]}, {
      Rational[213, 5], Rational[8, 5]}}, {{41, 1.6}, {42.6, 1.6}}]], 
   LineBox[NCache[{{41, 0}, {Rational[213, 5], 0}}, {{41, 0}, {42.6, 0}}]], 
   LineBox[NCache[{{Rational[213, 5], 8}, {Rational[221, 5], 8}}, {{
      42.6, 8}, {44.2, 8}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[32, 5]}, {
      Rational[221, 5], Rational[32, 5]}}, {{42.6, 6.4}, {44.2, 6.4}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[24, 5]}, {
      Rational[221, 5], Rational[24, 5]}}, {{42.6, 4.8}, {44.2, 4.8}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[16, 5]}, {
      Rational[221, 5], Rational[16, 5]}}, {{42.6, 3.2}, {44.2, 3.2}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[8, 5]}, {
      Rational[221, 5], Rational[8, 5]}}, {{42.6, 1.6}, {44.2, 1.6}}]], 
   LineBox[NCache[{{Rational[213, 5], 0}, {Rational[221, 5], 0}}, {{
      42.6, 0}, {44.2, 0}}]], 
   LineBox[NCache[{{Rational[221, 5], 8}, {Rational[229, 5], 8}}, {{
      44.2, 8}, {45.8, 8}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[32, 5]}, {
      Rational[229, 5], Rational[32, 5]}}, {{44.2, 6.4}, {45.8, 6.4}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[24, 5]}, {
      Rational[229, 5], Rational[24, 5]}}, {{44.2, 4.8}, {45.8, 4.8}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[16, 5]}, {
      Rational[229, 5], Rational[16, 5]}}, {{44.2, 3.2}, {45.8, 3.2}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[8, 5]}, {
      Rational[229, 5], Rational[8, 5]}}, {{44.2, 1.6}, {45.8, 1.6}}]], 
   LineBox[NCache[{{Rational[221, 5], 0}, {Rational[229, 5], 0}}, {{
      44.2, 0}, {45.8, 0}}]], 
   LineBox[NCache[{{Rational[229, 5], 8}, {Rational[237, 5], 8}}, {{
      45.8, 8}, {47.4, 8}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[32, 5]}, {
      Rational[237, 5], Rational[32, 5]}}, {{45.8, 6.4}, {47.4, 6.4}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[24, 5]}, {
      Rational[237, 5], Rational[24, 5]}}, {{45.8, 4.8}, {47.4, 4.8}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[16, 5]}, {
      Rational[237, 5], Rational[16, 5]}}, {{45.8, 3.2}, {47.4, 3.2}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[8, 5]}, {
      Rational[237, 5], Rational[8, 5]}}, {{45.8, 1.6}, {47.4, 1.6}}]], 
   LineBox[NCache[{{Rational[229, 5], 0}, {Rational[237, 5], 0}}, {{
      45.8, 0}, {47.4, 0}}]], 
   LineBox[NCache[{{Rational[237, 5], 8}, {49, 8}}, {{47.4, 8}, {49, 8}}]], 
   LineBox[
    NCache[{{Rational[237, 5], Rational[32, 5]}, {49, Rational[32, 5]}}, {{
      47.4, 6.4}, {49, 6.4}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[24, 5]}, {
      49, Rational[24, 5]}}, {{47.4, 4.8}, {49, 4.8}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[16, 5]}, {
      49, Rational[16, 5]}}, {{47.4, 3.2}, {49, 3.2}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[8, 5]}, {
      49, Rational[8, 5]}}, {{47.4, 1.6}, {49, 1.6}}]], 
   LineBox[NCache[{{Rational[237, 5], 0}, {49, 0}}, {{47.4, 0}, {49, 0}}]], 
   LineBox[NCache[{{41, 8}, {41, Rational[32, 5]}}, {{41, 8}, {41, 6.4}}]], 
   LineBox[NCache[{{41, Rational[32, 5]}, {41, Rational[24, 5]}}, {{
      41, 6.4}, {41, 4.8}}]], 
   LineBox[NCache[{{41, Rational[24, 5]}, {41, Rational[16, 5]}}, {{
      41, 4.8}, {41, 3.2}}]], 
   LineBox[NCache[{{41, Rational[16, 5]}, {41, Rational[8, 5]}}, {{41, 3.2}, {
      41, 1.6}}]], 
   LineBox[NCache[{{41, Rational[8, 5]}, {41, 0}}, {{41, 1.6}, {41, 0}}]], 
   LineBox[NCache[{{Rational[213, 5], 8}, {
      Rational[213, 5], Rational[32, 5]}}, {{42.6, 8}, {42.6, 6.4}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[32, 5]}, {
      Rational[213, 5], Rational[24, 5]}}, {{42.6, 6.4}, {42.6, 4.8}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[24, 5]}, {
      Rational[213, 5], Rational[16, 5]}}, {{42.6, 4.8}, {42.6, 3.2}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[16, 5]}, {
      Rational[213, 5], Rational[8, 5]}}, {{42.6, 3.2}, {42.6, 1.6}}]], 
   LineBox[NCache[{{Rational[213, 5], Rational[8, 5]}, {
      Rational[213, 5], 0}}, {{42.6, 1.6}, {42.6, 0}}]], 
   LineBox[NCache[{{Rational[221, 5], 8}, {
      Rational[221, 5], Rational[32, 5]}}, {{44.2, 8}, {44.2, 6.4}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[32, 5]}, {
      Rational[221, 5], Rational[24, 5]}}, {{44.2, 6.4}, {44.2, 4.8}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[24, 5]}, {
      Rational[221, 5], Rational[16, 5]}}, {{44.2, 4.8}, {44.2, 3.2}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[16, 5]}, {
      Rational[221, 5], Rational[8, 5]}}, {{44.2, 3.2}, {44.2, 1.6}}]], 
   LineBox[NCache[{{Rational[221, 5], Rational[8, 5]}, {
      Rational[221, 5], 0}}, {{44.2, 1.6}, {44.2, 0}}]], 
   LineBox[NCache[{{Rational[229, 5], 8}, {
      Rational[229, 5], Rational[32, 5]}}, {{45.8, 8}, {45.8, 6.4}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[32, 5]}, {
      Rational[229, 5], Rational[24, 5]}}, {{45.8, 6.4}, {45.8, 4.8}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[24, 5]}, {
      Rational[229, 5], Rational[16, 5]}}, {{45.8, 4.8}, {45.8, 3.2}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[16, 5]}, {
      Rational[229, 5], Rational[8, 5]}}, {{45.8, 3.2}, {45.8, 1.6}}]], 
   LineBox[NCache[{{Rational[229, 5], Rational[8, 5]}, {
      Rational[229, 5], 0}}, {{45.8, 1.6}, {45.8, 0}}]], 
   LineBox[NCache[{{Rational[237, 5], 8}, {
      Rational[237, 5], Rational[32, 5]}}, {{47.4, 8}, {47.4, 6.4}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[32, 5]}, {
      Rational[237, 5], Rational[24, 5]}}, {{47.4, 6.4}, {47.4, 4.8}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[24, 5]}, {
      Rational[237, 5], Rational[16, 5]}}, {{47.4, 4.8}, {47.4, 3.2}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[16, 5]}, {
      Rational[237, 5], Rational[8, 5]}}, {{47.4, 3.2}, {47.4, 1.6}}]], 
   LineBox[NCache[{{Rational[237, 5], Rational[8, 5]}, {
      Rational[237, 5], 0}}, {{47.4, 1.6}, {47.4, 0}}]], 
   LineBox[NCache[{{49, 8}, {49, Rational[32, 5]}}, {{49, 8}, {49, 6.4}}]], 
   LineBox[NCache[{{49, Rational[32, 5]}, {49, Rational[24, 5]}}, {{
      49, 6.4}, {49, 4.8}}]], 
   LineBox[NCache[{{49, Rational[24, 5]}, {49, Rational[16, 5]}}, {{
      49, 4.8}, {49, 3.2}}]], 
   LineBox[NCache[{{49, Rational[16, 5]}, {49, Rational[8, 5]}}, {{49, 3.2}, {
      49, 1.6}}]], 
   LineBox[NCache[{{49, Rational[8, 5]}, {49, 0}}, {{49, 1.6}, {49, 0}}]], 
   LineBox[NCache[{{51, 8}, {Rational[263, 5], 8}}, {{51, 8}, {52.6, 8}}]], 
   LineBox[NCache[{{51, Rational[32, 5]}, {
      Rational[263, 5], Rational[32, 5]}}, {{51, 6.4}, {52.6, 6.4}}]], 
   LineBox[
    NCache[{{51, Rational[24, 5]}, {Rational[263, 5], Rational[24, 5]}}, {{
      51, 4.8}, {52.6, 4.8}}]], 
   LineBox[NCache[{{51, Rational[16, 5]}, {
      Rational[263, 5], Rational[16, 5]}}, {{51, 3.2}, {52.6, 3.2}}]], 
   LineBox[NCache[{{51, Rational[8, 5]}, {
      Rational[263, 5], Rational[8, 5]}}, {{51, 1.6}, {52.6, 1.6}}]], 
   LineBox[NCache[{{51, 0}, {Rational[263, 5], 0}}, {{51, 0}, {52.6, 0}}]], 
   LineBox[NCache[{{Rational[263, 5], 8}, {Rational[271, 5], 8}}, {{
      52.6, 8}, {54.2, 8}}]], 
   LineBox[NCache[{{Rational[263, 5], Rational[32, 5]}, {
      Rational[271, 5], Rational[32, 5]}}, {{52.6, 6.4}, {54.2, 6.4}}]], 
   LineBox[NCache[{{Rational[263, 5], Rational[24, 5]}, {
      Rational[271, 5], Rational[24, 5]}}, {{52.6, 4.8}, {54.2, 4.8}}]], 
   LineBox[NCache[{{Rational[263, 5], Rational[16, 5]}, {
      Rational[271, 5], Rational[16, 5]}}, {{52.6, 3.2}, {54.2, 3.2}}]], 
   LineBox[NCache[{{Rational[263, 5], Rational[8, 5]}, {
      Rational[271, 5], Rational[8, 5]}}, {{52.6, 1.6}, {54.2, 1.6}}]], 
   LineBox[NCache[{{Rational[263, 5], 0}, {Rational[271, 5], 0}}, {{
      52.6, 0}, {54.2, 0}}]], 
   LineBox[NCache[{{Rational[271, 5], 8}, {Rational[279, 5], 8}}, {{
      54.2, 8}, {55.8, 8}}]], 
   LineBox[NCache[{{Rational[271, 5], Rational[32, 5]}, {
      Rational[279, 5], Rational[32, 5]}}, {{54.2, 6.4}, {55.8, 6.4}}]], 
   LineBox[NCache[{{Rational[271, 5], Rational[24, 5]}, {
      Rational[279, 5], Rational[24, 5]}}, {{54.2, 4.8}, {55.8, 4.8}}]], 
   LineBox[NCache[{{Rational[271, 5], Rational[16, 5]}, {
      Rational[279, 5], Rational[16, 5]}}, {{54.2, 3.2}, {55.8, 3.2}}]], 
   LineBox[NCache[{{Rational[271, 5], Rational[8, 5]}, {
      Rational[279, 5], Rational[8, 5]}}, {{54.2, 1.6}, {55.8, 1.6}}]], 
   LineBox[NCache[{{Rational[271, 5], 0}, {Rational[279, 5], 0}}, {{
      54.2, 0}, {55.8, 0}}]], 
   LineBox[NCache[{{Rational[279, 5], 8}, {Rational[287, 5], 8}}, {{
      55.8, 8}, {57.4, 8}}]], 
   LineBox[NCache[{{Rational[279, 5], Rational[32, 5]}, {
      Rational[287, 5], Rational[32, 5]}}, {{55.8, 6.4}, {57.4, 6.4}}]], 
   LineBox[
    NCache[{{Rational[279, 5], Rational[24, 5]}, {
      Rational[287, 5], Rational[24, 5]}}, {{55.8, 4.8}, {57.4, 4.8}}]], 
   LineBox[NCache[{{Rational[279, 5], Rational[16, 5]}, {
      Rational[287, 5], Rational[16, 5]}}, {{55.8, 3.2}, {57.4, 3.2}}]], 
   LineBox[NCache[{{Rational[279, 5], Rational[8, 5]}, {
      Rational[287, 5], Rational[8, 5]}}, {{55.8, 1.6}, {57.4, 1.6}}]], 
   LineBox[NCache[{{Rational[279, 5], 0}, {Rational[287, 5], 0}}, {{
      55.8, 0}, {57.4, 0}}]], 
   LineBox[NCache[{{Rational[287, 5], 8}, {59, 8}}, {{57.4, 8}, {59, 8}}]], 
   LineBox[NCache[{{Rational[287, 5], Rational[32, 5]}, {
      59, Rational[32, 5]}}, {{57.4, 6.4}, {59, 6.4}}]], 
   LineBox[NCache[{{Rational[287, 5], Rational[24, 5]}, {
      59, Rational[24, 5]}}, {{57.4, 4.8}, {59, 4.8}}]], 
   LineBox[NCache[{{Rational[287, 5], Rational[16, 5]}, {
      59, Rational[16, 5]}}, {{57.4, 3.2}, {59, 3.2}}]], 
   LineBox[NCache[{{Rational[287, 5], Rational[8, 5]}, {
      59, Rational[8, 5]}}, {{57.4, 1.6}, {59, 1.6}}]], 
   LineBox[NCache[{{Rational[287, 5], 0}, {59, 0}}, {{57.4, 0}, {59, 0}}]], 
   LineBox[NCache[{{51, 8}, {51, Rational[32, 5]}}, {{51, 8}, {51, 6.4}}]], 
   LineBox[NCache[{{51, Rational[32, 5]}, {51, Rational[24, 5]}}, {{
      51, 6.4}, {51, 4.8}}]], 
   LineBox[NCache[{{51, Rational[24, 5]}, {51, Rational[16, 5]}}, {{
      51, 4.8}, {51, 3.2}}]], 
   LineBox[NCache[{{51, Rational[16, 5]}, {51, Rational[8, 5]}}, {{51, 3.2}, {
      51, 1.6}}]], 
   LineBox[NCache[{{51, Rational[8, 5]}, {51, 0}}, {{51, 1.6}, {51, 0}}]], 
   LineBox[NCache[{{Rational[263, 5], 8}, {
      Rational[263, 5], Rational[32, 5]}}, {{52.6, 8}, {52.6, 6.4}}]], 
   LineBox[NCache[{{Rational[263, 5], Rational[32, 5]}, {
      Rational[263, 5], Rational[24, 5]}}, {{52.6, 6.4}, {52.6, 4.8}}]], 
   LineBox[NCache[{{Rational[263, 5], Rational[24, 5]}, {
      Rational[263, 5], Rational[16, 5]}}, {{52.6, 4.8}, {52.6, 3.2}}]], 
   LineBox[NCache[{{Rational[263, 5], Rational[16, 5]}, {
      Rational[263, 5], Rational[8, 5]}}, {{52.6, 3.2}, {52.6, 1.6}}]], 
   LineBox[
    NCache[{{Rational[263, 5], Rational[8, 5]}, {Rational[263, 5], 0}}, {{
      52.6, 1.6}, {52.6, 0}}]], 
   LineBox[NCache[{{Rational[271, 5], 8}, {
      Rational[271, 5], Rational[32, 5]}}, {{54.2, 8}, {54.2, 6.4}}]], 
   LineBox[NCache[{{Rational[271, 5], Rational[32, 5]}, {
      Rational[271, 5], Rational[24, 5]}}, {{54.2, 6.4}, {54.2, 4.8}}]], 
   LineBox[NCache[{{Rational[271, 5], Rational[24, 5]}, {
      Rational[271, 5], Rational[16, 5]}}, {{54.2, 4.8}, {54.2, 3.2}}]], 
   LineBox[NCache[{{Rational[271, 5], Rational[16, 5]}, {
      Rational[271, 5], Rational[8, 5]}}, {{54.2, 3.2}, {54.2, 1.6}}]], 
   LineBox[NCache[{{Rational[271, 5], Rational[8, 5]}, {
      Rational[271, 5], 0}}, {{54.2, 1.6}, {54.2, 0}}]], 
   LineBox[NCache[{{Rational[279, 5], 8}, {
      Rational[279, 5], Rational[32, 5]}}, {{55.8, 8}, {55.8, 6.4}}]], 
   LineBox[NCache[{{Rational[279, 5], Rational[32, 5]}, {
      Rational[279, 5], Rational[24, 5]}}, {{55.8, 6.4}, {55.8, 4.8}}]], 
   LineBox[NCache[{{Rational[279, 5], Rational[24, 5]}, {
      Rational[279, 5], Rational[16, 5]}}, {{55.8, 4.8}, {55.8, 3.2}}]], 
   LineBox[NCache[{{Rational[279, 5], Rational[16, 5]}, {
      Rational[279, 5], Rational[8, 5]}}, {{55.8, 3.2}, {55.8, 1.6}}]], 
   LineBox[NCache[{{Rational[279, 5], Rational[8, 5]}, {
      Rational[279, 5], 0}}, {{55.8, 1.6}, {55.8, 0}}]], 
   LineBox[NCache[{{Rational[287, 5], 8}, {
      Rational[287, 5], Rational[32, 5]}}, {{57.4, 8}, {57.4, 6.4}}]], 
   LineBox[NCache[{{Rational[287, 5], Rational[32, 5]}, {
      Rational[287, 5], Rational[24, 5]}}, {{57.4, 6.4}, {57.4, 4.8}}]], 
   LineBox[NCache[{{Rational[287, 5], Rational[24, 5]}, {
      Rational[287, 5], Rational[16, 5]}}, {{57.4, 4.8}, {57.4, 3.2}}]], 
   LineBox[NCache[{{Rational[287, 5], Rational[16, 5]}, {
      Rational[287, 5], Rational[8, 5]}}, {{57.4, 3.2}, {57.4, 1.6}}]], 
   LineBox[NCache[{{Rational[287, 5], Rational[8, 5]}, {
      Rational[287, 5], 0}}, {{57.4, 1.6}, {57.4, 0}}]], 
   LineBox[NCache[{{59, 8}, {59, Rational[32, 5]}}, {{59, 8}, {59, 6.4}}]], 
   LineBox[
    NCache[{{59, Rational[32, 5]}, {59, Rational[24, 5]}}, {{59, 6.4}, {
      59, 4.8}}]], 
   LineBox[NCache[{{59, Rational[24, 5]}, {59, Rational[16, 5]}}, {{
      59, 4.8}, {59, 3.2}}]], 
   LineBox[NCache[{{59, Rational[16, 5]}, {59, Rational[8, 5]}}, {{59, 3.2}, {
      59, 1.6}}]], 
   LineBox[NCache[{{59, Rational[8, 5]}, {59, 0}}, {{59, 1.6}, {59, 0}}]], 
   LineBox[NCache[{{61, 8}, {Rational[191, 3], 8}}, {{61, 8}, {
      63.666666666666664`, 8}}]], 
   LineBox[NCache[{{61, Rational[16, 3]}, {
      Rational[191, 3], Rational[16, 3]}}, {{61, 5.333333333333333}, {
      63.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{61, Rational[8, 3]}, {
      Rational[191, 3], Rational[8, 3]}}, {{61, 2.6666666666666665`}, {
      63.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{61, 0}, {Rational[191, 3], 0}}, {{61, 0}, {
      63.666666666666664`, 0}}]], 
   LineBox[NCache[{{Rational[191, 3], 8}, {Rational[199, 3], 8}}, {{
      63.666666666666664`, 8}, {66.33333333333333, 8}}]], 
   LineBox[NCache[{{Rational[191, 3], Rational[16, 3]}, {
      Rational[199, 3], Rational[16, 3]}}, {{63.666666666666664`, 
     5.333333333333333}, {66.33333333333333, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[191, 3], Rational[8, 3]}, {
      Rational[199, 3], Rational[8, 3]}}, {{63.666666666666664`, 
     2.6666666666666665`}, {66.33333333333333, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[191, 3], 0}, {Rational[199, 3], 0}}, {{
      63.666666666666664`, 0}, {66.33333333333333, 0}}]], 
   LineBox[NCache[{{Rational[199, 3], 8}, {69, 8}}, {{66.33333333333333, 8}, {
      69, 8}}]], 
   LineBox[NCache[{{Rational[199, 3], Rational[16, 3]}, {
      69, Rational[16, 3]}}, {{66.33333333333333, 5.333333333333333}, {
      69, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[199, 3], Rational[8, 3]}, {
      69, Rational[8, 3]}}, {{66.33333333333333, 2.6666666666666665`}, {
      69, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[199, 3], 0}, {69, 0}}, {{66.33333333333333, 0}, {
      69, 0}}]], 
   LineBox[NCache[{{61, 8}, {61, Rational[16, 3]}}, {{61, 8}, {
      61, 5.333333333333333}}]], 
   LineBox[NCache[{{61, Rational[16, 3]}, {61, Rational[8, 3]}}, {{
      61, 5.333333333333333}, {61, 2.6666666666666665`}}]], 
   LineBox[NCache[{{61, Rational[8, 3]}, {61, 0}}, {{
      61, 2.6666666666666665`}, {61, 0}}]], 
   LineBox[NCache[{{Rational[191, 3], 8}, {
      Rational[191, 3], Rational[16, 3]}}, {{63.666666666666664`, 8}, {
      63.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[191, 3], Rational[16, 3]}, {
      Rational[191, 3], Rational[8, 3]}}, {{63.666666666666664`, 
     5.333333333333333}, {63.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[191, 3], Rational[8, 3]}, {
      Rational[191, 3], 0}}, {{63.666666666666664`, 2.6666666666666665`}, {
      63.666666666666664`, 0}}]], 
   LineBox[NCache[{{Rational[199, 3], 8}, {
      Rational[199, 3], Rational[16, 3]}}, {{66.33333333333333, 8}, {
      66.33333333333333, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[199, 3], Rational[16, 3]}, {
      Rational[199, 3], Rational[8, 3]}}, {{66.33333333333333, 
     5.333333333333333}, {66.33333333333333, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[199, 3], Rational[8, 3]}, {
      Rational[199, 3], 0}}, {{66.33333333333333, 2.6666666666666665`}, {
      66.33333333333333, 0}}]], 
   LineBox[NCache[{{69, 8}, {69, Rational[16, 3]}}, {{69, 8}, {
      69, 5.333333333333333}}]], 
   LineBox[NCache[{{69, Rational[16, 3]}, {69, Rational[8, 3]}}, {{
      69, 5.333333333333333}, {69, 2.6666666666666665`}}]], 
   LineBox[NCache[{{69, Rational[8, 3]}, {69, 0}}, {{
      69, 2.6666666666666665`}, {69, 0}}]], LineBox[{{19, 78}, {21, 78}}], 
   LineBox[{{19, 74}, {21, 74}}], LineBox[{{19, 70}, {21, 70}}], 
   LineBox[{{19, 68}, {21, 68}}], LineBox[{{19, 64}, {21, 64}}], 
   LineBox[{{19, 60}, {21, 60}}], LineBox[{{19, 58}, {21, 58}}], 
   LineBox[{{19, 54}, {21, 54}}], LineBox[{{19, 50}, {21, 50}}], 
   LineBox[{{19, 48}, {21, 48}}], LineBox[{{19, 48}, {21, 46}}], 
   LineBox[{{19, 44}, {21, 44}}], LineBox[{{19, 44}, {21, 42}}], 
   LineBox[{{19, 40}, {21, 40}}], LineBox[{{19, 38}, {21, 38}}], 
   LineBox[{{19, 38}, {21, 36}}], LineBox[{{19, 34}, {21, 34}}], 
   LineBox[{{19, 34}, {21, 32}}], LineBox[{{19, 30}, {21, 30}}], 
   LineBox[{{19, 28}, {21, 28}}], LineBox[{{19, 28}, {21, 26}}], 
   LineBox[NCache[{{19, Rational[76, 3]}, {21, 24}}, {{
      19, 25.333333333333332`}, {21, 24}}]], 
   LineBox[NCache[{{19, Rational[68, 3]}, {21, 22}}, {{
      19, 22.666666666666668`}, {21, 22}}]], LineBox[{{19, 20}, {21, 20}}], 
   LineBox[{{19, 18}, {21, 18}}], LineBox[{{19, 16}, {21, 16}}], 
   LineBox[{{19, 14}, {21, 14}}], LineBox[{{19, 12}, {21, 12}}], 
   LineBox[{{19, 10}, {21, 10}}], LineBox[{{19, 8}, {21, 8}}], 
   LineBox[{{19, 6}, {21, 6}}], LineBox[{{19, 4}, {21, 4}}], 
   LineBox[{{19, 2}, {21, 2}}], LineBox[{{19, 0}, {21, 0}}], 
   LineBox[{{29, 78}, {31, 78}}], 
   LineBox[NCache[{{29, 78}, {31, Rational[538, 7]}}, {{29, 78}, {
      31, 76.85714285714286}}]], 
   LineBox[NCache[{{29, 78}, {31, Rational[530, 7]}}, {{29, 78}, {
      31, 75.71428571428571}}]], 
   LineBox[NCache[{{29, 74}, {31, Rational[522, 7]}}, {{29, 74}, {
      31, 74.57142857142857}}]], 
   LineBox[NCache[{{29, 74}, {31, Rational[514, 7]}}, {{29, 74}, {
      31, 73.42857142857143}}]], 
   LineBox[NCache[{{29, 74}, {31, Rational[506, 7]}}, {{29, 74}, {
      31, 72.28571428571429}}]], 
   LineBox[NCache[{{29, 70}, {31, Rational[498, 7]}}, {{29, 70}, {
      31, 71.14285714285714}}]], LineBox[{{29, 70}, {31, 70}}], 
   LineBox[{{29, 68}, {31, 68}}], 
   LineBox[NCache[{{29, 68}, {31, Rational[200, 3]}}, {{29, 68}, {
      31, 66.66666666666667}}]], 
   LineBox[NCache[{{29, 68}, {31, Rational[196, 3]}}, {{29, 68}, {
      31, 65.33333333333333}}]], LineBox[{{29, 64}, {31, 64}}], 
   LineBox[NCache[{{29, 64}, {31, Rational[188, 3]}}, {{29, 64}, {
      31, 62.666666666666664`}}]], 
   LineBox[NCache[{{29, 60}, {31, Rational[184, 3]}}, {{29, 60}, {
      31, 61.333333333333336`}}]], LineBox[{{29, 60}, {31, 60}}], 
   LineBox[{{29, 58}, {31, 58}}], 
   LineBox[NCache[{{29, 58}, {31, Rational[282, 5]}}, {{29, 58}, {
      31, 56.4}}]], 
   LineBox[NCache[{{29, 54}, {31, Rational[274, 5]}}, {{29, 54}, {
      31, 54.8}}]], 
   LineBox[NCache[{{29, 54}, {31, Rational[266, 5]}}, {{29, 54}, {
      31, 53.2}}]], 
   LineBox[NCache[{{29, 50}, {31, Rational[258, 5]}}, {{29, 50}, {
      31, 51.6}}]], LineBox[{{29, 50}, {31, 50}}], 
   LineBox[{{29, 48}, {31, 48}}], LineBox[{{29, 46}, {31, 48}}], 
   LineBox[NCache[{{29, 44}, {31, Rational[136, 3]}}, {{29, 44}, {
      31, 45.333333333333336`}}]], 
   LineBox[NCache[{{29, 42}, {31, Rational[128, 3]}}, {{29, 42}, {
      31, 42.666666666666664`}}]], LineBox[{{29, 40}, {31, 40}}], 
   LineBox[{{29, 38}, {31, 38}}], LineBox[{{29, 36}, {31, 38}}], 
   LineBox[{{29, 34}, {31, 34}}], LineBox[{{29, 32}, {31, 34}}], 
   LineBox[{{29, 30}, {31, 30}}], LineBox[{{29, 28}, {31, 28}}], 
   LineBox[{{29, 26}, {31, 28}}], LineBox[{{29, 24}, {31, 24}}], 
   LineBox[{{29, 22}, {31, 24}}], LineBox[{{29, 20}, {31, 20}}], 
   LineBox[{{29, 18}, {31, 18}}], LineBox[{{29, 16}, {31, 18}}], 
   LineBox[NCache[{{29, 14}, {31, Rational[46, 3]}}, {{29, 14}, {
      31, 15.333333333333334`}}]], 
   LineBox[NCache[{{29, 12}, {31, Rational[38, 3]}}, {{29, 12}, {
      31, 12.666666666666666`}}]], LineBox[{{29, 10}, {31, 10}}], 
   LineBox[{{29, 8}, {31, 8}}], 
   LineBox[NCache[{{29, 8}, {31, Rational[32, 5]}}, {{29, 8}, {31, 6.4}}]], 
   LineBox[NCache[{{29, 6}, {31, Rational[24, 5]}}, {{29, 6}, {31, 4.8}}]], 
   LineBox[NCache[{{29, 4}, {31, Rational[16, 5]}}, {{29, 4}, {31, 3.2}}]], 
   LineBox[NCache[{{29, 2}, {31, Rational[8, 5]}}, {{29, 2}, {31, 1.6}}]], 
   LineBox[{{29, 0}, {31, 0}}], LineBox[{{39, 78}, {41, 78}}], 
   LineBox[NCache[{{39, Rational[538, 7]}, {41, 78}}, {{
      39, 76.85714285714286}, {41, 78}}]], 
   LineBox[NCache[{{39, Rational[530, 7]}, {41, Rational[230, 3]}}, {{
      39, 75.71428571428571}, {41, 76.66666666666667}}]], 
   LineBox[NCache[{{39, Rational[522, 7]}, {41, Rational[226, 3]}}, {{
      39, 74.57142857142857}, {41, 75.33333333333333}}]], 
   LineBox[NCache[{{39, Rational[514, 7]}, {41, 74}}, {{
      39, 73.42857142857143}, {41, 74}}]], 
   LineBox[NCache[{{39, Rational[506, 7]}, {41, Rational[218, 3]}}, {{
      39, 72.28571428571429}, {41, 72.66666666666667}}]], 
   LineBox[NCache[{{39, Rational[498, 7]}, {41, Rational[214, 3]}}, {{
      39, 71.14285714285714}, {41, 71.33333333333333}}]], 
   LineBox[{{39, 70}, {41, 70}}], LineBox[{{39, 68}, {41, 68}}], 
   LineBox[NCache[{{39, Rational[200, 3]}, {41, Rational[200, 3]}}, {{
      39, 66.66666666666667}, {41, 66.66666666666667}}]], 
   LineBox[NCache[{{39, Rational[196, 3]}, {41, Rational[196, 3]}}, {{
      39, 65.33333333333333}, {41, 65.33333333333333}}]], 
   LineBox[{{39, 64}, {41, 64}}], 
   LineBox[NCache[{{39, Rational[188, 3]}, {41, Rational[188, 3]}}, {{
      39, 62.666666666666664`}, {41, 62.666666666666664`}}]], 
   LineBox[NCache[{{39, Rational[184, 3]}, {41, Rational[184, 3]}}, {{
      39, 61.333333333333336`}, {41, 61.333333333333336`}}]], 
   LineBox[{{39, 60}, {41, 60}}], LineBox[{{39, 58}, {41, 58}}], 
   LineBox[NCache[{{39, Rational[282, 5]}, {41, Rational[282, 5]}}, {{
      39, 56.4}, {41, 56.4}}]], 
   LineBox[NCache[{{39, Rational[274, 5]}, {41, Rational[274, 5]}}, {{
      39, 54.8}, {41, 54.8}}]], 
   LineBox[NCache[{{39, Rational[266, 5]}, {41, Rational[266, 5]}}, {{
      39, 53.2}, {41, 53.2}}]], 
   LineBox[NCache[{{39, Rational[258, 5]}, {41, Rational[258, 5]}}, {{
      39, 51.6}, {41, 51.6}}]], LineBox[{{39, 50}, {41, 50}}], 
   LineBox[{{39, 48}, {41, 48}}], 
   LineBox[NCache[{{39, Rational[136, 3]}, {41, Rational[136, 3]}}, {{
      39, 45.333333333333336`}, {41, 45.333333333333336`}}]], 
   LineBox[NCache[{{39, Rational[128, 3]}, {41, Rational[128, 3]}}, {{
      39, 42.666666666666664`}, {41, 42.666666666666664`}}]], 
   LineBox[{{39, 40}, {41, 40}}], LineBox[{{39, 38}, {41, 38}}], 
   LineBox[{{39, 34}, {41, 34}}], LineBox[{{39, 30}, {41, 30}}], 
   LineBox[{{39, 28}, {41, 28}}], LineBox[{{39, 24}, {41, 24}}], 
   LineBox[{{39, 20}, {41, 20}}], LineBox[{{39, 18}, {41, 18}}], 
   LineBox[NCache[{{39, Rational[46, 3]}, {41, Rational[46, 3]}}, {{
      39, 15.333333333333334`}, {41, 15.333333333333334`}}]], 
   LineBox[NCache[{{39, Rational[38, 3]}, {41, Rational[38, 3]}}, {{
      39, 12.666666666666666`}, {41, 12.666666666666666`}}]], 
   LineBox[{{39, 10}, {41, 10}}], LineBox[{{39, 8}, {41, 8}}], 
   LineBox[NCache[{{39, Rational[32, 5]}, {41, Rational[32, 5]}}, {{
      39, 6.4}, {41, 6.4}}]], 
   LineBox[NCache[{{39, Rational[24, 5]}, {41, Rational[24, 5]}}, {{
      39, 4.8}, {41, 4.8}}]], 
   LineBox[NCache[{{39, Rational[16, 5]}, {41, Rational[16, 5]}}, {{
      39, 3.2}, {41, 3.2}}]], 
   LineBox[NCache[{{39, Rational[8, 5]}, {41, Rational[8, 5]}}, {{39, 1.6}, {
      41, 1.6}}]], LineBox[{{39, 0}, {41, 0}}], LineBox[{{49, 78}, {51, 78}}],
    LineBox[NCache[{{49, Rational[230, 3]}, {51, 78}}, {{
      49, 76.66666666666667}, {51, 78}}]], 
   LineBox[NCache[{{49, Rational[226, 3]}, {51, 78}}, {{
      49, 75.33333333333333}, {51, 78}}]], LineBox[{{49, 74}, {51, 74}}], 
   LineBox[NCache[{{49, Rational[218, 3]}, {51, 74}}, {{
      49, 72.66666666666667}, {51, 74}}]], 
   LineBox[NCache[{{49, Rational[214, 3]}, {51, 70}}, {{
      49, 71.33333333333333}, {51, 70}}]], LineBox[{{49, 70}, {51, 70}}], 
   LineBox[{{49, 68}, {51, 68}}], 
   LineBox[NCache[{{49, Rational[200, 3]}, {51, 68}}, {{
      49, 66.66666666666667}, {51, 68}}]], 
   LineBox[NCache[{{49, Rational[196, 3]}, {51, Rational[196, 3]}}, {{
      49, 65.33333333333333}, {51, 65.33333333333333}}]], 
   LineBox[NCache[{{49, 64}, {51, Rational[196, 3]}}, {{49, 64}, {
      51, 65.33333333333333}}]], 
   LineBox[NCache[{{49, Rational[188, 3]}, {51, Rational[188, 3]}}, {{
      49, 62.666666666666664`}, {51, 62.666666666666664`}}]], 
   LineBox[NCache[{{49, Rational[184, 3]}, {51, Rational[188, 3]}}, {{
      49, 61.333333333333336`}, {51, 62.666666666666664`}}]], 
   LineBox[{{49, 60}, {51, 60}}], LineBox[{{49, 58}, {51, 58}}], 
   LineBox[NCache[{{49, Rational[282, 5]}, {51, 58}}, {{49, 56.4}, {51, 
      58}}]], 
   LineBox[NCache[{{49, Rational[274, 5]}, {51, 56}}, {{49, 54.8}, {51, 
      56}}]], LineBox[
    NCache[{{49, Rational[266, 5]}, {51, 54}}, {{49, 53.2}, {51, 54}}]], 
   LineBox[NCache[{{49, Rational[258, 5]}, {51, 52}}, {{49, 51.6}, {51, 
      52}}]], LineBox[{{49, 50}, {51, 50}}], LineBox[{{49, 48}, {51, 48}}], 
   LineBox[NCache[{{49, 48}, {51, Rational[140, 3]}}, {{49, 48}, {
      51, 46.666666666666664`}}]], 
   LineBox[NCache[{{49, Rational[136, 3]}, {51, Rational[136, 3]}}, {{
      49, 45.333333333333336`}, {51, 45.333333333333336`}}]], 
   LineBox[NCache[{{49, Rational[136, 3]}, {51, 44}}, {{
      49, 45.333333333333336`}, {51, 44}}]], 
   LineBox[NCache[{{49, Rational[128, 3]}, {51, Rational[128, 3]}}, {{
      49, 42.666666666666664`}, {51, 42.666666666666664`}}]], 
   LineBox[NCache[{{49, Rational[128, 3]}, {51, Rational[124, 3]}}, {{
      49, 42.666666666666664`}, {51, 41.333333333333336`}}]], 
   LineBox[{{49, 40}, {51, 40}}], LineBox[{{49, 38}, {51, 38}}], 
   LineBox[NCache[{{49, 38}, {51, Rational[110, 3]}}, {{49, 38}, {
      51, 36.666666666666664`}}]], 
   LineBox[NCache[{{49, 38}, {51, Rational[106, 3]}}, {{49, 38}, {
      51, 35.333333333333336`}}]], LineBox[{{49, 34}, {51, 34}}], 
   LineBox[NCache[{{49, 34}, {51, Rational[98, 3]}}, {{49, 34}, {
      51, 32.666666666666664`}}]], 
   LineBox[NCache[{{49, 30}, {51, Rational[94, 3]}}, {{49, 30}, {
      51, 31.333333333333332`}}]], LineBox[{{49, 30}, {51, 30}}], 
   LineBox[{{49, 28}, {51, 28}}], 
   LineBox[NCache[{{49, 28}, {51, Rational[80, 3]}}, {{49, 28}, {
      51, 26.666666666666668`}}]], 
   LineBox[NCache[{{49, 28}, {51, Rational[76, 3]}}, {{49, 28}, {
      51, 25.333333333333332`}}]], LineBox[{{49, 24}, {51, 24}}], 
   LineBox[NCache[{{49, 24}, {51, Rational[68, 3]}}, {{49, 24}, {
      51, 22.666666666666668`}}]], 
   LineBox[NCache[{{49, 20}, {51, Rational[64, 3]}}, {{49, 20}, {
      51, 21.333333333333332`}}]], LineBox[{{49, 20}, {51, 20}}], 
   LineBox[{{49, 18}, {51, 18}}], LineBox[{{49, 18}, {51, 16}}], 
   LineBox[
    NCache[{{49, Rational[46, 3]}, {51, 14}}, {{49, 15.333333333333334`}, {51,
       14}}]], LineBox[
    NCache[{{49, Rational[38, 3]}, {51, 12}}, {{49, 12.666666666666666`}, {51,
       12}}]], LineBox[{{49, 10}, {51, 10}}], LineBox[{{49, 8}, {51, 8}}], 
   LineBox[NCache[{{49, Rational[32, 5]}, {51, Rational[32, 5]}}, {{
      49, 6.4}, {51, 6.4}}]], 
   LineBox[NCache[{{49, Rational[24, 5]}, {51, Rational[24, 5]}}, {{
      49, 4.8}, {51, 4.8}}]], 
   LineBox[NCache[{{49, Rational[16, 5]}, {51, Rational[16, 5]}}, {{
      49, 3.2}, {51, 3.2}}]], 
   LineBox[NCache[{{49, Rational[8, 5]}, {51, Rational[8, 5]}}, {{49, 1.6}, {
      51, 1.6}}]], LineBox[{{49, 0}, {51, 0}}], LineBox[{{59, 78}, {61, 78}}],
    LineBox[{{59, 74}, {61, 74}}], LineBox[{{59, 70}, {61, 70}}], 
   LineBox[{{59, 68}, {61, 68}}], 
   LineBox[NCache[{{59, Rational[196, 3]}, {61, 68}}, {{
      59, 65.33333333333333}, {61, 68}}]], 
   LineBox[NCache[{{59, Rational[188, 3]}, {61, 64}}, {{
      59, 62.666666666666664`}, {61, 64}}]], LineBox[{{59, 60}, {61, 60}}], 
   LineBox[{{59, 58}, {61, 58}}], LineBox[{{59, 56}, {61, 58}}], 
   LineBox[{{59, 54}, {61, 54}}], LineBox[{{59, 52}, {61, 54}}], 
   LineBox[{{59, 50}, {61, 50}}], LineBox[{{59, 48}, {61, 48}}], 
   LineBox[NCache[{{59, Rational[140, 3]}, {61, 48}}, {{
      59, 46.666666666666664`}, {61, 48}}]], 
   LineBox[NCache[{{59, Rational[136, 3]}, {61, 48}}, {{
      59, 45.333333333333336`}, {61, 48}}]], LineBox[{{59, 44}, {61, 44}}], 
   LineBox[NCache[{{59, Rational[128, 3]}, {61, 44}}, {{
      59, 42.666666666666664`}, {61, 44}}]], 
   LineBox[NCache[{{59, Rational[124, 3]}, {61, 40}}, {{
      59, 41.333333333333336`}, {61, 40}}]], LineBox[{{59, 40}, {61, 40}}], 
   LineBox[{{59, 38}, {61, 38}}], 
   LineBox[NCache[{{59, Rational[110, 3]}, {61, 38}}, {{
      59, 36.666666666666664`}, {61, 38}}]], 
   LineBox[NCache[{{59, Rational[106, 3]}, {61, 36}}, {{
      59, 35.333333333333336`}, {61, 36}}]], LineBox[{{59, 34}, {61, 34}}], 
   LineBox[NCache[{{59, Rational[98, 3]}, {61, 34}}, {{
      59, 32.666666666666664`}, {61, 34}}]], 
   LineBox[NCache[{{59, Rational[94, 3]}, {61, 32}}, {{
      59, 31.333333333333332`}, {61, 32}}]], LineBox[{{59, 30}, {61, 30}}], 
   LineBox[{{59, 28}, {61, 28}}], 
   LineBox[NCache[{{59, Rational[80, 3]}, {61, 28}}, {{
      59, 26.666666666666668`}, {61, 28}}]], 
   LineBox[NCache[{{59, Rational[76, 3]}, {61, 26}}, {{
      59, 25.333333333333332`}, {61, 26}}]], LineBox[{{59, 24}, {61, 24}}], 
   LineBox[NCache[{{59, Rational[68, 3]}, {61, 24}}, {{
      59, 22.666666666666668`}, {61, 24}}]], 
   LineBox[NCache[{{59, Rational[64, 3]}, {61, 22}}, {{
      59, 21.333333333333332`}, {61, 22}}]], LineBox[{{59, 20}, {61, 20}}], 
   LineBox[{{59, 18}, {61, 18}}], LineBox[{{59, 16}, {61, 16}}], 
   LineBox[{{59, 14}, {61, 14}}], LineBox[{{59, 12}, {61, 12}}], 
   LineBox[{{59, 10}, {61, 10}}], LineBox[{{59, 8}, {61, 8}}], 
   LineBox[NCache[{{59, Rational[32, 5]}, {61, 8}}, {{59, 6.4}, {61, 8}}]], 
   LineBox[NCache[{{59, Rational[24, 5]}, {61, Rational[16, 3]}}, {{
      59, 4.8}, {61, 5.333333333333333}}]], 
   LineBox[NCache[{{59, Rational[16, 5]}, {61, Rational[8, 3]}}, {{59, 3.2}, {
      61, 2.6666666666666665`}}]], 
   LineBox[NCache[{{59, Rational[8, 5]}, {61, Rational[8, 3]}}, {{59, 1.6}, {
      61, 2.6666666666666665`}}]], LineBox[{{59, 0}, {61, 0}}], 
   LineBox[{{11, 70}, {11, 68}}], LineBox[{{15, 70}, {15, 68}}], 
   LineBox[{{19, 70}, {19, 68}}], LineBox[{{11, 60}, {11, 58}}], 
   LineBox[{{15, 60}, {15, 58}}], LineBox[{{19, 60}, {19, 58}}], 
   LineBox[{{11, 50}, {11, 48}}], LineBox[{{15, 50}, {15, 48}}], 
   LineBox[{{19, 50}, {19, 48}}], LineBox[{{11, 40}, {11, 38}}], 
   LineBox[{{15, 40}, {15, 38}}], LineBox[{{19, 40}, {19, 38}}], 
   LineBox[{{11, 30}, {11, 28}}], 
   LineBox[NCache[{{11, 30}, {Rational[41, 3], 28}}, {{11, 30}, {
      13.666666666666666`, 28}}]], 
   LineBox[NCache[{{15, 30}, {Rational[49, 3], 28}}, {{15, 30}, {
      16.333333333333332`, 28}}]], LineBox[{{19, 30}, {19, 28}}], 
   LineBox[{{11, 20}, {11, 18}}], LineBox[{{11, 20}, {13, 18}}], 
   LineBox[
    NCache[{{Rational[41, 3], 20}, {15, 18}}, {{13.666666666666666`, 20}, {15,
       18}}]], LineBox[
    NCache[{{Rational[49, 3], 20}, {17, 18}}, {{16.333333333333332`, 20}, {17,
       18}}]], LineBox[{{19, 20}, {19, 18}}], LineBox[{{11, 10}, {11, 8}}], 
   LineBox[{{13, 10}, {13, 8}}], LineBox[{{15, 10}, {15, 8}}], 
   LineBox[{{17, 10}, {17, 8}}], LineBox[{{19, 10}, {19, 8}}], 
   LineBox[{{21, 70}, {21, 68}}], LineBox[{{25, 70}, {25, 68}}], 
   LineBox[{{29, 70}, {29, 68}}], LineBox[{{21, 60}, {21, 58}}], 
   LineBox[{{25, 60}, {25, 58}}], LineBox[{{29, 60}, {29, 58}}], 
   LineBox[{{21, 50}, {21, 48}}], LineBox[{{21, 50}, {23, 48}}], 
   LineBox[{{25, 50}, {25, 48}}], LineBox[{{25, 50}, {27, 48}}], 
   LineBox[{{29, 50}, {29, 48}}], LineBox[{{21, 40}, {21, 38}}], 
   LineBox[{{23, 40}, {23, 38}}], LineBox[{{25, 40}, {25, 38}}], 
   LineBox[{{27, 40}, {27, 38}}], LineBox[{{29, 40}, {29, 38}}], 
   LineBox[{{21, 30}, {21, 28}}], LineBox[{{23, 30}, {23, 28}}], 
   LineBox[{{25, 30}, {25, 28}}], LineBox[{{27, 30}, {27, 28}}], 
   LineBox[{{29, 30}, {29, 28}}], LineBox[{{21, 20}, {21, 18}}], 
   LineBox[{{23, 20}, {23, 18}}], LineBox[{{25, 20}, {25, 18}}], 
   LineBox[{{27, 20}, {27, 18}}], LineBox[{{29, 20}, {29, 18}}], 
   LineBox[{{21, 10}, {21, 8}}], LineBox[{{23, 10}, {23, 8}}], 
   LineBox[{{25, 10}, {25, 8}}], LineBox[{{27, 10}, {27, 8}}], 
   LineBox[{{29, 10}, {29, 8}}], LineBox[{{31, 70}, {31, 68}}], 
   LineBox[NCache[{{Rational[225, 7], 70}, {31, 68}}, {{
      32.142857142857146`, 70}, {31, 68}}]], 
   LineBox[NCache[{{Rational[233, 7], 70}, {Rational[97, 3], 68}}, {{
      33.285714285714285`, 70}, {32.333333333333336`, 68}}]], 
   LineBox[NCache[{{Rational[241, 7], 70}, {Rational[101, 3], 68}}, {{
      34.42857142857143, 70}, {33.666666666666664`, 68}}]], 
   LineBox[NCache[{{Rational[249, 7], 70}, {35, 68}}, {{
      35.57142857142857, 70}, {35, 68}}]], 
   LineBox[NCache[{{Rational[257, 7], 70}, {Rational[109, 3], 68}}, {{
      36.714285714285715`, 70}, {36.333333333333336`, 68}}]], 
   LineBox[
    NCache[{{Rational[265, 7], 70}, {Rational[113, 3], 68}}, {{
      37.857142857142854`, 70}, {37.666666666666664`, 68}}]], 
   LineBox[{{39, 70}, {39, 68}}], LineBox[{{31, 60}, {31, 58}}], 
   LineBox[NCache[{{Rational[97, 3], 60}, {31, 58}}, {{
      32.333333333333336`, 60}, {31, 58}}]], 
   LineBox[NCache[{{Rational[101, 3], 60}, {Rational[163, 5], 58}}, {{
      33.666666666666664`, 60}, {32.6, 58}}]], 
   LineBox[NCache[{{35, 60}, {Rational[171, 5], 58}}, {{35, 60}, {
      34.2, 58}}]], 
   LineBox[NCache[{{Rational[109, 3], 60}, {Rational[179, 5], 58}}, {{
      36.333333333333336`, 60}, {35.8, 58}}]], 
   LineBox[NCache[{{Rational[113, 3], 60}, {Rational[187, 5], 58}}, {{
      37.666666666666664`, 60}, {37.4, 58}}]], LineBox[{{39, 60}, {39, 58}}], 
   LineBox[{{31, 50}, {31, 48}}], 
   LineBox[NCache[{{Rational[163, 5], 50}, {31, 48}}, {{32.6, 50}, {31, 
      48}}]], LineBox[
    NCache[{{Rational[171, 5], 50}, {Rational[101, 3], 48}}, {{34.2, 50}, {
      33.666666666666664`, 48}}]], 
   LineBox[NCache[{{Rational[179, 5], 50}, {Rational[109, 3], 48}}, {{
      35.8, 50}, {36.333333333333336`, 48}}]], 
   LineBox[NCache[{{Rational[187, 5], 50}, {Rational[109, 3], 48}}, {{
      37.4, 50}, {36.333333333333336`, 48}}]], LineBox[{{39, 50}, {39, 48}}], 
   LineBox[{{31, 40}, {31, 38}}], 
   LineBox[NCache[{{Rational[101, 3], 40}, {31, 38}}, {{
      33.666666666666664`, 40}, {31, 38}}]], 
   LineBox[NCache[{{Rational[109, 3], 40}, {35, 38}}, {{
      36.333333333333336`, 40}, {35, 38}}]], LineBox[{{39, 40}, {39, 38}}], 
   LineBox[{{31, 30}, {31, 28}}], LineBox[{{35, 30}, {35, 28}}], 
   LineBox[{{39, 30}, {39, 28}}], LineBox[{{31, 20}, {31, 18}}], 
   LineBox[NCache[{{31, 20}, {Rational[101, 3], 18}}, {{31, 20}, {
      33.666666666666664`, 18}}]], 
   LineBox[NCache[{{35, 20}, {Rational[109, 3], 18}}, {{35, 20}, {
      36.333333333333336`, 18}}]], LineBox[{{39, 20}, {39, 18}}], 
   LineBox[{{31, 10}, {31, 8}}], 
   LineBox[NCache[{{31, 10}, {Rational[163, 5], 8}}, {{31, 10}, {32.6, 8}}]], 
   LineBox[
    NCache[{{Rational[101, 3], 10}, {Rational[171, 5], 8}}, {{
      33.666666666666664`, 10}, {34.2, 8}}]], 
   LineBox[NCache[{{Rational[109, 3], 10}, {Rational[179, 5], 8}}, {{
      36.333333333333336`, 10}, {35.8, 8}}]], 
   LineBox[NCache[{{Rational[109, 3], 10}, {Rational[187, 5], 8}}, {{
      36.333333333333336`, 10}, {37.4, 8}}]], LineBox[{{39, 10}, {39, 8}}], 
   LineBox[{{41, 70}, {41, 68}}], 
   LineBox[NCache[{{Rational[127, 3], 70}, {Rational[127, 3], 68}}, {{
      42.333333333333336`, 70}, {42.333333333333336`, 68}}]], 
   LineBox[NCache[{{Rational[131, 3], 70}, {Rational[131, 3], 68}}, {{
      43.666666666666664`, 70}, {43.666666666666664`, 68}}]], 
   LineBox[{{45, 70}, {45, 68}}], 
   LineBox[NCache[{{Rational[139, 3], 70}, {Rational[139, 3], 68}}, {{
      46.333333333333336`, 70}, {46.333333333333336`, 68}}]], 
   LineBox[NCache[{{Rational[143, 3], 70}, {Rational[143, 3], 68}}, {{
      47.666666666666664`, 70}, {47.666666666666664`, 68}}]], 
   LineBox[{{49, 70}, {49, 68}}], LineBox[{{41, 60}, {41, 58}}], 
   LineBox[NCache[{{Rational[127, 3], 60}, {41, 58}}, {{
      42.333333333333336`, 60}, {41, 58}}]], 
   LineBox[NCache[{{Rational[131, 3], 60}, {Rational[213, 5], 58}}, {{
      43.666666666666664`, 60}, {42.6, 58}}]], 
   LineBox[NCache[{{45, 60}, {Rational[221, 5], 58}}, {{45, 60}, {
      44.2, 58}}]], 
   LineBox[NCache[{{Rational[139, 3], 60}, {Rational[229, 5], 58}}, {{
      46.333333333333336`, 60}, {45.8, 58}}]], 
   LineBox[NCache[{{Rational[143, 3], 60}, {Rational[237, 5], 58}}, {{
      47.666666666666664`, 60}, {47.4, 58}}]], LineBox[{{49, 60}, {49, 58}}], 
   LineBox[{{41, 50}, {41, 48}}], 
   LineBox[NCache[{{Rational[213, 5], 50}, {41, 48}}, {{42.6, 50}, {41, 
      48}}]], LineBox[
    NCache[{{Rational[221, 5], 50}, {Rational[131, 3], 48}}, {{44.2, 50}, {
      43.666666666666664`, 48}}]], 
   LineBox[NCache[{{Rational[229, 5], 50}, {Rational[139, 3], 48}}, {{
      45.8, 50}, {46.333333333333336`, 48}}]], 
   LineBox[NCache[{{Rational[237, 5], 50}, {Rational[139, 3], 48}}, {{
      47.4, 50}, {46.333333333333336`, 48}}]], LineBox[{{49, 50}, {49, 48}}], 
   LineBox[{{41, 40}, {41, 38}}], 
   LineBox[NCache[{{Rational[131, 3], 40}, {41, 38}}, {{
      43.666666666666664`, 40}, {41, 38}}]], 
   LineBox[NCache[{{Rational[139, 3], 40}, {45, 38}}, {{
      46.333333333333336`, 40}, {45, 38}}]], LineBox[{{49, 40}, {49, 38}}], 
   LineBox[{{41, 30}, {41, 28}}], LineBox[{{45, 30}, {45, 28}}], 
   LineBox[{{49, 30}, {49, 28}}], LineBox[{{41, 20}, {41, 18}}], 
   LineBox[NCache[{{41, 20}, {Rational[131, 3], 18}}, {{41, 20}, {
      43.666666666666664`, 18}}]], 
   LineBox[NCache[{{45, 20}, {Rational[139, 3], 18}}, {{45, 20}, {
      46.333333333333336`, 18}}]], LineBox[{{49, 20}, {49, 18}}], 
   LineBox[{{41, 10}, {41, 8}}], 
   LineBox[NCache[{{41, 10}, {Rational[213, 5], 8}}, {{41, 10}, {42.6, 8}}]], 
   LineBox[NCache[{{Rational[131, 3], 10}, {Rational[221, 5], 8}}, {{
      43.666666666666664`, 10}, {44.2, 8}}]], 
   LineBox[NCache[{{Rational[139, 3], 10}, {Rational[229, 5], 8}}, {{
      46.333333333333336`, 10}, {45.8, 8}}]], 
   LineBox[NCache[{{Rational[139, 3], 10}, {Rational[237, 5], 8}}, {{
      46.333333333333336`, 10}, {47.4, 8}}]], LineBox[{{49, 10}, {49, 8}}], 
   LineBox[{{51, 70}, {51, 68}}], 
   LineBox[NCache[{{51, 70}, {Rational[161, 3], 68}}, {{51, 70}, {
      53.666666666666664`, 68}}]], 
   LineBox[NCache[{{55, 70}, {Rational[169, 3], 68}}, {{55, 70}, {
      56.333333333333336`, 68}}]], LineBox[{{59, 70}, {59, 68}}], 
   LineBox[{{51, 60}, {51, 58}}], LineBox[{{51, 60}, {53, 58}}], 
   LineBox[NCache[{{Rational[161, 3], 60}, {55, 58}}, {{
      53.666666666666664`, 60}, {55, 58}}]], 
   LineBox[NCache[{{Rational[169, 3], 60}, {57, 58}}, {{
      56.333333333333336`, 60}, {57, 58}}]], LineBox[{{59, 60}, {59, 58}}], 
   LineBox[{{51, 50}, {51, 48}}], 
   LineBox[NCache[{{51, 50}, {Rational[157, 3], 48}}, {{51, 50}, {
      52.333333333333336`, 48}}]], 
   LineBox[NCache[{{53, 50}, {Rational[161, 3], 48}}, {{53, 50}, {
      53.666666666666664`, 48}}]], LineBox[{{55, 50}, {55, 48}}], 
   LineBox[
    NCache[{{55, 50}, {Rational[169, 3], 48}}, {{55, 50}, {
      56.333333333333336`, 48}}]], 
   LineBox[NCache[{{57, 50}, {Rational[173, 3], 48}}, {{57, 50}, {
      57.666666666666664`, 48}}]], LineBox[{{59, 50}, {59, 48}}], 
   LineBox[{{51, 40}, {51, 38}}], 
   LineBox[NCache[{{Rational[157, 3], 40}, {Rational[157, 3], 38}}, {{
      52.333333333333336`, 40}, {52.333333333333336`, 38}}]], 
   LineBox[NCache[{{Rational[161, 3], 40}, {Rational[161, 3], 38}}, {{
      53.666666666666664`, 40}, {53.666666666666664`, 38}}]], 
   LineBox[{{55, 40}, {55, 38}}], 
   LineBox[NCache[{{Rational[169, 3], 40}, {Rational[169, 3], 38}}, {{
      56.333333333333336`, 40}, {56.333333333333336`, 38}}]], 
   LineBox[NCache[{{Rational[173, 3], 40}, {Rational[173, 3], 38}}, {{
      57.666666666666664`, 40}, {57.666666666666664`, 38}}]], 
   LineBox[{{59, 40}, {59, 38}}], LineBox[{{51, 30}, {51, 28}}], 
   LineBox[NCache[{{Rational[157, 3], 30}, {Rational[157, 3], 28}}, {{
      52.333333333333336`, 30}, {52.333333333333336`, 28}}]], 
   LineBox[NCache[{{Rational[161, 3], 30}, {Rational[161, 3], 28}}, {{
      53.666666666666664`, 30}, {53.666666666666664`, 28}}]], 
   LineBox[{{55, 30}, {55, 28}}], 
   LineBox[NCache[{{Rational[169, 3], 30}, {Rational[169, 3], 28}}, {{
      56.333333333333336`, 30}, {56.333333333333336`, 28}}]], 
   LineBox[NCache[{{Rational[173, 3], 30}, {Rational[173, 3], 28}}, {{
      57.666666666666664`, 30}, {57.666666666666664`, 28}}]], 
   LineBox[{{59, 30}, {59, 28}}], LineBox[{{51, 20}, {51, 18}}], 
   LineBox[NCache[{{Rational[157, 3], 20}, {51, 18}}, {{
      52.333333333333336`, 20}, {51, 18}}]], 
   LineBox[NCache[{{Rational[161, 3], 20}, {53, 18}}, {{
      53.666666666666664`, 20}, {53, 18}}]], LineBox[{{55, 20}, {55, 18}}], 
   LineBox[NCache[{{Rational[169, 3], 20}, {55, 18}}, {{
      56.333333333333336`, 20}, {55, 18}}]], 
   LineBox[NCache[{{Rational[173, 3], 20}, {57, 18}}, {{
      57.666666666666664`, 20}, {57, 18}}]], LineBox[{{59, 20}, {59, 18}}], 
   LineBox[{{51, 10}, {51, 8}}], 
   LineBox[NCache[{{51, 10}, {Rational[263, 5], 8}}, {{51, 10}, {52.6, 8}}]], 
   LineBox[NCache[{{53, 10}, {Rational[271, 5], 8}}, {{53, 10}, {54.2, 8}}]], 
   LineBox[NCache[{{55, 10}, {Rational[279, 5], 8}}, {{55, 10}, {55.8, 8}}]], 
   LineBox[NCache[{{57, 10}, {Rational[287, 5], 8}}, {{57, 10}, {57.4, 8}}]], 
   LineBox[{{59, 10}, {59, 8}}], LineBox[{{61, 70}, {61, 68}}], 
   LineBox[{{65, 70}, {65, 68}}], LineBox[{{69, 70}, {69, 68}}], 
   LineBox[{{61, 60}, {61, 58}}], LineBox[{{65, 60}, {65, 58}}], 
   LineBox[{{69, 60}, {69, 58}}], LineBox[{{61, 50}, {61, 48}}], 
   LineBox[{{65, 50}, {65, 48}}], LineBox[{{69, 50}, {69, 48}}], 
   LineBox[{{61, 40}, {61, 38}}], LineBox[{{61, 40}, {63, 38}}], 
   LineBox[{{65, 40}, {65, 38}}], LineBox[{{65, 40}, {67, 38}}], 
   LineBox[{{69, 40}, {69, 38}}], LineBox[{{61, 30}, {61, 28}}], 
   LineBox[{{63, 30}, {63, 28}}], LineBox[{{65, 30}, {65, 28}}], 
   LineBox[{{67, 30}, {67, 28}}], LineBox[{{69, 30}, {69, 28}}], 
   LineBox[{{61, 20}, {61, 18}}], LineBox[{{63, 20}, {63, 18}}], 
   LineBox[{{65, 20}, {65, 18}}], LineBox[{{67, 20}, {67, 18}}], 
   LineBox[{{69, 20}, {69, 18}}], LineBox[{{61, 10}, {61, 8}}], 
   LineBox[{{63, 10}, {61, 8}}], 
   LineBox[NCache[{{65, 10}, {Rational[191, 3], 8}}, {{65, 10}, {
      63.666666666666664`, 8}}]], 
   LineBox[NCache[{{67, 10}, {Rational[199, 3], 8}}, {{67, 10}, {
      66.33333333333333, 8}}]], LineBox[{{69, 10}, {69, 8}}]},
  ImageSize->NCache[
    Rational[1125, 2], 562.5]]], "Output",
 CellChangeTimes->{
  3.470842993955387*^9, {3.470846037964948*^9, 3.470846059145713*^9}, 
   3.470846132306806*^9, 3.470849665421285*^9, 3.470867705700186*^9, 
   3.470867782958806*^9, 3.470874459317524*^9, 3.47087825082829*^9, 
   3.470881793085957*^9, 3.470912081547662*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateMazeFromImage", "[", 
  RowBox[{"img", ",", "resx3", ",", "resy3", ",", "300", ",", "True"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.470838755054338*^9, 3.470838762532947*^9}, {
   3.470838847462654*^9, 3.47083887147799*^9}, 3.470839002843334*^9, {
   3.470839767652123*^9, 3.470839768526553*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.5], AbsoluteThickness[3], LineBox[{{11, 2}, {13, 2}}], 
    LineBox[{{11, 4}, {13, 4}}], LineBox[{{11, 6}, {11, 4}}], 
    LineBox[{{11, 12}, {11, 10}}], LineBox[{{11, 14}, {13, 14}}], 
    LineBox[{{11, 16}, {11, 14}}], LineBox[{{11, 20}, {11, 18}}], 
    LineBox[NCache[{{11, Rational[68, 3]}, {
       Rational[41, 3], Rational[68, 3]}}, {{11, 22.666666666666668`}, {
       13.666666666666666`, 22.666666666666668`}}]], 
    LineBox[NCache[{{11, 28}, {11, Rational[76, 3]}}, {{11, 28}, {
       11, 25.333333333333332`}}]], LineBox[{{11, 30}, {11, 28}}], 
    LineBox[{{11, 34}, {15, 34}}], LineBox[{{11, 40}, {15, 40}}], 
    LineBox[{{11, 48}, {15, 48}}], LineBox[{{11, 50}, {15, 50}}], 
    LineBox[{{11, 54}, {11, 50}}], LineBox[{{11, 54}, {15, 54}}], 
    LineBox[{{11, 64}, {15, 64}}], LineBox[{{11, 68}, {11, 64}}], 
    LineBox[{{11, 70}, {15, 70}}], LineBox[{{11, 74}, {15, 74}}], 
    LineBox[{{11, 78}, {15, 78}}], LineBox[{{13, 2}, {13, 0}}], 
    LineBox[{{13, 4}, {15, 4}}], LineBox[{{13, 6}, {15, 6}}], 
    LineBox[{{13, 8}, {13, 6}}], LineBox[{{13, 10}, {13, 8}}], 
    LineBox[{{13, 12}, {13, 10}}], LineBox[{{13, 12}, {15, 12}}], 
    LineBox[{{13, 14}, {15, 14}}], LineBox[{{13, 16}, {15, 16}}], 
    LineBox[{{13, 18}, {13, 16}}], 
    LineBox[NCache[{{Rational[41, 3], 20}, {15, 18}}, {{
       13.666666666666666`, 20}, {15, 18}}]], 
    LineBox[NCache[{{Rational[41, 3], Rational[68, 3]}, {
       Rational[41, 3], 20}}, {{13.666666666666666`, 22.666666666666668`}, {
       13.666666666666666`, 20}}]], 
    LineBox[NCache[{{Rational[41, 3], Rational[76, 3]}, {
       Rational[41, 3], Rational[68, 3]}}, {{13.666666666666666`, 
      25.333333333333332`}, {13.666666666666666`, 22.666666666666668`}}]], 
    LineBox[NCache[{{Rational[41, 3], 28}, {
       Rational[41, 3], Rational[76, 3]}}, {{13.666666666666666`, 28}, {
       13.666666666666666`, 25.333333333333332`}}]], 
    LineBox[NCache[{{Rational[41, 3], 28}, {Rational[49, 3], 28}}, {{
       13.666666666666666`, 28}, {16.333333333333332`, 28}}]], 
    LineBox[{{15, 0}, {17, 0}}], LineBox[{{15, 2}, {17, 2}}], 
    LineBox[{{15, 4}, {15, 2}}], LineBox[{{15, 8}, {15, 6}}], 
    LineBox[{{15, 10}, {15, 8}}], LineBox[{{15, 10}, {17, 10}}], 
    LineBox[{{15, 12}, {17, 12}}], LineBox[{{15, 14}, {17, 14}}], 
    LineBox[{{15, 18}, {15, 16}}], 
    LineBox[NCache[{{15, 30}, {Rational[49, 3], 28}}, {{15, 30}, {
       16.333333333333332`, 28}}]], LineBox[{{15, 30}, {19, 30}}], 
    LineBox[{{15, 38}, {15, 34}}], LineBox[{{15, 38}, {19, 38}}], 
    LineBox[{{15, 40}, {15, 38}}], LineBox[{{15, 44}, {15, 40}}], 
    LineBox[{{15, 44}, {19, 44}}], LineBox[{{15, 48}, {19, 48}}], 
    LineBox[{{15, 50}, {15, 48}}], LineBox[{{15, 58}, {19, 58}}], 
    LineBox[{{15, 60}, {15, 58}}], LineBox[{{15, 64}, {15, 60}}], 
    LineBox[{{15, 68}, {19, 68}}], LineBox[{{15, 70}, {15, 68}}], 
    LineBox[{{15, 74}, {19, 74}}], 
    LineBox[NCache[{{Rational[49, 3], 20}, {17, 18}}, {{
       16.333333333333332`, 20}, {17, 18}}]], 
    LineBox[NCache[{{Rational[49, 3], Rational[68, 3]}, {
       Rational[49, 3], 20}}, {{16.333333333333332`, 22.666666666666668`}, {
       16.333333333333332`, 20}}]], 
    LineBox[NCache[{{Rational[49, 3], Rational[76, 3]}, {
       19, Rational[76, 3]}}, {{16.333333333333332`, 25.333333333333332`}, {
       19, 25.333333333333332`}}]], LineBox[{{17, 2}, {19, 2}}], 
    LineBox[{{17, 4}, {19, 4}}], LineBox[{{17, 6}, {17, 4}}], 
    LineBox[{{17, 6}, {19, 6}}], LineBox[{{17, 8}, {19, 8}}], 
    LineBox[{{17, 10}, {17, 8}}], LineBox[{{17, 12}, {19, 12}}], 
    LineBox[{{17, 14}, {17, 12}}], LineBox[{{17, 16}, {19, 16}}], 
    LineBox[{{17, 18}, {17, 16}}], LineBox[{{17, 18}, {19, 18}}], 
    LineBox[{{19, 2}, {19, 0}}], LineBox[{{19, 2}, {21, 2}}], 
    LineBox[{{19, 4}, {21, 4}}], LineBox[{{19, 8}, {21, 8}}], 
    LineBox[{{19, 10}, {21, 10}}], LineBox[{{19, 14}, {19, 12}}], 
    LineBox[{{19, 14}, {21, 14}}], LineBox[{{19, 16}, {21, 16}}], 
    LineBox[{{19, 20}, {19, 18}}], 
    LineBox[NCache[{{19, Rational[68, 3]}, {19, 20}}, {{
       19, 22.666666666666668`}, {19, 20}}]], 
    LineBox[
     NCache[{{19, Rational[68, 3]}, {21, 22}}, {{19, 22.666666666666668`}, {
       21, 22}}]], 
    LineBox[NCache[{{19, Rational[76, 3]}, {19, Rational[68, 3]}}, {{
       19, 25.333333333333332`}, {19, 22.666666666666668`}}]], 
    LineBox[NCache[{{19, 28}, {19, Rational[76, 3]}}, {{19, 28}, {
       19, 25.333333333333332`}}]], LineBox[{{19, 28}, {21, 26}}], 
    LineBox[{{19, 30}, {19, 28}}], LineBox[{{19, 34}, {21, 34}}], 
    LineBox[{{19, 38}, {19, 34}}], LineBox[{{19, 38}, {21, 36}}], 
    LineBox[{{19, 38}, {21, 38}}], LineBox[{{19, 44}, {19, 40}}], 
    LineBox[{{19, 44}, {21, 44}}], LineBox[{{19, 48}, {19, 44}}], 
    LineBox[{{19, 48}, {21, 48}}], LineBox[{{19, 50}, {21, 50}}], 
    LineBox[{{19, 54}, {19, 50}}], LineBox[{{19, 54}, {21, 54}}], 
    LineBox[{{19, 60}, {19, 58}}], LineBox[{{19, 64}, {19, 60}}], 
    LineBox[{{19, 64}, {21, 64}}], LineBox[{{19, 68}, {21, 68}}], 
    LineBox[{{19, 70}, {21, 70}}], LineBox[{{19, 74}, {19, 70}}], 
    LineBox[{{19, 78}, {19, 74}}], LineBox[{{21, 2}, {21, 0}}], 
    LineBox[{{21, 6}, {21, 4}}], LineBox[{{21, 8}, {21, 6}}], 
    LineBox[{{21, 12}, {21, 10}}], LineBox[{{21, 12}, {23, 12}}], 
    LineBox[{{21, 18}, {21, 16}}], LineBox[{{21, 18}, {23, 18}}], 
    LineBox[{{21, 22}, {21, 20}}], LineBox[{{21, 24}, {21, 22}}], 
    LineBox[{{21, 26}, {21, 24}}], LineBox[{{21, 28}, {21, 26}}], 
    LineBox[{{21, 28}, {23, 28}}], LineBox[{{21, 30}, {23, 30}}], 
    LineBox[{{21, 32}, {21, 30}}], LineBox[{{21, 34}, {23, 34}}], 
    LineBox[{{21, 38}, {21, 36}}], LineBox[{{21, 38}, {23, 38}}], 
    LineBox[{{21, 42}, {23, 42}}], LineBox[{{21, 44}, {23, 44}}], 
    LineBox[{{21, 46}, {21, 44}}], LineBox[{{21, 48}, {21, 46}}], 
    LineBox[{{21, 48}, {23, 48}}], LineBox[{{21, 50}, {23, 48}}], 
    LineBox[{{21, 58}, {21, 54}}], LineBox[{{21, 60}, {21, 58}}], 
    LineBox[{{21, 60}, {25, 60}}], LineBox[{{21, 64}, {21, 60}}], 
    LineBox[{{21, 68}, {25, 68}}], LineBox[{{21, 70}, {25, 70}}], 
    LineBox[{{21, 78}, {21, 74}}], LineBox[{{23, 0}, {25, 0}}], 
    LineBox[{{23, 2}, {25, 2}}], LineBox[{{23, 4}, {23, 2}}], 
    LineBox[{{23, 6}, {23, 4}}], LineBox[{{23, 6}, {25, 6}}], 
    LineBox[{{23, 8}, {25, 8}}], LineBox[{{23, 10}, {23, 8}}], 
    LineBox[{{23, 10}, {25, 10}}], LineBox[{{23, 14}, {23, 12}}], 
    LineBox[{{23, 16}, {23, 14}}], LineBox[{{23, 16}, {25, 16}}], 
    LineBox[{{23, 18}, {25, 18}}], LineBox[{{23, 20}, {23, 18}}], 
    LineBox[{{23, 22}, {23, 20}}], LineBox[{{23, 22}, {25, 22}}], 
    LineBox[{{23, 26}, {25, 26}}], LineBox[{{23, 28}, {25, 28}}], 
    LineBox[{{23, 30}, {23, 28}}], LineBox[{{23, 32}, {25, 32}}], 
    LineBox[{{23, 34}, {23, 32}}], LineBox[{{23, 36}, {23, 34}}], 
    LineBox[{{23, 36}, {25, 36}}], LineBox[{{23, 38}, {25, 38}}], 
    LineBox[{{23, 42}, {23, 40}}], LineBox[{{23, 44}, {23, 42}}], 
    LineBox[{{23, 44}, {25, 44}}], LineBox[{{23, 46}, {25, 46}}], 
    LineBox[{{25, 2}, {27, 2}}], LineBox[{{25, 6}, {25, 4}}], 
    LineBox[{{25, 8}, {27, 8}}], LineBox[{{25, 12}, {25, 10}}], 
    LineBox[{{25, 12}, {27, 12}}], LineBox[{{25, 14}, {25, 12}}], 
    LineBox[{{25, 16}, {25, 14}}], LineBox[{{25, 18}, {27, 18}}], 
    LineBox[{{25, 20}, {27, 20}}], LineBox[{{25, 22}, {25, 20}}], 
    LineBox[{{25, 26}, {25, 24}}], LineBox[{{25, 28}, {25, 26}}], 
    LineBox[{{25, 28}, {27, 28}}], LineBox[{{25, 32}, {25, 30}}], 
    LineBox[{{25, 32}, {27, 32}}], LineBox[{{25, 36}, {25, 34}}], 
    LineBox[{{25, 38}, {25, 36}}], LineBox[{{25, 38}, {27, 38}}], 
    LineBox[{{25, 42}, {27, 42}}], LineBox[{{25, 44}, {27, 44}}], 
    LineBox[{{25, 46}, {25, 44}}], LineBox[{{25, 48}, {27, 48}}], 
    LineBox[{{25, 50}, {25, 48}}], LineBox[{{25, 50}, {29, 50}}], 
    LineBox[{{25, 54}, {25, 50}}], LineBox[{{25, 54}, {29, 54}}], 
    LineBox[{{25, 58}, {25, 54}}], LineBox[{{25, 60}, {29, 60}}], 
    LineBox[{{25, 68}, {29, 68}}], LineBox[{{25, 70}, {25, 68}}], 
    LineBox[{{25, 78}, {25, 74}}], LineBox[{{27, 2}, {27, 0}}], 
    LineBox[{{27, 2}, {29, 2}}], LineBox[{{27, 4}, {29, 4}}], 
    LineBox[{{27, 6}, {27, 4}}], LineBox[{{27, 8}, {27, 6}}], 
    LineBox[{{27, 10}, {27, 8}}], LineBox[{{27, 12}, {27, 10}}], 
    LineBox[{{27, 14}, {27, 12}}], LineBox[{{27, 14}, {29, 14}}], 
    LineBox[{{27, 18}, {27, 16}}], LineBox[{{27, 20}, {29, 20}}], 
    LineBox[{{27, 24}, {27, 22}}], LineBox[{{27, 26}, {29, 26}}], 
    LineBox[{{27, 28}, {29, 28}}], LineBox[{{27, 30}, {27, 28}}], 
    LineBox[{{27, 32}, {29, 32}}], LineBox[{{27, 38}, {29, 38}}], 
    LineBox[{{27, 40}, {27, 38}}], LineBox[{{27, 42}, {29, 42}}], 
    LineBox[{{27, 44}, {27, 42}}], LineBox[{{27, 46}, {29, 46}}], 
    LineBox[{{27, 48}, {29, 48}}], LineBox[{{29, 2}, {29, 0}}], 
    LineBox[NCache[{{29, 4}, {31, Rational[16, 5]}}, {{29, 4}, {31, 3.2}}]], 
    LineBox[NCache[{{29, 6}, {31, Rational[24, 5]}}, {{29, 6}, {31, 4.8}}]], 
    LineBox[{{29, 8}, {29, 6}}], LineBox[{{29, 10}, {29, 8}}], 
    LineBox[{{29, 12}, {29, 10}}], 
    LineBox[NCache[{{29, 14}, {31, Rational[46, 3]}}, {{29, 14}, {
       31, 15.333333333333334`}}]], LineBox[{{29, 16}, {29, 14}}], 
    LineBox[{{29, 18}, {29, 16}}], LineBox[{{29, 18}, {31, 18}}], 
    LineBox[{{29, 22}, {29, 20}}], LineBox[{{29, 24}, {29, 22}}], 
    LineBox[{{29, 24}, {31, 24}}], LineBox[{{29, 26}, {31, 28}}], 
    LineBox[{{29, 28}, {29, 26}}], LineBox[{{29, 28}, {31, 28}}], 
    LineBox[{{29, 32}, {29, 30}}], LineBox[{{29, 32}, {31, 34}}], 
    LineBox[{{29, 34}, {31, 34}}], LineBox[{{29, 36}, {29, 34}}], 
    LineBox[{{29, 36}, {31, 38}}], LineBox[{{29, 38}, {29, 36}}], 
    LineBox[{{29, 40}, {29, 38}}], LineBox[{{29, 40}, {31, 40}}], 
    LineBox[{{29, 42}, {29, 40}}], 
    LineBox[NCache[{{29, 42}, {31, Rational[128, 3]}}, {{29, 42}, {
       31, 42.666666666666664`}}]], 
    LineBox[NCache[{{29, 44}, {31, Rational[136, 3]}}, {{29, 44}, {
       31, 45.333333333333336`}}]], LineBox[{{29, 46}, {29, 44}}], 
    LineBox[{{29, 48}, {31, 48}}], LineBox[{{29, 50}, {31, 50}}], 
    LineBox[NCache[{{29, 50}, {31, Rational[258, 5]}}, {{29, 50}, {
       31, 51.6}}]], 
    LineBox[NCache[{{29, 54}, {31, Rational[274, 5]}}, {{29, 54}, {
       31, 54.8}}]], LineBox[{{29, 58}, {29, 54}}], 
    LineBox[{{29, 58}, {31, 58}}], LineBox[{{29, 60}, {29, 58}}], 
    LineBox[{{29, 64}, {29, 60}}], 
    LineBox[NCache[{{29, 64}, {31, Rational[188, 3]}}, {{29, 64}, {
       31, 62.666666666666664`}}]], LineBox[{{29, 68}, {29, 64}}], 
    LineBox[NCache[{{29, 68}, {31, Rational[196, 3]}}, {{29, 68}, {
       31, 65.33333333333333}}]], LineBox[{{29, 68}, {31, 68}}], 
    LineBox[{{29, 70}, {31, 70}}], 
    LineBox[NCache[{{29, 70}, {31, Rational[498, 7]}}, {{29, 70}, {
       31, 71.14285714285714}}]], LineBox[{{29, 74}, {29, 70}}], 
    LineBox[NCache[{{29, 74}, {31, Rational[514, 7]}}, {{29, 74}, {
       31, 73.42857142857143}}]], 
    LineBox[NCache[{{29, 74}, {31, Rational[522, 7]}}, {{29, 74}, {
       31, 74.57142857142857}}]], LineBox[{{29, 78}, {29, 74}}], 
    LineBox[NCache[{{29, 78}, {31, Rational[530, 7]}}, {{29, 78}, {
       31, 75.71428571428571}}]], 
    LineBox[NCache[{{29, 78}, {31, Rational[538, 7]}}, {{29, 78}, {
       31, 76.85714285714286}}]], 
    LineBox[NCache[{{31, Rational[8, 5]}, {31, 0}}, {{31, 1.6}, {31, 0}}]], 
    LineBox[NCache[{{31, Rational[16, 5]}, {31, Rational[8, 5]}}, {{
       31, 3.2}, {31, 1.6}}]], 
    LineBox[NCache[{{31, Rational[24, 5]}, {
       Rational[163, 5], Rational[24, 5]}}, {{31, 4.8}, {32.6, 4.8}}]], 
    LineBox[NCache[{{31, 8}, {31, Rational[32, 5]}}, {{31, 8}, {31, 6.4}}]], 
    LineBox[NCache[{{31, 8}, {Rational[163, 5], 8}}, {{31, 8}, {32.6, 8}}]], 
    LineBox[{{31, 10}, {31, 8}}], 
    LineBox[NCache[{{31, 10}, {Rational[101, 3], 10}}, {{31, 10}, {
       33.666666666666664`, 10}}]], 
    LineBox[NCache[{{31, Rational[38, 3]}, {31, 10}}, {{
       31, 12.666666666666666`}, {31, 10}}]], 
    LineBox[NCache[{{31, Rational[46, 3]}, {31, Rational[38, 3]}}, {{
       31, 15.333333333333334`}, {31, 12.666666666666666`}}]], 
    LineBox[NCache[{{31, 18}, {Rational[101, 3], 18}}, {{31, 18}, {
       33.666666666666664`, 18}}]], LineBox[{{31, 20}, {31, 18}}], 
    LineBox[NCache[{{31, 20}, {Rational[101, 3], 18}}, {{31, 20}, {
       33.666666666666664`, 18}}]], LineBox[{{31, 20}, {35, 20}}], 
    LineBox[{{31, 24}, {31, 20}}], LineBox[{{31, 28}, {31, 24}}], 
    LineBox[{{31, 30}, {31, 28}}], LineBox[{{31, 30}, {35, 30}}], 
    LineBox[{{31, 34}, {31, 30}}], LineBox[{{31, 38}, {31, 34}}], 
    LineBox[{{31, 38}, {35, 38}}], 
    LineBox[NCache[{{31, Rational[128, 3]}, {
       Rational[101, 3], Rational[128, 3]}}, {{31, 42.666666666666664`}, {
       33.666666666666664`, 42.666666666666664`}}]], 
    LineBox[NCache[{{31, Rational[136, 3]}, {
       Rational[101, 3], Rational[136, 3]}}, {{31, 45.333333333333336`}, {
       33.666666666666664`, 45.333333333333336`}}]], 
    LineBox[NCache[{{31, 48}, {Rational[101, 3], 48}}, {{31, 48}, {
       33.666666666666664`, 48}}]], LineBox[{{31, 50}, {31, 48}}], 
    LineBox[NCache[{{31, Rational[266, 5]}, {31, Rational[258, 5]}}, {{
       31, 53.2}, {31, 51.6}}]], 
    LineBox[NCache[{{31, Rational[274, 5]}, {31, Rational[266, 5]}}, {{
       31, 54.8}, {31, 53.2}}]], 
    LineBox[NCache[{{31, Rational[282, 5]}, {31, Rational[274, 5]}}, {{
       31, 56.4}, {31, 54.8}}]], 
    LineBox[NCache[{{31, 58}, {31, Rational[282, 5]}}, {{31, 58}, {
       31, 56.4}}]], LineBox[{{31, 60}, {31, 58}}], 
    LineBox[NCache[{{31, Rational[184, 3]}, {31, 60}}, {{
       31, 61.333333333333336`}, {31, 60}}]], 
    LineBox[NCache[{{31, Rational[184, 3]}, {
       Rational[97, 3], Rational[184, 3]}}, {{31, 61.333333333333336`}, {
       32.333333333333336`, 61.333333333333336`}}]], 
    LineBox[NCache[{{31, 64}, {31, Rational[188, 3]}}, {{31, 64}, {
       31, 62.666666666666664`}}]], 
    LineBox[NCache[{{31, 64}, {Rational[97, 3], 64}}, {{31, 64}, {
       32.333333333333336`, 64}}]], 
    LineBox[NCache[{{31, Rational[196, 3]}, {
       Rational[97, 3], Rational[196, 3]}}, {{31, 65.33333333333333}, {
       32.333333333333336`, 65.33333333333333}}]], 
    LineBox[NCache[{{31, Rational[200, 3]}, {31, Rational[196, 3]}}, {{
       31, 66.66666666666667}, {31, 65.33333333333333}}]], 
    LineBox[NCache[{{31, Rational[200, 3]}, {
       Rational[97, 3], Rational[200, 3]}}, {{31, 66.66666666666667}, {
       32.333333333333336`, 66.66666666666667}}]], 
    LineBox[{{31, 70}, {31, 68}}], 
    LineBox[NCache[{{31, 70}, {Rational[225, 7], 70}}, {{31, 70}, {
       32.142857142857146`, 70}}]], 
    LineBox[NCache[{{31, Rational[506, 7]}, {31, Rational[498, 7]}}, {{
       31, 72.28571428571429}, {31, 71.14285714285714}}]], 
    LineBox[NCache[{{31, Rational[506, 7]}, {
       Rational[225, 7], Rational[506, 7]}}, {{31, 72.28571428571429}, {
       32.142857142857146`, 72.28571428571429}}]], 
    LineBox[NCache[{{31, Rational[522, 7]}, {
       Rational[225, 7], Rational[522, 7]}}, {{31, 74.57142857142857}, {
       32.142857142857146`, 74.57142857142857}}]], 
    LineBox[NCache[{{31, Rational[530, 7]}, {
       Rational[225, 7], Rational[530, 7]}}, {{31, 75.71428571428571}, {
       32.142857142857146`, 75.71428571428571}}]], 
    LineBox[NCache[{{31, Rational[538, 7]}, {31, Rational[530, 7]}}, {{
       31, 76.85714285714286}, {31, 75.71428571428571}}]], 
    LineBox[NCache[{{31, 78}, {Rational[225, 7], 78}}, {{31, 78}, {
       32.142857142857146`, 78}}]], 
    LineBox[NCache[{{Rational[225, 7], 70}, {31, 68}}, {{
       32.142857142857146`, 70}, {31, 68}}]], 
    LineBox[NCache[{{Rational[225, 7], Rational[498, 7]}, {
       Rational[233, 7], Rational[498, 7]}}, {{32.142857142857146`, 
      71.14285714285714}, {33.285714285714285`, 71.14285714285714}}]], 
    LineBox[NCache[{{Rational[225, 7], Rational[506, 7]}, {
       Rational[225, 7], Rational[498, 7]}}, {{32.142857142857146`, 
      72.28571428571429}, {32.142857142857146`, 71.14285714285714}}]], 
    LineBox[NCache[{{Rational[225, 7], Rational[514, 7]}, {
       Rational[233, 7], Rational[514, 7]}}, {{32.142857142857146`, 
      73.42857142857143}, {33.285714285714285`, 73.42857142857143}}]], 
    LineBox[NCache[{{Rational[225, 7], Rational[522, 7]}, {
       Rational[225, 7], Rational[514, 7]}}, {{32.142857142857146`, 
      74.57142857142857}, {32.142857142857146`, 73.42857142857143}}]], 
    LineBox[NCache[{{Rational[225, 7], Rational[530, 7]}, {
       Rational[233, 7], Rational[530, 7]}}, {{32.142857142857146`, 
      75.71428571428571}, {33.285714285714285`, 75.71428571428571}}]], 
    LineBox[NCache[{{Rational[225, 7], Rational[538, 7]}, {
       Rational[233, 7], Rational[538, 7]}}, {{32.142857142857146`, 
      76.85714285714286}, {33.285714285714285`, 76.85714285714286}}]], 
    LineBox[NCache[{{Rational[225, 7], 78}, {
       Rational[225, 7], Rational[538, 7]}}, {{32.142857142857146`, 78}, {
       32.142857142857146`, 76.85714285714286}}]], 
    LineBox[NCache[{{Rational[97, 3], 60}, {31, 58}}, {{
       32.333333333333336`, 60}, {31, 58}}]], 
    LineBox[NCache[{{Rational[97, 3], 60}, {Rational[101, 3], 60}}, {{
       32.333333333333336`, 60}, {33.666666666666664`, 60}}]], 
    LineBox[NCache[{{Rational[97, 3], Rational[188, 3]}, {
       Rational[97, 3], Rational[184, 3]}}, {{32.333333333333336`, 
      62.666666666666664`}, {32.333333333333336`, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[97, 3], Rational[188, 3]}, {
       Rational[101, 3], Rational[188, 3]}}, {{32.333333333333336`, 
      62.666666666666664`}, {33.666666666666664`, 62.666666666666664`}}]], 
    LineBox[NCache[{{Rational[97, 3], 64}, {Rational[101, 3], 64}}, {{
       32.333333333333336`, 64}, {33.666666666666664`, 64}}]], 
    LineBox[NCache[{{Rational[97, 3], Rational[196, 3]}, {
       Rational[101, 3], Rational[196, 3]}}, {{32.333333333333336`, 
      65.33333333333333}, {33.666666666666664`, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[97, 3], Rational[200, 3]}, {
       Rational[101, 3], Rational[200, 3]}}, {{32.333333333333336`, 
      66.66666666666667}, {33.666666666666664`, 66.66666666666667}}]], 
    LineBox[NCache[{{Rational[97, 3], 68}, {Rational[101, 3], 68}}, {{
       32.333333333333336`, 68}, {33.666666666666664`, 68}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[8, 5]}, {
       Rational[171, 5], Rational[8, 5]}}, {{32.6, 1.6}, {34.2, 1.6}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[16, 5]}, {
       Rational[163, 5], Rational[8, 5]}}, {{32.6, 3.2}, {32.6, 1.6}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[16, 5]}, {
       Rational[171, 5], Rational[16, 5]}}, {{32.6, 3.2}, {34.2, 3.2}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[32, 5]}, {
       Rational[163, 5], Rational[24, 5]}}, {{32.6, 6.4}, {32.6, 4.8}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[32, 5]}, {
       Rational[171, 5], Rational[32, 5]}}, {{32.6, 6.4}, {34.2, 6.4}}]], 
    LineBox[NCache[{{Rational[163, 5], 8}, {
       Rational[163, 5], Rational[32, 5]}}, {{32.6, 8}, {32.6, 6.4}}]], 
    LineBox[NCache[{{Rational[163, 5], 50}, {31, 48}}, {{32.6, 50}, {31, 
       48}}]], LineBox[
     NCache[{{Rational[163, 5], Rational[258, 5]}, {Rational[163, 5], 50}}, {{
       32.6, 51.6}, {32.6, 50}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[266, 5]}, {
       Rational[163, 5], Rational[258, 5]}}, {{32.6, 53.2}, {32.6, 51.6}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[274, 5]}, {
       Rational[163, 5], Rational[266, 5]}}, {{32.6, 54.8}, {32.6, 53.2}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[274, 5]}, {
       Rational[171, 5], Rational[274, 5]}}, {{32.6, 54.8}, {34.2, 54.8}}]], 
    LineBox[NCache[{{Rational[163, 5], Rational[282, 5]}, {
       Rational[171, 5], Rational[282, 5]}}, {{32.6, 56.4}, {34.2, 56.4}}]], 
    LineBox[NCache[{{Rational[163, 5], 58}, {Rational[171, 5], 58}}, {{
       32.6, 58}, {34.2, 58}}]], 
    LineBox[NCache[{{Rational[233, 7], 70}, {Rational[97, 3], 68}}, {{
       33.285714285714285`, 70}, {32.333333333333336`, 68}}]], 
    LineBox[NCache[{{Rational[233, 7], Rational[498, 7]}, {
       Rational[233, 7], 70}}, {{33.285714285714285`, 71.14285714285714}, {
       33.285714285714285`, 70}}]], 
    LineBox[NCache[{{Rational[233, 7], Rational[506, 7]}, {
       Rational[241, 7], Rational[506, 7]}}, {{33.285714285714285`, 
      72.28571428571429}, {34.42857142857143, 72.28571428571429}}]], 
    LineBox[NCache[{{Rational[233, 7], Rational[514, 7]}, {
       Rational[241, 7], Rational[514, 7]}}, {{33.285714285714285`, 
      73.42857142857143}, {34.42857142857143, 73.42857142857143}}]], 
    LineBox[NCache[{{Rational[233, 7], Rational[522, 7]}, {
       Rational[233, 7], Rational[514, 7]}}, {{33.285714285714285`, 
      74.57142857142857}, {33.285714285714285`, 73.42857142857143}}]], 
    LineBox[NCache[{{Rational[233, 7], Rational[530, 7]}, {
       Rational[233, 7], Rational[522, 7]}}, {{33.285714285714285`, 
      75.71428571428571}, {33.285714285714285`, 74.57142857142857}}]], 
    LineBox[NCache[{{Rational[233, 7], Rational[538, 7]}, {
       Rational[241, 7], Rational[538, 7]}}, {{33.285714285714285`, 
      76.85714285714286}, {34.42857142857143, 76.85714285714286}}]], 
    LineBox[NCache[{{Rational[101, 3], 10}, {Rational[171, 5], 8}}, {{
       33.666666666666664`, 10}, {34.2, 8}}]], 
    LineBox[NCache[{{Rational[101, 3], 10}, {Rational[109, 3], 10}}, {{
       33.666666666666664`, 10}, {36.333333333333336`, 10}}]], 
    LineBox[NCache[{{Rational[101, 3], Rational[46, 3]}, {
       Rational[101, 3], Rational[38, 3]}}, {{33.666666666666664`, 
      15.333333333333334`}, {33.666666666666664`, 12.666666666666666`}}]], 
    LineBox[NCache[{{Rational[101, 3], 18}, {
       Rational[101, 3], Rational[46, 3]}}, {{33.666666666666664`, 18}, {
       33.666666666666664`, 15.333333333333334`}}]], 
    LineBox[NCache[{{Rational[101, 3], 40}, {31, 38}}, {{
       33.666666666666664`, 40}, {31, 38}}]], 
    LineBox[NCache[{{Rational[101, 3], Rational[128, 3]}, {
       Rational[101, 3], 40}}, {{33.666666666666664`, 42.666666666666664`}, {
       33.666666666666664`, 40}}]], 
    LineBox[NCache[{{Rational[101, 3], Rational[128, 3]}, {
       Rational[109, 3], Rational[128, 3]}}, {{33.666666666666664`, 
      42.666666666666664`}, {36.333333333333336`, 42.666666666666664`}}]], 
    LineBox[NCache[{{Rational[101, 3], 48}, {Rational[109, 3], 48}}, {{
       33.666666666666664`, 48}, {36.333333333333336`, 48}}]], 
    LineBox[NCache[{{Rational[101, 3], 60}, {35, 60}}, {{
       33.666666666666664`, 60}, {35, 60}}]], 
    LineBox[NCache[{{Rational[101, 3], Rational[184, 3]}, {
       Rational[101, 3], 60}}, {{33.666666666666664`, 61.333333333333336`}, {
       33.666666666666664`, 60}}]], 
    LineBox[
     NCache[{{Rational[101, 3], Rational[184, 3]}, {35, Rational[184, 3]}}, {{
       33.666666666666664`, 61.333333333333336`}, {
       35, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[101, 3], 64}, {
       Rational[101, 3], Rational[188, 3]}}, {{33.666666666666664`, 64}, {
       33.666666666666664`, 62.666666666666664`}}]], 
    LineBox[NCache[{{Rational[101, 3], Rational[196, 3]}, {
       35, Rational[196, 3]}}, {{33.666666666666664`, 65.33333333333333}, {
       35, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[101, 3], Rational[200, 3]}, {
       35, Rational[200, 3]}}, {{33.666666666666664`, 66.66666666666667}, {
       35, 66.66666666666667}}]], 
    LineBox[NCache[{{Rational[101, 3], 68}, {35, 68}}, {{
       33.666666666666664`, 68}, {35, 68}}]], 
    LineBox[NCache[{{Rational[171, 5], Rational[8, 5]}, {
       Rational[171, 5], 0}}, {{34.2, 1.6}, {34.2, 0}}]], 
    LineBox[NCache[{{Rational[171, 5], Rational[24, 5]}, {
       Rational[171, 5], Rational[16, 5]}}, {{34.2, 4.8}, {34.2, 3.2}}]], 
    LineBox[NCache[{{Rational[171, 5], Rational[24, 5]}, {
       Rational[179, 5], Rational[24, 5]}}, {{34.2, 4.8}, {35.8, 4.8}}]], 
    LineBox[NCache[{{Rational[171, 5], 8}, {
       Rational[171, 5], Rational[32, 5]}}, {{34.2, 8}, {34.2, 6.4}}]], 
    LineBox[NCache[{{Rational[171, 5], 50}, {Rational[179, 5], 50}}, {{
       34.2, 50}, {35.8, 50}}]], 
    LineBox[NCache[{{Rational[171, 5], Rational[258, 5]}, {
       Rational[171, 5], 50}}, {{34.2, 51.6}, {34.2, 50}}]], 
    LineBox[NCache[{{Rational[171, 5], Rational[266, 5]}, {
       Rational[171, 5], Rational[258, 5]}}, {{34.2, 53.2}, {34.2, 51.6}}]], 
    LineBox[NCache[{{Rational[171, 5], Rational[266, 5]}, {
       Rational[179, 5], Rational[266, 5]}}, {{34.2, 53.2}, {35.8, 53.2}}]], 
    LineBox[NCache[{{Rational[171, 5], Rational[282, 5]}, {
       Rational[171, 5], Rational[274, 5]}}, {{34.2, 56.4}, {34.2, 54.8}}]], 
    LineBox[NCache[{{Rational[171, 5], 58}, {Rational[179, 5], 58}}, {{
       34.2, 58}, {35.8, 58}}]], 
    LineBox[NCache[{{Rational[241, 7], 70}, {Rational[101, 3], 68}}, {{
       34.42857142857143, 70}, {33.666666666666664`, 68}}]], 
    LineBox[NCache[{{Rational[241, 7], Rational[498, 7]}, {
       Rational[249, 7], Rational[498, 7]}}, {{34.42857142857143, 
      71.14285714285714}, {35.57142857142857, 71.14285714285714}}]], 
    LineBox[NCache[{{Rational[241, 7], Rational[506, 7]}, {
       Rational[249, 7], Rational[506, 7]}}, {{34.42857142857143, 
      72.28571428571429}, {35.57142857142857, 72.28571428571429}}]], 
    LineBox[NCache[{{Rational[241, 7], Rational[514, 7]}, {
       Rational[241, 7], Rational[506, 7]}}, {{34.42857142857143, 
      73.42857142857143}, {34.42857142857143, 72.28571428571429}}]], 
    LineBox[NCache[{{Rational[241, 7], Rational[522, 7]}, {
       Rational[249, 7], Rational[522, 7]}}, {{34.42857142857143, 
      74.57142857142857}, {35.57142857142857, 74.57142857142857}}]], 
    LineBox[NCache[{{Rational[241, 7], Rational[530, 7]}, {
       Rational[241, 7], Rational[522, 7]}}, {{34.42857142857143, 
      75.71428571428571}, {34.42857142857143, 74.57142857142857}}]], 
    LineBox[NCache[{{Rational[241, 7], Rational[538, 7]}, {
       Rational[241, 7], Rational[530, 7]}}, {{34.42857142857143, 
      76.85714285714286}, {34.42857142857143, 75.71428571428571}}]], 
    LineBox[NCache[{{Rational[241, 7], 78}, {Rational[249, 7], 78}}, {{
       34.42857142857143, 78}, {35.57142857142857, 78}}]], 
    LineBox[NCache[{{35, 20}, {Rational[109, 3], 18}}, {{35, 20}, {
       36.333333333333336`, 18}}]], LineBox[{{35, 28}, {35, 24}}], 
    LineBox[{{35, 30}, {35, 28}}], LineBox[{{35, 30}, {39, 30}}], 
    LineBox[{{35, 38}, {39, 38}}], 
    LineBox[NCache[{{35, 60}, {Rational[109, 3], 60}}, {{35, 60}, {
       36.333333333333336`, 60}}]], 
    LineBox[NCache[{{35, Rational[188, 3]}, {35, Rational[184, 3]}}, {{
       35, 62.666666666666664`}, {35, 61.333333333333336`}}]], 
    LineBox[NCache[{{35, 64}, {35, Rational[188, 3]}}, {{35, 64}, {
       35, 62.666666666666664`}}]], 
    LineBox[NCache[{{35, Rational[196, 3]}, {
       Rational[109, 3], Rational[196, 3]}}, {{35, 65.33333333333333}, {
       36.333333333333336`, 65.33333333333333}}]], 
    LineBox[NCache[{{35, Rational[200, 3]}, {
       Rational[109, 3], Rational[200, 3]}}, {{35, 66.66666666666667}, {
       36.333333333333336`, 66.66666666666667}}]], 
    LineBox[NCache[{{Rational[249, 7], 70}, {35, 68}}, {{
       35.57142857142857, 70}, {35, 68}}]], 
    LineBox[NCache[{{Rational[249, 7], 70}, {Rational[257, 7], 70}}, {{
       35.57142857142857, 70}, {36.714285714285715`, 70}}]], 
    LineBox[NCache[{{Rational[249, 7], Rational[506, 7]}, {
       Rational[249, 7], Rational[498, 7]}}, {{35.57142857142857, 
      72.28571428571429}, {35.57142857142857, 71.14285714285714}}]], 
    LineBox[NCache[{{Rational[249, 7], Rational[514, 7]}, {
       Rational[257, 7], Rational[514, 7]}}, {{35.57142857142857, 
      73.42857142857143}, {36.714285714285715`, 73.42857142857143}}]], 
    LineBox[NCache[{{Rational[249, 7], Rational[522, 7]}, {
       Rational[249, 7], Rational[514, 7]}}, {{35.57142857142857, 
      74.57142857142857}, {35.57142857142857, 73.42857142857143}}]], 
    LineBox[NCache[{{Rational[249, 7], Rational[522, 7]}, {
       Rational[257, 7], Rational[522, 7]}}, {{35.57142857142857, 
      74.57142857142857}, {36.714285714285715`, 74.57142857142857}}]], 
    LineBox[NCache[{{Rational[249, 7], Rational[530, 7]}, {
       Rational[257, 7], Rational[530, 7]}}, {{35.57142857142857, 
      75.71428571428571}, {36.714285714285715`, 75.71428571428571}}]], 
    LineBox[NCache[{{Rational[249, 7], Rational[538, 7]}, {
       Rational[249, 7], Rational[530, 7]}}, {{35.57142857142857, 
      76.85714285714286}, {35.57142857142857, 75.71428571428571}}]], 
    LineBox[NCache[{{Rational[179, 5], 0}, {Rational[187, 5], 0}}, {{
       35.8, 0}, {37.4, 0}}]], 
    LineBox[NCache[{{Rational[179, 5], Rational[8, 5]}, {
       Rational[187, 5], Rational[8, 5]}}, {{35.8, 1.6}, {37.4, 1.6}}]], 
    LineBox[NCache[{{Rational[179, 5], Rational[16, 5]}, {
       Rational[179, 5], Rational[8, 5]}}, {{35.8, 3.2}, {35.8, 1.6}}]], 
    LineBox[NCache[{{Rational[179, 5], Rational[16, 5]}, {
       Rational[187, 5], Rational[16, 5]}}, {{35.8, 3.2}, {37.4, 3.2}}]], 
    LineBox[NCache[{{Rational[179, 5], Rational[32, 5]}, {
       Rational[179, 5], Rational[24, 5]}}, {{35.8, 6.4}, {35.8, 4.8}}]], 
    LineBox[NCache[{{Rational[179, 5], 8}, {
       Rational[179, 5], Rational[32, 5]}}, {{35.8, 8}, {35.8, 6.4}}]], 
    LineBox[NCache[{{Rational[179, 5], 8}, {Rational[187, 5], 8}}, {{
       35.8, 8}, {37.4, 8}}]], 
    LineBox[NCache[{{Rational[179, 5], 50}, {Rational[187, 5], 50}}, {{
       35.8, 50}, {37.4, 50}}]], 
    LineBox[NCache[{{Rational[179, 5], Rational[258, 5]}, {
       Rational[187, 5], Rational[258, 5]}}, {{35.8, 51.6}, {37.4, 51.6}}]], 
    LineBox[NCache[{{Rational[179, 5], Rational[274, 5]}, {
       Rational[179, 5], Rational[266, 5]}}, {{35.8, 54.8}, {35.8, 53.2}}]], 
    LineBox[NCache[{{Rational[179, 5], Rational[274, 5]}, {
       Rational[187, 5], Rational[274, 5]}}, {{35.8, 54.8}, {37.4, 54.8}}]], 
    LineBox[NCache[{{Rational[179, 5], Rational[282, 5]}, {
       Rational[187, 5], Rational[282, 5]}}, {{35.8, 56.4}, {37.4, 56.4}}]], 
    LineBox[NCache[{{Rational[179, 5], 58}, {
       Rational[179, 5], Rational[282, 5]}}, {{35.8, 58}, {35.8, 56.4}}]], 
    LineBox[NCache[{{Rational[109, 3], 10}, {39, 10}}, {{
       36.333333333333336`, 10}, {39, 10}}]], 
    LineBox[NCache[{{Rational[109, 3], Rational[38, 3]}, {
       Rational[109, 3], 10}}, {{36.333333333333336`, 12.666666666666666`}, {
       36.333333333333336`, 10}}]], 
    LineBox[NCache[{{Rational[109, 3], Rational[46, 3]}, {
       Rational[109, 3], Rational[38, 3]}}, {{36.333333333333336`, 
      15.333333333333334`}, {36.333333333333336`, 12.666666666666666`}}]], 
    LineBox[NCache[{{Rational[109, 3], Rational[46, 3]}, {
       39, Rational[46, 3]}}, {{36.333333333333336`, 15.333333333333334`}, {
       39, 15.333333333333334`}}]], 
    LineBox[NCache[{{Rational[109, 3], 40}, {35, 38}}, {{
       36.333333333333336`, 40}, {35, 38}}]], 
    LineBox[NCache[{{Rational[109, 3], 40}, {39, 40}}, {{
       36.333333333333336`, 40}, {39, 40}}]], 
    LineBox[
     NCache[{{Rational[109, 3], Rational[136, 3]}, {
       Rational[109, 3], Rational[128, 3]}}, {{36.333333333333336`, 
      45.333333333333336`}, {36.333333333333336`, 42.666666666666664`}}]], 
    LineBox[NCache[{{Rational[109, 3], 48}, {
       Rational[109, 3], Rational[136, 3]}}, {{36.333333333333336`, 48}, {
       36.333333333333336`, 45.333333333333336`}}]], 
    LineBox[NCache[{{Rational[109, 3], 48}, {39, 48}}, {{
       36.333333333333336`, 48}, {39, 48}}]], 
    LineBox[NCache[{{Rational[109, 3], 60}, {Rational[179, 5], 58}}, {{
       36.333333333333336`, 60}, {35.8, 58}}]], 
    LineBox[NCache[{{Rational[109, 3], Rational[184, 3]}, {
       Rational[113, 3], Rational[184, 3]}}, {{36.333333333333336`, 
      61.333333333333336`}, {37.666666666666664`, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[109, 3], Rational[188, 3]}, {
       Rational[113, 3], Rational[188, 3]}}, {{36.333333333333336`, 
      62.666666666666664`}, {37.666666666666664`, 62.666666666666664`}}]], 
    LineBox[NCache[{{Rational[109, 3], 64}, {
       Rational[109, 3], Rational[188, 3]}}, {{36.333333333333336`, 64}, {
       36.333333333333336`, 62.666666666666664`}}]], 
    LineBox[NCache[{{Rational[109, 3], 64}, {Rational[113, 3], 64}}, {{
       36.333333333333336`, 64}, {37.666666666666664`, 64}}]], 
    LineBox[NCache[{{Rational[109, 3], Rational[196, 3]}, {
       Rational[113, 3], Rational[196, 3]}}, {{36.333333333333336`, 
      65.33333333333333}, {37.666666666666664`, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[109, 3], 68}, {
       Rational[109, 3], Rational[200, 3]}}, {{36.333333333333336`, 68}, {
       36.333333333333336`, 66.66666666666667}}]], 
    LineBox[NCache[{{Rational[109, 3], 68}, {Rational[113, 3], 68}}, {{
       36.333333333333336`, 68}, {37.666666666666664`, 68}}]], 
    LineBox[NCache[{{Rational[257, 7], 70}, {Rational[265, 7], 70}}, {{
       36.714285714285715`, 70}, {37.857142857142854`, 70}}]], 
    LineBox[NCache[{{Rational[257, 7], Rational[498, 7]}, {
       Rational[265, 7], Rational[498, 7]}}, {{36.714285714285715`, 
      71.14285714285714}, {37.857142857142854`, 71.14285714285714}}]], 
    LineBox[NCache[{{Rational[257, 7], Rational[506, 7]}, {
       Rational[257, 7], Rational[498, 7]}}, {{36.714285714285715`, 
      72.28571428571429}, {36.714285714285715`, 71.14285714285714}}]], 
    LineBox[NCache[{{Rational[257, 7], Rational[514, 7]}, {
       Rational[257, 7], Rational[506, 7]}}, {{36.714285714285715`, 
      73.42857142857143}, {36.714285714285715`, 72.28571428571429}}]], 
    LineBox[NCache[{{Rational[257, 7], Rational[522, 7]}, {
       Rational[265, 7], Rational[522, 7]}}, {{36.714285714285715`, 
      74.57142857142857}, {37.857142857142854`, 74.57142857142857}}]], 
    LineBox[NCache[{{Rational[257, 7], Rational[538, 7]}, {
       Rational[257, 7], Rational[530, 7]}}, {{36.714285714285715`, 
      76.85714285714286}, {36.714285714285715`, 75.71428571428571}}]], 
    LineBox[NCache[{{Rational[257, 7], 78}, {
       Rational[257, 7], Rational[538, 7]}}, {{36.714285714285715`, 78}, {
       36.714285714285715`, 76.85714285714286}}]], 
    LineBox[NCache[{{Rational[187, 5], Rational[8, 5]}, {
       39, Rational[8, 5]}}, {{37.4, 1.6}, {39, 1.6}}]], 
    LineBox[NCache[{{Rational[187, 5], Rational[16, 5]}, {
       39, Rational[16, 5]}}, {{37.4, 3.2}, {39, 3.2}}]], 
    LineBox[NCache[{{Rational[187, 5], Rational[24, 5]}, {
       Rational[187, 5], Rational[16, 5]}}, {{37.4, 4.8}, {37.4, 3.2}}]], 
    LineBox[NCache[{{Rational[187, 5], Rational[24, 5]}, {
       39, Rational[24, 5]}}, {{37.4, 4.8}, {39, 4.8}}]], 
    LineBox[NCache[{{Rational[187, 5], 8}, {
       Rational[187, 5], Rational[32, 5]}}, {{37.4, 8}, {37.4, 6.4}}]], 
    LineBox[NCache[{{Rational[187, 5], 50}, {39, 50}}, {{37.4, 50}, {39, 
       50}}]], LineBox[
     NCache[{{Rational[187, 5], Rational[266, 5]}, {
       Rational[187, 5], Rational[258, 5]}}, {{37.4, 53.2}, {37.4, 51.6}}]], 
    LineBox[NCache[{{Rational[187, 5], Rational[266, 5]}, {
       39, Rational[266, 5]}}, {{37.4, 53.2}, {39, 53.2}}]], 
    LineBox[NCache[{{Rational[187, 5], Rational[274, 5]}, {
       Rational[187, 5], Rational[266, 5]}}, {{37.4, 54.8}, {37.4, 53.2}}]], 
    LineBox[
     NCache[{{Rational[187, 5], 58}, {Rational[187, 5], Rational[282, 5]}}, {{
       37.4, 58}, {37.4, 56.4}}]], 
    LineBox[NCache[{{Rational[113, 3], 60}, {39, 60}}, {{
       37.666666666666664`, 60}, {39, 60}}]], 
    LineBox[NCache[{{Rational[113, 3], Rational[184, 3]}, {
       Rational[113, 3], 60}}, {{37.666666666666664`, 61.333333333333336`}, {
       37.666666666666664`, 60}}]], 
    LineBox[NCache[{{Rational[113, 3], Rational[188, 3]}, {
       Rational[113, 3], Rational[184, 3]}}, {{37.666666666666664`, 
      62.666666666666664`}, {37.666666666666664`, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[113, 3], 64}, {39, 64}}, {{
       37.666666666666664`, 64}, {39, 64}}]], 
    LineBox[NCache[{{Rational[113, 3], Rational[196, 3]}, {
       39, Rational[196, 3]}}, {{37.666666666666664`, 65.33333333333333}, {
       39, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[113, 3], Rational[200, 3]}, {
       39, Rational[200, 3]}}, {{37.666666666666664`, 66.66666666666667}, {
       39, 66.66666666666667}}]], 
    LineBox[NCache[{{Rational[113, 3], 68}, {39, 68}}, {{
       37.666666666666664`, 68}, {39, 68}}]], 
    LineBox[NCache[{{Rational[265, 7], 70}, {Rational[113, 3], 68}}, {{
       37.857142857142854`, 70}, {37.666666666666664`, 68}}]], 
    LineBox[NCache[{{Rational[265, 7], Rational[506, 7]}, {
       Rational[265, 7], Rational[498, 7]}}, {{37.857142857142854`, 
      72.28571428571429}, {37.857142857142854`, 71.14285714285714}}]], 
    LineBox[NCache[{{Rational[265, 7], Rational[506, 7]}, {
       39, Rational[506, 7]}}, {{37.857142857142854`, 72.28571428571429}, {
       39, 72.28571428571429}}]], 
    LineBox[NCache[{{Rational[265, 7], Rational[514, 7]}, {
       39, Rational[514, 7]}}, {{37.857142857142854`, 73.42857142857143}, {
       39, 73.42857142857143}}]], 
    LineBox[NCache[{{Rational[265, 7], Rational[522, 7]}, {
       Rational[265, 7], Rational[514, 7]}}, {{37.857142857142854`, 
      74.57142857142857}, {37.857142857142854`, 73.42857142857143}}]], 
    LineBox[NCache[{{Rational[265, 7], Rational[530, 7]}, {
       Rational[265, 7], Rational[522, 7]}}, {{37.857142857142854`, 
      75.71428571428571}, {37.857142857142854`, 74.57142857142857}}]], 
    LineBox[NCache[{{Rational[265, 7], Rational[538, 7]}, {
       Rational[265, 7], Rational[530, 7]}}, {{37.857142857142854`, 
      76.85714285714286}, {37.857142857142854`, 75.71428571428571}}]], 
    LineBox[NCache[{{Rational[265, 7], Rational[538, 7]}, {
       39, Rational[538, 7]}}, {{37.857142857142854`, 76.85714285714286}, {
       39, 76.85714285714286}}]], 
    LineBox[NCache[{{Rational[265, 7], 78}, {
       Rational[265, 7], Rational[538, 7]}}, {{37.857142857142854`, 78}, {
       37.857142857142854`, 76.85714285714286}}]], 
    LineBox[NCache[{{39, Rational[8, 5]}, {39, 0}}, {{39, 1.6}, {39, 0}}]], 
    LineBox[NCache[{{39, Rational[16, 5]}, {41, Rational[16, 5]}}, {{
       39, 3.2}, {41, 3.2}}]], 
    LineBox[NCache[{{39, Rational[24, 5]}, {41, Rational[24, 5]}}, {{
       39, 4.8}, {41, 4.8}}]], 
    LineBox[NCache[{{39, Rational[32, 5]}, {41, Rational[32, 5]}}, {{
       39, 6.4}, {41, 6.4}}]], 
    LineBox[NCache[{{39, 8}, {39, Rational[32, 5]}}, {{39, 8}, {39, 6.4}}]], 
    LineBox[{{39, 10}, {39, 8}}], LineBox[{{39, 10}, {41, 10}}], 
    LineBox[NCache[{{39, Rational[46, 3]}, {41, Rational[46, 3]}}, {{
       39, 15.333333333333334`}, {41, 15.333333333333334`}}]], 
    LineBox[NCache[{{39, 18}, {39, Rational[46, 3]}}, {{39, 18}, {
       39, 15.333333333333334`}}]], LineBox[{{39, 20}, {41, 20}}], 
    LineBox[{{39, 24}, {39, 20}}], LineBox[{{39, 28}, {39, 24}}], 
    LineBox[{{39, 28}, {41, 28}}], LineBox[{{39, 40}, {41, 40}}], 
    LineBox[NCache[{{39, Rational[128, 3]}, {39, 40}}, {{
       39, 42.666666666666664`}, {39, 40}}]], 
    LineBox[NCache[{{39, Rational[136, 3]}, {39, Rational[128, 3]}}, {{
       39, 45.333333333333336`}, {39, 42.666666666666664`}}]], 
    LineBox[NCache[{{39, Rational[136, 3]}, {41, Rational[136, 3]}}, {{
       39, 45.333333333333336`}, {41, 45.333333333333336`}}]], 
    LineBox[{{39, 48}, {41, 48}}], LineBox[{{39, 50}, {41, 50}}], 
    LineBox[
     NCache[{{39, Rational[258, 5]}, {39, 50}}, {{39, 51.6}, {39, 50}}]], 
    LineBox[NCache[{{39, Rational[266, 5]}, {39, Rational[258, 5]}}, {{
       39, 53.2}, {39, 51.6}}]], 
    LineBox[NCache[{{39, Rational[274, 5]}, {41, Rational[274, 5]}}, {{
       39, 54.8}, {41, 54.8}}]], 
    LineBox[NCache[{{39, Rational[282, 5]}, {39, Rational[274, 5]}}, {{
       39, 56.4}, {39, 54.8}}]], 
    LineBox[NCache[{{39, Rational[282, 5]}, {41, Rational[282, 5]}}, {{
       39, 56.4}, {41, 56.4}}]], LineBox[{{39, 58}, {41, 58}}], 
    LineBox[{{39, 60}, {39, 58}}], 
    LineBox[NCache[{{39, Rational[184, 3]}, {39, 60}}, {{
       39, 61.333333333333336`}, {39, 60}}]], 
    LineBox[NCache[{{39, Rational[188, 3]}, {39, Rational[184, 3]}}, {{
       39, 62.666666666666664`}, {39, 61.333333333333336`}}]], 
    LineBox[NCache[{{39, Rational[188, 3]}, {41, Rational[188, 3]}}, {{
       39, 62.666666666666664`}, {41, 62.666666666666664`}}]], 
    LineBox[NCache[{{39, Rational[196, 3]}, {39, 64}}, {{
       39, 65.33333333333333}, {39, 64}}]], 
    LineBox[NCache[{{39, Rational[200, 3]}, {39, Rational[196, 3]}}, {{
       39, 66.66666666666667}, {39, 65.33333333333333}}]], 
    LineBox[{{39, 68}, {41, 68}}], LineBox[{{39, 70}, {41, 70}}], 
    LineBox[NCache[{{39, Rational[498, 7]}, {39, 70}}, {{
       39, 71.14285714285714}, {39, 70}}]], 
    LineBox[NCache[{{39, Rational[506, 7]}, {39, Rational[498, 7]}}, {{
       39, 72.28571428571429}, {39, 71.14285714285714}}]], 
    LineBox[NCache[{{39, Rational[522, 7]}, {39, Rational[514, 7]}}, {{
       39, 74.57142857142857}, {39, 73.42857142857143}}]], 
    LineBox[NCache[{{39, Rational[530, 7]}, {41, Rational[230, 3]}}, {{
       39, 75.71428571428571}, {41, 76.66666666666667}}]], 
    LineBox[NCache[{{39, Rational[538, 7]}, {39, Rational[530, 7]}}, {{
       39, 76.85714285714286}, {39, 75.71428571428571}}]], 
    LineBox[{{39, 78}, {41, 78}}], 
    LineBox[NCache[{{41, Rational[8, 5]}, {41, 0}}, {{41, 1.6}, {41, 0}}]], 
    LineBox[NCache[{{41, Rational[16, 5]}, {41, Rational[8, 5]}}, {{
       41, 3.2}, {41, 1.6}}]], 
    LineBox[NCache[{{41, Rational[32, 5]}, {
       Rational[213, 5], Rational[32, 5]}}, {{41, 6.4}, {42.6, 6.4}}]], 
    LineBox[NCache[{{41, 8}, {41, Rational[32, 5]}}, {{41, 8}, {41, 6.4}}]], 
    LineBox[NCache[{{41, 8}, {Rational[213, 5], 8}}, {{41, 8}, {42.6, 8}}]], 
    LineBox[NCache[{{41, 10}, {Rational[213, 5], 8}}, {{41, 10}, {42.6, 8}}]],
     LineBox[NCache[{{41, Rational[38, 3]}, {41, 10}}, {{
       41, 12.666666666666666`}, {41, 10}}]], 
    LineBox[NCache[{{41, Rational[46, 3]}, {41, Rational[38, 3]}}, {{
       41, 15.333333333333334`}, {41, 12.666666666666666`}}]], 
    LineBox[NCache[{{41, 18}, {Rational[131, 3], 18}}, {{41, 18}, {
       43.666666666666664`, 18}}]], LineBox[{{41, 20}, {41, 18}}], 
    LineBox[{{41, 20}, {45, 20}}], LineBox[{{41, 24}, {41, 20}}], 
    LineBox[{{41, 24}, {45, 24}}], LineBox[{{41, 28}, {45, 28}}], 
    LineBox[{{41, 34}, {41, 30}}], LineBox[{{41, 34}, {45, 34}}], 
    LineBox[{{41, 38}, {41, 34}}], LineBox[{{41, 38}, {45, 38}}], 
    LineBox[{{41, 40}, {41, 38}}], 
    LineBox[NCache[{{41, Rational[128, 3]}, {41, 40}}, {{
       41, 42.666666666666664`}, {41, 40}}]], 
    LineBox[NCache[{{41, Rational[136, 3]}, {
       Rational[131, 3], Rational[136, 3]}}, {{41, 45.333333333333336`}, {
       43.666666666666664`, 45.333333333333336`}}]], 
    LineBox[NCache[{{41, 48}, {Rational[131, 3], 48}}, {{41, 48}, {
       43.666666666666664`, 48}}]], 
    LineBox[NCache[{{41, Rational[258, 5]}, {41, 50}}, {{41, 51.6}, {41, 
       50}}]], LineBox[
     NCache[{{41, Rational[266, 5]}, {Rational[213, 5], Rational[266, 5]}}, {{
       41, 53.2}, {42.6, 53.2}}]], 
    LineBox[NCache[{{41, Rational[274, 5]}, {41, Rational[266, 5]}}, {{
       41, 54.8}, {41, 53.2}}]], 
    LineBox[NCache[{{41, 58}, {41, Rational[282, 5]}}, {{41, 58}, {
       41, 56.4}}]], 
    LineBox[NCache[{{41, 58}, {Rational[213, 5], 58}}, {{41, 58}, {
       42.6, 58}}]], 
    LineBox[NCache[{{41, 60}, {Rational[127, 3], 60}}, {{41, 60}, {
       42.333333333333336`, 60}}]], 
    LineBox[NCache[{{41, 64}, {41, Rational[188, 3]}}, {{41, 64}, {
       41, 62.666666666666664`}}]], 
    LineBox[NCache[{{41, Rational[196, 3]}, {
       Rational[127, 3], Rational[196, 3]}}, {{41, 65.33333333333333}, {
       42.333333333333336`, 65.33333333333333}}]], 
    LineBox[NCache[{{41, Rational[200, 3]}, {41, Rational[196, 3]}}, {{
       41, 66.66666666666667}, {41, 65.33333333333333}}]], 
    LineBox[NCache[{{41, Rational[200, 3]}, {
       Rational[127, 3], Rational[200, 3]}}, {{41, 66.66666666666667}, {
       42.333333333333336`, 66.66666666666667}}]], 
    LineBox[NCache[{{41, 68}, {Rational[127, 3], 68}}, {{41, 68}, {
       42.333333333333336`, 68}}]], 
    LineBox[NCache[{{41, Rational[214, 3]}, {41, 70}}, {{
       41, 71.33333333333333}, {41, 70}}]], 
    LineBox[NCache[{{41, Rational[214, 3]}, {
       Rational[127, 3], Rational[214, 3]}}, {{41, 71.33333333333333}, {
       42.333333333333336`, 71.33333333333333}}]], 
    LineBox[NCache[{{41, Rational[218, 3]}, {
       Rational[127, 3], Rational[218, 3]}}, {{41, 72.66666666666667}, {
       42.333333333333336`, 72.66666666666667}}]], 
    LineBox[NCache[{{41, 74}, {41, Rational[218, 3]}}, {{41, 74}, {
       41, 72.66666666666667}}]], 
    LineBox[NCache[{{41, Rational[226, 3]}, {41, 74}}, {{
       41, 75.33333333333333}, {41, 74}}]], 
    LineBox[NCache[{{41, Rational[226, 3]}, {
       Rational[127, 3], Rational[226, 3]}}, {{41, 75.33333333333333}, {
       42.333333333333336`, 75.33333333333333}}]], 
    LineBox[NCache[{{41, Rational[230, 3]}, {
       Rational[127, 3], Rational[230, 3]}}, {{41, 76.66666666666667}, {
       42.333333333333336`, 76.66666666666667}}]], 
    LineBox[NCache[{{Rational[127, 3], 60}, {41, 58}}, {{
       42.333333333333336`, 60}, {41, 58}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[184, 3]}, {
       Rational[127, 3], 60}}, {{42.333333333333336`, 61.333333333333336`}, {
       42.333333333333336`, 60}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[184, 3]}, {
       Rational[131, 3], Rational[184, 3]}}, {{42.333333333333336`, 
      61.333333333333336`}, {43.666666666666664`, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[188, 3]}, {
       Rational[127, 3], Rational[184, 3]}}, {{42.333333333333336`, 
      62.666666666666664`}, {42.333333333333336`, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[127, 3], 64}, {
       Rational[127, 3], Rational[188, 3]}}, {{42.333333333333336`, 64}, {
       42.333333333333336`, 62.666666666666664`}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[196, 3]}, {
       Rational[127, 3], 64}}, {{42.333333333333336`, 65.33333333333333}, {
       42.333333333333336`, 64}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[200, 3]}, {
       Rational[127, 3], Rational[196, 3]}}, {{42.333333333333336`, 
      66.66666666666667}, {42.333333333333336`, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[127, 3], 68}, {Rational[131, 3], 68}}, {{
       42.333333333333336`, 68}, {43.666666666666664`, 68}}]], 
    LineBox[NCache[{{Rational[127, 3], 70}, {Rational[131, 3], 70}}, {{
       42.333333333333336`, 70}, {43.666666666666664`, 70}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[214, 3]}, {
       Rational[127, 3], 70}}, {{42.333333333333336`, 71.33333333333333}, {
       42.333333333333336`, 70}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[218, 3]}, {
       Rational[127, 3], Rational[214, 3]}}, {{42.333333333333336`, 
      72.66666666666667}, {42.333333333333336`, 71.33333333333333}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[226, 3]}, {
       Rational[127, 3], 74}}, {{42.333333333333336`, 75.33333333333333}, {
       42.333333333333336`, 74}}]], 
    LineBox[NCache[{{Rational[127, 3], Rational[230, 3]}, {
       Rational[131, 3], Rational[230, 3]}}, {{42.333333333333336`, 
      76.66666666666667}, {43.666666666666664`, 76.66666666666667}}]], 
    LineBox[NCache[{{Rational[127, 3], 78}, {Rational[131, 3], 78}}, {{
       42.333333333333336`, 78}, {43.666666666666664`, 78}}]], 
    LineBox[NCache[{{Rational[213, 5], Rational[8, 5]}, {
       Rational[221, 5], Rational[8, 5]}}, {{42.6, 1.6}, {44.2, 1.6}}]], 
    LineBox[NCache[{{Rational[213, 5], Rational[16, 5]}, {
       Rational[213, 5], Rational[8, 5]}}, {{42.6, 3.2}, {42.6, 1.6}}]], 
    LineBox[
     NCache[{{Rational[213, 5], Rational[16, 5]}, {
       Rational[221, 5], Rational[16, 5]}}, {{42.6, 3.2}, {44.2, 3.2}}]], 
    LineBox[NCache[{{Rational[213, 5], Rational[24, 5]}, {
       Rational[213, 5], Rational[16, 5]}}, {{42.6, 4.8}, {42.6, 3.2}}]], 
    LineBox[NCache[{{Rational[213, 5], Rational[32, 5]}, {
       Rational[213, 5], Rational[24, 5]}}, {{42.6, 6.4}, {42.6, 4.8}}]], 
    LineBox[NCache[{{Rational[213, 5], 50}, {41, 48}}, {{42.6, 50}, {41, 
       48}}]], LineBox[
     NCache[{{Rational[213, 5], Rational[258, 5]}, {Rational[213, 5], 50}}, {{
       42.6, 51.6}, {42.6, 50}}]], 
    LineBox[NCache[{{Rational[213, 5], Rational[258, 5]}, {
       Rational[221, 5], Rational[258, 5]}}, {{42.6, 51.6}, {44.2, 51.6}}]], 
    LineBox[NCache[{{Rational[213, 5], Rational[274, 5]}, {
       Rational[213, 5], Rational[266, 5]}}, {{42.6, 54.8}, {42.6, 53.2}}]], 
    LineBox[NCache[{{Rational[213, 5], Rational[282, 5]}, {
       Rational[213, 5], Rational[274, 5]}}, {{42.6, 56.4}, {42.6, 54.8}}]], 
    LineBox[NCache[{{Rational[213, 5], Rational[282, 5]}, {
       Rational[221, 5], Rational[282, 5]}}, {{42.6, 56.4}, {44.2, 56.4}}]], 
    LineBox[NCache[{{Rational[213, 5], 58}, {
       Rational[213, 5], Rational[282, 5]}}, {{42.6, 58}, {42.6, 56.4}}]], 
    LineBox[NCache[{{Rational[213, 5], 58}, {Rational[221, 5], 58}}, {{
       42.6, 58}, {44.2, 58}}]], 
    LineBox[NCache[{{Rational[131, 3], 10}, {Rational[139, 3], 10}}, {{
       43.666666666666664`, 10}, {46.333333333333336`, 10}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[38, 3]}, {
       Rational[131, 3], 10}}, {{43.666666666666664`, 12.666666666666666`}, {
       43.666666666666664`, 10}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[46, 3]}, {
       Rational[139, 3], Rational[46, 3]}}, {{43.666666666666664`, 
      15.333333333333334`}, {46.333333333333336`, 15.333333333333334`}}]], 
    LineBox[NCache[{{Rational[131, 3], 18}, {
       Rational[131, 3], Rational[46, 3]}}, {{43.666666666666664`, 18}, {
       43.666666666666664`, 15.333333333333334`}}]], 
    LineBox[
     NCache[{{Rational[131, 3], 40}, {41, 38}}, {{43.666666666666664`, 40}, {
       41, 38}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[128, 3]}, {
       Rational[139, 3], Rational[128, 3]}}, {{43.666666666666664`, 
      42.666666666666664`}, {46.333333333333336`, 42.666666666666664`}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[136, 3]}, {
       Rational[131, 3], Rational[128, 3]}}, {{43.666666666666664`, 
      45.333333333333336`}, {43.666666666666664`, 42.666666666666664`}}]], 
    LineBox[NCache[{{Rational[131, 3], 48}, {Rational[139, 3], 48}}, {{
       43.666666666666664`, 48}, {46.333333333333336`, 48}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[184, 3]}, {
       45, Rational[184, 3]}}, {{43.666666666666664`, 61.333333333333336`}, {
       45, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[188, 3]}, {
       Rational[131, 3], Rational[184, 3]}}, {{43.666666666666664`, 
      62.666666666666664`}, {43.666666666666664`, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[131, 3], 64}, {45, 64}}, {{
       43.666666666666664`, 64}, {45, 64}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[196, 3]}, {
       Rational[131, 3], 64}}, {{43.666666666666664`, 65.33333333333333}, {
       43.666666666666664`, 64}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[200, 3]}, {
       Rational[131, 3], Rational[196, 3]}}, {{43.666666666666664`, 
      66.66666666666667}, {43.666666666666664`, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[131, 3], 68}, {
       Rational[131, 3], Rational[200, 3]}}, {{43.666666666666664`, 68}, {
       43.666666666666664`, 66.66666666666667}}]], 
    LineBox[NCache[{{Rational[131, 3], 68}, {45, 68}}, {{
       43.666666666666664`, 68}, {45, 68}}]], 
    LineBox[NCache[{{Rational[131, 3], 70}, {45, 70}}, {{
       43.666666666666664`, 70}, {45, 70}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[218, 3]}, {
       Rational[131, 3], Rational[214, 3]}}, {{43.666666666666664`, 
      72.66666666666667}, {43.666666666666664`, 71.33333333333333}}]], 
    LineBox[
     NCache[{{Rational[131, 3], 74}, {Rational[131, 3], Rational[218, 3]}}, {{
       43.666666666666664`, 74}, {43.666666666666664`, 72.66666666666667}}]], 
    LineBox[NCache[{{Rational[131, 3], 74}, {45, 74}}, {{
       43.666666666666664`, 74}, {45, 74}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[226, 3]}, {
       Rational[131, 3], 74}}, {{43.666666666666664`, 75.33333333333333}, {
       43.666666666666664`, 74}}]], 
    LineBox[NCache[{{Rational[131, 3], Rational[230, 3]}, {
       Rational[131, 3], Rational[226, 3]}}, {{43.666666666666664`, 
      76.66666666666667}, {43.666666666666664`, 75.33333333333333}}]], 
    LineBox[NCache[{{Rational[221, 5], Rational[8, 5]}, {
       Rational[221, 5], 0}}, {{44.2, 1.6}, {44.2, 0}}]], 
    LineBox[NCache[{{Rational[221, 5], Rational[8, 5]}, {
       Rational[229, 5], Rational[8, 5]}}, {{44.2, 1.6}, {45.8, 1.6}}]], 
    LineBox[NCache[{{Rational[221, 5], Rational[32, 5]}, {
       Rational[221, 5], Rational[24, 5]}}, {{44.2, 6.4}, {44.2, 4.8}}]], 
    LineBox[NCache[{{Rational[221, 5], 8}, {
       Rational[221, 5], Rational[32, 5]}}, {{44.2, 8}, {44.2, 6.4}}]], 
    LineBox[NCache[{{Rational[221, 5], 50}, {Rational[131, 3], 48}}, {{
       44.2, 50}, {43.666666666666664`, 48}}]], 
    LineBox[NCache[{{Rational[221, 5], 50}, {Rational[229, 5], 50}}, {{
       44.2, 50}, {45.8, 50}}]], 
    LineBox[NCache[{{Rational[221, 5], Rational[266, 5]}, {
       Rational[221, 5], Rational[258, 5]}}, {{44.2, 53.2}, {44.2, 51.6}}]], 
    LineBox[NCache[{{Rational[221, 5], Rational[266, 5]}, {
       Rational[229, 5], Rational[266, 5]}}, {{44.2, 53.2}, {45.8, 53.2}}]], 
    LineBox[NCache[{{Rational[221, 5], Rational[282, 5]}, {
       Rational[221, 5], Rational[274, 5]}}, {{44.2, 56.4}, {44.2, 54.8}}]], 
    LineBox[NCache[{{Rational[221, 5], Rational[282, 5]}, {
       Rational[229, 5], Rational[282, 5]}}, {{44.2, 56.4}, {45.8, 56.4}}]], 
    LineBox[{{45, 20}, {49, 20}}], LineBox[{{45, 24}, {49, 24}}], 
    LineBox[{{45, 28}, {45, 24}}], LineBox[{{45, 30}, {45, 28}}], 
    LineBox[{{45, 34}, {45, 30}}], LineBox[{{45, 38}, {45, 34}}], 
    LineBox[{{45, 38}, {49, 38}}], 
    LineBox[NCache[{{45, 60}, {Rational[139, 3], 60}}, {{45, 60}, {
       46.333333333333336`, 60}}]], 
    LineBox[NCache[{{45, Rational[184, 3]}, {
       Rational[139, 3], Rational[184, 3]}}, {{45, 61.333333333333336`}, {
       46.333333333333336`, 61.333333333333336`}}]], 
    LineBox[NCache[{{45, Rational[188, 3]}, {
       Rational[139, 3], Rational[188, 3]}}, {{45, 62.666666666666664`}, {
       46.333333333333336`, 62.666666666666664`}}]], 
    LineBox[NCache[{{45, 64}, {Rational[139, 3], 64}}, {{45, 64}, {
       46.333333333333336`, 64}}]], 
    LineBox[NCache[{{45, Rational[196, 3]}, {
       Rational[139, 3], Rational[196, 3]}}, {{45, 65.33333333333333}, {
       46.333333333333336`, 65.33333333333333}}]], 
    LineBox[NCache[{{45, Rational[200, 3]}, {45, Rational[196, 3]}}, {{
       45, 66.66666666666667}, {45, 65.33333333333333}}]], 
    LineBox[NCache[{{45, Rational[200, 3]}, {
       Rational[139, 3], Rational[200, 3]}}, {{45, 66.66666666666667}, {
       46.333333333333336`, 66.66666666666667}}]], 
    LineBox[NCache[{{45, 68}, {Rational[139, 3], 68}}, {{45, 68}, {
       46.333333333333336`, 68}}]], 
    LineBox[NCache[{{45, Rational[214, 3]}, {45, 70}}, {{
       45, 71.33333333333333}, {45, 70}}]], 
    LineBox[NCache[{{45, Rational[218, 3]}, {45, Rational[214, 3]}}, {{
       45, 72.66666666666667}, {45, 71.33333333333333}}]], 
    LineBox[NCache[{{45, Rational[218, 3]}, {
       Rational[139, 3], Rational[218, 3]}}, {{45, 72.66666666666667}, {
       46.333333333333336`, 72.66666666666667}}]], 
    LineBox[NCache[{{45, 74}, {Rational[139, 3], 74}}, {{45, 74}, {
       46.333333333333336`, 74}}]], 
    LineBox[NCache[{{45, Rational[226, 3]}, {
       Rational[139, 3], Rational[226, 3]}}, {{45, 75.33333333333333}, {
       46.333333333333336`, 75.33333333333333}}]], 
    LineBox[NCache[{{45, Rational[230, 3]}, {45, Rational[226, 3]}}, {{
       45, 76.66666666666667}, {45, 75.33333333333333}}]], 
    LineBox[NCache[{{45, 78}, {45, Rational[230, 3]}}, {{45, 78}, {
       45, 76.66666666666667}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[8, 5]}, {
       Rational[237, 5], Rational[8, 5]}}, {{45.8, 1.6}, {47.4, 1.6}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[16, 5]}, {
       Rational[237, 5], Rational[16, 5]}}, {{45.8, 3.2}, {47.4, 3.2}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[24, 5]}, {
       Rational[229, 5], Rational[16, 5]}}, {{45.8, 4.8}, {45.8, 3.2}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[24, 5]}, {
       Rational[237, 5], Rational[24, 5]}}, {{45.8, 4.8}, {47.4, 4.8}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[32, 5]}, {
       Rational[229, 5], Rational[24, 5]}}, {{45.8, 6.4}, {45.8, 4.8}}]], 
    LineBox[NCache[{{Rational[229, 5], 8}, {
       Rational[229, 5], Rational[32, 5]}}, {{45.8, 8}, {45.8, 6.4}}]], 
    LineBox[NCache[{{Rational[229, 5], 8}, {Rational[237, 5], 8}}, {{
       45.8, 8}, {47.4, 8}}]], 
    LineBox[NCache[{{Rational[229, 5], 50}, {Rational[237, 5], 50}}, {{
       45.8, 50}, {47.4, 50}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[258, 5]}, {
       Rational[237, 5], Rational[258, 5]}}, {{45.8, 51.6}, {47.4, 51.6}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[266, 5]}, {
       Rational[229, 5], Rational[258, 5]}}, {{45.8, 53.2}, {45.8, 51.6}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[266, 5]}, {
       Rational[237, 5], Rational[266, 5]}}, {{45.8, 53.2}, {47.4, 53.2}}]], 
    LineBox[NCache[{{Rational[229, 5], Rational[282, 5]}, {
       Rational[237, 5], Rational[282, 5]}}, {{45.8, 56.4}, {47.4, 56.4}}]], 
    LineBox[NCache[{{Rational[229, 5], 58}, {
       Rational[229, 5], Rational[282, 5]}}, {{45.8, 58}, {45.8, 56.4}}]], 
    LineBox[NCache[{{Rational[229, 5], 58}, {Rational[237, 5], 58}}, {{
       45.8, 58}, {47.4, 58}}]], 
    LineBox[NCache[{{Rational[139, 3], 10}, {Rational[229, 5], 8}}, {{
       46.333333333333336`, 10}, {45.8, 8}}]], 
    LineBox[NCache[{{Rational[139, 3], Rational[38, 3]}, {
       Rational[139, 3], 10}}, {{46.333333333333336`, 12.666666666666666`}, {
       46.333333333333336`, 10}}]], 
    LineBox[NCache[{{Rational[139, 3], Rational[46, 3]}, {
       Rational[139, 3], Rational[38, 3]}}, {{46.333333333333336`, 
      15.333333333333334`}, {46.333333333333336`, 12.666666666666666`}}]], 
    LineBox[NCache[{{Rational[139, 3], Rational[128, 3]}, {
       Rational[139, 3], 40}}, {{46.333333333333336`, 42.666666666666664`}, {
       46.333333333333336`, 40}}]], 
    LineBox[NCache[{{Rational[139, 3], 48}, {
       Rational[139, 3], Rational[136, 3]}}, {{46.333333333333336`, 48}, {
       46.333333333333336`, 45.333333333333336`}}]], 
    LineBox[NCache[{{Rational[139, 3], 48}, {49, 48}}, {{
       46.333333333333336`, 48}, {49, 48}}]], 
    LineBox[NCache[{{Rational[139, 3], 60}, {Rational[229, 5], 58}}, {{
       46.333333333333336`, 60}, {45.8, 58}}]], 
    LineBox[NCache[{{Rational[139, 3], Rational[188, 3]}, {
       Rational[139, 3], Rational[184, 3]}}, {{46.333333333333336`, 
      62.666666666666664`}, {46.333333333333336`, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[139, 3], 64}, {Rational[143, 3], 64}}, {{
       46.333333333333336`, 64}, {47.666666666666664`, 64}}]], 
    LineBox[NCache[{{Rational[139, 3], Rational[196, 3]}, {
       Rational[143, 3], Rational[196, 3]}}, {{46.333333333333336`, 
      65.33333333333333}, {47.666666666666664`, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[139, 3], Rational[200, 3]}, {
       Rational[143, 3], Rational[200, 3]}}, {{46.333333333333336`, 
      66.66666666666667}, {47.666666666666664`, 66.66666666666667}}]], 
    LineBox[NCache[{{Rational[139, 3], 70}, {Rational[139, 3], 68}}, {{
       46.333333333333336`, 70}, {46.333333333333336`, 68}}]], 
    LineBox[NCache[{{Rational[139, 3], Rational[214, 3]}, {
       Rational[139, 3], 70}}, {{46.333333333333336`, 71.33333333333333}, {
       46.333333333333336`, 70}}]], 
    LineBox[NCache[{{Rational[139, 3], 74}, {Rational[143, 3], 74}}, {{
       46.333333333333336`, 74}, {47.666666666666664`, 74}}]], 
    LineBox[NCache[{{Rational[139, 3], Rational[230, 3]}, {
       Rational[139, 3], Rational[226, 3]}}, {{46.333333333333336`, 
      76.66666666666667}, {46.333333333333336`, 75.33333333333333}}]], 
    LineBox[NCache[{{Rational[139, 3], 78}, {
       Rational[139, 3], Rational[230, 3]}}, {{46.333333333333336`, 78}, {
       46.333333333333336`, 76.66666666666667}}]], 
    LineBox[NCache[{{Rational[237, 5], 0}, {49, 0}}, {{47.4, 0}, {49, 0}}]], 
    LineBox[NCache[{{Rational[237, 5], Rational[8, 5]}, {
       Rational[237, 5], 0}}, {{47.4, 1.6}, {47.4, 0}}]], 
    LineBox[NCache[{{Rational[237, 5], Rational[16, 5]}, {
       49, Rational[16, 5]}}, {{47.4, 3.2}, {49, 3.2}}]], 
    LineBox[NCache[{{Rational[237, 5], Rational[32, 5]}, {
       Rational[237, 5], Rational[24, 5]}}, {{47.4, 6.4}, {47.4, 4.8}}]], 
    LineBox[NCache[{{Rational[237, 5], 8}, {49, 8}}, {{47.4, 8}, {49, 8}}]], 
    LineBox[NCache[{{Rational[237, 5], 50}, {49, 50}}, {{47.4, 50}, {49, 
       50}}]], LineBox[
     NCache[{{Rational[237, 5], Rational[258, 5]}, {49, Rational[258, 5]}}, {{
       47.4, 51.6}, {49, 51.6}}]], 
    LineBox[NCache[{{Rational[237, 5], Rational[274, 5]}, {
       Rational[237, 5], Rational[266, 5]}}, {{47.4, 54.8}, {47.4, 53.2}}]], 
    LineBox[NCache[{{Rational[237, 5], Rational[274, 5]}, {
       49, Rational[274, 5]}}, {{47.4, 54.8}, {49, 54.8}}]], 
    LineBox[NCache[{{Rational[237, 5], Rational[282, 5]}, {
       Rational[237, 5], Rational[274, 5]}}, {{47.4, 56.4}, {47.4, 54.8}}]], 
    LineBox[NCache[{{Rational[237, 5], 58}, {49, 58}}, {{47.4, 58}, {49, 
       58}}]], LineBox[
     NCache[{{Rational[143, 3], 60}, {49, 60}}, {{47.666666666666664`, 60}, {
       49, 60}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[184, 3]}, {
       Rational[143, 3], 60}}, {{47.666666666666664`, 61.333333333333336`}, {
       47.666666666666664`, 60}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[188, 3]}, {
       Rational[143, 3], Rational[184, 3]}}, {{47.666666666666664`, 
      62.666666666666664`}, {47.666666666666664`, 61.333333333333336`}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[188, 3]}, {
       49, Rational[188, 3]}}, {{47.666666666666664`, 62.666666666666664`}, {
       49, 62.666666666666664`}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[196, 3]}, {
       Rational[143, 3], 64}}, {{47.666666666666664`, 65.33333333333333}, {
       47.666666666666664`, 64}}]], 
    LineBox[NCache[{{Rational[143, 3], 68}, {
       Rational[143, 3], Rational[200, 3]}}, {{47.666666666666664`, 68}, {
       47.666666666666664`, 66.66666666666667}}]], 
    LineBox[NCache[{{Rational[143, 3], 68}, {49, 68}}, {{
       47.666666666666664`, 68}, {49, 68}}]], 
    LineBox[NCache[{{Rational[143, 3], 70}, {49, 70}}, {{
       47.666666666666664`, 70}, {49, 70}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[214, 3]}, {
       Rational[143, 3], 70}}, {{47.666666666666664`, 71.33333333333333}, {
       47.666666666666664`, 70}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[218, 3]}, {
       Rational[143, 3], Rational[214, 3]}}, {{47.666666666666664`, 
      72.66666666666667}, {47.666666666666664`, 71.33333333333333}}]], 
    LineBox[NCache[{{Rational[143, 3], 74}, {
       Rational[143, 3], Rational[218, 3]}}, {{47.666666666666664`, 74}, {
       47.666666666666664`, 72.66666666666667}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[226, 3]}, {
       Rational[143, 3], 74}}, {{47.666666666666664`, 75.33333333333333}, {
       47.666666666666664`, 74}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[230, 3]}, {
       Rational[143, 3], Rational[226, 3]}}, {{47.666666666666664`, 
      76.66666666666667}, {47.666666666666664`, 75.33333333333333}}]], 
    LineBox[NCache[{{Rational[143, 3], Rational[230, 3]}, {
       49, Rational[230, 3]}}, {{47.666666666666664`, 76.66666666666667}, {
       49, 76.66666666666667}}]], 
    LineBox[NCache[{{Rational[143, 3], 78}, {
       Rational[143, 3], Rational[230, 3]}}, {{47.666666666666664`, 78}, {
       47.666666666666664`, 76.66666666666667}}]], 
    LineBox[NCache[{{49, Rational[8, 5]}, {51, Rational[8, 5]}}, {{49, 1.6}, {
       51, 1.6}}]], 
    LineBox[NCache[{{49, Rational[16, 5]}, {49, Rational[8, 5]}}, {{
       49, 3.2}, {49, 1.6}}]], 
    LineBox[NCache[{{49, Rational[24, 5]}, {51, Rational[24, 5]}}, {{
       49, 4.8}, {51, 4.8}}]], 
    LineBox[NCache[{{49, Rational[32, 5]}, {49, Rational[24, 5]}}, {{
       49, 6.4}, {49, 4.8}}]], 
    LineBox[NCache[{{49, 8}, {49, Rational[32, 5]}}, {{49, 8}, {49, 6.4}}]], 
    LineBox[{{49, 10}, {51, 10}}], 
    LineBox[NCache[{{49, Rational[38, 3]}, {49, 10}}, {{
       49, 12.666666666666666`}, {49, 10}}]], 
    LineBox[NCache[{{49, Rational[46, 3]}, {51, 14}}, {{
       49, 15.333333333333334`}, {51, 14}}]], 
    LineBox[NCache[{{49, 18}, {49, Rational[46, 3]}}, {{49, 18}, {
       49, 15.333333333333334`}}]], LineBox[{{49, 18}, {51, 16}}], 
    LineBox[{{49, 18}, {51, 18}}], LineBox[{{49, 20}, {51, 20}}], 
    LineBox[NCache[{{49, 20}, {51, Rational[64, 3]}}, {{49, 20}, {
       51, 21.333333333333332`}}]], LineBox[{{49, 24}, {49, 20}}], 
    LineBox[NCache[{{49, 24}, {51, Rational[68, 3]}}, {{49, 24}, {
       51, 22.666666666666668`}}]], LineBox[{{49, 24}, {51, 24}}], 
    LineBox[{{49, 30}, {51, 30}}], 
    LineBox[NCache[{{49, 34}, {51, Rational[98, 3]}}, {{49, 34}, {
       51, 32.666666666666664`}}]], 
    LineBox[NCache[{{49, 38}, {51, Rational[106, 3]}}, {{49, 38}, {
       51, 35.333333333333336`}}]], 
    LineBox[NCache[{{49, 38}, {51, Rational[110, 3]}}, {{49, 38}, {
       51, 36.666666666666664`}}]], LineBox[{{49, 38}, {51, 38}}], 
    LineBox[{{49, 40}, {49, 38}}], LineBox[{{49, 40}, {51, 40}}], 
    LineBox[NCache[{{49, Rational[128, 3]}, {51, Rational[124, 3]}}, {{
       49, 42.666666666666664`}, {51, 41.333333333333336`}}]], 
    LineBox[NCache[{{49, Rational[136, 3]}, {49, Rational[128, 3]}}, {{
       49, 45.333333333333336`}, {49, 42.666666666666664`}}]], 
    LineBox[NCache[{{49, Rational[136, 3]}, {51, 44}}, {{
       49, 45.333333333333336`}, {51, 44}}]], 
    LineBox[NCache[{{49, Rational[136, 3]}, {51, Rational[136, 3]}}, {{
       49, 45.333333333333336`}, {51, 45.333333333333336`}}]], 
    LineBox[NCache[{{49, 48}, {51, Rational[140, 3]}}, {{49, 48}, {
       51, 46.666666666666664`}}]], LineBox[{{49, 48}, {51, 48}}], 
    LineBox[{{49, 50}, {51, 50}}], 
    LineBox[NCache[{{49, Rational[258, 5]}, {51, 52}}, {{49, 51.6}, {51, 
       52}}]], 
    LineBox[NCache[{{49, Rational[266, 5]}, {49, Rational[258, 5]}}, {{
       49, 53.2}, {49, 51.6}}]], 
    LineBox[NCache[{{49, Rational[274, 5]}, {49, Rational[266, 5]}}, {{
       49, 54.8}, {49, 53.2}}]], 
    LineBox[NCache[{{49, Rational[282, 5]}, {51, 58}}, {{49, 56.4}, {51, 
       58}}]], LineBox[
     NCache[{{49, 58}, {49, Rational[282, 5]}}, {{49, 58}, {49, 56.4}}]], 
    LineBox[{{49, 60}, {49, 58}}], 
    LineBox[NCache[{{49, Rational[184, 3]}, {51, Rational[188, 3]}}, {{
       49, 61.333333333333336`}, {51, 62.666666666666664`}}]], 
    LineBox[NCache[{{49, Rational[188, 3]}, {49, Rational[184, 3]}}, {{
       49, 62.666666666666664`}, {49, 61.333333333333336`}}]], 
    LineBox[NCache[{{49, 64}, {51, Rational[196, 3]}}, {{49, 64}, {
       51, 65.33333333333333}}]], 
    LineBox[NCache[{{49, Rational[196, 3]}, {49, 64}}, {{
       49, 65.33333333333333}, {49, 64}}]], 
    LineBox[NCache[{{49, Rational[200, 3]}, {49, Rational[196, 3]}}, {{
       49, 66.66666666666667}, {49, 65.33333333333333}}]], 
    LineBox[NCache[{{49, Rational[200, 3]}, {51, 68}}, {{
       49, 66.66666666666667}, {51, 68}}]], 
    LineBox[NCache[{{49, 68}, {49, Rational[200, 3]}}, {{49, 68}, {
       49, 66.66666666666667}}]], 
    LineBox[NCache[{{49, Rational[214, 3]}, {49, 70}}, {{
       49, 71.33333333333333}, {49, 70}}]], 
    LineBox[NCache[{{49, Rational[218, 3]}, {49, Rational[214, 3]}}, {{
       49, 72.66666666666667}, {49, 71.33333333333333}}]], 
    LineBox[NCache[{{49, 74}, {49, Rational[218, 3]}}, {{49, 74}, {
       49, 72.66666666666667}}]], LineBox[{{49, 74}, {51, 74}}], 
    LineBox[NCache[{{49, Rational[226, 3]}, {51, 78}}, {{
       49, 75.33333333333333}, {51, 78}}]], 
    LineBox[NCache[{{49, 78}, {49, Rational[230, 3]}}, {{49, 78}, {
       49, 76.66666666666667}}]], 
    LineBox[NCache[{{51, Rational[8, 5]}, {51, 0}}, {{51, 1.6}, {51, 0}}]], 
    LineBox[NCache[{{51, Rational[16, 5]}, {
       Rational[263, 5], Rational[16, 5]}}, {{51, 3.2}, {52.6, 3.2}}]], 
    LineBox[NCache[{{51, Rational[24, 5]}, {51, Rational[16, 5]}}, {{
       51, 4.8}, {51, 3.2}}]], 
    LineBox[NCache[{{51, Rational[24, 5]}, {
       Rational[263, 5], Rational[24, 5]}}, {{51, 4.8}, {52.6, 4.8}}]], 
    LineBox[NCache[{{51, 8}, {51, Rational[32, 5]}}, {{51, 8}, {51, 6.4}}]], 
    LineBox[NCache[{{51, 8}, {Rational[263, 5], 8}}, {{51, 8}, {52.6, 8}}]], 
    LineBox[{{51, 10}, {53, 10}}], LineBox[{{51, 12}, {51, 10}}], 
    LineBox[{{51, 14}, {51, 12}}], LineBox[{{51, 16}, {53, 16}}], 
    LineBox[{{51, 18}, {53, 18}}], 
    LineBox[NCache[{{51, 20}, {Rational[157, 3], 20}}, {{51, 20}, {
       52.333333333333336`, 20}}]], 
    LineBox[NCache[{{51, Rational[68, 3]}, {
       Rational[157, 3], Rational[68, 3]}}, {{51, 22.666666666666668`}, {
       52.333333333333336`, 22.666666666666668`}}]], 
    LineBox[NCache[{{51, Rational[76, 3]}, {51, 24}}, {{
       51, 25.333333333333332`}, {51, 24}}]], 
    LineBox[NCache[{{51, Rational[76, 3]}, {
       Rational[157, 3], Rational[76, 3]}}, {{51, 25.333333333333332`}, {
       52.333333333333336`, 25.333333333333332`}}]], 
    LineBox[NCache[{{51, Rational[80, 3]}, {51, Rational[76, 3]}}, {{
       51, 26.666666666666668`}, {51, 25.333333333333332`}}]], 
    LineBox[NCache[{{51, Rational[80, 3]}, {
       Rational[157, 3], Rational[80, 3]}}, {{51, 26.666666666666668`}, {
       52.333333333333336`, 26.666666666666668`}}]], 
    LineBox[NCache[{{51, 28}, {51, Rational[80, 3]}}, {{51, 28}, {
       51, 26.666666666666668`}}]], 
    LineBox[NCache[{{51, 28}, {Rational[157, 3], 28}}, {{51, 28}, {
       52.333333333333336`, 28}}]], LineBox[{{51, 30}, {51, 28}}], 
    LineBox[NCache[{{51, 30}, {Rational[157, 3], 30}}, {{51, 30}, {
       52.333333333333336`, 30}}]], 
    LineBox[NCache[{{51, Rational[98, 3]}, {
       Rational[157, 3], Rational[98, 3]}}, {{51, 32.666666666666664`}, {
       52.333333333333336`, 32.666666666666664`}}]], 
    LineBox[NCache[{{51, 34}, {51, Rational[98, 3]}}, {{51, 34}, {
       51, 32.666666666666664`}}]], 
    LineBox[NCache[{{51, 34}, {Rational[157, 3], 34}}, {{51, 34}, {
       52.333333333333336`, 34}}]], 
    LineBox[NCache[{{51, Rational[106, 3]}, {51, 34}}, {{
       51, 35.333333333333336`}, {51, 34}}]], 
    LineBox[NCache[{{51, Rational[110, 3]}, {
       Rational[157, 3], Rational[110, 3]}}, {{51, 36.666666666666664`}, {
       52.333333333333336`, 36.666666666666664`}}]], 
    LineBox[NCache[{{51, 40}, {Rational[157, 3], 40}}, {{51, 40}, {
       52.333333333333336`, 40}}]], 
    LineBox[NCache[{{51, Rational[124, 3]}, {51, 40}}, {{
       51, 41.333333333333336`}, {51, 40}}]], 
    LineBox[NCache[{{51, Rational[128, 3]}, {
       Rational[157, 3], Rational[128, 3]}}, {{51, 42.666666666666664`}, {
       52.333333333333336`, 42.666666666666664`}}]], 
    LineBox[NCache[{{51, 44}, {51, Rational[128, 3]}}, {{51, 44}, {
       51, 42.666666666666664`}}]], 
    LineBox[NCache[{{51, Rational[136, 3]}, {
       Rational[157, 3], Rational[136, 3]}}, {{51, 45.333333333333336`}, {
       52.333333333333336`, 45.333333333333336`}}]], 
    LineBox[NCache[{{51, Rational[140, 3]}, {
       Rational[157, 3], Rational[140, 3]}}, {{51, 46.666666666666664`}, {
       52.333333333333336`, 46.666666666666664`}}]], 
    LineBox[NCache[{{51, 48}, {Rational[157, 3], 48}}, {{51, 48}, {
       52.333333333333336`, 48}}]], LineBox[{{51, 50}, {53, 50}}], 
    LineBox[{{51, 52}, {51, 50}}], LineBox[{{51, 54}, {53, 54}}], 
    LineBox[{{51, 56}, {51, 54}}], LineBox[{{51, 58}, {51, 56}}], 
    LineBox[{{51, 60}, {51, 58}}], LineBox[{{51, 60}, {53, 58}}], 
    LineBox[NCache[{{51, 60}, {Rational[161, 3], 60}}, {{51, 60}, {
       53.666666666666664`, 60}}]], 
    LineBox[NCache[{{51, Rational[188, 3]}, {
       Rational[161, 3], Rational[188, 3]}}, {{51, 62.666666666666664`}, {
       53.666666666666664`, 62.666666666666664`}}]], 
    LineBox[NCache[{{51, Rational[196, 3]}, {51, Rational[188, 3]}}, {{
       51, 65.33333333333333}, {51, 62.666666666666664`}}]], 
    LineBox[NCache[{{51, 68}, {51, Rational[196, 3]}}, {{51, 68}, {
       51, 65.33333333333333}}]], LineBox[{{51, 70}, {51, 68}}], 
    LineBox[NCache[{{51, 70}, {Rational[161, 3], 68}}, {{51, 70}, {
       53.666666666666664`, 68}}]], LineBox[{{51, 70}, {55, 70}}], 
    LineBox[{{51, 74}, {51, 70}}], LineBox[{{51, 78}, {51, 74}}], 
    LineBox[NCache[{{Rational[157, 3], 20}, {51, 18}}, {{
       52.333333333333336`, 20}, {51, 18}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[64, 3]}, {
       Rational[157, 3], 20}}, {{52.333333333333336`, 21.333333333333332`}, {
       52.333333333333336`, 20}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[68, 3]}, {
       Rational[157, 3], Rational[64, 3]}}, {{52.333333333333336`, 
      22.666666666666668`}, {52.333333333333336`, 21.333333333333332`}}]], 
    LineBox[NCache[{{Rational[157, 3], 24}, {Rational[161, 3], 24}}, {{
       52.333333333333336`, 24}, {53.666666666666664`, 24}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[76, 3]}, {
       Rational[157, 3], 24}}, {{52.333333333333336`, 25.333333333333332`}, {
       52.333333333333336`, 24}}]], 
    LineBox[NCache[{{Rational[157, 3], 28}, {
       Rational[157, 3], Rational[80, 3]}}, {{52.333333333333336`, 28}, {
       52.333333333333336`, 26.666666666666668`}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[94, 3]}, {
       Rational[157, 3], 30}}, {{52.333333333333336`, 31.333333333333332`}, {
       52.333333333333336`, 30}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[94, 3]}, {
       Rational[161, 3], Rational[94, 3]}}, {{52.333333333333336`, 
      31.333333333333332`}, {53.666666666666664`, 31.333333333333332`}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[98, 3]}, {
       Rational[157, 3], Rational[94, 3]}}, {{52.333333333333336`, 
      32.666666666666664`}, {52.333333333333336`, 31.333333333333332`}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[98, 3]}, {
       Rational[161, 3], Rational[98, 3]}}, {{52.333333333333336`, 
      32.666666666666664`}, {53.666666666666664`, 32.666666666666664`}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[106, 3]}, {
       Rational[161, 3], Rational[106, 3]}}, {{52.333333333333336`, 
      35.333333333333336`}, {53.666666666666664`, 35.333333333333336`}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[110, 3]}, {
       Rational[161, 3], Rational[110, 3]}}, {{52.333333333333336`, 
      36.666666666666664`}, {53.666666666666664`, 36.666666666666664`}}]], 
    LineBox[NCache[{{Rational[157, 3], 38}, {
       Rational[157, 3], Rational[110, 3]}}, {{52.333333333333336`, 38}, {
       52.333333333333336`, 36.666666666666664`}}]], 
    LineBox[NCache[{{Rational[157, 3], 38}, {Rational[161, 3], 38}}, {{
       52.333333333333336`, 38}, {53.666666666666664`, 38}}]], 
    LineBox[NCache[{{Rational[157, 3], 40}, {Rational[161, 3], 40}}, {{
       52.333333333333336`, 40}, {53.666666666666664`, 40}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[128, 3]}, {
       Rational[157, 3], Rational[124, 3]}}, {{52.333333333333336`, 
      42.666666666666664`}, {52.333333333333336`, 41.333333333333336`}}]], 
    LineBox[NCache[{{Rational[157, 3], 44}, {Rational[161, 3], 44}}, {{
       52.333333333333336`, 44}, {53.666666666666664`, 44}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[136, 3]}, {
       Rational[157, 3], 44}}, {{52.333333333333336`, 45.333333333333336`}, {
       52.333333333333336`, 44}}]], 
    LineBox[NCache[{{Rational[157, 3], Rational[140, 3]}, {
       Rational[161, 3], Rational[140, 3]}}, {{52.333333333333336`, 
      46.666666666666664`}, {53.666666666666664`, 46.666666666666664`}}]], 
    LineBox[NCache[{{Rational[157, 3], 48}, {Rational[161, 3], 48}}, {{
       52.333333333333336`, 48}, {53.666666666666664`, 48}}]], 
    LineBox[NCache[{{Rational[263, 5], Rational[8, 5]}, {
       Rational[263, 5], 0}}, {{52.6, 1.6}, {52.6, 0}}]], 
    LineBox[NCache[{{Rational[263, 5], Rational[8, 5]}, {
       Rational[271, 5], Rational[8, 5]}}, {{52.6, 1.6}, {54.2, 1.6}}]], 
    LineBox[NCache[{{Rational[263, 5], Rational[16, 5]}, {
       Rational[271, 5], Rational[16, 5]}}, {{52.6, 3.2}, {54.2, 3.2}}]], 
    LineBox[NCache[{{Rational[263, 5], Rational[32, 5]}, {
       Rational[263, 5], Rational[24, 5]}}, {{52.6, 6.4}, {52.6, 4.8}}]], 
    LineBox[NCache[{{Rational[263, 5], 8}, {
       Rational[263, 5], Rational[32, 5]}}, {{52.6, 8}, {52.6, 6.4}}]], 
    LineBox[{{53, 12}, {53, 10}}], LineBox[{{53, 14}, {53, 12}}], 
    LineBox[{{53, 16}, {53, 14}}], LineBox[{{53, 18}, {55, 18}}], 
    LineBox[{{53, 50}, {55, 50}}], LineBox[{{53, 52}, {55, 52}}], 
    LineBox[{{53, 54}, {53, 52}}], LineBox[{{53, 56}, {55, 56}}], 
    LineBox[{{53, 58}, {53, 56}}], 
    LineBox[NCache[{{Rational[161, 3], 20}, {55, 20}}, {{
       53.666666666666664`, 20}, {55, 20}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[64, 3]}, {
       Rational[161, 3], 20}}, {{53.666666666666664`, 21.333333333333332`}, {
       53.666666666666664`, 20}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[68, 3]}, {
       Rational[161, 3], Rational[64, 3]}}, {{53.666666666666664`, 
      22.666666666666668`}, {53.666666666666664`, 21.333333333333332`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[68, 3]}, {
       55, Rational[68, 3]}}, {{53.666666666666664`, 22.666666666666668`}, {
       55, 22.666666666666668`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[76, 3]}, {
       Rational[161, 3], 24}}, {{53.666666666666664`, 25.333333333333332`}, {
       53.666666666666664`, 24}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[76, 3]}, {
       55, Rational[76, 3]}}, {{53.666666666666664`, 25.333333333333332`}, {
       55, 25.333333333333332`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[80, 3]}, {
       Rational[161, 3], Rational[76, 3]}}, {{53.666666666666664`, 
      26.666666666666668`}, {53.666666666666664`, 25.333333333333332`}}]], 
    LineBox[NCache[{{Rational[161, 3], 28}, {
       Rational[161, 3], Rational[80, 3]}}, {{53.666666666666664`, 28}, {
       53.666666666666664`, 26.666666666666668`}}]], 
    LineBox[NCache[{{Rational[161, 3], 30}, {Rational[161, 3], 28}}, {{
       53.666666666666664`, 30}, {53.666666666666664`, 28}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[94, 3]}, {
       55, Rational[94, 3]}}, {{53.666666666666664`, 31.333333333333332`}, {
       55, 31.333333333333332`}}]], 
    LineBox[NCache[{{Rational[161, 3], 34}, {
       Rational[161, 3], Rational[98, 3]}}, {{53.666666666666664`, 34}, {
       53.666666666666664`, 32.666666666666664`}}]], 
    LineBox[NCache[{{Rational[161, 3], 34}, {55, 34}}, {{
       53.666666666666664`, 34}, {55, 34}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[106, 3]}, {
       Rational[161, 3], 34}}, {{53.666666666666664`, 35.333333333333336`}, {
       53.666666666666664`, 34}}]], 
    LineBox[NCache[{{Rational[161, 3], 38}, {
       Rational[161, 3], Rational[110, 3]}}, {{53.666666666666664`, 38}, {
       53.666666666666664`, 36.666666666666664`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[124, 3]}, {
       Rational[161, 3], 40}}, {{53.666666666666664`, 41.333333333333336`}, {
       53.666666666666664`, 40}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[124, 3]}, {
       55, Rational[124, 3]}}, {{53.666666666666664`, 41.333333333333336`}, {
       55, 41.333333333333336`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[128, 3]}, {
       Rational[161, 3], Rational[124, 3]}}, {{53.666666666666664`, 
      42.666666666666664`}, {53.666666666666664`, 41.333333333333336`}}]], 
    LineBox[NCache[{{Rational[161, 3], 44}, {
       Rational[161, 3], Rational[128, 3]}}, {{53.666666666666664`, 44}, {
       53.666666666666664`, 42.666666666666664`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[136, 3]}, {
       Rational[161, 3], 44}}, {{53.666666666666664`, 45.333333333333336`}, {
       53.666666666666664`, 44}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[140, 3]}, {
       Rational[161, 3], Rational[136, 3]}}, {{53.666666666666664`, 
      46.666666666666664`}, {53.666666666666664`, 45.333333333333336`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[140, 3]}, {
       55, Rational[140, 3]}}, {{53.666666666666664`, 46.666666666666664`}, {
       55, 46.666666666666664`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[188, 3]}, {
       Rational[161, 3], 60}}, {{53.666666666666664`, 62.666666666666664`}, {
       53.666666666666664`, 60}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[188, 3]}, {
       Rational[169, 3], Rational[188, 3]}}, {{53.666666666666664`, 
      62.666666666666664`}, {56.333333333333336`, 62.666666666666664`}}]], 
    LineBox[NCache[{{Rational[161, 3], Rational[196, 3]}, {
       Rational[169, 3], Rational[196, 3]}}, {{53.666666666666664`, 
      65.33333333333333}, {56.333333333333336`, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[161, 3], 68}, {Rational[169, 3], 68}}, {{
       53.666666666666664`, 68}, {56.333333333333336`, 68}}]], 
    LineBox[NCache[{{Rational[271, 5], Rational[8, 5]}, {
       Rational[271, 5], 0}}, {{54.2, 1.6}, {54.2, 0}}]], 
    LineBox[NCache[{{Rational[271, 5], Rational[24, 5]}, {
       Rational[271, 5], Rational[16, 5]}}, {{54.2, 4.8}, {54.2, 3.2}}]], 
    LineBox[NCache[{{Rational[271, 5], Rational[32, 5]}, {
       Rational[271, 5], Rational[24, 5]}}, {{54.2, 6.4}, {54.2, 4.8}}]], 
    LineBox[NCache[{{Rational[271, 5], 8}, {
       Rational[271, 5], Rational[32, 5]}}, {{54.2, 8}, {54.2, 6.4}}]], 
    LineBox[NCache[{{Rational[271, 5], 8}, {Rational[279, 5], 8}}, {{
       54.2, 8}, {55.8, 8}}]], 
    LineBox[NCache[{{55, 10}, {Rational[279, 5], 8}}, {{55, 10}, {55.8, 8}}]],
     LineBox[{{55, 12}, {55, 10}}], LineBox[{{55, 14}, {55, 12}}], 
    LineBox[{{55, 16}, {55, 14}}], LineBox[{{55, 18}, {55, 16}}], 
    LineBox[NCache[{{55, 20}, {Rational[169, 3], 20}}, {{55, 20}, {
       56.333333333333336`, 20}}]], 
    LineBox[NCache[{{55, Rational[64, 3]}, {
       Rational[169, 3], Rational[64, 3]}}, {{55, 21.333333333333332`}, {
       56.333333333333336`, 21.333333333333332`}}]], 
    LineBox[NCache[{{55, Rational[68, 3]}, {55, Rational[64, 3]}}, {{
       55, 22.666666666666668`}, {55, 21.333333333333332`}}]], 
    LineBox[NCache[{{55, 24}, {55, Rational[68, 3]}}, {{55, 24}, {
       55, 22.666666666666668`}}]], 
    LineBox[NCache[{{55, 24}, {Rational[169, 3], 24}}, {{55, 24}, {
       56.333333333333336`, 24}}]], 
    LineBox[NCache[{{55, Rational[80, 3]}, {55, Rational[76, 3]}}, {{
       55, 26.666666666666668`}, {55, 25.333333333333332`}}]], 
    LineBox[NCache[{{55, Rational[80, 3]}, {
       Rational[169, 3], Rational[80, 3]}}, {{55, 26.666666666666668`}, {
       56.333333333333336`, 26.666666666666668`}}]], 
    LineBox[NCache[{{55, 28}, {Rational[169, 3], 28}}, {{55, 28}, {
       56.333333333333336`, 28}}]], LineBox[{{55, 30}, {55, 28}}], 
    LineBox[NCache[{{55, 30}, {Rational[169, 3], 30}}, {{55, 30}, {
       56.333333333333336`, 30}}]], 
    LineBox[NCache[{{55, Rational[98, 3]}, {55, Rational[94, 3]}}, {{
       55, 32.666666666666664`}, {55, 31.333333333333332`}}]], 
    LineBox[NCache[{{55, Rational[98, 3]}, {
       Rational[169, 3], Rational[98, 3]}}, {{55, 32.666666666666664`}, {
       56.333333333333336`, 32.666666666666664`}}]], 
    LineBox[NCache[{{55, 34}, {Rational[169, 3], 34}}, {{55, 34}, {
       56.333333333333336`, 34}}]], 
    LineBox[NCache[{{55, Rational[106, 3]}, {
       Rational[169, 3], Rational[106, 3]}}, {{55, 35.333333333333336`}, {
       56.333333333333336`, 35.333333333333336`}}]], 
    LineBox[NCache[{{55, Rational[110, 3]}, {55, Rational[106, 3]}}, {{
       55, 36.666666666666664`}, {55, 35.333333333333336`}}]], 
    LineBox[NCache[{{55, Rational[110, 3]}, {
       Rational[169, 3], Rational[110, 3]}}, {{55, 36.666666666666664`}, {
       56.333333333333336`, 36.666666666666664`}}]], 
    LineBox[NCache[{{55, 38}, {Rational[169, 3], 38}}, {{55, 38}, {
       56.333333333333336`, 38}}]], LineBox[{{55, 40}, {55, 38}}], 
    LineBox[NCache[{{55, 40}, {Rational[169, 3], 40}}, {{55, 40}, {
       56.333333333333336`, 40}}]], 
    LineBox[NCache[{{55, Rational[124, 3]}, {
       Rational[169, 3], Rational[124, 3]}}, {{55, 41.333333333333336`}, {
       56.333333333333336`, 41.333333333333336`}}]], 
    LineBox[NCache[{{55, Rational[128, 3]}, {
       Rational[169, 3], Rational[128, 3]}}, {{55, 42.666666666666664`}, {
       56.333333333333336`, 42.666666666666664`}}]], 
    LineBox[NCache[{{55, 44}, {55, Rational[128, 3]}}, {{55, 44}, {
       55, 42.666666666666664`}}]], 
    LineBox[NCache[{{55, Rational[136, 3]}, {
       Rational[169, 3], Rational[136, 3]}}, {{55, 45.333333333333336`}, {
       56.333333333333336`, 45.333333333333336`}}]], 
    LineBox[NCache[{{55, Rational[140, 3]}, {
       Rational[169, 3], Rational[140, 3]}}, {{55, 46.666666666666664`}, {
       56.333333333333336`, 46.666666666666664`}}]], 
    LineBox[NCache[{{55, 48}, {Rational[169, 3], 48}}, {{55, 48}, {
       56.333333333333336`, 48}}]], LineBox[{{55, 50}, {55, 48}}], 
    LineBox[{{55, 50}, {57, 50}}], LineBox[{{55, 54}, {55, 52}}], 
    LineBox[{{55, 56}, {55, 54}}], LineBox[{{55, 58}, {57, 58}}], 
    LineBox[{{55, 74}, {55, 70}}], LineBox[{{55, 78}, {55, 74}}], 
    LineBox[NCache[{{Rational[279, 5], Rational[8, 5]}, {
       Rational[279, 5], 0}}, {{55.8, 1.6}, {55.8, 0}}]], 
    LineBox[NCache[{{Rational[279, 5], Rational[16, 5]}, {
       Rational[279, 5], Rational[8, 5]}}, {{55.8, 3.2}, {55.8, 1.6}}]], 
    LineBox[NCache[{{Rational[279, 5], Rational[16, 5]}, {
       Rational[287, 5], Rational[16, 5]}}, {{55.8, 3.2}, {57.4, 3.2}}]], 
    LineBox[NCache[{{Rational[279, 5], Rational[24, 5]}, {
       Rational[287, 5], Rational[24, 5]}}, {{55.8, 4.8}, {57.4, 4.8}}]], 
    LineBox[NCache[{{Rational[279, 5], Rational[32, 5]}, {
       Rational[279, 5], Rational[24, 5]}}, {{55.8, 6.4}, {55.8, 4.8}}]], 
    LineBox[NCache[{{Rational[279, 5], Rational[32, 5]}, {
       Rational[287, 5], Rational[32, 5]}}, {{55.8, 6.4}, {57.4, 6.4}}]], 
    LineBox[NCache[{{Rational[279, 5], 8}, {Rational[287, 5], 8}}, {{
       55.8, 8}, {57.4, 8}}]], 
    LineBox[NCache[{{Rational[169, 3], 20}, {55, 18}}, {{
       56.333333333333336`, 20}, {55, 18}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[68, 3]}, {
       Rational[173, 3], Rational[68, 3]}}, {{56.333333333333336`, 
      22.666666666666668`}, {57.666666666666664`, 22.666666666666668`}}]], 
    LineBox[NCache[{{Rational[169, 3], 24}, {Rational[173, 3], 24}}, {{
       56.333333333333336`, 24}, {57.666666666666664`, 24}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[76, 3]}, {
       Rational[169, 3], 24}}, {{56.333333333333336`, 25.333333333333332`}, {
       56.333333333333336`, 24}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[80, 3]}, {
       Rational[169, 3], Rational[76, 3]}}, {{56.333333333333336`, 
      26.666666666666668`}, {56.333333333333336`, 25.333333333333332`}}]], 
    LineBox[NCache[{{Rational[169, 3], 30}, {Rational[169, 3], 28}}, {{
       56.333333333333336`, 30}, {56.333333333333336`, 28}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[94, 3]}, {
       Rational[173, 3], Rational[94, 3]}}, {{56.333333333333336`, 
      31.333333333333332`}, {57.666666666666664`, 31.333333333333332`}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[98, 3]}, {
       Rational[169, 3], Rational[94, 3]}}, {{56.333333333333336`, 
      32.666666666666664`}, {56.333333333333336`, 31.333333333333332`}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[98, 3]}, {
       Rational[173, 3], Rational[98, 3]}}, {{56.333333333333336`, 
      32.666666666666664`}, {57.666666666666664`, 32.666666666666664`}}]], 
    LineBox[NCache[{{Rational[169, 3], 34}, {Rational[173, 3], 34}}, {{
       56.333333333333336`, 34}, {57.666666666666664`, 34}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[110, 3]}, {
       Rational[169, 3], Rational[106, 3]}}, {{56.333333333333336`, 
      36.666666666666664`}, {56.333333333333336`, 35.333333333333336`}}]], 
    LineBox[NCache[{{Rational[169, 3], 38}, {Rational[173, 3], 38}}, {{
       56.333333333333336`, 38}, {57.666666666666664`, 38}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[124, 3]}, {
       Rational[169, 3], 40}}, {{56.333333333333336`, 41.333333333333336`}, {
       56.333333333333336`, 40}}]], 
    LineBox[NCache[{{Rational[169, 3], 44}, {
       Rational[169, 3], Rational[128, 3]}}, {{56.333333333333336`, 44}, {
       56.333333333333336`, 42.666666666666664`}}]], 
    LineBox[NCache[{{Rational[169, 3], 44}, {Rational[173, 3], 44}}, {{
       56.333333333333336`, 44}, {57.666666666666664`, 44}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[140, 3]}, {
       Rational[169, 3], Rational[136, 3]}}, {{56.333333333333336`, 
      46.666666666666664`}, {56.333333333333336`, 45.333333333333336`}}]], 
    LineBox[NCache[{{Rational[169, 3], 48}, {Rational[173, 3], 48}}, {{
       56.333333333333336`, 48}, {57.666666666666664`, 48}}]], 
    LineBox[NCache[{{Rational[169, 3], 60}, {59, 60}}, {{
       56.333333333333336`, 60}, {59, 60}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[188, 3]}, {
       Rational[169, 3], 60}}, {{56.333333333333336`, 62.666666666666664`}, {
       56.333333333333336`, 60}}]], 
    LineBox[NCache[{{Rational[169, 3], Rational[196, 3]}, {
       59, Rational[196, 3]}}, {{56.333333333333336`, 65.33333333333333}, {
       59, 65.33333333333333}}]], 
    LineBox[NCache[{{Rational[169, 3], 68}, {59, 68}}, {{
       56.333333333333336`, 68}, {59, 68}}]], LineBox[{{57, 10}, {59, 10}}], 
    LineBox[{{57, 12}, {57, 10}}], LineBox[{{57, 12}, {59, 12}}], 
    LineBox[{{57, 14}, {57, 12}}], LineBox[{{57, 16}, {57, 14}}], 
    LineBox[{{57, 18}, {57, 16}}], 
    LineBox[NCache[{{57, 50}, {Rational[173, 3], 48}}, {{57, 50}, {
       57.666666666666664`, 48}}]], LineBox[{{57, 52}, {57, 50}}], 
    LineBox[{{57, 54}, {57, 52}}], LineBox[{{57, 54}, {59, 54}}], 
    LineBox[{{57, 56}, {59, 56}}], LineBox[{{57, 58}, {57, 56}}], 
    LineBox[NCache[{{Rational[287, 5], Rational[8, 5]}, {
       Rational[287, 5], 0}}, {{57.4, 1.6}, {57.4, 0}}]], 
    LineBox[NCache[{{Rational[287, 5], Rational[16, 5]}, {
       Rational[287, 5], Rational[8, 5]}}, {{57.4, 3.2}, {57.4, 1.6}}]], 
    LineBox[NCache[{{Rational[287, 5], Rational[24, 5]}, {
       59, Rational[24, 5]}}, {{57.4, 4.8}, {59, 4.8}}]], 
    LineBox[NCache[{{Rational[287, 5], Rational[32, 5]}, {
       59, Rational[32, 5]}}, {{57.4, 6.4}, {59, 6.4}}]], 
    LineBox[NCache[{{Rational[173, 3], 20}, {57, 18}}, {{
       57.666666666666664`, 20}, {57, 18}}]], 
    LineBox[NCache[{{Rational[173, 3], 20}, {59, 20}}, {{
       57.666666666666664`, 20}, {59, 20}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[64, 3]}, {
       Rational[173, 3], 20}}, {{57.666666666666664`, 21.333333333333332`}, {
       57.666666666666664`, 20}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[64, 3]}, {
       59, Rational[64, 3]}}, {{57.666666666666664`, 21.333333333333332`}, {
       59, 21.333333333333332`}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[68, 3]}, {
       59, Rational[68, 3]}}, {{57.666666666666664`, 22.666666666666668`}, {
       59, 22.666666666666668`}}]], 
    LineBox[NCache[{{Rational[173, 3], 24}, {59, 24}}, {{
       57.666666666666664`, 24}, {59, 24}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[76, 3]}, {
       59, Rational[76, 3]}}, {{57.666666666666664`, 25.333333333333332`}, {
       59, 25.333333333333332`}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[80, 3]}, {
       59, Rational[80, 3]}}, {{57.666666666666664`, 26.666666666666668`}, {
       59, 26.666666666666668`}}]], 
    LineBox[NCache[{{Rational[173, 3], 28}, {
       Rational[173, 3], Rational[80, 3]}}, {{57.666666666666664`, 28}, {
       57.666666666666664`, 26.666666666666668`}}]], 
    LineBox[NCache[{{Rational[173, 3], 28}, {59, 28}}, {{
       57.666666666666664`, 28}, {59, 28}}]], 
    LineBox[NCache[{{Rational[173, 3], 30}, {59, 30}}, {{
       57.666666666666664`, 30}, {59, 30}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[94, 3]}, {
       Rational[173, 3], 30}}, {{57.666666666666664`, 31.333333333333332`}, {
       57.666666666666664`, 30}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[98, 3]}, {
       59, Rational[98, 3]}}, {{57.666666666666664`, 32.666666666666664`}, {
       59, 32.666666666666664`}}]], 
    LineBox[NCache[{{Rational[173, 3], 34}, {59, 34}}, {{
       57.666666666666664`, 34}, {59, 34}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[106, 3]}, {
       59, Rational[106, 3]}}, {{57.666666666666664`, 35.333333333333336`}, {
       59, 35.333333333333336`}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[110, 3]}, {
       Rational[173, 3], Rational[106, 3]}}, {{57.666666666666664`, 
      36.666666666666664`}, {57.666666666666664`, 35.333333333333336`}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[110, 3]}, {
       59, Rational[110, 3]}}, {{57.666666666666664`, 36.666666666666664`}, {
       59, 36.666666666666664`}}]], 
    LineBox[NCache[{{Rational[173, 3], 40}, {Rational[173, 3], 38}}, {{
       57.666666666666664`, 40}, {57.666666666666664`, 38}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[124, 3]}, {
       Rational[173, 3], 40}}, {{57.666666666666664`, 41.333333333333336`}, {
       57.666666666666664`, 40}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[128, 3]}, {
       Rational[173, 3], Rational[124, 3]}}, {{57.666666666666664`, 
      42.666666666666664`}, {57.666666666666664`, 41.333333333333336`}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[136, 3]}, {
       Rational[173, 3], 44}}, {{57.666666666666664`, 45.333333333333336`}, {
       57.666666666666664`, 44}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[140, 3]}, {
       Rational[173, 3], Rational[136, 3]}}, {{57.666666666666664`, 
      46.666666666666664`}, {57.666666666666664`, 45.333333333333336`}}]], 
    LineBox[NCache[{{Rational[173, 3], Rational[140, 3]}, {
       59, Rational[140, 3]}}, {{57.666666666666664`, 46.666666666666664`}, {
       59, 46.666666666666664`}}]], 
    LineBox[NCache[{{59, Rational[8, 5]}, {59, 0}}, {{59, 1.6}, {59, 0}}]], 
    LineBox[NCache[{{59, Rational[8, 5]}, {61, Rational[8, 3]}}, {{59, 1.6}, {
       61, 2.6666666666666665`}}]], 
    LineBox[NCache[{{59, Rational[16, 5]}, {61, Rational[8, 3]}}, {{
       59, 3.2}, {61, 2.6666666666666665`}}]], 
    LineBox[NCache[{{59, Rational[24, 5]}, {59, Rational[16, 5]}}, {{
       59, 4.8}, {59, 3.2}}]], 
    LineBox[NCache[{{59, 8}, {59, Rational[32, 5]}}, {{59, 8}, {59, 6.4}}]], 
    LineBox[{{59, 8}, {61, 8}}], LineBox[{{59, 10}, {59, 8}}], 
    LineBox[{{59, 12}, {61, 12}}], LineBox[{{59, 14}, {61, 14}}], 
    LineBox[{{59, 16}, {59, 14}}], LineBox[{{59, 18}, {59, 16}}], 
    LineBox[{{59, 18}, {61, 18}}], LineBox[{{59, 20}, {61, 20}}], 
    LineBox[NCache[{{59, Rational[64, 3]}, {61, 22}}, {{
       59, 21.333333333333332`}, {61, 22}}]], 
    LineBox[NCache[{{59, Rational[68, 3]}, {61, 24}}, {{
       59, 22.666666666666668`}, {61, 24}}]], 
    LineBox[NCache[{{59, Rational[76, 3]}, {59, 24}}, {{
       59, 25.333333333333332`}, {59, 24}}]], 
    LineBox[
     NCache[{{59, Rational[76, 3]}, {61, 26}}, {{59, 25.333333333333332`}, {
       61, 26}}]], 
    LineBox[NCache[{{59, Rational[80, 3]}, {61, 28}}, {{
       59, 26.666666666666668`}, {61, 28}}]], LineBox[{{59, 28}, {61, 28}}], 
    LineBox[{{59, 30}, {61, 30}}], 
    LineBox[NCache[{{59, Rational[94, 3]}, {61, 32}}, {{
       59, 31.333333333333332`}, {61, 32}}]], 
    LineBox[NCache[{{59, Rational[98, 3]}, {61, 34}}, {{
       59, 32.666666666666664`}, {61, 34}}]], LineBox[{{59, 34}, {61, 34}}], 
    LineBox[NCache[{{59, 38}, {59, Rational[110, 3]}}, {{59, 38}, {
       59, 36.666666666666664`}}]], LineBox[{{59, 40}, {59, 38}}], 
    LineBox[NCache[{{59, Rational[124, 3]}, {59, 40}}, {{
       59, 41.333333333333336`}, {59, 40}}]], 
    LineBox[NCache[{{59, Rational[128, 3]}, {59, Rational[124, 3]}}, {{
       59, 42.666666666666664`}, {59, 41.333333333333336`}}]], 
    LineBox[NCache[{{59, 44}, {59, Rational[128, 3]}}, {{59, 44}, {
       59, 42.666666666666664`}}]], LineBox[{{59, 44}, {61, 44}}], 
    LineBox[NCache[{{59, Rational[136, 3]}, {59, 44}}, {{
       59, 45.333333333333336`}, {59, 44}}]], 
    LineBox[NCache[{{59, Rational[140, 3]}, {59, Rational[136, 3]}}, {{
       59, 46.666666666666664`}, {59, 45.333333333333336`}}]], 
    LineBox[NCache[{{59, 48}, {59, Rational[140, 3]}}, {{59, 48}, {
       59, 46.666666666666664`}}]], LineBox[{{59, 48}, {61, 48}}], 
    LineBox[{{59, 52}, {59, 50}}], LineBox[{{59, 52}, {61, 54}}], 
    LineBox[{{59, 54}, {61, 54}}], LineBox[{{59, 58}, {59, 56}}], 
    LineBox[{{59, 60}, {59, 58}}], LineBox[{{59, 60}, {61, 60}}], 
    LineBox[NCache[{{59, Rational[188, 3]}, {61, 64}}, {{
       59, 62.666666666666664`}, {61, 64}}]], 
    LineBox[NCache[{{59, Rational[196, 3]}, {61, 68}}, {{
       59, 65.33333333333333}, {61, 68}}]], LineBox[{{59, 70}, {59, 68}}], 
    LineBox[{{59, 70}, {61, 70}}], LineBox[{{59, 74}, {61, 74}}], 
    LineBox[{{59, 78}, {59, 74}}], 
    LineBox[NCache[{{61, Rational[8, 3]}, {61, 0}}, {{
       61, 2.6666666666666665`}, {61, 0}}]], 
    LineBox[NCache[{{61, Rational[16, 3]}, {
       Rational[191, 3], Rational[16, 3]}}, {{61, 5.333333333333333}, {
       63.666666666666664`, 5.333333333333333}}]], 
    LineBox[NCache[{{61, 8}, {61, Rational[16, 3]}}, {{61, 8}, {
       61, 5.333333333333333}}]], 
    LineBox[NCache[{{61, 8}, {Rational[191, 3], 8}}, {{61, 8}, {
       63.666666666666664`, 8}}]], LineBox[{{61, 10}, {63, 10}}], 
    LineBox[{{61, 12}, {61, 10}}], LineBox[{{61, 12}, {63, 12}}], 
    LineBox[{{61, 18}, {61, 16}}], LineBox[{{61, 22}, {63, 22}}], 
    LineBox[{{61, 24}, {61, 22}}], LineBox[{{61, 24}, {63, 24}}], 
    LineBox[{{61, 26}, {63, 26}}], LineBox[{{61, 28}, {63, 28}}], 
    LineBox[{{61, 30}, {63, 30}}], LineBox[{{61, 32}, {63, 32}}], 
    LineBox[{{61, 36}, {61, 34}}], LineBox[{{61, 38}, {61, 36}}], 
    LineBox[{{61, 38}, {63, 38}}], LineBox[{{61, 40}, {61, 38}}], 
    LineBox[{{61, 40}, {63, 38}}], LineBox[{{61, 44}, {61, 40}}], 
    LineBox[{{61, 44}, {65, 44}}], LineBox[{{61, 48}, {65, 48}}], 
    LineBox[{{61, 50}, {61, 48}}], LineBox[{{61, 54}, {61, 50}}], 
    LineBox[{{61, 58}, {61, 54}}], LineBox[{{61, 58}, {65, 58}}], 
    LineBox[{{61, 60}, {61, 58}}], LineBox[{{61, 64}, {65, 64}}], 
    LineBox[{{61, 68}, {65, 68}}], LineBox[{{61, 70}, {61, 68}}], 
    LineBox[{{61, 78}, {61, 74}}], LineBox[{{63, 10}, {61, 8}}], 
    LineBox[{{63, 10}, {65, 10}}], LineBox[{{63, 14}, {65, 14}}], 
    LineBox[{{63, 16}, {63, 14}}], LineBox[{{63, 18}, {63, 16}}], 
    LineBox[{{63, 20}, {63, 18}}], LineBox[{{63, 20}, {65, 20}}], 
    LineBox[{{63, 24}, {65, 24}}], LineBox[{{63, 28}, {63, 26}}], 
    LineBox[{{63, 32}, {63, 30}}], LineBox[{{63, 34}, {65, 34}}], 
    LineBox[{{63, 36}, {63, 34}}], LineBox[{{63, 36}, {65, 36}}], 
    LineBox[{{63, 38}, {65, 38}}], 
    LineBox[NCache[{{Rational[191, 3], Rational[8, 3]}, {
       Rational[199, 3], Rational[8, 3]}}, {{63.666666666666664`, 
      2.6666666666666665`}, {66.33333333333333, 2.6666666666666665`}}]], 
    LineBox[NCache[{{Rational[191, 3], Rational[16, 3]}, {
       Rational[191, 3], Rational[8, 3]}}, {{63.666666666666664`, 
      5.333333333333333}, {63.666666666666664`, 2.6666666666666665`}}]], 
    LineBox[NCache[{{Rational[191, 3], 8}, {Rational[199, 3], 8}}, {{
       63.666666666666664`, 8}, {66.33333333333333, 8}}]], 
    LineBox[{{65, 12}, {67, 12}}], LineBox[{{65, 14}, {65, 12}}], 
    LineBox[{{65, 16}, {67, 16}}], LineBox[{{65, 18}, {65, 16}}], 
    LineBox[{{65, 18}, {67, 18}}], LineBox[{{65, 22}, {65, 20}}], 
    LineBox[{{65, 22}, {67, 22}}], LineBox[{{65, 26}, {65, 24}}], 
    LineBox[{{65, 28}, {65, 26}}], LineBox[{{65, 30}, {65, 28}}], 
    LineBox[{{65, 30}, {67, 30}}], LineBox[{{65, 32}, {65, 30}}], 
    LineBox[{{65, 32}, {67, 32}}], LineBox[{{65, 36}, {65, 34}}], 
    LineBox[{{65, 40}, {65, 38}}], LineBox[{{65, 40}, {67, 38}}], 
    LineBox[{{65, 40}, {69, 40}}], LineBox[{{65, 44}, {69, 44}}], 
    LineBox[{{65, 48}, {69, 48}}], LineBox[{{65, 50}, {65, 48}}], 
    LineBox[{{65, 54}, {65, 50}}], LineBox[{{65, 60}, {65, 58}}], 
    LineBox[{{65, 64}, {65, 60}}], LineBox[{{65, 70}, {65, 68}}], 
    LineBox[{{65, 74}, {65, 70}}], LineBox[{{65, 74}, {69, 74}}], 
    LineBox[{{65, 78}, {69, 78}}], 
    LineBox[NCache[{{Rational[199, 3], 0}, {69, 0}}, {{
       66.33333333333333, 0}, {69, 0}}]], 
    LineBox[NCache[{{Rational[199, 3], Rational[16, 3]}, {
       Rational[199, 3], Rational[8, 3]}}, {{66.33333333333333, 
      5.333333333333333}, {66.33333333333333, 2.6666666666666665`}}]], 
    LineBox[NCache[{{Rational[199, 3], Rational[16, 3]}, {
       69, Rational[16, 3]}}, {{66.33333333333333, 5.333333333333333}, {
       69, 5.333333333333333}}]], 
    LineBox[NCache[{{Rational[199, 3], 8}, {69, 8}}, {{
       66.33333333333333, 8}, {69, 8}}]], 
    LineBox[NCache[{{67, 10}, {Rational[199, 3], 8}}, {{67, 10}, {
       66.33333333333333, 8}}]], LineBox[{{67, 10}, {69, 10}}], 
    LineBox[{{67, 14}, {67, 12}}], LineBox[{{67, 16}, {67, 14}}], 
    LineBox[{{67, 20}, {67, 18}}], LineBox[{{67, 20}, {69, 20}}], 
    LineBox[{{67, 22}, {67, 20}}], LineBox[{{67, 24}, {69, 24}}], 
    LineBox[{{67, 26}, {67, 24}}], LineBox[{{67, 28}, {67, 26}}], 
    LineBox[{{67, 28}, {69, 28}}], LineBox[{{67, 30}, {69, 30}}], 
    LineBox[{{67, 34}, {67, 32}}], LineBox[{{67, 34}, {69, 34}}], 
    LineBox[{{67, 36}, {69, 36}}], LineBox[{{67, 38}, {67, 36}}], 
    LineBox[{{69, 14}, {69, 12}}], LineBox[{{69, 18}, {69, 16}}], 
    LineBox[{{69, 24}, {69, 22}}], LineBox[{{69, 38}, {69, 36}}], 
    LineBox[{{69, 58}, {69, 54}}], LineBox[{{69, 64}, {69, 60}}], 
    LineBox[{{69, 68}, {69, 64}}]}, 
   {GrayLevel[0], AbsoluteThickness[
    5], {LineBox[
      NCache[{{Rational[265, 7], Rational[522, 7]}, {
        39, Rational[522, 7]}}, {{37.857142857142854`, 74.57142857142857}, {
        39, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[225, 7], 78}, {Rational[233, 7], 78}}, {{
        32.142857142857146`, 78}, {33.285714285714285`, 78}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[530, 7]}, {
        Rational[249, 7], Rational[522, 7]}}, {{35.57142857142857, 
       75.71428571428571}, {35.57142857142857, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[530, 7]}, {
        Rational[249, 7], Rational[530, 7]}}, {{34.42857142857143, 
       75.71428571428571}, {35.57142857142857, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[530, 7]}, {
        Rational[241, 7], Rational[530, 7]}}, {{33.285714285714285`, 
       75.71428571428571}, {34.42857142857143, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[538, 7]}, {
        Rational[233, 7], Rational[530, 7]}}, {{33.285714285714285`, 
       76.85714285714286}, {33.285714285714285`, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[233, 7], 78}, {
        Rational[233, 7], Rational[538, 7]}}, {{33.285714285714285`, 78}, {
        33.285714285714285`, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[233, 7], 78}, {Rational[241, 7], 78}}, {{
        33.285714285714285`, 78}, {34.42857142857143, 78}}]], 
     LineBox[NCache[{{Rational[241, 7], 78}, {
        Rational[241, 7], Rational[538, 7]}}, {{34.42857142857143, 78}, {
        34.42857142857143, 76.85714285714286}}]], 
     LineBox[
      NCache[{{Rational[241, 7], Rational[538, 7]}, {
        Rational[249, 7], Rational[538, 7]}}, {{34.42857142857143, 
       76.85714285714286}, {35.57142857142857, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[538, 7]}, {
        Rational[265, 7], Rational[538, 7]}}, {{36.714285714285715`, 
       76.85714285714286}, {37.857142857142854`, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[538, 7]}, {
        Rational[257, 7], Rational[538, 7]}}, {{35.57142857142857, 
       76.85714285714286}, {36.714285714285715`, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[249, 7], 78}, {
        Rational[249, 7], Rational[538, 7]}}, {{35.57142857142857, 78}, {
        35.57142857142857, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[249, 7], 78}, {Rational[257, 7], 78}}, {{
        35.57142857142857, 78}, {36.714285714285715`, 78}}]], 
     LineBox[NCache[{{Rational[257, 7], 78}, {Rational[265, 7], 78}}, {{
        36.714285714285715`, 78}, {37.857142857142854`, 78}}]], 
     LineBox[NCache[{{Rational[265, 7], 78}, {39, 78}}, {{
        37.857142857142854`, 78}, {39, 78}}]], 
     LineBox[NCache[{{39, 78}, {39, Rational[538, 7]}}, {{39, 78}, {
        39, 76.85714285714286}}]], 
     LineBox[NCache[{{39, Rational[538, 7]}, {41, 78}}, {{
        39, 76.85714285714286}, {41, 78}}]], LineBox[{{49, 58}, {51, 58}}], 
     LineBox[{{51, 58}, {53, 58}}], LineBox[{{53, 58}, {55, 58}}], 
     LineBox[NCache[{{69, Rational[8, 3]}, {69, 0}}, {{
        69, 2.6666666666666665`}, {69, 0}}]], 
     LineBox[NCache[{{Rational[199, 3], 8}, {
        Rational[199, 3], Rational[16, 3]}}, {{66.33333333333333, 8}, {
        66.33333333333333, 5.333333333333333}}]], 
     LineBox[NCache[{{Rational[191, 3], Rational[16, 3]}, {
        Rational[199, 3], Rational[16, 3]}}, {{63.666666666666664`, 
       5.333333333333333}, {66.33333333333333, 5.333333333333333}}]], 
     LineBox[NCache[{{Rational[191, 3], 8}, {
        Rational[191, 3], Rational[16, 3]}}, {{63.666666666666664`, 8}, {
        63.666666666666664`, 5.333333333333333}}]], 
     LineBox[
      NCache[{{65, 10}, {Rational[191, 3], 8}}, {{65, 10}, {
        63.666666666666664`, 8}}]], LineBox[{{69, 26}, {69, 24}}], 
     LineBox[{{63, 30}, {65, 30}}], LineBox[{{63, 30}, {63, 28}}], 
     LineBox[{{63, 28}, {65, 28}}], LineBox[{{65, 28}, {67, 28}}], 
     LineBox[{{67, 30}, {67, 28}}], LineBox[{{67, 32}, {67, 30}}], 
     LineBox[{{67, 32}, {69, 32}}], LineBox[{{69, 36}, {69, 34}}], 
     LineBox[{{69, 34}, {69, 32}}], LineBox[{{69, 32}, {69, 30}}], 
     LineBox[{{69, 30}, {69, 28}}], LineBox[{{69, 28}, {69, 26}}], 
     LineBox[{{67, 26}, {69, 26}}], LineBox[{{65, 26}, {67, 26}}], 
     LineBox[{{63, 26}, {65, 26}}], LineBox[{{63, 26}, {63, 24}}], 
     LineBox[{{63, 24}, {63, 22}}], LineBox[{{65, 20}, {67, 20}}], 
     LineBox[{{65, 20}, {65, 18}}], LineBox[{{63, 18}, {65, 18}}], 
     LineBox[{{61, 18}, {63, 18}}], LineBox[{{61, 20}, {61, 18}}], 
     LineBox[{{61, 22}, {61, 20}}], LineBox[{{61, 20}, {63, 20}}], 
     LineBox[{{63, 22}, {63, 20}}], LineBox[{{63, 22}, {65, 22}}], 
     LineBox[{{65, 24}, {65, 22}}], LineBox[{{65, 24}, {67, 24}}], 
     LineBox[{{67, 24}, {67, 22}}], LineBox[{{67, 22}, {69, 22}}], 
     LineBox[{{69, 22}, {69, 20}}], LineBox[{{69, 20}, {69, 18}}], 
     LineBox[{{67, 18}, {69, 18}}], LineBox[{{67, 18}, {67, 16}}], 
     LineBox[{{67, 16}, {69, 16}}], LineBox[{{69, 16}, {69, 14}}], 
     LineBox[{{67, 14}, {69, 14}}], LineBox[{{65, 14}, {67, 14}}], 
     LineBox[{{65, 16}, {65, 14}}], LineBox[{{63, 16}, {65, 16}}], 
     LineBox[{{61, 16}, {63, 16}}], 
     LineBox[NCache[{{Rational[157, 3], 20}, {Rational[161, 3], 20}}, {{
        52.333333333333336`, 20}, {53.666666666666664`, 20}}]], 
     LineBox[NCache[{{Rational[161, 3], 20}, {53, 18}}, {{
        53.666666666666664`, 20}, {53, 18}}]], LineBox[{{53, 18}, {53, 16}}], 
     LineBox[{{53, 16}, {55, 16}}], LineBox[{{55, 16}, {57, 16}}], 
     LineBox[{{57, 16}, {59, 16}}], LineBox[{{59, 16}, {61, 16}}], 
     LineBox[{{61, 16}, {61, 14}}], LineBox[{{61, 14}, {61, 12}}], 
     LineBox[{{61, 14}, {63, 14}}], LineBox[{{63, 14}, {63, 12}}], 
     LineBox[{{63, 12}, {63, 10}}], LineBox[{{63, 12}, {65, 12}}], 
     LineBox[{{65, 12}, {65, 10}}], LineBox[{{65, 10}, {67, 10}}], 
     LineBox[{{67, 12}, {67, 10}}], LineBox[{{67, 12}, {69, 12}}], 
     LineBox[{{69, 12}, {69, 10}}], LineBox[{{69, 10}, {69, 8}}], 
     LineBox[NCache[{{69, 8}, {69, Rational[16, 3]}}, {{69, 8}, {
        69, 5.333333333333333}}]], 
     LineBox[NCache[{{69, Rational[16, 3]}, {69, Rational[8, 3]}}, {{
        69, 5.333333333333333}, {69, 2.6666666666666665`}}]], 
     LineBox[NCache[{{Rational[199, 3], Rational[8, 3]}, {
        69, Rational[8, 3]}}, {{66.33333333333333, 2.6666666666666665`}, {
        69, 2.6666666666666665`}}]], 
     LineBox[NCache[{{Rational[199, 3], Rational[8, 3]}, {
        Rational[199, 3], 0}}, {{66.33333333333333, 2.6666666666666665`}, {
        66.33333333333333, 0}}]], 
     LineBox[NCache[{{Rational[191, 3], 0}, {Rational[199, 3], 0}}, {{
        63.666666666666664`, 0}, {66.33333333333333, 0}}]], 
     LineBox[NCache[{{Rational[287, 5], 8}, {59, 8}}, {{57.4, 8}, {59, 8}}]], 
     LineBox[NCache[{{Rational[221, 5], 8}, {Rational[229, 5], 8}}, {{
        44.2, 8}, {45.8, 8}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[16, 5]}, {
        Rational[187, 5], Rational[8, 5]}}, {{37.4, 3.2}, {37.4, 1.6}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[8, 5]}, {
        Rational[187, 5], 0}}, {{37.4, 1.6}, {37.4, 0}}]], 
     LineBox[NCache[{{Rational[187, 5], 0}, {39, 0}}, {{37.4, 0}, {39, 0}}]], 
     LineBox[{{39, 0}, {41, 0}}], 
     LineBox[NCache[{{41, 0}, {Rational[213, 5], 0}}, {{41, 0}, {42.6, 0}}]], 
     LineBox[NCache[{{Rational[229, 5], 0}, {Rational[237, 5], 0}}, {{
        45.8, 0}, {47.4, 0}}]], 
     LineBox[NCache[{{41, Rational[16, 5]}, {
        Rational[213, 5], Rational[16, 5]}}, {{41, 3.2}, {42.6, 3.2}}]], 
     LineBox[NCache[{{41, Rational[24, 5]}, {41, Rational[16, 5]}}, {{
        41, 4.8}, {41, 3.2}}]], 
     LineBox[NCache[{{41, Rational[32, 5]}, {41, Rational[24, 5]}}, {{
        41, 6.4}, {41, 4.8}}]], 
     LineBox[NCache[{{41, Rational[24, 5]}, {
        Rational[213, 5], Rational[24, 5]}}, {{41, 4.8}, {42.6, 4.8}}]], 
     LineBox[
      NCache[{{Rational[213, 5], Rational[24, 5]}, {
        Rational[221, 5], Rational[24, 5]}}, {{42.6, 4.8}, {44.2, 4.8}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[24, 5]}, {
        Rational[229, 5], Rational[24, 5]}}, {{44.2, 4.8}, {45.8, 4.8}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[24, 5]}, {
        Rational[221, 5], Rational[16, 5]}}, {{44.2, 4.8}, {44.2, 3.2}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[16, 5]}, {
        Rational[221, 5], Rational[8, 5]}}, {{44.2, 3.2}, {44.2, 1.6}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[16, 5]}, {
        Rational[229, 5], Rational[16, 5]}}, {{44.2, 3.2}, {45.8, 3.2}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[16, 5]}, {
        Rational[229, 5], Rational[8, 5]}}, {{45.8, 3.2}, {45.8, 1.6}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[8, 5]}, {
        Rational[229, 5], 0}}, {{45.8, 1.6}, {45.8, 0}}]], 
     LineBox[NCache[{{Rational[221, 5], 0}, {Rational[229, 5], 0}}, {{
        44.2, 0}, {45.8, 0}}]], 
     LineBox[NCache[{{Rational[213, 5], 0}, {Rational[221, 5], 0}}, {{
        42.6, 0}, {44.2, 0}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[8, 5]}, {
        Rational[213, 5], 0}}, {{42.6, 1.6}, {42.6, 0}}]], 
     LineBox[NCache[{{41, Rational[8, 5]}, {
        Rational[213, 5], Rational[8, 5]}}, {{41, 1.6}, {42.6, 1.6}}]], 
     LineBox[NCache[{{39, Rational[8, 5]}, {41, Rational[8, 5]}}, {{
        39, 1.6}, {41, 1.6}}]], 
     LineBox[NCache[{{39, Rational[16, 5]}, {39, Rational[8, 5]}}, {{
        39, 3.2}, {39, 1.6}}]], 
     LineBox[NCache[{{39, Rational[24, 5]}, {39, Rational[16, 5]}}, {{
        39, 4.8}, {39, 3.2}}]], 
     LineBox[NCache[{{39, Rational[32, 5]}, {39, Rational[24, 5]}}, {{
        39, 6.4}, {39, 4.8}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[32, 5]}, {
        39, Rational[32, 5]}}, {{37.4, 6.4}, {39, 6.4}}]], 
     LineBox[{{29, 8}, {31, 8}}], LineBox[{{27, 8}, {29, 8}}], 
     LineBox[NCache[{{29, 8}, {31, Rational[32, 5]}}, {{29, 8}, {31, 6.4}}]], 
     LineBox[NCache[{{31, Rational[32, 5]}, {
        Rational[163, 5], Rational[32, 5]}}, {{31, 6.4}, {32.6, 6.4}}]], 
     LineBox[
      NCache[{{31, Rational[32, 5]}, {31, Rational[24, 5]}}, {{31, 6.4}, {
        31, 4.8}}]], 
     LineBox[NCache[{{31, Rational[24, 5]}, {31, Rational[16, 5]}}, {{
        31, 4.8}, {31, 3.2}}]], 
     LineBox[NCache[{{31, Rational[16, 5]}, {
        Rational[163, 5], Rational[16, 5]}}, {{31, 3.2}, {32.6, 3.2}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[24, 5]}, {
        Rational[163, 5], Rational[16, 5]}}, {{32.6, 4.8}, {32.6, 3.2}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[24, 5]}, {
        Rational[171, 5], Rational[24, 5]}}, {{32.6, 4.8}, {34.2, 4.8}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[32, 5]}, {
        Rational[171, 5], Rational[24, 5]}}, {{34.2, 6.4}, {34.2, 4.8}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[32, 5]}, {
        Rational[179, 5], Rational[32, 5]}}, {{34.2, 6.4}, {35.8, 6.4}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[32, 5]}, {
        Rational[187, 5], Rational[32, 5]}}, {{35.8, 6.4}, {37.4, 6.4}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[32, 5]}, {
        Rational[187, 5], Rational[24, 5]}}, {{37.4, 6.4}, {37.4, 4.8}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[24, 5]}, {
        Rational[187, 5], Rational[24, 5]}}, {{35.8, 4.8}, {37.4, 4.8}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[24, 5]}, {
        Rational[179, 5], Rational[16, 5]}}, {{35.8, 4.8}, {35.8, 3.2}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[16, 5]}, {
        Rational[179, 5], Rational[16, 5]}}, {{34.2, 3.2}, {35.8, 3.2}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[16, 5]}, {
        Rational[171, 5], Rational[8, 5]}}, {{34.2, 3.2}, {34.2, 1.6}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[8, 5]}, {
        Rational[179, 5], Rational[8, 5]}}, {{34.2, 1.6}, {35.8, 1.6}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[8, 5]}, {
        Rational[179, 5], 0}}, {{35.8, 1.6}, {35.8, 0}}]], 
     LineBox[NCache[{{Rational[171, 5], 0}, {Rational[179, 5], 0}}, {{
        34.2, 0}, {35.8, 0}}]], 
     LineBox[NCache[{{Rational[163, 5], 0}, {Rational[171, 5], 0}}, {{
        32.6, 0}, {34.2, 0}}]], LineBox[{{27, 4}, {27, 2}}], 
     LineBox[{{25, 4}, {27, 4}}], LineBox[{{11, 4}, {11, 2}}], 
     LineBox[{{11, 2}, {11, 0}}], LineBox[{{11, 0}, {13, 0}}], 
     LineBox[{{13, 0}, {15, 0}}], LineBox[{{15, 2}, {15, 0}}], 
     LineBox[{{13, 2}, {15, 2}}], LineBox[{{13, 4}, {13, 2}}], 
     LineBox[{{13, 6}, {13, 4}}], LineBox[{{11, 6}, {13, 6}}], 
     LineBox[{{11, 8}, {11, 6}}], LineBox[{{55, 12}, {57, 12}}], 
     LineBox[{{53, 12}, {55, 12}}], LineBox[{{51, 12}, {53, 12}}], 
     LineBox[NCache[{{49, Rational[38, 3]}, {51, 12}}, {{
        49, 12.666666666666666`}, {51, 12}}]], LineBox[{{49, 20}, {49, 18}}], 
     LineBox[NCache[{{Rational[139, 3], 18}, {49, 18}}, {{
        46.333333333333336`, 18}, {49, 18}}]], 
     LineBox[NCache[{{41, 20}, {Rational[131, 3], 18}}, {{41, 20}, {
        43.666666666666664`, 18}}]], 
     LineBox[NCache[{{Rational[131, 3], 18}, {Rational[139, 3], 18}}, {{
        43.666666666666664`, 18}, {46.333333333333336`, 18}}]], 
     LineBox[{{45, 24}, {45, 20}}], 
     LineBox[NCache[{{45, 20}, {Rational[139, 3], 18}}, {{45, 20}, {
        46.333333333333336`, 18}}]], 
     LineBox[NCache[{{Rational[139, 3], 18}, {
        Rational[139, 3], Rational[46, 3]}}, {{46.333333333333336`, 18}, {
        46.333333333333336`, 15.333333333333334`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[46, 3]}, {
        49, Rational[46, 3]}}, {{46.333333333333336`, 15.333333333333334`}, {
        49, 15.333333333333334`}}]], 
     LineBox[NCache[{{49, Rational[46, 3]}, {49, Rational[38, 3]}}, {{
        49, 15.333333333333334`}, {49, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[38, 3]}, {
        49, Rational[38, 3]}}, {{46.333333333333336`, 12.666666666666666`}, {
        49, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[38, 3]}, {
        Rational[139, 3], Rational[38, 3]}}, {{43.666666666666664`, 
       12.666666666666666`}, {46.333333333333336`, 12.666666666666666`}}]], 
     LineBox[NCache[{{39, Rational[46, 3]}, {39, Rational[38, 3]}}, {{
        39, 15.333333333333334`}, {39, 12.666666666666666`}}]], 
     LineBox[
      NCache[{{39, Rational[38, 3]}, {39, 10}}, {{39, 12.666666666666666`}, {
        39, 10}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[38, 3]}, {
        Rational[101, 3], 10}}, {{33.666666666666664`, 12.666666666666666`}, {
        33.666666666666664`, 10}}]], LineBox[{{27, 12}, {29, 12}}], 
     LineBox[{{29, 14}, {29, 12}}], 
     LineBox[NCache[{{29, 12}, {31, Rational[38, 3]}}, {{29, 12}, {
        31, 12.666666666666666`}}]], 
     LineBox[NCache[{{31, Rational[38, 3]}, {
        Rational[101, 3], Rational[38, 3]}}, {{31, 12.666666666666666`}, {
        33.666666666666664`, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[38, 3]}, {
        Rational[109, 3], Rational[38, 3]}}, {{33.666666666666664`, 
       12.666666666666666`}, {36.333333333333336`, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[38, 3]}, {
        39, Rational[38, 3]}}, {{36.333333333333336`, 12.666666666666666`}, {
        39, 12.666666666666666`}}]], 
     LineBox[NCache[{{39, Rational[38, 3]}, {41, Rational[38, 3]}}, {{
        39, 12.666666666666666`}, {41, 12.666666666666666`}}]], 
     LineBox[NCache[{{41, Rational[38, 3]}, {
        Rational[131, 3], Rational[38, 3]}}, {{41, 12.666666666666666`}, {
        43.666666666666664`, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[46, 3]}, {
        Rational[131, 3], Rational[38, 3]}}, {{43.666666666666664`, 
       15.333333333333334`}, {43.666666666666664`, 12.666666666666666`}}]], 
     LineBox[NCache[{{41, Rational[46, 3]}, {
        Rational[131, 3], Rational[46, 3]}}, {{41, 15.333333333333334`}, {
        43.666666666666664`, 15.333333333333334`}}]], 
     LineBox[NCache[{{41, 18}, {41, Rational[46, 3]}}, {{41, 18}, {
        41, 15.333333333333334`}}]], LineBox[{{39, 18}, {41, 18}}], 
     LineBox[NCache[{{51, Rational[94, 3]}, {51, 30}}, {{
        51, 31.333333333333332`}, {51, 30}}]], 
     LineBox[NCache[{{51, Rational[94, 3]}, {
        Rational[157, 3], Rational[94, 3]}}, {{51, 31.333333333333332`}, {
        52.333333333333336`, 31.333333333333332`}}]], 
     LineBox[
      NCache[{{51, Rational[98, 3]}, {51, Rational[94, 3]}}, {{
        51, 32.666666666666664`}, {51, 31.333333333333332`}}]], 
     LineBox[NCache[{{49, 30}, {51, Rational[94, 3]}}, {{49, 30}, {
        51, 31.333333333333332`}}]], LineBox[{{45, 34}, {49, 34}}], 
     LineBox[{{49, 38}, {49, 34}}], LineBox[{{49, 34}, {51, 34}}], 
     LineBox[{{49, 34}, {49, 30}}], 
     LineBox[NCache[{{49, 28}, {51, Rational[80, 3]}}, {{49, 28}, {
        51, 26.666666666666668`}}]], LineBox[{{49, 28}, {51, 28}}], 
     LineBox[{{49, 28}, {49, 24}}], LineBox[{{45, 28}, {49, 28}}], 
     LineBox[NCache[{{49, 28}, {51, Rational[76, 3]}}, {{49, 28}, {
        51, 25.333333333333332`}}]], LineBox[{{49, 30}, {49, 28}}], 
     LineBox[{{45, 30}, {49, 30}}], LineBox[{{41, 30}, {45, 30}}], 
     LineBox[{{31, 34}, {35, 34}}], LineBox[{{35, 34}, {35, 30}}], 
     LineBox[{{35, 38}, {35, 34}}], LineBox[{{35, 34}, {39, 34}}], 
     LineBox[{{39, 38}, {41, 38}}], LineBox[{{39, 40}, {39, 38}}], 
     LineBox[{{39, 38}, {39, 34}}], LineBox[{{39, 34}, {41, 34}}], 
     LineBox[{{39, 34}, {39, 30}}], LineBox[{{31, 28}, {35, 28}}], 
     LineBox[{{35, 28}, {39, 28}}], LineBox[{{39, 30}, {39, 28}}], 
     LineBox[{{39, 30}, {41, 30}}], LineBox[{{41, 30}, {41, 28}}], 
     LineBox[{{41, 28}, {41, 24}}], LineBox[{{39, 24}, {41, 24}}], 
     LineBox[{{35, 24}, {39, 24}}], LineBox[{{29, 26}, {29, 24}}], 
     LineBox[{{27, 24}, {29, 24}}], LineBox[{{27, 28}, {27, 26}}], 
     LineBox[{{25, 26}, {27, 26}}], LineBox[{{27, 26}, {27, 24}}], 
     LineBox[{{25, 24}, {27, 24}}], LineBox[{{21, 26}, {23, 26}}], 
     LineBox[{{23, 28}, {23, 26}}], LineBox[{{23, 26}, {23, 24}}], 
     LineBox[{{21, 22}, {23, 22}}], LineBox[{{23, 24}, {23, 22}}], 
     LineBox[NCache[{{19, Rational[76, 3]}, {21, 24}}, {{
        19, 25.333333333333332`}, {21, 24}}]], LineBox[{{21, 24}, {23, 24}}], 
     LineBox[{{23, 24}, {25, 24}}], LineBox[{{25, 24}, {25, 22}}], 
     LineBox[{{25, 22}, {27, 22}}], LineBox[{{29, 20}, {31, 20}}], 
     LineBox[{{29, 20}, {29, 18}}], LineBox[{{27, 18}, {29, 18}}], 
     LineBox[{{27, 20}, {27, 18}}], LineBox[{{27, 22}, {27, 20}}], 
     LineBox[{{27, 22}, {29, 22}}], LineBox[{{29, 22}, {31, 24}}], 
     LineBox[{{31, 24}, {35, 24}}], LineBox[{{35, 24}, {35, 20}}], 
     LineBox[{{35, 20}, {39, 20}}], LineBox[{{39, 20}, {39, 18}}], 
     LineBox[NCache[{{Rational[109, 3], 18}, {39, 18}}, {{
        36.333333333333336`, 18}, {39, 18}}]], 
     LineBox[NCache[{{Rational[101, 3], 18}, {Rational[109, 3], 18}}, {{
        33.666666666666664`, 18}, {36.333333333333336`, 18}}]], 
     LineBox[NCache[{{Rational[109, 3], 18}, {
        Rational[109, 3], Rational[46, 3]}}, {{36.333333333333336`, 18}, {
        36.333333333333336`, 15.333333333333334`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[46, 3]}, {
        Rational[109, 3], Rational[46, 3]}}, {{33.666666666666664`, 
       15.333333333333334`}, {36.333333333333336`, 15.333333333333334`}}]], 
     LineBox[NCache[{{31, Rational[46, 3]}, {
        Rational[101, 3], Rational[46, 3]}}, {{31, 15.333333333333334`}, {
        33.666666666666664`, 15.333333333333334`}}]], 
     LineBox[NCache[{{31, 18}, {31, Rational[46, 3]}}, {{31, 18}, {
        31, 15.333333333333334`}}]], LineBox[{{29, 16}, {31, 18}}], 
     LineBox[{{27, 16}, {29, 16}}], LineBox[{{23, 18}, {23, 16}}], 
     LineBox[{{21, 16}, {23, 16}}], LineBox[{{21, 16}, {21, 14}}], 
     LineBox[{{19, 4}, {19, 2}}], LineBox[{{19, 6}, {19, 4}}], 
     LineBox[{{23, 12}, {25, 12}}], LineBox[{{23, 12}, {23, 10}}], 
     LineBox[{{21, 10}, {23, 10}}], LineBox[{{21, 10}, {21, 8}}], 
     LineBox[{{21, 8}, {23, 8}}], LineBox[{{23, 8}, {23, 6}}], 
     LineBox[{{21, 6}, {23, 6}}], LineBox[{{19, 6}, {21, 6}}], 
     LineBox[{{19, 8}, {19, 6}}], LineBox[{{19, 10}, {19, 8}}], 
     LineBox[{{17, 12}, {17, 10}}], LineBox[{{17, 10}, {19, 10}}], 
     LineBox[{{19, 12}, {19, 10}}], LineBox[{{19, 12}, {21, 12}}], 
     LineBox[{{21, 14}, {21, 12}}], LineBox[{{21, 14}, {23, 14}}], 
     LineBox[{{23, 14}, {25, 14}}], LineBox[{{25, 14}, {27, 14}}], 
     LineBox[{{27, 16}, {27, 14}}], LineBox[{{25, 16}, {27, 16}}], 
     LineBox[{{25, 18}, {25, 16}}], LineBox[{{25, 20}, {25, 18}}], 
     LineBox[{{23, 20}, {25, 20}}], LineBox[{{21, 20}, {23, 20}}], 
     LineBox[{{15, 18}, {17, 18}}], LineBox[{{13, 18}, {15, 18}}], 
     LineBox[{{11, 14}, {11, 12}}], LineBox[{{11, 12}, {13, 12}}], 
     LineBox[{{13, 14}, {13, 12}}], LineBox[{{13, 16}, {13, 14}}], 
     LineBox[{{11, 16}, {13, 16}}], LineBox[{{11, 18}, {11, 16}}], 
     LineBox[{{11, 18}, {13, 18}}], LineBox[{{11, 20}, {13, 18}}], 
     LineBox[{{25, 30}, {25, 28}}], LineBox[{{27, 38}, {27, 36}}], 
     LineBox[{{27, 36}, {29, 36}}], LineBox[{{25, 36}, {27, 36}}], 
     LineBox[{{27, 36}, {27, 34}}], LineBox[{{29, 34}, {29, 32}}], 
     LineBox[{{27, 34}, {29, 34}}], LineBox[{{23, 34}, {25, 34}}], 
     LineBox[{{25, 34}, {25, 32}}], LineBox[{{25, 34}, {27, 34}}], 
     LineBox[{{27, 34}, {27, 32}}], LineBox[{{27, 32}, {27, 30}}], 
     LineBox[{{29, 30}, {29, 28}}], LineBox[{{29, 30}, {31, 30}}], 
     LineBox[{{27, 30}, {29, 30}}], LineBox[{{25, 30}, {27, 30}}], 
     LineBox[{{23, 30}, {25, 30}}], LineBox[{{23, 32}, {23, 30}}], 
     LineBox[{{21, 32}, {23, 32}}], LineBox[{{27, 42}, {27, 40}}], 
     LineBox[{{27, 40}, {29, 40}}], LineBox[{{25, 40}, {27, 40}}], 
     LineBox[{{25, 40}, {25, 38}}], LineBox[{{23, 42}, {25, 42}}], 
     LineBox[{{25, 44}, {25, 42}}], LineBox[{{25, 42}, {25, 40}}], 
     LineBox[{{23, 40}, {25, 40}}], LineBox[{{21, 44}, {21, 42}}], 
     LineBox[{{19, 44}, {21, 42}}], LineBox[{{21, 42}, {21, 40}}], 
     LineBox[{{15, 40}, {19, 40}}], LineBox[{{19, 40}, {19, 38}}], 
     LineBox[{{19, 40}, {21, 40}}], LineBox[{{21, 40}, {21, 38}}], 
     LineBox[{{21, 40}, {23, 40}}], LineBox[{{23, 40}, {23, 38}}], 
     LineBox[{{23, 38}, {23, 36}}], LineBox[{{21, 36}, {23, 36}}], 
     LineBox[{{21, 36}, {21, 34}}], LineBox[{{21, 34}, {21, 32}}], 
     LineBox[{{19, 34}, {21, 32}}], 
     LineBox[NCache[{{11, 28}, {Rational[41, 3], 28}}, {{11, 28}, {
        13.666666666666666`, 28}}]], 
     LineBox[NCache[{{11, 30}, {Rational[41, 3], 28}}, {{11, 30}, {
        13.666666666666666`, 28}}]], LineBox[{{11, 38}, {15, 38}}], 
     LineBox[{{15, 48}, {15, 44}}], LineBox[{{11, 44}, {15, 44}}], 
     LineBox[{{11, 50}, {11, 48}}], LineBox[{{11, 48}, {11, 44}}], 
     LineBox[{{11, 44}, {11, 40}}], LineBox[{{11, 40}, {11, 38}}], 
     LineBox[{{11, 38}, {11, 34}}], LineBox[{{11, 34}, {11, 30}}], 
     LineBox[{{11, 30}, {15, 30}}], LineBox[{{15, 34}, {15, 30}}], 
     LineBox[{{15, 34}, {19, 34}}], LineBox[{{19, 34}, {19, 30}}], 
     LineBox[{{19, 30}, {21, 30}}], LineBox[{{21, 30}, {21, 28}}], 
     LineBox[{{19, 28}, {21, 28}}], 
     LineBox[NCache[{{Rational[49, 3], 28}, {19, 28}}, {{
        16.333333333333332`, 28}, {19, 28}}]], 
     LineBox[NCache[{{Rational[49, 3], 28}, {
        Rational[49, 3], Rational[76, 3]}}, {{16.333333333333332`, 28}, {
        16.333333333333332`, 25.333333333333332`}}]], 
     LineBox[NCache[{{Rational[49, 3], Rational[68, 3]}, {
        19, Rational[68, 3]}}, {{16.333333333333332`, 22.666666666666668`}, {
        19, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[41, 3], Rational[68, 3]}, {
        Rational[49, 3], Rational[68, 3]}}, {{13.666666666666666`, 
       22.666666666666668`}, {16.333333333333332`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[49, 3], Rational[76, 3]}, {
        Rational[49, 3], Rational[68, 3]}}, {{16.333333333333332`, 
       25.333333333333332`}, {16.333333333333332`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[41, 3], Rational[76, 3]}, {
        Rational[49, 3], Rational[76, 3]}}, {{13.666666666666666`, 
       25.333333333333332`}, {16.333333333333332`, 25.333333333333332`}}]], 
     LineBox[NCache[{{11, Rational[76, 3]}, {
        Rational[41, 3], Rational[76, 3]}}, {{11, 25.333333333333332`}, {
        13.666666666666666`, 25.333333333333332`}}]], 
     LineBox[NCache[{{11, Rational[76, 3]}, {11, Rational[68, 3]}}, {{
        11, 25.333333333333332`}, {11, 22.666666666666668`}}]], 
     LineBox[NCache[{{11, Rational[68, 3]}, {11, 20}}, {{
        11, 22.666666666666668`}, {11, 20}}]], 
     LineBox[NCache[{{11, 20}, {Rational[41, 3], 20}}, {{11, 20}, {
        13.666666666666666`, 20}}]], 
     LineBox[NCache[{{Rational[41, 3], 20}, {Rational[49, 3], 20}}, {{
        13.666666666666666`, 20}, {16.333333333333332`, 20}}]], 
     LineBox[NCache[{{Rational[49, 3], 20}, {19, 20}}, {{
        16.333333333333332`, 20}, {19, 20}}]], LineBox[{{19, 20}, {21, 20}}], 
     LineBox[{{21, 20}, {21, 18}}], LineBox[{{19, 18}, {21, 18}}], 
     LineBox[{{19, 18}, {19, 16}}], LineBox[{{19, 16}, {19, 14}}], 
     LineBox[{{17, 14}, {19, 14}}], LineBox[{{17, 16}, {17, 14}}], 
     LineBox[{{15, 16}, {17, 16}}], LineBox[{{15, 16}, {15, 14}}], 
     LineBox[{{15, 14}, {15, 12}}], LineBox[{{15, 12}, {15, 10}}], 
     LineBox[{{13, 10}, {15, 10}}], LineBox[{{11, 10}, {13, 10}}], 
     LineBox[{{11, 10}, {11, 8}}], LineBox[{{11, 8}, {13, 8}}], 
     LineBox[{{13, 8}, {15, 8}}], LineBox[{{15, 8}, {17, 8}}], 
     LineBox[{{17, 8}, {17, 6}}], LineBox[{{15, 6}, {17, 6}}], 
     LineBox[{{15, 6}, {15, 4}}], LineBox[{{15, 4}, {17, 4}}], 
     LineBox[{{17, 4}, {17, 2}}], LineBox[{{17, 2}, {17, 0}}], 
     LineBox[{{17, 0}, {19, 0}}], LineBox[{{19, 0}, {21, 0}}], 
     LineBox[{{21, 0}, {23, 0}}], LineBox[{{23, 2}, {23, 0}}], 
     LineBox[{{21, 2}, {23, 2}}], LineBox[{{21, 4}, {21, 2}}], 
     LineBox[{{21, 4}, {23, 4}}], LineBox[{{23, 4}, {25, 4}}], 
     LineBox[{{25, 4}, {25, 2}}], LineBox[{{25, 2}, {25, 0}}], 
     LineBox[{{25, 0}, {27, 0}}], LineBox[{{27, 0}, {29, 0}}], 
     LineBox[{{29, 0}, {31, 0}}], 
     LineBox[NCache[{{31, 0}, {Rational[163, 5], 0}}, {{31, 0}, {32.6, 0}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[8, 5]}, {
        Rational[163, 5], 0}}, {{32.6, 1.6}, {32.6, 0}}]], 
     LineBox[NCache[{{31, Rational[8, 5]}, {
        Rational[163, 5], Rational[8, 5]}}, {{31, 1.6}, {32.6, 1.6}}]], 
     LineBox[NCache[{{29, 2}, {31, Rational[8, 5]}}, {{29, 2}, {31, 1.6}}]], 
     LineBox[{{29, 4}, {29, 2}}], LineBox[{{29, 6}, {29, 4}}], 
     LineBox[{{27, 6}, {29, 6}}], LineBox[{{25, 6}, {27, 6}}], 
     LineBox[{{25, 8}, {25, 6}}], LineBox[{{25, 10}, {25, 8}}], 
     LineBox[{{25, 10}, {27, 10}}], LineBox[{{27, 10}, {29, 10}}], 
     LineBox[{{29, 10}, {31, 10}}], 
     LineBox[NCache[{{31, 10}, {Rational[163, 5], 8}}, {{31, 10}, {
        32.6, 8}}]], 
     LineBox[NCache[{{Rational[163, 5], 8}, {Rational[171, 5], 8}}, {{
        32.6, 8}, {34.2, 8}}]], 
     LineBox[NCache[{{Rational[171, 5], 8}, {Rational[179, 5], 8}}, {{
        34.2, 8}, {35.8, 8}}]], 
     LineBox[NCache[{{Rational[109, 3], 10}, {Rational[179, 5], 8}}, {{
        36.333333333333336`, 10}, {35.8, 8}}]], 
     LineBox[NCache[{{Rational[109, 3], 10}, {Rational[187, 5], 8}}, {{
        36.333333333333336`, 10}, {37.4, 8}}]], 
     LineBox[NCache[{{Rational[187, 5], 8}, {39, 8}}, {{37.4, 8}, {39, 8}}]], 
     LineBox[{{39, 8}, {41, 8}}], LineBox[{{41, 10}, {41, 8}}], 
     LineBox[NCache[{{41, 10}, {Rational[131, 3], 10}}, {{41, 10}, {
        43.666666666666664`, 10}}]], 
     LineBox[NCache[{{Rational[131, 3], 10}, {Rational[221, 5], 8}}, {{
        43.666666666666664`, 10}, {44.2, 8}}]], 
     LineBox[NCache[{{Rational[213, 5], 8}, {Rational[221, 5], 8}}, {{
        42.6, 8}, {44.2, 8}}]], 
     LineBox[NCache[{{Rational[213, 5], 8}, {
        Rational[213, 5], Rational[32, 5]}}, {{42.6, 8}, {42.6, 6.4}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[32, 5]}, {
        Rational[221, 5], Rational[32, 5]}}, {{42.6, 6.4}, {44.2, 6.4}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[32, 5]}, {
        Rational[229, 5], Rational[32, 5]}}, {{44.2, 6.4}, {45.8, 6.4}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[32, 5]}, {
        Rational[237, 5], Rational[32, 5]}}, {{45.8, 6.4}, {47.4, 6.4}}]], 
     LineBox[NCache[{{Rational[279, 5], 8}, {
        Rational[279, 5], Rational[32, 5]}}, {{55.8, 8}, {55.8, 6.4}}]], 
     LineBox[NCache[{{Rational[271, 5], Rational[32, 5]}, {
        Rational[279, 5], Rational[32, 5]}}, {{54.2, 6.4}, {55.8, 6.4}}]], 
     LineBox[NCache[{{Rational[263, 5], Rational[32, 5]}, {
        Rational[271, 5], Rational[32, 5]}}, {{52.6, 6.4}, {54.2, 6.4}}]], 
     LineBox[NCache[{{51, Rational[32, 5]}, {
        Rational[263, 5], Rational[32, 5]}}, {{51, 6.4}, {52.6, 6.4}}]], 
     LineBox[NCache[{{51, Rational[32, 5]}, {51, Rational[24, 5]}}, {{
        51, 6.4}, {51, 4.8}}]], 
     LineBox[NCache[{{49, Rational[32, 5]}, {51, Rational[32, 5]}}, {{
        49, 6.4}, {51, 6.4}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[32, 5]}, {
        49, Rational[32, 5]}}, {{47.4, 6.4}, {49, 6.4}}]], 
     LineBox[NCache[{{Rational[237, 5], 8}, {
        Rational[237, 5], Rational[32, 5]}}, {{47.4, 8}, {47.4, 6.4}}]], 
     LineBox[NCache[{{Rational[139, 3], 10}, {Rational[237, 5], 8}}, {{
        46.333333333333336`, 10}, {47.4, 8}}]], 
     LineBox[NCache[{{Rational[139, 3], 10}, {49, 10}}, {{
        46.333333333333336`, 10}, {49, 10}}]], LineBox[{{49, 10}, {49, 8}}], 
     LineBox[{{49, 8}, {51, 8}}], LineBox[{{51, 10}, {51, 8}}], 
     LineBox[NCache[{{51, 10}, {Rational[263, 5], 8}}, {{51, 10}, {
        52.6, 8}}]], 
     LineBox[NCache[{{Rational[263, 5], 8}, {Rational[271, 5], 8}}, {{
        52.6, 8}, {54.2, 8}}]], 
     LineBox[NCache[{{53, 10}, {Rational[271, 5], 8}}, {{53, 10}, {
        54.2, 8}}]], LineBox[{{53, 10}, {55, 10}}], 
     LineBox[{{55, 10}, {57, 10}}], 
     LineBox[NCache[{{57, 10}, {Rational[287, 5], 8}}, {{57, 10}, {
        57.4, 8}}]], 
     LineBox[NCache[{{Rational[287, 5], 8}, {
        Rational[287, 5], Rational[32, 5]}}, {{57.4, 8}, {57.4, 6.4}}]], 
     LineBox[NCache[{{Rational[287, 5], Rational[32, 5]}, {
        Rational[287, 5], Rational[24, 5]}}, {{57.4, 6.4}, {57.4, 4.8}}]], 
     LineBox[NCache[{{Rational[287, 5], Rational[24, 5]}, {
        Rational[287, 5], Rational[16, 5]}}, {{57.4, 4.8}, {57.4, 3.2}}]], 
     LineBox[NCache[{{Rational[287, 5], Rational[16, 5]}, {
        59, Rational[16, 5]}}, {{57.4, 3.2}, {59, 3.2}}]], 
     LineBox[NCache[{{59, Rational[16, 5]}, {59, Rational[8, 5]}}, {{
        59, 3.2}, {59, 1.6}}]], 
     LineBox[NCache[{{Rational[287, 5], Rational[8, 5]}, {
        59, Rational[8, 5]}}, {{57.4, 1.6}, {59, 1.6}}]], 
     LineBox[NCache[{{Rational[279, 5], Rational[8, 5]}, {
        Rational[287, 5], Rational[8, 5]}}, {{55.8, 1.6}, {57.4, 1.6}}]], 
     LineBox[NCache[{{Rational[271, 5], Rational[8, 5]}, {
        Rational[279, 5], Rational[8, 5]}}, {{54.2, 1.6}, {55.8, 1.6}}]], 
     LineBox[
      NCache[{{Rational[271, 5], Rational[16, 5]}, {
        Rational[271, 5], Rational[8, 5]}}, {{54.2, 3.2}, {54.2, 1.6}}]], 
     LineBox[NCache[{{Rational[271, 5], Rational[16, 5]}, {
        Rational[279, 5], Rational[16, 5]}}, {{54.2, 3.2}, {55.8, 3.2}}]], 
     LineBox[NCache[{{Rational[279, 5], Rational[24, 5]}, {
        Rational[279, 5], Rational[16, 5]}}, {{55.8, 4.8}, {55.8, 3.2}}]], 
     LineBox[NCache[{{Rational[271, 5], Rational[24, 5]}, {
        Rational[279, 5], Rational[24, 5]}}, {{54.2, 4.8}, {55.8, 4.8}}]], 
     LineBox[NCache[{{Rational[263, 5], Rational[24, 5]}, {
        Rational[271, 5], Rational[24, 5]}}, {{52.6, 4.8}, {54.2, 4.8}}]], 
     LineBox[NCache[{{Rational[263, 5], Rational[24, 5]}, {
        Rational[263, 5], Rational[16, 5]}}, {{52.6, 4.8}, {52.6, 3.2}}]], 
     LineBox[NCache[{{Rational[263, 5], Rational[16, 5]}, {
        Rational[263, 5], Rational[8, 5]}}, {{52.6, 3.2}, {52.6, 1.6}}]], 
     LineBox[NCache[{{51, Rational[8, 5]}, {
        Rational[263, 5], Rational[8, 5]}}, {{51, 1.6}, {52.6, 1.6}}]], 
     LineBox[NCache[{{51, Rational[16, 5]}, {51, Rational[8, 5]}}, {{
        51, 3.2}, {51, 1.6}}]], 
     LineBox[NCache[{{49, Rational[16, 5]}, {51, Rational[16, 5]}}, {{
        49, 3.2}, {51, 3.2}}]], 
     LineBox[NCache[{{49, Rational[24, 5]}, {49, Rational[16, 5]}}, {{
        49, 4.8}, {49, 3.2}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[24, 5]}, {
        49, Rational[24, 5]}}, {{47.4, 4.8}, {49, 4.8}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[24, 5]}, {
        Rational[237, 5], Rational[16, 5]}}, {{47.4, 4.8}, {47.4, 3.2}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[16, 5]}, {
        Rational[237, 5], Rational[8, 5]}}, {{47.4, 3.2}, {47.4, 1.6}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[8, 5]}, {
        49, Rational[8, 5]}}, {{47.4, 1.6}, {49, 1.6}}]], 
     LineBox[NCache[{{49, Rational[8, 5]}, {49, 0}}, {{49, 1.6}, {49, 0}}]], 
     LineBox[{{49, 0}, {51, 0}}], 
     LineBox[NCache[{{51, 0}, {Rational[263, 5], 0}}, {{51, 0}, {52.6, 0}}]], 
     LineBox[NCache[{{Rational[263, 5], 0}, {Rational[271, 5], 0}}, {{
        52.6, 0}, {54.2, 0}}]], 
     LineBox[NCache[{{Rational[271, 5], 0}, {Rational[279, 5], 0}}, {{
        54.2, 0}, {55.8, 0}}]], 
     LineBox[NCache[{{Rational[279, 5], 0}, {Rational[287, 5], 0}}, {{
        55.8, 0}, {57.4, 0}}]], 
     LineBox[NCache[{{Rational[287, 5], 0}, {59, 0}}, {{57.4, 0}, {59, 0}}]], 
     LineBox[{{59, 0}, {61, 0}}], 
     LineBox[NCache[{{61, 0}, {Rational[191, 3], 0}}, {{61, 0}, {
        63.666666666666664`, 0}}]], 
     LineBox[NCache[{{Rational[191, 3], Rational[8, 3]}, {
        Rational[191, 3], 0}}, {{63.666666666666664`, 2.6666666666666665`}, {
        63.666666666666664`, 0}}]], 
     LineBox[NCache[{{61, Rational[8, 3]}, {
        Rational[191, 3], Rational[8, 3]}}, {{61, 2.6666666666666665`}, {
        63.666666666666664`, 2.6666666666666665`}}]], 
     LineBox[NCache[{{61, Rational[16, 3]}, {61, Rational[8, 3]}}, {{
        61, 5.333333333333333}, {61, 2.6666666666666665`}}]], 
     LineBox[NCache[{{59, Rational[24, 5]}, {61, Rational[16, 3]}}, {{
        59, 4.8}, {61, 5.333333333333333}}]], 
     LineBox[NCache[{{59, Rational[32, 5]}, {59, Rational[24, 5]}}, {{
        59, 6.4}, {59, 4.8}}]], 
     LineBox[NCache[{{59, Rational[32, 5]}, {61, 8}}, {{59, 6.4}, {61, 8}}]], 
     LineBox[{{61, 10}, {61, 8}}], LineBox[{{59, 10}, {61, 10}}], 
     LineBox[{{59, 12}, {59, 10}}], LineBox[{{59, 14}, {59, 12}}], 
     LineBox[{{57, 14}, {59, 14}}], LineBox[{{55, 14}, {57, 14}}], 
     LineBox[{{53, 14}, {55, 14}}], LineBox[{{51, 14}, {53, 14}}], 
     LineBox[{{51, 16}, {51, 14}}], LineBox[{{51, 18}, {51, 16}}], 
     LineBox[{{51, 20}, {51, 18}}], 
     LineBox[NCache[{{51, Rational[64, 3]}, {51, 20}}, {{
        51, 21.333333333333332`}, {51, 20}}]], 
     LineBox[NCache[{{Rational[169, 3], 20}, {Rational[173, 3], 20}}, {{
        56.333333333333336`, 20}, {57.666666666666664`, 20}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[64, 3]}, {
        Rational[169, 3], 20}}, {{56.333333333333336`, 21.333333333333332`}, {
        56.333333333333336`, 20}}]], 
     LineBox[NCache[{{Rational[169, 3], 24}, {
        Rational[169, 3], Rational[68, 3]}}, {{56.333333333333336`, 24}, {
        56.333333333333336`, 22.666666666666668`}}]], 
     LineBox[NCache[{{55, Rational[68, 3]}, {
        Rational[169, 3], Rational[68, 3]}}, {{55, 22.666666666666668`}, {
        56.333333333333336`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[68, 3]}, {
        Rational[169, 3], Rational[64, 3]}}, {{56.333333333333336`, 
       22.666666666666668`}, {56.333333333333336`, 21.333333333333332`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[64, 3]}, {
        Rational[173, 3], Rational[64, 3]}}, {{56.333333333333336`, 
       21.333333333333332`}, {57.666666666666664`, 21.333333333333332`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[68, 3]}, {
        Rational[173, 3], Rational[64, 3]}}, {{57.666666666666664`, 
       22.666666666666668`}, {57.666666666666664`, 21.333333333333332`}}]], 
     LineBox[NCache[{{Rational[173, 3], 24}, {
        Rational[173, 3], Rational[68, 3]}}, {{57.666666666666664`, 24}, {
        57.666666666666664`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[76, 3]}, {
        Rational[173, 3], 24}}, {{57.666666666666664`, 25.333333333333332`}, {
        57.666666666666664`, 24}}]], 
     LineBox[NCache[{{59, Rational[140, 3]}, {61, 48}}, {{
        59, 46.666666666666664`}, {61, 48}}]], 
     LineBox[NCache[{{Rational[173, 3], 44}, {59, 44}}, {{
        57.666666666666664`, 44}, {59, 44}}]], 
     LineBox[NCache[{{Rational[173, 3], 44}, {
        Rational[173, 3], Rational[128, 3]}}, {{57.666666666666664`, 44}, {
        57.666666666666664`, 42.666666666666664`}}]], 
     LineBox[{{63, 38}, {63, 36}}], LineBox[{{61, 36}, {63, 36}}], 
     LineBox[NCache[{{59, Rational[106, 3]}, {61, 36}}, {{
        59, 35.333333333333336`}, {61, 36}}]], 
     LineBox[NCache[{{59, Rational[80, 3]}, {59, Rational[76, 3]}}, {{
        59, 26.666666666666668`}, {59, 25.333333333333332`}}]], 
     LineBox[NCache[{{59, 28}, {59, Rational[80, 3]}}, {{59, 28}, {
        59, 26.666666666666668`}}]], LineBox[{{59, 30}, {59, 28}}], 
     LineBox[NCache[{{59, Rational[94, 3]}, {59, 30}}, {{
        59, 31.333333333333332`}, {59, 30}}]], 
     LineBox[
      NCache[{{Rational[169, 3], 34}, {Rational[169, 3], Rational[98, 3]}}, {{
        56.333333333333336`, 34}, {56.333333333333336`, 
        32.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[106, 3]}, {
        Rational[169, 3], 34}}, {{56.333333333333336`, 35.333333333333336`}, {
        56.333333333333336`, 34}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[106, 3]}, {
        Rational[173, 3], Rational[106, 3]}}, {{56.333333333333336`, 
       35.333333333333336`}, {57.666666666666664`, 35.333333333333336`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[106, 3]}, {
        Rational[173, 3], 34}}, {{57.666666666666664`, 35.333333333333336`}, {
        57.666666666666664`, 34}}]], 
     LineBox[NCache[{{Rational[173, 3], 34}, {
        Rational[173, 3], Rational[98, 3]}}, {{57.666666666666664`, 34}, {
        57.666666666666664`, 32.666666666666664`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[98, 3]}, {
        Rational[173, 3], Rational[94, 3]}}, {{57.666666666666664`, 
       32.666666666666664`}, {57.666666666666664`, 31.333333333333332`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[94, 3]}, {
        59, Rational[94, 3]}}, {{57.666666666666664`, 31.333333333333332`}, {
        59, 31.333333333333332`}}]], 
     LineBox[NCache[{{59, Rational[98, 3]}, {59, Rational[94, 3]}}, {{
        59, 32.666666666666664`}, {59, 31.333333333333332`}}]], 
     LineBox[NCache[{{59, 34}, {59, Rational[98, 3]}}, {{59, 34}, {
        59, 32.666666666666664`}}]], 
     LineBox[NCache[{{59, Rational[106, 3]}, {59, 34}}, {{
        59, 35.333333333333336`}, {59, 34}}]], 
     LineBox[NCache[{{59, Rational[110, 3]}, {59, Rational[106, 3]}}, {{
        59, 36.666666666666664`}, {59, 35.333333333333336`}}]], 
     LineBox[NCache[{{59, Rational[110, 3]}, {61, 38}}, {{
        59, 36.666666666666664`}, {61, 38}}]], LineBox[{{59, 38}, {61, 38}}], 
     LineBox[NCache[{{Rational[173, 3], 38}, {59, 38}}, {{
        57.666666666666664`, 38}, {59, 38}}]], 
     LineBox[NCache[{{Rational[173, 3], 38}, {
        Rational[173, 3], Rational[110, 3]}}, {{57.666666666666664`, 38}, {
        57.666666666666664`, 36.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[110, 3]}, {
        Rational[173, 3], Rational[110, 3]}}, {{56.333333333333336`, 
       36.666666666666664`}, {57.666666666666664`, 36.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], 38}, {
        Rational[169, 3], Rational[110, 3]}}, {{56.333333333333336`, 38}, {
        56.333333333333336`, 36.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], 40}, {Rational[169, 3], 38}}, {{
        56.333333333333336`, 40}, {56.333333333333336`, 38}}]], 
     LineBox[NCache[{{Rational[169, 3], 40}, {Rational[173, 3], 40}}, {{
        56.333333333333336`, 40}, {57.666666666666664`, 40}}]], 
     LineBox[NCache[{{Rational[173, 3], 40}, {59, 40}}, {{
        57.666666666666664`, 40}, {59, 40}}]], LineBox[{{59, 40}, {61, 40}}], 
     LineBox[{{65, 48}, {65, 44}}], LineBox[{{65, 44}, {65, 40}}], 
     LineBox[{{61, 40}, {65, 40}}], 
     LineBox[NCache[{{59, Rational[124, 3]}, {61, 40}}, {{
        59, 41.333333333333336`}, {61, 40}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[124, 3]}, {
        59, Rational[124, 3]}}, {{57.666666666666664`, 41.333333333333336`}, {
        59, 41.333333333333336`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[124, 3]}, {
        Rational[173, 3], Rational[124, 3]}}, {{56.333333333333336`, 
       41.333333333333336`}, {57.666666666666664`, 41.333333333333336`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[128, 3]}, {
        Rational[169, 3], Rational[124, 3]}}, {{56.333333333333336`, 
       42.666666666666664`}, {56.333333333333336`, 41.333333333333336`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[128, 3]}, {
        Rational[173, 3], Rational[128, 3]}}, {{56.333333333333336`, 
       42.666666666666664`}, {57.666666666666664`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[128, 3]}, {
        59, Rational[128, 3]}}, {{57.666666666666664`, 42.666666666666664`}, {
        59, 42.666666666666664`}}]], 
     LineBox[NCache[{{59, Rational[128, 3]}, {61, 44}}, {{
        59, 42.666666666666664`}, {61, 44}}]], LineBox[{{61, 48}, {61, 44}}], 
     LineBox[NCache[{{59, Rational[136, 3]}, {61, 48}}, {{
        59, 45.333333333333336`}, {61, 48}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[136, 3]}, {
        59, Rational[136, 3]}}, {{57.666666666666664`, 45.333333333333336`}, {
        59, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[136, 3]}, {
        Rational[173, 3], Rational[136, 3]}}, {{56.333333333333336`, 
       45.333333333333336`}, {57.666666666666664`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[136, 3]}, {
        Rational[169, 3], 44}}, {{56.333333333333336`, 45.333333333333336`}, {
        56.333333333333336`, 44}}]], 
     LineBox[NCache[{{55, 44}, {Rational[169, 3], 44}}, {{55, 44}, {
        56.333333333333336`, 44}}]], 
     LineBox[NCache[{{Rational[161, 3], 44}, {55, 44}}, {{
        53.666666666666664`, 44}, {55, 44}}]], 
     LineBox[NCache[{{55, Rational[136, 3]}, {55, 44}}, {{
        55, 45.333333333333336`}, {55, 44}}]], 
     LineBox[NCache[{{Rational[161, 3], 48}, {
        Rational[161, 3], Rational[140, 3]}}, {{53.666666666666664`, 48}, {
        53.666666666666664`, 46.666666666666664`}}]], 
     LineBox[NCache[{{49, Rational[258, 5]}, {49, 50}}, {{49, 51.6}, {49, 
        50}}]], LineBox[{{49, 50}, {49, 48}}], 
     LineBox[NCache[{{49, 48}, {49, Rational[136, 3]}}, {{49, 48}, {
        49, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[136, 3]}, {
        49, Rational[136, 3]}}, {{46.333333333333336`, 45.333333333333336`}, {
        49, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[131, 3], 48}, {
        Rational[131, 3], Rational[136, 3]}}, {{43.666666666666664`, 48}, {
        43.666666666666664`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[136, 3]}, {
        Rational[139, 3], Rational[136, 3]}}, {{43.666666666666664`, 
       45.333333333333336`}, {46.333333333333336`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[136, 3]}, {
        Rational[139, 3], Rational[128, 3]}}, {{46.333333333333336`, 
       45.333333333333336`}, {46.333333333333336`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[128, 3]}, {
        49, Rational[128, 3]}}, {{46.333333333333336`, 42.666666666666664`}, {
        49, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[124, 3]}, {
        Rational[161, 3], Rational[124, 3]}}, {{52.333333333333336`, 
       41.333333333333336`}, {53.666666666666664`, 41.333333333333336`}}]], 
     LineBox[{{51, 40}, {51, 38}}], 
     LineBox[NCache[{{Rational[157, 3], 34}, {
        Rational[157, 3], Rational[98, 3]}}, {{52.333333333333336`, 34}, {
        52.333333333333336`, 32.666666666666664`}}]], 
     LineBox[NCache[{{Rational[157, 3], 34}, {Rational[161, 3], 34}}, {{
        52.333333333333336`, 34}, {53.666666666666664`, 34}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[106, 3]}, {
        Rational[157, 3], 34}}, {{52.333333333333336`, 35.333333333333336`}, {
        52.333333333333336`, 34}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[110, 3]}, {
        Rational[157, 3], Rational[106, 3]}}, {{52.333333333333336`, 
       36.666666666666664`}, {52.333333333333336`, 35.333333333333336`}}]], 
     LineBox[NCache[{{51, Rational[106, 3]}, {
        Rational[157, 3], Rational[106, 3]}}, {{51, 35.333333333333336`}, {
        52.333333333333336`, 35.333333333333336`}}]], 
     LineBox[NCache[{{51, Rational[110, 3]}, {51, Rational[106, 3]}}, {{
        51, 36.666666666666664`}, {51, 35.333333333333336`}}]], 
     LineBox[NCache[{{51, 38}, {51, Rational[110, 3]}}, {{51, 38}, {
        51, 36.666666666666664`}}]], 
     LineBox[NCache[{{51, 38}, {Rational[157, 3], 38}}, {{51, 38}, {
        52.333333333333336`, 38}}]], 
     LineBox[NCache[{{Rational[157, 3], 40}, {Rational[157, 3], 38}}, {{
        52.333333333333336`, 40}, {52.333333333333336`, 38}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[124, 3]}, {
        Rational[157, 3], 40}}, {{52.333333333333336`, 41.333333333333336`}, {
        52.333333333333336`, 40}}]], 
     LineBox[NCache[{{51, Rational[124, 3]}, {
        Rational[157, 3], Rational[124, 3]}}, {{51, 41.333333333333336`}, {
        52.333333333333336`, 41.333333333333336`}}]], 
     LineBox[NCache[{{51, Rational[128, 3]}, {51, Rational[124, 3]}}, {{
        51, 42.666666666666664`}, {51, 41.333333333333336`}}]], 
     LineBox[NCache[{{49, Rational[128, 3]}, {51, Rational[128, 3]}}, {{
        49, 42.666666666666664`}, {51, 42.666666666666664`}}]], 
     LineBox[NCache[{{49, Rational[128, 3]}, {49, 40}}, {{
        49, 42.666666666666664`}, {49, 40}}]], 
     LineBox[NCache[{{Rational[139, 3], 40}, {49, 40}}, {{
        46.333333333333336`, 40}, {49, 40}}]], 
     LineBox[NCache[{{Rational[139, 3], 40}, {45, 38}}, {{
        46.333333333333336`, 40}, {45, 38}}]], 
     LineBox[NCache[{{Rational[131, 3], 40}, {Rational[139, 3], 40}}, {{
        43.666666666666664`, 40}, {46.333333333333336`, 40}}]], 
     LineBox[NCache[{{41, 40}, {Rational[131, 3], 40}}, {{41, 40}, {
        43.666666666666664`, 40}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[128, 3]}, {
        Rational[131, 3], 40}}, {{43.666666666666664`, 42.666666666666664`}, {
        43.666666666666664`, 40}}]], 
     LineBox[NCache[{{41, Rational[128, 3]}, {
        Rational[131, 3], Rational[128, 3]}}, {{41, 42.666666666666664`}, {
        43.666666666666664`, 42.666666666666664`}}]], 
     LineBox[NCache[{{31, Rational[530, 7]}, {31, Rational[522, 7]}}, {{
        31, 75.71428571428571}, {31, 74.57142857142857}}]], 
     LineBox[NCache[{{31, Rational[522, 7]}, {31, Rational[514, 7]}}, {{
        31, 74.57142857142857}, {31, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[101, 3], 68}, {
        Rational[101, 3], Rational[200, 3]}}, {{33.666666666666664`, 68}, {
        33.666666666666664`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[200, 3]}, {
        Rational[101, 3], Rational[196, 3]}}, {{33.666666666666664`, 
       66.66666666666667}, {33.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[196, 3]}, {
        Rational[101, 3], 64}}, {{33.666666666666664`, 65.33333333333333}, {
        33.666666666666664`, 64}}]], 
     LineBox[NCache[{{Rational[101, 3], 64}, {35, 64}}, {{
        33.666666666666664`, 64}, {35, 64}}]], 
     LineBox[NCache[{{Rational[113, 3], 68}, {
        Rational[113, 3], Rational[200, 3]}}, {{37.666666666666664`, 68}, {
        37.666666666666664`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[196, 3]}, {
        Rational[131, 3], Rational[196, 3]}}, {{42.333333333333336`, 
       65.33333333333333}, {43.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[196, 3]}, {
        45, Rational[196, 3]}}, {{43.666666666666664`, 65.33333333333333}, {
        45, 65.33333333333333}}]], 
     LineBox[NCache[{{45, Rational[196, 3]}, {45, 64}}, {{
        45, 65.33333333333333}, {45, 64}}]], 
     LineBox[NCache[{{45, 64}, {45, Rational[188, 3]}}, {{45, 64}, {
        45, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[127, 3], 60}, {Rational[131, 3], 60}}, {{
        42.333333333333336`, 60}, {43.666666666666664`, 60}}]], 
     LineBox[NCache[{{Rational[131, 3], 60}, {Rational[213, 5], 58}}, {{
        43.666666666666664`, 60}, {42.6, 58}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[184, 3]}, {
        Rational[131, 3], 60}}, {{43.666666666666664`, 61.333333333333336`}, {
        43.666666666666664`, 60}}]], 
     LineBox[NCache[{{Rational[131, 3], 60}, {45, 60}}, {{
        43.666666666666664`, 60}, {45, 60}}]], 
     LineBox[NCache[{{Rational[221, 5], 58}, {
        Rational[221, 5], Rational[282, 5]}}, {{44.2, 58}, {44.2, 56.4}}]], 
     LineBox[NCache[{{Rational[221, 5], 58}, {Rational[229, 5], 58}}, {{
        44.2, 58}, {45.8, 58}}]], 
     LineBox[NCache[{{45, 60}, {Rational[221, 5], 58}}, {{45, 60}, {
        44.2, 58}}]], 
     LineBox[NCache[{{45, Rational[184, 3]}, {45, 60}}, {{
        45, 61.333333333333336`}, {45, 60}}]], 
     LineBox[NCache[{{45, Rational[188, 3]}, {45, Rational[184, 3]}}, {{
        45, 62.666666666666664`}, {45, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[188, 3]}, {
        45, Rational[188, 3]}}, {{43.666666666666664`, 62.666666666666664`}, {
        45, 62.666666666666664`}}]], LineBox[{{41, 60}, {41, 58}}], 
     LineBox[{{39, 60}, {41, 60}}], 
     LineBox[NCache[{{41, Rational[184, 3]}, {41, 60}}, {{
        41, 61.333333333333336`}, {41, 60}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[184, 3]}, {
        39, Rational[184, 3]}}, {{37.666666666666664`, 61.333333333333336`}, {
        39, 61.333333333333336`}}]], 
     LineBox[NCache[{{39, Rational[184, 3]}, {41, Rational[184, 3]}}, {{
        39, 61.333333333333336`}, {41, 61.333333333333336`}}]], 
     LineBox[NCache[{{41, Rational[184, 3]}, {
        Rational[127, 3], Rational[184, 3]}}, {{41, 61.333333333333336`}, {
        42.333333333333336`, 61.333333333333336`}}]], 
     LineBox[NCache[{{41, Rational[188, 3]}, {41, Rational[184, 3]}}, {{
        41, 62.666666666666664`}, {41, 61.333333333333336`}}]], 
     LineBox[NCache[{{41, Rational[188, 3]}, {
        Rational[127, 3], Rational[188, 3]}}, {{41, 62.666666666666664`}, {
        42.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[188, 3]}, {
        Rational[131, 3], Rational[188, 3]}}, {{42.333333333333336`, 
       62.666666666666664`}, {43.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[131, 3], 64}, {
        Rational[131, 3], Rational[188, 3]}}, {{43.666666666666664`, 64}, {
        43.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[127, 3], 64}, {Rational[131, 3], 64}}, {{
        42.333333333333336`, 64}, {43.666666666666664`, 64}}]], 
     LineBox[NCache[{{41, 64}, {Rational[127, 3], 64}}, {{41, 64}, {
        42.333333333333336`, 64}}]], 
     LineBox[NCache[{{39, Rational[196, 3]}, {41, Rational[196, 3]}}, {{
        39, 65.33333333333333}, {41, 65.33333333333333}}]], 
     LineBox[NCache[{{41, Rational[196, 3]}, {41, 64}}, {{
        41, 65.33333333333333}, {41, 64}}]], LineBox[{{39, 64}, {41, 64}}], 
     LineBox[NCache[{{39, 64}, {39, Rational[188, 3]}}, {{39, 64}, {
        39, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[188, 3]}, {
        39, Rational[188, 3]}}, {{37.666666666666664`, 62.666666666666664`}, {
        39, 62.666666666666664`}}]], 
     LineBox[
      NCache[{{Rational[113, 3], 64}, {
        Rational[113, 3], Rational[188, 3]}}, {{37.666666666666664`, 64}, {
        37.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[196, 3]}, {
        Rational[113, 3], 64}}, {{37.666666666666664`, 65.33333333333333}, {
        37.666666666666664`, 64}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[200, 3]}, {
        Rational[113, 3], Rational[196, 3]}}, {{37.666666666666664`, 
       66.66666666666667}, {37.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[200, 3]}, {
        Rational[113, 3], Rational[200, 3]}}, {{36.333333333333336`, 
       66.66666666666667}, {37.666666666666664`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[200, 3]}, {
        Rational[109, 3], Rational[196, 3]}}, {{36.333333333333336`, 
       66.66666666666667}, {36.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[196, 3]}, {
        Rational[109, 3], 64}}, {{36.333333333333336`, 65.33333333333333}, {
        36.333333333333336`, 64}}]], 
     LineBox[NCache[{{35, 64}, {Rational[109, 3], 64}}, {{35, 64}, {
        36.333333333333336`, 64}}]], 
     LineBox[NCache[{{35, Rational[196, 3]}, {35, 64}}, {{
        35, 65.33333333333333}, {35, 64}}]], 
     LineBox[NCache[{{35, Rational[200, 3]}, {35, Rational[196, 3]}}, {{
        35, 66.66666666666667}, {35, 65.33333333333333}}]], 
     LineBox[NCache[{{35, 68}, {35, Rational[200, 3]}}, {{35, 68}, {
        35, 66.66666666666667}}]], 
     LineBox[NCache[{{35, 68}, {Rational[109, 3], 68}}, {{35, 68}, {
        36.333333333333336`, 68}}]], 
     LineBox[NCache[{{Rational[257, 7], 70}, {Rational[109, 3], 68}}, {{
        36.714285714285715`, 70}, {36.333333333333336`, 68}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[498, 7]}, {
        Rational[257, 7], 70}}, {{36.714285714285715`, 71.14285714285714}, {
        36.714285714285715`, 70}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[498, 7]}, {
        Rational[257, 7], Rational[498, 7]}}, {{35.57142857142857, 
       71.14285714285714}, {36.714285714285715`, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[498, 7]}, {
        Rational[249, 7], 70}}, {{35.57142857142857, 71.14285714285714}, {
        35.57142857142857, 70}}]], 
     LineBox[NCache[{{Rational[241, 7], 70}, {Rational[249, 7], 70}}, {{
        34.42857142857143, 70}, {35.57142857142857, 70}}]], 
     LineBox[NCache[{{31, Rational[498, 7]}, {31, 70}}, {{
        31, 71.14285714285714}, {31, 70}}]], 
     LineBox[NCache[{{31, Rational[498, 7]}, {
        Rational[225, 7], Rational[498, 7]}}, {{31, 71.14285714285714}, {
        32.142857142857146`, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[498, 7]}, {
        Rational[225, 7], 70}}, {{32.142857142857146`, 71.14285714285714}, {
        32.142857142857146`, 70}}]], 
     LineBox[NCache[{{Rational[225, 7], 70}, {Rational[233, 7], 70}}, {{
        32.142857142857146`, 70}, {33.285714285714285`, 70}}]], 
     LineBox[NCache[{{Rational[233, 7], 70}, {Rational[241, 7], 70}}, {{
        33.285714285714285`, 70}, {34.42857142857143, 70}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[498, 7]}, {
        Rational[241, 7], 70}}, {{34.42857142857143, 71.14285714285714}, {
        34.42857142857143, 70}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[506, 7]}, {
        Rational[241, 7], Rational[498, 7]}}, {{34.42857142857143, 
       72.28571428571429}, {34.42857142857143, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[498, 7]}, {
        Rational[241, 7], Rational[498, 7]}}, {{33.285714285714285`, 
       71.14285714285714}, {34.42857142857143, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[506, 7]}, {
        Rational[233, 7], Rational[498, 7]}}, {{33.285714285714285`, 
       72.28571428571429}, {33.285714285714285`, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[514, 7]}, {
        Rational[233, 7], Rational[506, 7]}}, {{33.285714285714285`, 
       73.42857142857143}, {33.285714285714285`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[506, 7]}, {
        Rational[233, 7], Rational[506, 7]}}, {{32.142857142857146`, 
       72.28571428571429}, {33.285714285714285`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[514, 7]}, {
        Rational[225, 7], Rational[506, 7]}}, {{32.142857142857146`, 
       73.42857142857143}, {32.142857142857146`, 72.28571428571429}}]], 
     LineBox[NCache[{{31, Rational[514, 7]}, {
        Rational[225, 7], Rational[514, 7]}}, {{31, 73.42857142857143}, {
        32.142857142857146`, 73.42857142857143}}]], 
     LineBox[NCache[{{31, Rational[514, 7]}, {31, Rational[506, 7]}}, {{
        31, 73.42857142857143}, {31, 72.28571428571429}}]], 
     LineBox[NCache[{{29, 74}, {31, Rational[506, 7]}}, {{29, 74}, {
        31, 72.28571428571429}}]], LineBox[{{25, 74}, {29, 74}}], 
     LineBox[{{19, 74}, {21, 74}}], 
     LineBox[NCache[{{31, Rational[196, 3]}, {31, 64}}, {{
        31, 65.33333333333333}, {31, 64}}]], LineBox[{{29, 64}, {31, 64}}], 
     LineBox[{{25, 64}, {29, 64}}], LineBox[{{25, 68}, {25, 64}}], 
     LineBox[NCache[{{31, Rational[274, 5]}, {
        Rational[163, 5], Rational[274, 5]}}, {{31, 54.8}, {32.6, 54.8}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[282, 5]}, {
        Rational[163, 5], Rational[274, 5]}}, {{32.6, 56.4}, {32.6, 54.8}}]], 
     LineBox[NCache[{{31, 58}, {Rational[163, 5], 58}}, {{31, 58}, {
        32.6, 58}}]], 
     LineBox[NCache[{{Rational[101, 3], 60}, {Rational[163, 5], 58}}, {{
        33.666666666666664`, 60}, {32.6, 58}}]], 
     LineBox[NCache[{{Rational[163, 5], 58}, {
        Rational[163, 5], Rational[282, 5]}}, {{32.6, 58}, {32.6, 56.4}}]], 
     LineBox[NCache[{{31, Rational[282, 5]}, {
        Rational[163, 5], Rational[282, 5]}}, {{31, 56.4}, {32.6, 56.4}}]], 
     LineBox[NCache[{{29, 58}, {31, Rational[282, 5]}}, {{29, 58}, {
        31, 56.4}}]], LineBox[{{25, 58}, {29, 58}}], 
     LineBox[{{23, 46}, {23, 44}}], LineBox[{{21, 54}, {25, 54}}], 
     LineBox[{{21, 54}, {21, 50}}], LineBox[{{21, 50}, {21, 48}}], 
     LineBox[{{21, 50}, {25, 50}}], LineBox[{{25, 50}, {27, 48}}], 
     LineBox[{{27, 48}, {27, 46}}], LineBox[{{29, 44}, {29, 42}}], 
     LineBox[{{27, 44}, {29, 44}}], LineBox[{{27, 46}, {27, 44}}], 
     LineBox[{{25, 46}, {27, 46}}], LineBox[{{25, 48}, {25, 46}}], 
     LineBox[{{23, 48}, {25, 48}}], LineBox[{{23, 48}, {23, 46}}], 
     LineBox[{{21, 46}, {23, 46}}], LineBox[{{19, 48}, {21, 46}}], 
     LineBox[{{19, 50}, {19, 48}}], LineBox[{{15, 50}, {19, 50}}], 
     LineBox[{{15, 54}, {15, 50}}], LineBox[{{11, 64}, {11, 60}}], 
     LineBox[{{19, 60}, {21, 60}}], LineBox[{{15, 60}, {19, 60}}], 
     LineBox[{{11, 60}, {15, 60}}], LineBox[{{11, 60}, {11, 58}}], 
     LineBox[{{11, 58}, {11, 54}}], LineBox[{{11, 58}, {15, 58}}], 
     LineBox[{{15, 58}, {15, 54}}], LineBox[{{15, 54}, {19, 54}}], 
     LineBox[{{19, 58}, {19, 54}}], LineBox[{{19, 58}, {21, 58}}], 
     LineBox[{{21, 58}, {25, 58}}], LineBox[{{25, 60}, {25, 58}}], 
     LineBox[{{25, 64}, {25, 60}}], LineBox[{{21, 64}, {25, 64}}], 
     LineBox[{{21, 68}, {21, 64}}], LineBox[{{21, 70}, {21, 68}}], 
     LineBox[{{21, 74}, {21, 70}}], LineBox[{{21, 74}, {25, 74}}], 
     LineBox[{{25, 74}, {25, 70}}], LineBox[{{25, 70}, {29, 70}}], 
     LineBox[{{29, 70}, {29, 68}}], 
     LineBox[NCache[{{29, 68}, {31, Rational[200, 3]}}, {{29, 68}, {
        31, 66.66666666666667}}]], 
     LineBox[NCache[{{31, 68}, {31, Rational[200, 3]}}, {{31, 68}, {
        31, 66.66666666666667}}]], 
     LineBox[NCache[{{31, 68}, {Rational[97, 3], 68}}, {{31, 68}, {
        32.333333333333336`, 68}}]], 
     LineBox[NCache[{{Rational[97, 3], 68}, {
        Rational[97, 3], Rational[200, 3]}}, {{32.333333333333336`, 68}, {
        32.333333333333336`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[97, 3], Rational[200, 3]}, {
        Rational[97, 3], Rational[196, 3]}}, {{32.333333333333336`, 
       66.66666666666667}, {32.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[97, 3], Rational[196, 3]}, {
        Rational[97, 3], 64}}, {{32.333333333333336`, 65.33333333333333}, {
        32.333333333333336`, 64}}]], 
     LineBox[NCache[{{Rational[97, 3], 64}, {
        Rational[97, 3], Rational[188, 3]}}, {{32.333333333333336`, 64}, {
        32.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{31, Rational[188, 3]}, {
        Rational[97, 3], Rational[188, 3]}}, {{31, 62.666666666666664`}, {
        32.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{31, Rational[188, 3]}, {31, Rational[184, 3]}}, {{
        31, 62.666666666666664`}, {31, 61.333333333333336`}}]], 
     LineBox[NCache[{{29, 60}, {31, Rational[184, 3]}}, {{29, 60}, {
        31, 61.333333333333336`}}]], LineBox[{{29, 60}, {31, 60}}], 
     LineBox[NCache[{{31, 60}, {Rational[97, 3], 60}}, {{31, 60}, {
        32.333333333333336`, 60}}]], 
     LineBox[NCache[{{Rational[97, 3], Rational[184, 3]}, {
        Rational[97, 3], 60}}, {{32.333333333333336`, 61.333333333333336`}, {
        32.333333333333336`, 60}}]], 
     LineBox[NCache[{{Rational[97, 3], Rational[184, 3]}, {
        Rational[101, 3], Rational[184, 3]}}, {{32.333333333333336`, 
       61.333333333333336`}, {33.666666666666664`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[188, 3]}, {
        Rational[101, 3], Rational[184, 3]}}, {{33.666666666666664`, 
       62.666666666666664`}, {33.666666666666664`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[188, 3]}, {
        35, Rational[188, 3]}}, {{33.666666666666664`, 62.666666666666664`}, {
        35, 62.666666666666664`}}]], 
     LineBox[NCache[{{35, Rational[188, 3]}, {
        Rational[109, 3], Rational[188, 3]}}, {{35, 62.666666666666664`}, {
        36.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[188, 3]}, {
        Rational[109, 3], Rational[184, 3]}}, {{36.333333333333336`, 
       62.666666666666664`}, {36.333333333333336`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[179, 5], 58}, {Rational[187, 5], 58}}, {{
        35.8, 58}, {37.4, 58}}]], 
     LineBox[NCache[{{41, Rational[282, 5]}, {
        Rational[213, 5], Rational[282, 5]}}, {{41, 56.4}, {42.6, 56.4}}]], 
     LineBox[NCache[{{41, Rational[282, 5]}, {41, Rational[274, 5]}}, {{
        41, 56.4}, {41, 54.8}}]], 
     LineBox[
      NCache[{{41, Rational[274, 5]}, {
        Rational[213, 5], Rational[274, 5]}}, {{41, 54.8}, {42.6, 54.8}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[274, 5]}, {
        Rational[221, 5], Rational[274, 5]}}, {{42.6, 54.8}, {44.2, 54.8}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[282, 5]}, {
        Rational[229, 5], Rational[274, 5]}}, {{45.8, 56.4}, {45.8, 54.8}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[274, 5]}, {
        Rational[237, 5], Rational[274, 5]}}, {{45.8, 54.8}, {47.4, 54.8}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[274, 5]}, {
        Rational[229, 5], Rational[266, 5]}}, {{45.8, 54.8}, {45.8, 53.2}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[274, 5]}, {
        Rational[229, 5], Rational[274, 5]}}, {{44.2, 54.8}, {45.8, 54.8}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[274, 5]}, {
        Rational[221, 5], Rational[266, 5]}}, {{44.2, 54.8}, {44.2, 53.2}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[266, 5]}, {
        Rational[221, 5], Rational[266, 5]}}, {{42.6, 53.2}, {44.2, 53.2}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[266, 5]}, {
        Rational[213, 5], Rational[258, 5]}}, {{42.6, 53.2}, {42.6, 51.6}}]], 
     LineBox[NCache[{{41, Rational[258, 5]}, {
        Rational[213, 5], Rational[258, 5]}}, {{41, 51.6}, {42.6, 51.6}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[136, 3]}, {
        Rational[101, 3], Rational[128, 3]}}, {{33.666666666666664`, 
       45.333333333333336`}, {33.666666666666664`, 42.666666666666664`}}]], 
     LineBox[{{39, 50}, {39, 48}}], 
     LineBox[NCache[{{39, 48}, {39, Rational[136, 3]}}, {{39, 48}, {
        39, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[136, 3]}, {
        39, Rational[136, 3]}}, {{36.333333333333336`, 45.333333333333336`}, {
        39, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[136, 3]}, {
        Rational[109, 3], Rational[136, 3]}}, {{33.666666666666664`, 
       45.333333333333336`}, {36.333333333333336`, 45.333333333333336`}}]], 
     LineBox[
      NCache[{{Rational[101, 3], 48}, {
        Rational[101, 3], Rational[136, 3]}}, {{33.666666666666664`, 48}, {
        33.666666666666664`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[171, 5], 50}, {Rational[101, 3], 48}}, {{
        34.2, 50}, {33.666666666666664`, 48}}]], 
     LineBox[NCache[{{Rational[163, 5], 50}, {Rational[171, 5], 50}}, {{
        32.6, 50}, {34.2, 50}}]], 
     LineBox[NCache[{{31, 50}, {Rational[163, 5], 50}}, {{31, 50}, {
        32.6, 50}}]], 
     LineBox[NCache[{{31, Rational[258, 5]}, {31, 50}}, {{31, 51.6}, {31, 
        50}}]], LineBox[
      NCache[{{31, Rational[258, 5]}, {
        Rational[163, 5], Rational[258, 5]}}, {{31, 51.6}, {32.6, 51.6}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[258, 5]}, {
        Rational[171, 5], Rational[258, 5]}}, {{32.6, 51.6}, {34.2, 51.6}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[258, 5]}, {
        Rational[179, 5], Rational[258, 5]}}, {{34.2, 51.6}, {35.8, 51.6}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[266, 5]}, {
        Rational[187, 5], Rational[266, 5]}}, {{35.8, 53.2}, {37.4, 53.2}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[266, 5]}, {
        Rational[179, 5], Rational[258, 5]}}, {{35.8, 53.2}, {35.8, 51.6}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[258, 5]}, {
        Rational[179, 5], 50}}, {{35.8, 51.6}, {35.8, 50}}]], 
     LineBox[NCache[{{Rational[179, 5], 50}, {Rational[109, 3], 48}}, {{
        35.8, 50}, {36.333333333333336`, 48}}]], 
     LineBox[NCache[{{Rational[187, 5], 50}, {Rational[109, 3], 48}}, {{
        37.4, 50}, {36.333333333333336`, 48}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[258, 5]}, {
        Rational[187, 5], 50}}, {{37.4, 51.6}, {37.4, 50}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[258, 5]}, {
        39, Rational[258, 5]}}, {{37.4, 51.6}, {39, 51.6}}]], 
     LineBox[NCache[{{39, Rational[258, 5]}, {41, Rational[258, 5]}}, {{
        39, 51.6}, {41, 51.6}}]], 
     LineBox[NCache[{{41, Rational[266, 5]}, {41, Rational[258, 5]}}, {{
        41, 53.2}, {41, 51.6}}]], 
     LineBox[NCache[{{39, Rational[266, 5]}, {41, Rational[266, 5]}}, {{
        39, 53.2}, {41, 53.2}}]], 
     LineBox[NCache[{{39, Rational[274, 5]}, {39, Rational[266, 5]}}, {{
        39, 54.8}, {39, 53.2}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[274, 5]}, {
        39, Rational[274, 5]}}, {{37.4, 54.8}, {39, 54.8}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[282, 5]}, {
        Rational[187, 5], Rational[274, 5]}}, {{37.4, 56.4}, {37.4, 54.8}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[282, 5]}, {
        39, Rational[282, 5]}}, {{37.4, 56.4}, {39, 56.4}}]], 
     LineBox[NCache[{{39, 58}, {39, Rational[282, 5]}}, {{39, 58}, {
        39, 56.4}}]], 
     LineBox[NCache[{{Rational[187, 5], 58}, {39, 58}}, {{37.4, 58}, {39, 
        58}}]], LineBox[
      NCache[{{Rational[113, 3], 60}, {Rational[187, 5], 58}}, {{
        37.666666666666664`, 60}, {37.4, 58}}]], 
     LineBox[NCache[{{Rational[109, 3], 60}, {Rational[113, 3], 60}}, {{
        36.333333333333336`, 60}, {37.666666666666664`, 60}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[184, 3]}, {
        Rational[109, 3], 60}}, {{36.333333333333336`, 61.333333333333336`}, {
        36.333333333333336`, 60}}]], 
     LineBox[NCache[{{35, Rational[184, 3]}, {
        Rational[109, 3], Rational[184, 3]}}, {{35, 61.333333333333336`}, {
        36.333333333333336`, 61.333333333333336`}}]], 
     LineBox[NCache[{{35, Rational[184, 3]}, {35, 60}}, {{
        35, 61.333333333333336`}, {35, 60}}]], 
     LineBox[NCache[{{35, 60}, {Rational[171, 5], 58}}, {{35, 60}, {
        34.2, 58}}]], 
     LineBox[NCache[{{Rational[171, 5], 58}, {
        Rational[171, 5], Rational[282, 5]}}, {{34.2, 58}, {34.2, 56.4}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[282, 5]}, {
        Rational[179, 5], Rational[282, 5]}}, {{34.2, 56.4}, {35.8, 56.4}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[282, 5]}, {
        Rational[179, 5], Rational[274, 5]}}, {{35.8, 56.4}, {35.8, 54.8}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[274, 5]}, {
        Rational[179, 5], Rational[274, 5]}}, {{34.2, 54.8}, {35.8, 54.8}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[274, 5]}, {
        Rational[171, 5], Rational[266, 5]}}, {{34.2, 54.8}, {34.2, 53.2}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[266, 5]}, {
        Rational[171, 5], Rational[266, 5]}}, {{32.6, 53.2}, {34.2, 53.2}}]], 
     LineBox[NCache[{{31, Rational[266, 5]}, {
        Rational[163, 5], Rational[266, 5]}}, {{31, 53.2}, {32.6, 53.2}}]], 
     LineBox[NCache[{{29, 54}, {31, Rational[266, 5]}}, {{29, 54}, {
        31, 53.2}}]], LineBox[{{29, 54}, {29, 50}}], 
     LineBox[{{29, 50}, {29, 48}}], LineBox[{{29, 48}, {29, 46}}], 
     LineBox[{{29, 46}, {31, 48}}], 
     LineBox[NCache[{{31, 48}, {31, Rational[136, 3]}}, {{31, 48}, {
        31, 45.333333333333336`}}]], 
     LineBox[NCache[{{31, Rational[136, 3]}, {31, Rational[128, 3]}}, {{
        31, 45.333333333333336`}, {31, 42.666666666666664`}}]], 
     LineBox[NCache[{{31, Rational[128, 3]}, {31, 40}}, {{
        31, 42.666666666666664`}, {31, 40}}]], LineBox[{{29, 38}, {31, 38}}], 
     LineBox[{{31, 40}, {31, 38}}], 
     LineBox[NCache[{{31, 40}, {Rational[101, 3], 40}}, {{31, 40}, {
        33.666666666666664`, 40}}]], 
     LineBox[NCache[{{Rational[101, 3], 40}, {Rational[109, 3], 40}}, {{
        33.666666666666664`, 40}, {36.333333333333336`, 40}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[128, 3]}, {
        Rational[109, 3], 40}}, {{36.333333333333336`, 42.666666666666664`}, {
        36.333333333333336`, 40}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[128, 3]}, {
        39, Rational[128, 3]}}, {{36.333333333333336`, 42.666666666666664`}, {
        39, 42.666666666666664`}}]], 
     LineBox[NCache[{{39, Rational[128, 3]}, {41, Rational[128, 3]}}, {{
        39, 42.666666666666664`}, {41, 42.666666666666664`}}]], 
     LineBox[NCache[{{41, Rational[136, 3]}, {41, Rational[128, 3]}}, {{
        41, 45.333333333333336`}, {41, 42.666666666666664`}}]], 
     LineBox[NCache[{{41, 48}, {41, Rational[136, 3]}}, {{41, 48}, {
        41, 45.333333333333336`}}]], LineBox[{{41, 50}, {41, 48}}], 
     LineBox[NCache[{{41, 50}, {Rational[213, 5], 50}}, {{41, 50}, {
        42.6, 50}}]], 
     LineBox[NCache[{{Rational[213, 5], 50}, {Rational[221, 5], 50}}, {{
        42.6, 50}, {44.2, 50}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[258, 5]}, {
        Rational[221, 5], 50}}, {{44.2, 51.6}, {44.2, 50}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[258, 5]}, {
        Rational[229, 5], Rational[258, 5]}}, {{44.2, 51.6}, {45.8, 51.6}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[258, 5]}, {
        Rational[229, 5], 50}}, {{45.8, 51.6}, {45.8, 50}}]], 
     LineBox[NCache[{{Rational[229, 5], 50}, {Rational[139, 3], 48}}, {{
        45.8, 50}, {46.333333333333336`, 48}}]], 
     LineBox[NCache[{{Rational[237, 5], 50}, {Rational[139, 3], 48}}, {{
        47.4, 50}, {46.333333333333336`, 48}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[258, 5]}, {
        Rational[237, 5], 50}}, {{47.4, 51.6}, {47.4, 50}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[266, 5]}, {
        Rational[237, 5], Rational[258, 5]}}, {{47.4, 53.2}, {47.4, 51.6}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[266, 5]}, {
        49, Rational[266, 5]}}, {{47.4, 53.2}, {49, 53.2}}]], 
     LineBox[NCache[{{49, Rational[266, 5]}, {51, 54}}, {{49, 53.2}, {51, 
        54}}]], LineBox[{{51, 54}, {51, 52}}], LineBox[{{51, 52}, {53, 52}}], 
     LineBox[{{53, 52}, {53, 50}}], 
     LineBox[NCache[{{53, 50}, {Rational[161, 3], 48}}, {{53, 50}, {
        53.666666666666664`, 48}}]], 
     LineBox[NCache[{{Rational[161, 3], 48}, {55, 48}}, {{
        53.666666666666664`, 48}, {55, 48}}]], 
     LineBox[NCache[{{55, 48}, {55, Rational[140, 3]}}, {{55, 48}, {
        55, 46.666666666666664`}}]], 
     LineBox[NCache[{{55, Rational[140, 3]}, {55, Rational[136, 3]}}, {{
        55, 46.666666666666664`}, {55, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[136, 3]}, {
        55, Rational[136, 3]}}, {{53.666666666666664`, 45.333333333333336`}, {
        55, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[136, 3]}, {
        Rational[161, 3], Rational[136, 3]}}, {{52.333333333333336`, 
       45.333333333333336`}, {53.666666666666664`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[140, 3]}, {
        Rational[157, 3], Rational[136, 3]}}, {{52.333333333333336`, 
       46.666666666666664`}, {52.333333333333336`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[157, 3], 48}, {
        Rational[157, 3], Rational[140, 3]}}, {{52.333333333333336`, 48}, {
        52.333333333333336`, 46.666666666666664`}}]], 
     LineBox[NCache[{{51, 50}, {Rational[157, 3], 48}}, {{51, 50}, {
        52.333333333333336`, 48}}]], LineBox[{{51, 50}, {51, 48}}], 
     LineBox[NCache[{{51, 48}, {51, Rational[140, 3]}}, {{51, 48}, {
        51, 46.666666666666664`}}]], 
     LineBox[NCache[{{51, Rational[140, 3]}, {51, Rational[136, 3]}}, {{
        51, 46.666666666666664`}, {51, 45.333333333333336`}}]], 
     LineBox[NCache[{{51, Rational[136, 3]}, {51, 44}}, {{
        51, 45.333333333333336`}, {51, 44}}]], 
     LineBox[NCache[{{51, 44}, {Rational[157, 3], 44}}, {{51, 44}, {
        52.333333333333336`, 44}}]], 
     LineBox[NCache[{{Rational[157, 3], 44}, {
        Rational[157, 3], Rational[128, 3]}}, {{52.333333333333336`, 44}, {
        52.333333333333336`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[128, 3]}, {
        Rational[161, 3], Rational[128, 3]}}, {{52.333333333333336`, 
       42.666666666666664`}, {53.666666666666664`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[128, 3]}, {
        55, Rational[128, 3]}}, {{53.666666666666664`, 42.666666666666664`}, {
        55, 42.666666666666664`}}]], 
     LineBox[NCache[{{55, Rational[128, 3]}, {55, Rational[124, 3]}}, {{
        55, 42.666666666666664`}, {55, 41.333333333333336`}}]], 
     LineBox[NCache[{{55, Rational[124, 3]}, {55, 40}}, {{
        55, 41.333333333333336`}, {55, 40}}]], 
     LineBox[NCache[{{Rational[161, 3], 40}, {55, 40}}, {{
        53.666666666666664`, 40}, {55, 40}}]], 
     LineBox[NCache[{{Rational[161, 3], 40}, {Rational[161, 3], 38}}, {{
        53.666666666666664`, 40}, {53.666666666666664`, 38}}]], 
     LineBox[NCache[{{Rational[161, 3], 38}, {55, 38}}, {{
        53.666666666666664`, 38}, {55, 38}}]], 
     LineBox[NCache[{{55, 38}, {55, Rational[110, 3]}}, {{55, 38}, {
        55, 36.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[110, 3]}, {
        55, Rational[110, 3]}}, {{53.666666666666664`, 36.666666666666664`}, {
        55, 36.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[110, 3]}, {
        Rational[161, 3], Rational[106, 3]}}, {{53.666666666666664`, 
       36.666666666666664`}, {53.666666666666664`, 35.333333333333336`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[106, 3]}, {
        55, Rational[106, 3]}}, {{53.666666666666664`, 35.333333333333336`}, {
        55, 35.333333333333336`}}]], 
     LineBox[NCache[{{55, Rational[106, 3]}, {55, 34}}, {{
        55, 35.333333333333336`}, {55, 34}}]], 
     LineBox[NCache[{{55, 34}, {55, Rational[98, 3]}}, {{55, 34}, {
        55, 32.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[98, 3]}, {
        55, Rational[98, 3]}}, {{53.666666666666664`, 32.666666666666664`}, {
        55, 32.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[98, 3]}, {
        Rational[161, 3], Rational[94, 3]}}, {{53.666666666666664`, 
       32.666666666666664`}, {53.666666666666664`, 31.333333333333332`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[94, 3]}, {
        Rational[161, 3], 30}}, {{53.666666666666664`, 31.333333333333332`}, {
        53.666666666666664`, 30}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[76, 3]}, {
        Rational[161, 3], Rational[76, 3]}}, {{52.333333333333336`, 
       25.333333333333332`}, {53.666666666666664`, 25.333333333333332`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[80, 3]}, {
        Rational[157, 3], Rational[76, 3]}}, {{52.333333333333336`, 
       26.666666666666668`}, {52.333333333333336`, 25.333333333333332`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[80, 3]}, {
        Rational[161, 3], Rational[80, 3]}}, {{52.333333333333336`, 
       26.666666666666668`}, {53.666666666666664`, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[80, 3]}, {
        55, Rational[80, 3]}}, {{53.666666666666664`, 26.666666666666668`}, {
        55, 26.666666666666668`}}]], 
     LineBox[NCache[{{55, 28}, {55, Rational[80, 3]}}, {{55, 28}, {
        55, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[161, 3], 28}, {55, 28}}, {{
        53.666666666666664`, 28}, {55, 28}}]], 
     LineBox[NCache[{{Rational[157, 3], 28}, {Rational[161, 3], 28}}, {{
        52.333333333333336`, 28}, {53.666666666666664`, 28}}]], 
     LineBox[NCache[{{Rational[157, 3], 30}, {Rational[157, 3], 28}}, {{
        52.333333333333336`, 30}, {52.333333333333336`, 28}}]], 
     LineBox[NCache[{{Rational[157, 3], 30}, {Rational[161, 3], 30}}, {{
        52.333333333333336`, 30}, {53.666666666666664`, 30}}]], 
     LineBox[NCache[{{Rational[161, 3], 30}, {55, 30}}, {{
        53.666666666666664`, 30}, {55, 30}}]], 
     LineBox[NCache[{{55, Rational[94, 3]}, {55, 30}}, {{
        55, 31.333333333333332`}, {55, 30}}]], 
     LineBox[NCache[{{55, Rational[94, 3]}, {
        Rational[169, 3], Rational[94, 3]}}, {{55, 31.333333333333332`}, {
        56.333333333333336`, 31.333333333333332`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[94, 3]}, {
        Rational[169, 3], 30}}, {{56.333333333333336`, 31.333333333333332`}, {
        56.333333333333336`, 30}}]], 
     LineBox[NCache[{{Rational[169, 3], 30}, {Rational[173, 3], 30}}, {{
        56.333333333333336`, 30}, {57.666666666666664`, 30}}]], 
     LineBox[NCache[{{Rational[173, 3], 30}, {Rational[173, 3], 28}}, {{
        57.666666666666664`, 30}, {57.666666666666664`, 28}}]], 
     LineBox[NCache[{{Rational[169, 3], 28}, {Rational[173, 3], 28}}, {{
        56.333333333333336`, 28}, {57.666666666666664`, 28}}]], 
     LineBox[NCache[{{Rational[169, 3], 28}, {
        Rational[169, 3], Rational[80, 3]}}, {{56.333333333333336`, 28}, {
        56.333333333333336`, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[80, 3]}, {
        Rational[173, 3], Rational[80, 3]}}, {{56.333333333333336`, 
       26.666666666666668`}, {57.666666666666664`, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[80, 3]}, {
        Rational[173, 3], Rational[76, 3]}}, {{57.666666666666664`, 
       26.666666666666668`}, {57.666666666666664`, 25.333333333333332`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[76, 3]}, {
        Rational[173, 3], Rational[76, 3]}}, {{56.333333333333336`, 
       25.333333333333332`}, {57.666666666666664`, 25.333333333333332`}}]], 
     LineBox[NCache[{{55, Rational[76, 3]}, {
        Rational[169, 3], Rational[76, 3]}}, {{55, 25.333333333333332`}, {
        56.333333333333336`, 25.333333333333332`}}]], 
     LineBox[NCache[{{55, Rational[76, 3]}, {55, 24}}, {{
        55, 25.333333333333332`}, {55, 24}}]], 
     LineBox[NCache[{{Rational[161, 3], 24}, {55, 24}}, {{
        53.666666666666664`, 24}, {55, 24}}]], 
     LineBox[NCache[{{Rational[161, 3], 24}, {
        Rational[161, 3], Rational[68, 3]}}, {{53.666666666666664`, 24}, {
        53.666666666666664`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[68, 3]}, {
        Rational[161, 3], Rational[68, 3]}}, {{52.333333333333336`, 
       22.666666666666668`}, {53.666666666666664`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[157, 3], 24}, {
        Rational[157, 3], Rational[68, 3]}}, {{52.333333333333336`, 24}, {
        52.333333333333336`, 22.666666666666668`}}]], 
     LineBox[NCache[{{51, 24}, {Rational[157, 3], 24}}, {{51, 24}, {
        52.333333333333336`, 24}}]], 
     LineBox[NCache[{{51, 24}, {51, Rational[68, 3]}}, {{51, 24}, {
        51, 22.666666666666668`}}]], 
     LineBox[NCache[{{51, Rational[68, 3]}, {51, Rational[64, 3]}}, {{
        51, 22.666666666666668`}, {51, 21.333333333333332`}}]], 
     LineBox[NCache[{{51, Rational[64, 3]}, {
        Rational[157, 3], Rational[64, 3]}}, {{51, 21.333333333333332`}, {
        52.333333333333336`, 21.333333333333332`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[64, 3]}, {
        Rational[161, 3], Rational[64, 3]}}, {{52.333333333333336`, 
       21.333333333333332`}, {53.666666666666664`, 21.333333333333332`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[64, 3]}, {
        55, Rational[64, 3]}}, {{53.666666666666664`, 21.333333333333332`}, {
        55, 21.333333333333332`}}]], 
     LineBox[
      NCache[{{55, Rational[64, 3]}, {55, 20}}, {{55, 21.333333333333332`}, {
        55, 20}}]], LineBox[{{55, 20}, {55, 18}}], 
     LineBox[{{55, 18}, {57, 18}}], LineBox[{{57, 18}, {59, 18}}], 
     LineBox[{{59, 20}, {59, 18}}], 
     LineBox[NCache[{{59, Rational[64, 3]}, {59, 20}}, {{
        59, 21.333333333333332`}, {59, 20}}]], 
     LineBox[NCache[{{59, Rational[68, 3]}, {59, Rational[64, 3]}}, {{
        59, 22.666666666666668`}, {59, 21.333333333333332`}}]], 
     LineBox[NCache[{{59, 24}, {59, Rational[68, 3]}}, {{59, 24}, {
        59, 22.666666666666668`}}]], LineBox[{{59, 24}, {61, 24}}], 
     LineBox[{{61, 26}, {61, 24}}], LineBox[{{61, 28}, {61, 26}}], 
     LineBox[{{61, 30}, {61, 28}}], LineBox[{{61, 32}, {61, 30}}], 
     LineBox[{{61, 34}, {61, 32}}], LineBox[{{61, 34}, {63, 34}}], 
     LineBox[{{63, 34}, {63, 32}}], LineBox[{{63, 32}, {65, 32}}], 
     LineBox[{{65, 34}, {65, 32}}], LineBox[{{65, 34}, {67, 34}}], 
     LineBox[{{67, 36}, {67, 34}}], LineBox[{{65, 36}, {67, 36}}], 
     LineBox[{{65, 38}, {65, 36}}], LineBox[{{65, 38}, {67, 38}}], 
     LineBox[{{67, 38}, {69, 38}}], LineBox[{{69, 40}, {69, 38}}], 
     LineBox[{{69, 44}, {69, 40}}], LineBox[{{69, 48}, {69, 44}}], 
     LineBox[{{69, 50}, {69, 48}}], LineBox[{{61, 54}, {65, 54}}], 
     LineBox[NCache[{{Rational[143, 3], 74}, {49, 74}}, {{
        47.666666666666664`, 74}, {49, 74}}]], 
     LineBox[NCache[{{49, Rational[226, 3]}, {49, 74}}, {{
        49, 75.33333333333333}, {49, 74}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[230, 3]}, {
        Rational[143, 3], Rational[230, 3]}}, {{46.333333333333336`, 
       76.66666666666667}, {47.666666666666664`, 76.66666666666667}}]], 
     LineBox[NCache[{{45, Rational[230, 3]}, {
        Rational[139, 3], Rational[230, 3]}}, {{45, 76.66666666666667}, {
        46.333333333333336`, 76.66666666666667}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[230, 3]}, {
        45, Rational[230, 3]}}, {{43.666666666666664`, 76.66666666666667}, {
        45, 76.66666666666667}}]], 
     LineBox[NCache[{{Rational[131, 3], 78}, {
        Rational[131, 3], Rational[230, 3]}}, {{43.666666666666664`, 78}, {
        43.666666666666664`, 76.66666666666667}}]], 
     LineBox[NCache[{{Rational[131, 3], 78}, {45, 78}}, {{
        43.666666666666664`, 78}, {45, 78}}]], 
     LineBox[NCache[{{45, 78}, {Rational[139, 3], 78}}, {{45, 78}, {
        46.333333333333336`, 78}}]], 
     LineBox[NCache[{{Rational[139, 3], 78}, {Rational[143, 3], 78}}, {{
        46.333333333333336`, 78}, {47.666666666666664`, 78}}]], 
     LineBox[NCache[{{Rational[143, 3], 78}, {49, 78}}, {{
        47.666666666666664`, 78}, {49, 78}}]], LineBox[{{49, 78}, {51, 78}}], 
     LineBox[{{69, 78}, {69, 74}}], LineBox[{{69, 74}, {69, 70}}], 
     LineBox[{{65, 64}, {69, 64}}], LineBox[{{65, 68}, {65, 64}}], 
     LineBox[{{65, 68}, {69, 68}}], LineBox[{{69, 70}, {69, 68}}], 
     LineBox[{{65, 70}, {69, 70}}], LineBox[{{61, 70}, {65, 70}}], 
     LineBox[{{61, 74}, {61, 70}}], LineBox[{{61, 74}, {65, 74}}], 
     LineBox[{{65, 78}, {65, 74}}], LineBox[{{61, 78}, {65, 78}}], 
     LineBox[{{59, 78}, {61, 78}}], LineBox[{{55, 78}, {59, 78}}], 
     LineBox[{{51, 78}, {55, 78}}], 
     LineBox[NCache[{{49, Rational[230, 3]}, {51, 78}}, {{
        49, 76.66666666666667}, {51, 78}}]], 
     LineBox[NCache[{{49, Rational[230, 3]}, {49, Rational[226, 3]}}, {{
        49, 76.66666666666667}, {49, 75.33333333333333}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[226, 3]}, {
        49, Rational[226, 3]}}, {{47.666666666666664`, 75.33333333333333}, {
        49, 75.33333333333333}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[226, 3]}, {
        Rational[143, 3], Rational[226, 3]}}, {{46.333333333333336`, 
       75.33333333333333}, {47.666666666666664`, 75.33333333333333}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[226, 3]}, {
        Rational[139, 3], 74}}, {{46.333333333333336`, 75.33333333333333}, {
        46.333333333333336`, 74}}]], 
     LineBox[NCache[{{Rational[139, 3], 74}, {
        Rational[139, 3], Rational[218, 3]}}, {{46.333333333333336`, 74}, {
        46.333333333333336`, 72.66666666666667}}]], 
     LineBox[
      NCache[{{Rational[127, 3], Rational[214, 3]}, {
        Rational[131, 3], Rational[214, 3]}}, {{42.333333333333336`, 
       71.33333333333333}, {43.666666666666664`, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[131, 3], 70}, {Rational[131, 3], 68}}, {{
        43.666666666666664`, 70}, {43.666666666666664`, 68}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[214, 3]}, {
        Rational[131, 3], 70}}, {{43.666666666666664`, 71.33333333333333}, {
        43.666666666666664`, 70}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[214, 3]}, {
        45, Rational[214, 3]}}, {{43.666666666666664`, 71.33333333333333}, {
        45, 71.33333333333333}}]], 
     LineBox[NCache[{{45, Rational[214, 3]}, {
        Rational[139, 3], Rational[214, 3]}}, {{45, 71.33333333333333}, {
        46.333333333333336`, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[196, 3]}, {
        Rational[161, 3], Rational[188, 3]}}, {{53.666666666666664`, 
       65.33333333333333}, {53.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[200, 3]}, {
        49, Rational[200, 3]}}, {{47.666666666666664`, 66.66666666666667}, {
        49, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[200, 3]}, {
        Rational[143, 3], Rational[196, 3]}}, {{47.666666666666664`, 
       66.66666666666667}, {47.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[196, 3]}, {
        49, Rational[196, 3]}}, {{47.666666666666664`, 65.33333333333333}, {
        49, 65.33333333333333}}]], 
     LineBox[NCache[{{49, Rational[196, 3]}, {51, Rational[196, 3]}}, {{
        49, 65.33333333333333}, {51, 65.33333333333333}}]], 
     LineBox[NCache[{{51, Rational[196, 3]}, {
        Rational[161, 3], Rational[196, 3]}}, {{51, 65.33333333333333}, {
        53.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[161, 3], 68}, {
        Rational[161, 3], Rational[196, 3]}}, {{53.666666666666664`, 68}, {
        53.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{51, 68}, {Rational[161, 3], 68}}, {{51, 68}, {
        53.666666666666664`, 68}}]], LineBox[{{49, 68}, {51, 68}}], 
     LineBox[{{49, 70}, {49, 68}}], LineBox[{{49, 70}, {51, 70}}], 
     LineBox[NCache[{{49, Rational[214, 3]}, {51, 70}}, {{
        49, 71.33333333333333}, {51, 70}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[214, 3]}, {
        49, Rational[214, 3]}}, {{47.666666666666664`, 71.33333333333333}, {
        49, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[214, 3]}, {
        Rational[143, 3], Rational[214, 3]}}, {{46.333333333333336`, 
       71.33333333333333}, {47.666666666666664`, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[218, 3]}, {
        Rational[139, 3], Rational[214, 3]}}, {{46.333333333333336`, 
       72.66666666666667}, {46.333333333333336`, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[218, 3]}, {
        Rational[143, 3], Rational[218, 3]}}, {{46.333333333333336`, 
       72.66666666666667}, {47.666666666666664`, 72.66666666666667}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[218, 3]}, {
        49, Rational[218, 3]}}, {{47.666666666666664`, 72.66666666666667}, {
        49, 72.66666666666667}}]], 
     LineBox[NCache[{{49, Rational[218, 3]}, {51, 74}}, {{
        49, 72.66666666666667}, {51, 74}}]], LineBox[{{51, 74}, {55, 74}}], 
     LineBox[{{55, 74}, {59, 74}}], LineBox[{{59, 74}, {59, 70}}], 
     LineBox[{{55, 70}, {59, 70}}], 
     LineBox[NCache[{{55, 70}, {Rational[169, 3], 68}}, {{55, 70}, {
        56.333333333333336`, 68}}]], 
     LineBox[NCache[{{Rational[169, 3], 68}, {
        Rational[169, 3], Rational[196, 3]}}, {{56.333333333333336`, 68}, {
        56.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[196, 3]}, {
        Rational[169, 3], Rational[188, 3]}}, {{56.333333333333336`, 
       65.33333333333333}, {56.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[188, 3]}, {
        59, Rational[188, 3]}}, {{56.333333333333336`, 62.666666666666664`}, {
        59, 62.666666666666664`}}]], 
     LineBox[
      NCache[{{59, Rational[188, 3]}, {59, 60}}, {{59, 62.666666666666664`}, {
        59, 60}}]], 
     LineBox[NCache[{{59, Rational[196, 3]}, {59, Rational[188, 3]}}, {{
        59, 65.33333333333333}, {59, 62.666666666666664`}}]], 
     LineBox[NCache[{{59, 68}, {59, Rational[196, 3]}}, {{59, 68}, {
        59, 65.33333333333333}}]], LineBox[{{59, 68}, {61, 68}}], 
     LineBox[{{61, 68}, {61, 64}}], LineBox[{{61, 64}, {61, 60}}], 
     LineBox[{{61, 60}, {65, 60}}], LineBox[{{65, 60}, {69, 60}}], 
     LineBox[{{69, 60}, {69, 58}}], LineBox[{{65, 58}, {69, 58}}], 
     LineBox[{{65, 58}, {65, 54}}], LineBox[{{65, 54}, {69, 54}}], 
     LineBox[{{69, 54}, {69, 50}}], LineBox[{{65, 50}, {69, 50}}], 
     LineBox[{{61, 50}, {65, 50}}], LineBox[{{59, 50}, {61, 50}}], 
     LineBox[{{57, 50}, {59, 50}}], LineBox[{{59, 50}, {59, 48}}], 
     LineBox[NCache[{{Rational[173, 3], 48}, {59, 48}}, {{
        57.666666666666664`, 48}, {59, 48}}]], 
     LineBox[NCache[{{Rational[173, 3], 48}, {
        Rational[173, 3], Rational[140, 3]}}, {{57.666666666666664`, 48}, {
        57.666666666666664`, 46.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[140, 3]}, {
        Rational[173, 3], Rational[140, 3]}}, {{56.333333333333336`, 
       46.666666666666664`}, {57.666666666666664`, 46.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], 48}, {
        Rational[169, 3], Rational[140, 3]}}, {{56.333333333333336`, 48}, {
        56.333333333333336`, 46.666666666666664`}}]], 
     LineBox[NCache[{{55, 50}, {Rational[169, 3], 48}}, {{55, 50}, {
        56.333333333333336`, 48}}]], LineBox[{{55, 52}, {55, 50}}], 
     LineBox[{{55, 52}, {57, 52}}], LineBox[{{57, 52}, {59, 52}}], 
     LineBox[{{59, 54}, {59, 52}}], LineBox[{{59, 56}, {59, 54}}], 
     LineBox[{{59, 56}, {61, 58}}], LineBox[{{59, 58}, {61, 58}}], 
     LineBox[{{57, 58}, {59, 58}}], 
     LineBox[NCache[{{Rational[169, 3], 60}, {57, 58}}, {{
        56.333333333333336`, 60}, {57, 58}}]], 
     LineBox[NCache[{{Rational[161, 3], 60}, {Rational[169, 3], 60}}, {{
        53.666666666666664`, 60}, {56.333333333333336`, 60}}]], 
     LineBox[NCache[{{Rational[161, 3], 60}, {55, 58}}, {{
        53.666666666666664`, 60}, {55, 58}}]], LineBox[{{55, 58}, {55, 56}}], 
     LineBox[{{55, 56}, {57, 56}}], LineBox[{{57, 56}, {57, 54}}], 
     LineBox[{{55, 54}, {57, 54}}], LineBox[{{53, 54}, {55, 54}}], 
     LineBox[{{53, 56}, {53, 54}}], LineBox[{{51, 56}, {53, 56}}], 
     LineBox[NCache[{{49, Rational[274, 5]}, {51, 56}}, {{49, 54.8}, {51, 
        56}}]], LineBox[
      NCache[{{49, Rational[282, 5]}, {49, Rational[274, 5]}}, {{49, 56.4}, {
        49, 54.8}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[282, 5]}, {
        49, Rational[282, 5]}}, {{47.4, 56.4}, {49, 56.4}}]], 
     LineBox[NCache[{{Rational[237, 5], 58}, {
        Rational[237, 5], Rational[282, 5]}}, {{47.4, 58}, {47.4, 56.4}}]], 
     LineBox[NCache[{{Rational[143, 3], 60}, {Rational[237, 5], 58}}, {{
        47.666666666666664`, 60}, {47.4, 58}}]], 
     LineBox[NCache[{{Rational[139, 3], 60}, {Rational[143, 3], 60}}, {{
        46.333333333333336`, 60}, {47.666666666666664`, 60}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[184, 3]}, {
        Rational[139, 3], 60}}, {{46.333333333333336`, 61.333333333333336`}, {
        46.333333333333336`, 60}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[184, 3]}, {
        Rational[143, 3], Rational[184, 3]}}, {{46.333333333333336`, 
       61.333333333333336`}, {47.666666666666664`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[184, 3]}, {
        49, Rational[184, 3]}}, {{47.666666666666664`, 61.333333333333336`}, {
        49, 61.333333333333336`}}]], 
     LineBox[NCache[{{49, Rational[184, 3]}, {49, 60}}, {{
        49, 61.333333333333336`}, {49, 60}}]], LineBox[{{49, 60}, {51, 60}}], 
     LineBox[NCache[{{51, Rational[188, 3]}, {51, 60}}, {{
        51, 62.666666666666664`}, {51, 60}}]], 
     LineBox[NCache[{{49, Rational[188, 3]}, {51, Rational[188, 3]}}, {{
        49, 62.666666666666664`}, {51, 62.666666666666664`}}]], 
     LineBox[NCache[{{49, 64}, {49, Rational[188, 3]}}, {{49, 64}, {
        49, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[143, 3], 64}, {49, 64}}, {{
        47.666666666666664`, 64}, {49, 64}}]], 
     LineBox[NCache[{{Rational[143, 3], 64}, {
        Rational[143, 3], Rational[188, 3]}}, {{47.666666666666664`, 64}, {
        47.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[188, 3]}, {
        Rational[143, 3], Rational[188, 3]}}, {{46.333333333333336`, 
       62.666666666666664`}, {47.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[139, 3], 64}, {
        Rational[139, 3], Rational[188, 3]}}, {{46.333333333333336`, 64}, {
        46.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[196, 3]}, {
        Rational[139, 3], 64}}, {{46.333333333333336`, 65.33333333333333}, {
        46.333333333333336`, 64}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[200, 3]}, {
        Rational[139, 3], Rational[196, 3]}}, {{46.333333333333336`, 
       66.66666666666667}, {46.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[139, 3], 68}, {
        Rational[139, 3], Rational[200, 3]}}, {{46.333333333333336`, 68}, {
        46.333333333333336`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[139, 3], 68}, {Rational[143, 3], 68}}, {{
        46.333333333333336`, 68}, {47.666666666666664`, 68}}]], 
     LineBox[NCache[{{Rational[143, 3], 70}, {Rational[143, 3], 68}}, {{
        47.666666666666664`, 70}, {47.666666666666664`, 68}}]], 
     LineBox[NCache[{{Rational[139, 3], 70}, {Rational[143, 3], 70}}, {{
        46.333333333333336`, 70}, {47.666666666666664`, 70}}]], 
     LineBox[NCache[{{45, 70}, {Rational[139, 3], 70}}, {{45, 70}, {
        46.333333333333336`, 70}}]], LineBox[{{45, 70}, {45, 68}}], 
     LineBox[NCache[{{45, 68}, {45, Rational[200, 3]}}, {{45, 68}, {
        45, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[200, 3]}, {
        45, Rational[200, 3]}}, {{43.666666666666664`, 66.66666666666667}, {
        45, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[200, 3]}, {
        Rational[131, 3], Rational[200, 3]}}, {{42.333333333333336`, 
       66.66666666666667}, {43.666666666666664`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[127, 3], 68}, {
        Rational[127, 3], Rational[200, 3]}}, {{42.333333333333336`, 68}, {
        42.333333333333336`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[127, 3], 70}, {Rational[127, 3], 68}}, {{
        42.333333333333336`, 70}, {42.333333333333336`, 68}}]], 
     LineBox[NCache[{{41, 70}, {Rational[127, 3], 70}}, {{41, 70}, {
        42.333333333333336`, 70}}]], LineBox[{{41, 70}, {41, 68}}], 
     LineBox[NCache[{{41, 68}, {41, Rational[200, 3]}}, {{41, 68}, {
        41, 66.66666666666667}}]], 
     LineBox[NCache[{{39, Rational[200, 3]}, {41, Rational[200, 3]}}, {{
        39, 66.66666666666667}, {41, 66.66666666666667}}]], 
     LineBox[NCache[{{39, 68}, {39, Rational[200, 3]}}, {{39, 68}, {
        39, 66.66666666666667}}]], LineBox[{{39, 70}, {39, 68}}], 
     LineBox[NCache[{{Rational[265, 7], 70}, {39, 70}}, {{
        37.857142857142854`, 70}, {39, 70}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[498, 7]}, {
        Rational[265, 7], 70}}, {{37.857142857142854`, 71.14285714285714}, {
        37.857142857142854`, 70}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[498, 7]}, {
        39, Rational[498, 7]}}, {{37.857142857142854`, 71.14285714285714}, {
        39, 71.14285714285714}}]], 
     LineBox[NCache[{{39, Rational[498, 7]}, {41, Rational[214, 3]}}, {{
        39, 71.14285714285714}, {41, 71.33333333333333}}]], 
     LineBox[NCache[{{41, Rational[218, 3]}, {41, Rational[214, 3]}}, {{
        41, 72.66666666666667}, {41, 71.33333333333333}}]], 
     LineBox[NCache[{{39, Rational[506, 7]}, {41, Rational[218, 3]}}, {{
        39, 72.28571428571429}, {41, 72.66666666666667}}]], 
     LineBox[NCache[{{39, Rational[514, 7]}, {39, Rational[506, 7]}}, {{
        39, 73.42857142857143}, {39, 72.28571428571429}}]], 
     LineBox[NCache[{{39, Rational[514, 7]}, {41, 74}}, {{
        39, 73.42857142857143}, {41, 74}}]], 
     LineBox[NCache[{{41, 74}, {Rational[127, 3], 74}}, {{41, 74}, {
        42.333333333333336`, 74}}]], 
     LineBox[NCache[{{Rational[127, 3], 74}, {Rational[131, 3], 74}}, {{
        42.333333333333336`, 74}, {43.666666666666664`, 74}}]], 
     LineBox[NCache[{{Rational[127, 3], 74}, {
        Rational[127, 3], Rational[218, 3]}}, {{42.333333333333336`, 74}, {
        42.333333333333336`, 72.66666666666667}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[218, 3]}, {
        Rational[131, 3], Rational[218, 3]}}, {{42.333333333333336`, 
       72.66666666666667}, {43.666666666666664`, 72.66666666666667}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[218, 3]}, {
        45, Rational[218, 3]}}, {{43.666666666666664`, 72.66666666666667}, {
        45, 72.66666666666667}}]], 
     LineBox[NCache[{{45, 74}, {45, Rational[218, 3]}}, {{45, 74}, {
        45, 72.66666666666667}}]], 
     LineBox[NCache[{{45, Rational[226, 3]}, {45, 74}}, {{
        45, 75.33333333333333}, {45, 74}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[226, 3]}, {
        45, Rational[226, 3]}}, {{43.666666666666664`, 75.33333333333333}, {
        45, 75.33333333333333}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[226, 3]}, {
        Rational[131, 3], Rational[226, 3]}}, {{42.333333333333336`, 
       75.33333333333333}, {43.666666666666664`, 75.33333333333333}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[230, 3]}, {
        Rational[127, 3], Rational[226, 3]}}, {{42.333333333333336`, 
       76.66666666666667}, {42.333333333333336`, 75.33333333333333}}]], 
     LineBox[NCache[{{Rational[127, 3], 78}, {
        Rational[127, 3], Rational[230, 3]}}, {{42.333333333333336`, 78}, {
        42.333333333333336`, 76.66666666666667}}]], 
     LineBox[NCache[{{41, 78}, {Rational[127, 3], 78}}, {{41, 78}, {
        42.333333333333336`, 78}}]], 
     LineBox[NCache[{{41, 78}, {41, Rational[230, 3]}}, {{41, 78}, {
        41, 76.66666666666667}}]], 
     LineBox[NCache[{{41, Rational[230, 3]}, {41, Rational[226, 3]}}, {{
        41, 76.66666666666667}, {41, 75.33333333333333}}]], 
     LineBox[NCache[{{39, Rational[522, 7]}, {41, Rational[226, 3]}}, {{
        39, 74.57142857142857}, {41, 75.33333333333333}}]], 
     LineBox[
      NCache[{{39, Rational[530, 7]}, {39, Rational[522, 7]}}, {{
        39, 75.71428571428571}, {39, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[530, 7]}, {
        39, Rational[530, 7]}}, {{37.857142857142854`, 75.71428571428571}, {
        39, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[530, 7]}, {
        Rational[265, 7], Rational[530, 7]}}, {{36.714285714285715`, 
       75.71428571428571}, {37.857142857142854`, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[530, 7]}, {
        Rational[257, 7], Rational[522, 7]}}, {{36.714285714285715`, 
       75.71428571428571}, {36.714285714285715`, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[522, 7]}, {
        Rational[257, 7], Rational[514, 7]}}, {{36.714285714285715`, 
       74.57142857142857}, {36.714285714285715`, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[514, 7]}, {
        Rational[265, 7], Rational[514, 7]}}, {{36.714285714285715`, 
       73.42857142857143}, {37.857142857142854`, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[514, 7]}, {
        Rational[265, 7], Rational[506, 7]}}, {{37.857142857142854`, 
       73.42857142857143}, {37.857142857142854`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[506, 7]}, {
        Rational[265, 7], Rational[506, 7]}}, {{36.714285714285715`, 
       72.28571428571429}, {37.857142857142854`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[506, 7]}, {
        Rational[257, 7], Rational[506, 7]}}, {{35.57142857142857, 
       72.28571428571429}, {36.714285714285715`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[514, 7]}, {
        Rational[249, 7], Rational[506, 7]}}, {{35.57142857142857, 
       73.42857142857143}, {35.57142857142857, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[514, 7]}, {
        Rational[249, 7], Rational[514, 7]}}, {{34.42857142857143, 
       73.42857142857143}, {35.57142857142857, 73.42857142857143}}]], 
     LineBox[
      NCache[{{Rational[241, 7], Rational[522, 7]}, {
        Rational[241, 7], Rational[514, 7]}}, {{34.42857142857143, 
       74.57142857142857}, {34.42857142857143, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[522, 7]}, {
        Rational[241, 7], Rational[522, 7]}}, {{33.285714285714285`, 
       74.57142857142857}, {34.42857142857143, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[522, 7]}, {
        Rational[233, 7], Rational[522, 7]}}, {{32.142857142857146`, 
       74.57142857142857}, {33.285714285714285`, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[530, 7]}, {
        Rational[225, 7], Rational[522, 7]}}, {{32.142857142857146`, 
       75.71428571428571}, {32.142857142857146`, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[538, 7]}, {
        Rational[225, 7], Rational[530, 7]}}, {{32.142857142857146`, 
       76.85714285714286}, {32.142857142857146`, 75.71428571428571}}]], 
     LineBox[NCache[{{31, Rational[538, 7]}, {
        Rational[225, 7], Rational[538, 7]}}, {{31, 76.85714285714286}, {
        32.142857142857146`, 76.85714285714286}}]], 
     LineBox[NCache[{{31, 78}, {31, Rational[538, 7]}}, {{31, 78}, {
        31, 76.85714285714286}}]], LineBox[{{29, 78}, {31, 78}}], 
     LineBox[{{25, 78}, {29, 78}}], LineBox[{{21, 78}, {25, 78}}], 
     LineBox[{{19, 78}, {21, 78}}], LineBox[{{15, 78}, {19, 78}}], 
     LineBox[{{15, 78}, {15, 74}}], LineBox[{{15, 74}, {15, 70}}], 
     LineBox[{{15, 70}, {19, 70}}], LineBox[{{19, 70}, {19, 68}}], 
     LineBox[{{19, 68}, {19, 64}}], LineBox[{{15, 64}, {19, 64}}], 
     LineBox[{{15, 68}, {15, 64}}], LineBox[{{11, 68}, {15, 68}}], 
     LineBox[{{11, 70}, {11, 68}}], LineBox[{{11, 74}, {11, 70}}], 
     LineBox[{{11, 78}, {11, 74}}]}, 
    {RGBColor[0, 1, 0], DiskBox[{11, 78}]}, 
    {RGBColor[1, 0, 0], DiskBox[{69, 0}]}}},
  ImageSize->NCache[
    Rational[1125, 2], 562.5]]], "Output",
 CellChangeTimes->{
  3.470843003812735*^9, {3.470846041564597*^9, 3.470846061171313*^9}, 
   3.470846142375858*^9, 3.470849675388457*^9, 3.470867714010704*^9, 
   3.470867793658545*^9, 3.470874469130161*^9, 3.470874966946853*^9, 
   3.470878260962941*^9, 3.470881802987815*^9, 3.470912091622696*^9, {
   3.470912155518358*^9, 3.470912176208816*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateMazeFromImage", "[", 
  RowBox[{"img", ",", "resx3", ",", "resy3", ",", "350"}], "]"}]], "Input",
 CellChangeTimes->{{3.470838825645105*^9, 3.470838842796834*^9}, 
   3.470839020062038*^9, {3.470839073202456*^9, 3.470839073331858*^9}, {
   3.470839760189356*^9, 3.470839761291362*^9}, {3.470867735181334*^9, 
   3.470867735494497*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.5], AbsoluteThickness[3]}, 
   {GrayLevel[0], AbsoluteThickness[
    5], {LineBox[
      NCache[{{Rational[143, 3], Rational[230, 3]}, {
        Rational[143, 3], Rational[226, 3]}}, {{47.666666666666664`, 
       76.66666666666667}, {47.666666666666664`, 75.33333333333333}}]], 
     LineBox[{{61, 78}, {61, 74}}], LineBox[{{61, 78}, {65, 78}}], 
     LineBox[{{65, 78}, {69, 78}}], LineBox[{{65, 78}, {65, 74}}], 
     LineBox[{{65, 74}, {69, 74}}], LineBox[{{69, 74}, {69, 70}}], 
     LineBox[{{59, 38}, {61, 38}}], LineBox[{{69, 30}, {69, 28}}], 
     LineBox[{{69, 48}, {69, 44}}], LineBox[{{69, 44}, {69, 40}}], 
     LineBox[{{63, 28}, {65, 28}}], LineBox[{{65, 30}, {65, 28}}], 
     LineBox[{{65, 32}, {67, 32}}], LineBox[{{65, 32}, {65, 30}}], 
     LineBox[{{63, 30}, {65, 30}}], LineBox[{{63, 32}, {63, 30}}], 
     LineBox[{{63, 34}, {63, 32}}], LineBox[{{63, 34}, {65, 34}}], 
     LineBox[{{65, 36}, {65, 34}}], LineBox[{{65, 38}, {65, 36}}], 
     LineBox[{{65, 38}, {67, 38}}], LineBox[{{65, 40}, {67, 38}}], 
     LineBox[{{65, 40}, {69, 40}}], LineBox[{{69, 40}, {69, 38}}], 
     LineBox[{{69, 38}, {69, 36}}], LineBox[{{67, 36}, {69, 36}}], 
     LineBox[{{67, 36}, {67, 34}}], LineBox[{{67, 34}, {69, 34}}], 
     LineBox[{{69, 34}, {69, 32}}], LineBox[{{69, 32}, {69, 30}}], 
     LineBox[{{67, 30}, {69, 30}}], LineBox[{{67, 30}, {67, 28}}], 
     LineBox[{{67, 28}, {67, 26}}], LineBox[{{67, 26}, {69, 26}}], 
     LineBox[{{69, 26}, {69, 24}}], LineBox[{{69, 24}, {69, 22}}], 
     LineBox[NCache[{{Rational[173, 3], Rational[76, 3]}, {
        59, Rational[76, 3]}}, {{57.666666666666664`, 25.333333333333332`}, {
        59, 25.333333333333332`}}]], 
     LineBox[NCache[{{55, 28}, {55, Rational[80, 3]}}, {{55, 28}, {
        55, 26.666666666666668`}}]], LineBox[{{55, 30}, {55, 28}}], 
     LineBox[NCache[{{55, 30}, {Rational[169, 3], 30}}, {{55, 30}, {
        56.333333333333336`, 30}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[98, 3]}, {
        Rational[173, 3], Rational[94, 3]}}, {{57.666666666666664`, 
       32.666666666666664`}, {57.666666666666664`, 31.333333333333332`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[94, 3]}, {
        59, Rational[94, 3]}}, {{57.666666666666664`, 31.333333333333332`}, {
        59, 31.333333333333332`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[94, 3]}, {
        Rational[173, 3], 30}}, {{57.666666666666664`, 31.333333333333332`}, {
        57.666666666666664`, 30}}]], 
     LineBox[NCache[{{Rational[169, 3], 30}, {Rational[173, 3], 30}}, {{
        56.333333333333336`, 30}, {57.666666666666664`, 30}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[94, 3]}, {
        Rational[169, 3], 30}}, {{56.333333333333336`, 31.333333333333332`}, {
        56.333333333333336`, 30}}]], 
     LineBox[NCache[{{55, Rational[94, 3]}, {
        Rational[169, 3], Rational[94, 3]}}, {{55, 31.333333333333332`}, {
        56.333333333333336`, 31.333333333333332`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[94, 3]}, {
        55, Rational[94, 3]}}, {{53.666666666666664`, 31.333333333333332`}, {
        55, 31.333333333333332`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[94, 3]}, {
        Rational[161, 3], Rational[94, 3]}}, {{52.333333333333336`, 
       31.333333333333332`}, {53.666666666666664`, 31.333333333333332`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[94, 3]}, {
        Rational[157, 3], 30}}, {{52.333333333333336`, 31.333333333333332`}, {
        52.333333333333336`, 30}}]], LineBox[{{41, 40}, {41, 38}}], 
     LineBox[{{41, 38}, {45, 38}}], 
     LineBox[NCache[{{Rational[157, 3], Rational[140, 3]}, {
        Rational[157, 3], Rational[136, 3]}}, {{52.333333333333336`, 
       46.666666666666664`}, {52.333333333333336`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[140, 3]}, {
        Rational[161, 3], Rational[140, 3]}}, {{52.333333333333336`, 
       46.666666666666664`}, {53.666666666666664`, 46.666666666666664`}}]], 
     LineBox[NCache[{{Rational[157, 3], 48}, {
        Rational[157, 3], Rational[140, 3]}}, {{52.333333333333336`, 48}, {
        52.333333333333336`, 46.666666666666664`}}]], 
     LineBox[
      NCache[{{51, 48}, {Rational[157, 3], 48}}, {{51, 48}, {
        52.333333333333336`, 48}}]], 
     LineBox[NCache[{{51, 50}, {Rational[157, 3], 48}}, {{51, 50}, {
        52.333333333333336`, 48}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[274, 5]}, {
        Rational[221, 5], Rational[266, 5]}}, {{44.2, 54.8}, {44.2, 53.2}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[282, 5]}, {
        Rational[237, 5], Rational[274, 5]}}, {{47.4, 56.4}, {47.4, 54.8}}]], 
     LineBox[NCache[{{59, Rational[136, 3]}, {59, 44}}, {{
        59, 45.333333333333336`}, {59, 44}}]], 
     LineBox[NCache[{{59, Rational[136, 3]}, {61, 48}}, {{
        59, 45.333333333333336`}, {61, 48}}]], LineBox[{{57, 58}, {59, 58}}], 
     LineBox[{{59, 60}, {59, 58}}], LineBox[{{59, 68}, {61, 68}}], 
     LineBox[NCache[{{Rational[143, 3], Rational[200, 3]}, {
        49, Rational[200, 3]}}, {{47.666666666666664`, 66.66666666666667}, {
        49, 66.66666666666667}}]], 
     LineBox[NCache[{{49, Rational[200, 3]}, {49, Rational[196, 3]}}, {{
        49, 66.66666666666667}, {49, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[196, 3]}, {
        49, Rational[196, 3]}}, {{47.666666666666664`, 65.33333333333333}, {
        49, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[196, 3]}, {
        Rational[143, 3], 64}}, {{47.666666666666664`, 65.33333333333333}, {
        47.666666666666664`, 64}}]], 
     LineBox[NCache[{{Rational[143, 3], 64}, {49, 64}}, {{
        47.666666666666664`, 64}, {49, 64}}]], 
     LineBox[NCache[{{49, 64}, {49, Rational[188, 3]}}, {{49, 64}, {
        49, 62.666666666666664`}}]], 
     LineBox[NCache[{{45, Rational[184, 3]}, {45, 60}}, {{
        45, 61.333333333333336`}, {45, 60}}]], 
     LineBox[NCache[{{45, 60}, {Rational[221, 5], 58}}, {{45, 60}, {
        44.2, 58}}]], 
     LineBox[NCache[{{Rational[131, 3], 60}, {45, 60}}, {{
        43.666666666666664`, 60}, {45, 60}}]], 
     LineBox[NCache[{{45, 60}, {Rational[139, 3], 60}}, {{45, 60}, {
        46.333333333333336`, 60}}]], 
     LineBox[NCache[{{Rational[139, 3], 60}, {Rational[143, 3], 60}}, {{
        46.333333333333336`, 60}, {47.666666666666664`, 60}}]], 
     LineBox[NCache[{{Rational[143, 3], 60}, {49, 60}}, {{
        47.666666666666664`, 60}, {49, 60}}]], LineBox[{{53, 56}, {53, 54}}], 
     LineBox[{{53, 58}, {53, 56}}], LineBox[{{51, 60}, {53, 58}}], 
     LineBox[{{49, 60}, {51, 60}}], 
     LineBox[NCache[{{49, Rational[184, 3]}, {49, 60}}, {{
        49, 61.333333333333336`}, {49, 60}}]], 
     LineBox[NCache[{{49, Rational[188, 3]}, {49, Rational[184, 3]}}, {{
        49, 62.666666666666664`}, {49, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[188, 3]}, {
        49, Rational[188, 3]}}, {{47.666666666666664`, 62.666666666666664`}, {
        49, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[188, 3]}, {
        Rational[143, 3], Rational[184, 3]}}, {{47.666666666666664`, 
       62.666666666666664`}, {47.666666666666664`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[184, 3]}, {
        Rational[143, 3], Rational[184, 3]}}, {{46.333333333333336`, 
       61.333333333333336`}, {47.666666666666664`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[188, 3]}, {
        Rational[139, 3], Rational[184, 3]}}, {{46.333333333333336`, 
       62.666666666666664`}, {46.333333333333336`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[213, 5], 58}, {
        Rational[213, 5], Rational[282, 5]}}, {{42.6, 58}, {42.6, 56.4}}]], 
     LineBox[NCache[{{41, 58}, {Rational[213, 5], 58}}, {{41, 58}, {
        42.6, 58}}]], LineBox[{{39, 60}, {39, 58}}], 
     LineBox[NCache[{{39, 58}, {39, Rational[282, 5]}}, {{39, 58}, {
        39, 56.4}}]], 
     LineBox[NCache[{{Rational[187, 5], 58}, {39, 58}}, {{37.4, 58}, {39, 
        58}}]], LineBox[{{39, 58}, {41, 58}}], 
     LineBox[NCache[{{41, 58}, {41, Rational[282, 5]}}, {{41, 58}, {
        41, 56.4}}]], 
     LineBox[NCache[{{Rational[127, 3], 60}, {41, 58}}, {{
        42.333333333333336`, 60}, {41, 58}}]], 
     LineBox[NCache[{{41, 60}, {Rational[127, 3], 60}}, {{41, 60}, {
        42.333333333333336`, 60}}]], 
     LineBox[
      NCache[{{41, Rational[184, 3]}, {41, 60}}, {{41, 61.333333333333336`}, {
        41, 60}}]], 
     LineBox[NCache[{{41, Rational[200, 3]}, {
        Rational[127, 3], Rational[200, 3]}}, {{41, 66.66666666666667}, {
        42.333333333333336`, 66.66666666666667}}]], 
     LineBox[NCache[{{41, 68}, {41, Rational[200, 3]}}, {{41, 68}, {
        41, 66.66666666666667}}]], 
     LineBox[NCache[{{39, Rational[200, 3]}, {41, Rational[200, 3]}}, {{
        39, 66.66666666666667}, {41, 66.66666666666667}}]], 
     LineBox[NCache[{{41, Rational[200, 3]}, {41, Rational[196, 3]}}, {{
        41, 66.66666666666667}, {41, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[196, 3]}, {
        39, Rational[196, 3]}}, {{37.666666666666664`, 65.33333333333333}, {
        39, 65.33333333333333}}]], 
     LineBox[NCache[{{39, Rational[196, 3]}, {39, 64}}, {{
        39, 65.33333333333333}, {39, 64}}]], 
     LineBox[NCache[{{39, Rational[196, 3]}, {41, Rational[196, 3]}}, {{
        39, 65.33333333333333}, {41, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[196, 3]}, {
        Rational[127, 3], 64}}, {{42.333333333333336`, 65.33333333333333}, {
        42.333333333333336`, 64}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[196, 3]}, {
        Rational[131, 3], Rational[196, 3]}}, {{42.333333333333336`, 
       65.33333333333333}, {43.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{41, Rational[196, 3]}, {
        Rational[127, 3], Rational[196, 3]}}, {{41, 65.33333333333333}, {
        42.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{41, Rational[196, 3]}, {41, 64}}, {{
        41, 65.33333333333333}, {41, 64}}]], 
     LineBox[NCache[{{41, 64}, {41, Rational[188, 3]}}, {{41, 64}, {
        41, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[109, 3], 64}, {Rational[113, 3], 64}}, {{
        36.333333333333336`, 64}, {37.666666666666664`, 64}}]], 
     LineBox[NCache[{{Rational[113, 3], 64}, {
        Rational[113, 3], Rational[188, 3]}}, {{37.666666666666664`, 64}, {
        37.666666666666664`, 62.666666666666664`}}]], 
     LineBox[
      NCache[{{Rational[109, 3], Rational[188, 3]}, {
        Rational[109, 3], Rational[184, 3]}}, {{36.333333333333336`, 
       62.666666666666664`}, {36.333333333333336`, 61.333333333333336`}}]], 
     LineBox[NCache[{{35, Rational[188, 3]}, {
        Rational[109, 3], Rational[188, 3]}}, {{35, 62.666666666666664`}, {
        36.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[188, 3]}, {
        Rational[113, 3], Rational[188, 3]}}, {{36.333333333333336`, 
       62.666666666666664`}, {37.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[184, 3]}, {
        39, Rational[184, 3]}}, {{37.666666666666664`, 61.333333333333336`}, {
        39, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[184, 3]}, {
        Rational[113, 3], 60}}, {{37.666666666666664`, 61.333333333333336`}, {
        37.666666666666664`, 60}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[188, 3]}, {
        Rational[113, 3], Rational[184, 3]}}, {{37.666666666666664`, 
       62.666666666666664`}, {37.666666666666664`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[113, 3], Rational[188, 3]}, {
        39, Rational[188, 3]}}, {{37.666666666666664`, 62.666666666666664`}, {
        39, 62.666666666666664`}}]], 
     LineBox[NCache[{{39, Rational[188, 3]}, {41, Rational[188, 3]}}, {{
        39, 62.666666666666664`}, {41, 62.666666666666664`}}]], 
     LineBox[NCache[{{41, Rational[188, 3]}, {
        Rational[127, 3], Rational[188, 3]}}, {{41, 62.666666666666664`}, {
        42.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{41, Rational[188, 3]}, {41, Rational[184, 3]}}, {{
        41, 62.666666666666664`}, {41, 61.333333333333336`}}]], 
     LineBox[NCache[{{41, Rational[184, 3]}, {
        Rational[127, 3], Rational[184, 3]}}, {{41, 61.333333333333336`}, {
        42.333333333333336`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[184, 3]}, {
        Rational[131, 3], Rational[184, 3]}}, {{42.333333333333336`, 
       61.333333333333336`}, {43.666666666666664`, 61.333333333333336`}}]], 
     LineBox[
      NCache[{{Rational[131, 3], Rational[188, 3]}, {
        Rational[131, 3], Rational[184, 3]}}, {{43.666666666666664`, 
       62.666666666666664`}, {43.666666666666664`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[131, 3], 64}, {45, 64}}, {{
        43.666666666666664`, 64}, {45, 64}}]], 
     LineBox[NCache[{{Rational[131, 3], 64}, {
        Rational[131, 3], Rational[188, 3]}}, {{43.666666666666664`, 64}, {
        43.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[188, 3]}, {
        45, Rational[188, 3]}}, {{43.666666666666664`, 62.666666666666664`}, {
        45, 62.666666666666664`}}]], 
     LineBox[NCache[{{45, Rational[188, 3]}, {
        Rational[139, 3], Rational[188, 3]}}, {{45, 62.666666666666664`}, {
        46.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[139, 3], 64}, {
        Rational[139, 3], Rational[188, 3]}}, {{46.333333333333336`, 64}, {
        46.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[196, 3]}, {
        Rational[139, 3], 64}}, {{46.333333333333336`, 65.33333333333333}, {
        46.333333333333336`, 64}}]], 
     LineBox[NCache[{{Rational[139, 3], 68}, {
        Rational[139, 3], Rational[200, 3]}}, {{46.333333333333336`, 68}, {
        46.333333333333336`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[200, 3]}, {
        Rational[139, 3], Rational[196, 3]}}, {{46.333333333333336`, 
       66.66666666666667}, {46.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{45, Rational[196, 3]}, {
        Rational[139, 3], Rational[196, 3]}}, {{45, 65.33333333333333}, {
        46.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{45, Rational[200, 3]}, {45, Rational[196, 3]}}, {{
        45, 66.66666666666667}, {45, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[127, 3], 70}, {Rational[127, 3], 68}}, {{
        42.333333333333336`, 70}, {42.333333333333336`, 68}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[498, 7]}, {
        Rational[265, 7], 70}}, {{37.857142857142854`, 71.14285714285714}, {
        37.857142857142854`, 70}}]], 
     LineBox[NCache[{{Rational[265, 7], 70}, {39, 70}}, {{
        37.857142857142854`, 70}, {39, 70}}]], LineBox[{{39, 70}, {39, 68}}], 
     LineBox[NCache[{{39, Rational[498, 7]}, {39, 70}}, {{
        39, 71.14285714285714}, {39, 70}}]], 
     LineBox[NCache[{{39, Rational[498, 7]}, {41, Rational[214, 3]}}, {{
        39, 71.14285714285714}, {41, 71.33333333333333}}]], 
     LineBox[NCache[{{41, Rational[214, 3]}, {41, 70}}, {{
        41, 71.33333333333333}, {41, 70}}]], 
     LineBox[NCache[{{41, 70}, {Rational[127, 3], 70}}, {{41, 70}, {
        42.333333333333336`, 70}}]], 
     LineBox[NCache[{{Rational[127, 3], 70}, {Rational[131, 3], 70}}, {{
        42.333333333333336`, 70}, {43.666666666666664`, 70}}]], 
     LineBox[NCache[{{Rational[131, 3], 70}, {Rational[131, 3], 68}}, {{
        43.666666666666664`, 70}, {43.666666666666664`, 68}}]], 
     LineBox[NCache[{{Rational[131, 3], 68}, {
        Rational[131, 3], Rational[200, 3]}}, {{43.666666666666664`, 68}, {
        43.666666666666664`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[200, 3]}, {
        45, Rational[200, 3]}}, {{43.666666666666664`, 66.66666666666667}, {
        45, 66.66666666666667}}]], 
     LineBox[NCache[{{45, 68}, {45, Rational[200, 3]}}, {{45, 68}, {
        45, 66.66666666666667}}]], LineBox[{{45, 70}, {45, 68}}], 
     LineBox[NCache[{{45, Rational[214, 3]}, {45, 70}}, {{
        45, 71.33333333333333}, {45, 70}}]], 
     LineBox[NCache[{{45, Rational[214, 3]}, {
        Rational[139, 3], Rational[214, 3]}}, {{45, 71.33333333333333}, {
        46.333333333333336`, 71.33333333333333}}]], 
     LineBox[NCache[{{49, Rational[218, 3]}, {49, Rational[214, 3]}}, {{
        49, 72.66666666666667}, {49, 71.33333333333333}}]], 
     LineBox[{{49, 70}, {51, 70}}], 
     LineBox[NCache[{{49, Rational[214, 3]}, {51, 70}}, {{
        49, 71.33333333333333}, {51, 70}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[214, 3]}, {
        49, Rational[214, 3]}}, {{47.666666666666664`, 71.33333333333333}, {
        49, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[218, 3]}, {
        Rational[143, 3], Rational[214, 3]}}, {{47.666666666666664`, 
       72.66666666666667}, {47.666666666666664`, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[218, 3]}, {
        Rational[143, 3], Rational[218, 3]}}, {{46.333333333333336`, 
       72.66666666666667}, {47.666666666666664`, 72.66666666666667}}]], 
     LineBox[NCache[{{Rational[139, 3], 74}, {
        Rational[139, 3], Rational[218, 3]}}, {{46.333333333333336`, 74}, {
        46.333333333333336`, 72.66666666666667}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[218, 3]}, {
        Rational[139, 3], Rational[214, 3]}}, {{46.333333333333336`, 
       72.66666666666667}, {46.333333333333336`, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[214, 3]}, {
        Rational[139, 3], 70}}, {{46.333333333333336`, 71.33333333333333}, {
        46.333333333333336`, 70}}]], 
     LineBox[NCache[{{Rational[139, 3], 70}, {Rational[143, 3], 70}}, {{
        46.333333333333336`, 70}, {47.666666666666664`, 70}}]], 
     LineBox[NCache[{{Rational[143, 3], 70}, {Rational[143, 3], 68}}, {{
        47.666666666666664`, 70}, {47.666666666666664`, 68}}]], 
     LineBox[NCache[{{Rational[143, 3], 68}, {49, 68}}, {{
        47.666666666666664`, 68}, {49, 68}}]], LineBox[{{49, 68}, {51, 68}}], 
     LineBox[NCache[{{51, 68}, {Rational[161, 3], 68}}, {{51, 68}, {
        53.666666666666664`, 68}}]], 
     LineBox[NCache[{{Rational[161, 3], 68}, {Rational[169, 3], 68}}, {{
        53.666666666666664`, 68}, {56.333333333333336`, 68}}]], 
     LineBox[NCache[{{Rational[169, 3], 68}, {59, 68}}, {{
        56.333333333333336`, 68}, {59, 68}}]], 
     LineBox[NCache[{{59, 68}, {59, Rational[196, 3]}}, {{59, 68}, {
        59, 65.33333333333333}}]], 
     LineBox[NCache[{{59, Rational[196, 3]}, {59, Rational[188, 3]}}, {{
        59, 65.33333333333333}, {59, 62.666666666666664`}}]], 
     LineBox[NCache[{{59, Rational[188, 3]}, {61, 64}}, {{
        59, 62.666666666666664`}, {61, 64}}]], LineBox[{{61, 64}, {61, 60}}], 
     LineBox[{{59, 60}, {61, 60}}], 
     LineBox[NCache[{{Rational[169, 3], 60}, {59, 60}}, {{
        56.333333333333336`, 60}, {59, 60}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[188, 3]}, {
        Rational[169, 3], 60}}, {{56.333333333333336`, 62.666666666666664`}, {
        56.333333333333336`, 60}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[196, 3]}, {
        Rational[169, 3], Rational[188, 3]}}, {{56.333333333333336`, 
       65.33333333333333}, {56.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[196, 3]}, {
        Rational[169, 3], Rational[196, 3]}}, {{53.666666666666664`, 
       65.33333333333333}, {56.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{51, Rational[196, 3]}, {
        Rational[161, 3], Rational[196, 3]}}, {{51, 65.33333333333333}, {
        53.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{51, Rational[196, 3]}, {51, Rational[188, 3]}}, {{
        51, 65.33333333333333}, {51, 62.666666666666664`}}]], 
     LineBox[NCache[{{51, Rational[188, 3]}, {
        Rational[161, 3], Rational[188, 3]}}, {{51, 62.666666666666664`}, {
        53.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[188, 3]}, {
        Rational[161, 3], 60}}, {{53.666666666666664`, 62.666666666666664`}, {
        53.666666666666664`, 60}}]], 
     LineBox[NCache[{{Rational[161, 3], 60}, {55, 58}}, {{
        53.666666666666664`, 60}, {55, 58}}]], LineBox[{{55, 58}, {55, 56}}], 
     LineBox[{{55, 56}, {57, 56}}], LineBox[{{57, 56}, {59, 56}}], 
     LineBox[{{59, 56}, {61, 58}}], LineBox[{{61, 58}, {65, 58}}], 
     LineBox[{{65, 58}, {65, 54}}], LineBox[{{61, 54}, {65, 54}}], 
     LineBox[{{61, 54}, {61, 50}}], LineBox[{{61, 50}, {61, 48}}], 
     LineBox[NCache[{{59, Rational[140, 3]}, {61, 48}}, {{
        59, 46.666666666666664`}, {61, 48}}]], 
     LineBox[NCache[{{59, 48}, {59, Rational[140, 3]}}, {{59, 48}, {
        59, 46.666666666666664`}}]], 
     LineBox[NCache[{{Rational[173, 3], 48}, {59, 48}}, {{
        57.666666666666664`, 48}, {59, 48}}]], 
     LineBox[NCache[{{Rational[169, 3], 48}, {Rational[173, 3], 48}}, {{
        56.333333333333336`, 48}, {57.666666666666664`, 48}}]], 
     LineBox[NCache[{{55, 50}, {Rational[169, 3], 48}}, {{55, 50}, {
        56.333333333333336`, 48}}]], LineBox[{{55, 50}, {57, 50}}], 
     LineBox[{{57, 52}, {57, 50}}], LineBox[{{57, 50}, {59, 50}}], 
     LineBox[{{59, 52}, {59, 50}}], LineBox[{{59, 54}, {59, 52}}], 
     LineBox[{{57, 54}, {59, 54}}], LineBox[{{55, 54}, {57, 54}}], 
     LineBox[{{55, 54}, {55, 52}}], LineBox[{{53, 52}, {55, 52}}], 
     LineBox[{{51, 52}, {53, 52}}], LineBox[{{51, 54}, {51, 52}}], 
     LineBox[NCache[{{49, Rational[266, 5]}, {51, 54}}, {{49, 53.2}, {51, 
        54}}]], LineBox[
      NCache[{{49, Rational[266, 5]}, {49, Rational[258, 5]}}, {{49, 53.2}, {
        49, 51.6}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[258, 5]}, {
        49, Rational[258, 5]}}, {{47.4, 51.6}, {49, 51.6}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[266, 5]}, {
        Rational[237, 5], Rational[258, 5]}}, {{47.4, 53.2}, {47.4, 51.6}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[274, 5]}, {
        Rational[237, 5], Rational[266, 5]}}, {{47.4, 54.8}, {47.4, 53.2}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[274, 5]}, {
        49, Rational[274, 5]}}, {{47.4, 54.8}, {49, 54.8}}]], 
     LineBox[NCache[{{49, Rational[274, 5]}, {51, 56}}, {{49, 54.8}, {51, 
        56}}]], LineBox[{{51, 58}, {51, 56}}], 
     LineBox[NCache[{{49, Rational[282, 5]}, {51, 58}}, {{49, 56.4}, {51, 
        58}}]], LineBox[
      NCache[{{49, 58}, {49, Rational[282, 5]}}, {{49, 58}, {49, 56.4}}]], 
     LineBox[NCache[{{Rational[237, 5], 58}, {49, 58}}, {{47.4, 58}, {49, 
        58}}]], LineBox[
      NCache[{{Rational[229, 5], 58}, {Rational[237, 5], 58}}, {{45.8, 58}, {
        47.4, 58}}]], 
     LineBox[NCache[{{Rational[229, 5], 58}, {
        Rational[229, 5], Rational[282, 5]}}, {{45.8, 58}, {45.8, 56.4}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[282, 5]}, {
        Rational[229, 5], Rational[282, 5]}}, {{44.2, 56.4}, {45.8, 56.4}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[282, 5]}, {
        Rational[221, 5], Rational[274, 5]}}, {{44.2, 56.4}, {44.2, 54.8}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[274, 5]}, {
        Rational[229, 5], Rational[274, 5]}}, {{44.2, 54.8}, {45.8, 54.8}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[274, 5]}, {
        Rational[229, 5], Rational[266, 5]}}, {{45.8, 54.8}, {45.8, 53.2}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[266, 5]}, {
        Rational[229, 5], Rational[258, 5]}}, {{45.8, 53.2}, {45.8, 51.6}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[258, 5]}, {
        Rational[229, 5], 50}}, {{45.8, 51.6}, {45.8, 50}}]], 
     LineBox[NCache[{{Rational[229, 5], 50}, {Rational[237, 5], 50}}, {{
        45.8, 50}, {47.4, 50}}]], 
     LineBox[NCache[{{Rational[237, 5], 50}, {49, 50}}, {{47.4, 50}, {49, 
        50}}]], LineBox[{{49, 50}, {51, 50}}], LineBox[{{51, 50}, {53, 50}}], 
     LineBox[NCache[{{53, 50}, {Rational[161, 3], 48}}, {{53, 50}, {
        53.666666666666664`, 48}}]], 
     LineBox[NCache[{{Rational[161, 3], 48}, {55, 48}}, {{
        53.666666666666664`, 48}, {55, 48}}]], 
     LineBox[NCache[{{55, 48}, {55, Rational[140, 3]}}, {{55, 48}, {
        55, 46.666666666666664`}}]], 
     LineBox[NCache[{{55, Rational[140, 3]}, {
        Rational[169, 3], Rational[140, 3]}}, {{55, 46.666666666666664`}, {
        56.333333333333336`, 46.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[140, 3]}, {
        Rational[173, 3], Rational[140, 3]}}, {{56.333333333333336`, 
       46.666666666666664`}, {57.666666666666664`, 46.666666666666664`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[140, 3]}, {
        Rational[173, 3], Rational[136, 3]}}, {{57.666666666666664`, 
       46.666666666666664`}, {57.666666666666664`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[136, 3]}, {
        Rational[173, 3], 44}}, {{57.666666666666664`, 45.333333333333336`}, {
        57.666666666666664`, 44}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[124, 3]}, {
        Rational[161, 3], 40}}, {{53.666666666666664`, 41.333333333333336`}, {
        53.666666666666664`, 40}}]], 
     LineBox[NCache[{{51, Rational[124, 3]}, {
        Rational[157, 3], Rational[124, 3]}}, {{51, 41.333333333333336`}, {
        52.333333333333336`, 41.333333333333336`}}]], 
     LineBox[NCache[{{51, Rational[128, 3]}, {51, Rational[124, 3]}}, {{
        51, 42.666666666666664`}, {51, 41.333333333333336`}}]], 
     LineBox[NCache[{{51, Rational[128, 3]}, {
        Rational[157, 3], Rational[128, 3]}}, {{51, 42.666666666666664`}, {
        52.333333333333336`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[128, 3]}, {
        Rational[161, 3], Rational[128, 3]}}, {{52.333333333333336`, 
       42.666666666666664`}, {53.666666666666664`, 42.666666666666664`}}]], 
     LineBox[NCache[{{55, 44}, {55, Rational[128, 3]}}, {{55, 44}, {
        55, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[128, 3]}, {
        Rational[169, 3], Rational[124, 3]}}, {{56.333333333333336`, 
       42.666666666666664`}, {56.333333333333336`, 41.333333333333336`}}]], 
     LineBox[NCache[{{55, Rational[128, 3]}, {
        Rational[169, 3], Rational[128, 3]}}, {{55, 42.666666666666664`}, {
        56.333333333333336`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[128, 3]}, {
        55, Rational[128, 3]}}, {{53.666666666666664`, 42.666666666666664`}, {
        55, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[128, 3]}, {
        Rational[161, 3], Rational[124, 3]}}, {{53.666666666666664`, 
       42.666666666666664`}, {53.666666666666664`, 41.333333333333336`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[124, 3]}, {
        55, Rational[124, 3]}}, {{53.666666666666664`, 41.333333333333336`}, {
        55, 41.333333333333336`}}]], 
     LineBox[NCache[{{55, Rational[124, 3]}, {55, 40}}, {{
        55, 41.333333333333336`}, {55, 40}}]], 
     LineBox[NCache[{{55, 40}, {Rational[169, 3], 40}}, {{55, 40}, {
        56.333333333333336`, 40}}]], 
     LineBox[NCache[{{Rational[169, 3], 40}, {Rational[173, 3], 40}}, {{
        56.333333333333336`, 40}, {57.666666666666664`, 40}}]], 
     LineBox[
      NCache[{{Rational[173, 3], Rational[124, 3]}, {
        Rational[173, 3], 40}}, {{57.666666666666664`, 41.333333333333336`}, {
        57.666666666666664`, 40}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[128, 3]}, {
        Rational[173, 3], Rational[124, 3]}}, {{57.666666666666664`, 
       42.666666666666664`}, {57.666666666666664`, 41.333333333333336`}}]], 
     LineBox[NCache[{{Rational[173, 3], 44}, {
        Rational[173, 3], Rational[128, 3]}}, {{57.666666666666664`, 44}, {
        57.666666666666664`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], 44}, {Rational[173, 3], 44}}, {{
        56.333333333333336`, 44}, {57.666666666666664`, 44}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[136, 3]}, {
        Rational[169, 3], 44}}, {{56.333333333333336`, 45.333333333333336`}, {
        56.333333333333336`, 44}}]], 
     LineBox[NCache[{{55, Rational[136, 3]}, {
        Rational[169, 3], Rational[136, 3]}}, {{55, 45.333333333333336`}, {
        56.333333333333336`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[136, 3]}, {
        55, Rational[136, 3]}}, {{53.666666666666664`, 45.333333333333336`}, {
        55, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[136, 3]}, {
        Rational[161, 3], 44}}, {{53.666666666666664`, 45.333333333333336`}, {
        53.666666666666664`, 44}}]], 
     LineBox[NCache[{{Rational[157, 3], 44}, {Rational[161, 3], 44}}, {{
        52.333333333333336`, 44}, {53.666666666666664`, 44}}]], 
     LineBox[NCache[{{51, 44}, {Rational[157, 3], 44}}, {{51, 44}, {
        52.333333333333336`, 44}}]], 
     LineBox[NCache[{{49, Rational[136, 3]}, {51, 44}}, {{
        49, 45.333333333333336`}, {51, 44}}]], 
     LineBox[NCache[{{49, Rational[136, 3]}, {51, Rational[136, 3]}}, {{
        49, 45.333333333333336`}, {51, 45.333333333333336`}}]], 
     LineBox[NCache[{{51, Rational[140, 3]}, {51, Rational[136, 3]}}, {{
        51, 46.666666666666664`}, {51, 45.333333333333336`}}]], 
     LineBox[NCache[{{49, 48}, {51, Rational[140, 3]}}, {{49, 48}, {
        51, 46.666666666666664`}}]], 
     LineBox[
      NCache[{{Rational[139, 3], 48}, {49, 48}}, {{46.333333333333336`, 48}, {
        49, 48}}]], 
     LineBox[NCache[{{Rational[139, 3], 48}, {
        Rational[139, 3], Rational[136, 3]}}, {{46.333333333333336`, 48}, {
        46.333333333333336`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[136, 3]}, {
        Rational[139, 3], Rational[128, 3]}}, {{46.333333333333336`, 
       45.333333333333336`}, {46.333333333333336`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[128, 3]}, {
        49, Rational[128, 3]}}, {{46.333333333333336`, 42.666666666666664`}, {
        49, 42.666666666666664`}}]], 
     LineBox[NCache[{{49, Rational[128, 3]}, {49, 40}}, {{
        49, 42.666666666666664`}, {49, 40}}]], LineBox[{{49, 40}, {49, 38}}], 
     LineBox[{{45, 38}, {49, 38}}], 
     LineBox[NCache[{{Rational[139, 3], 40}, {45, 38}}, {{
        46.333333333333336`, 40}, {45, 38}}]], 
     LineBox[NCache[{{Rational[131, 3], 40}, {Rational[139, 3], 40}}, {{
        43.666666666666664`, 40}, {46.333333333333336`, 40}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[128, 3]}, {
        Rational[131, 3], 40}}, {{43.666666666666664`, 42.666666666666664`}, {
        43.666666666666664`, 40}}]], 
     LineBox[NCache[{{41, Rational[128, 3]}, {
        Rational[131, 3], Rational[128, 3]}}, {{41, 42.666666666666664`}, {
        43.666666666666664`, 42.666666666666664`}}]], 
     LineBox[NCache[{{41, Rational[136, 3]}, {41, Rational[128, 3]}}, {{
        41, 45.333333333333336`}, {41, 42.666666666666664`}}]], 
     LineBox[NCache[{{41, 50}, {Rational[213, 5], 50}}, {{41, 50}, {
        42.6, 50}}]], 
     LineBox[NCache[{{Rational[213, 5], 50}, {41, 48}}, {{42.6, 50}, {41, 
        48}}]], LineBox[{{39, 48}, {41, 48}}], 
     LineBox[NCache[{{41, 48}, {41, Rational[136, 3]}}, {{41, 48}, {
        41, 45.333333333333336`}}]], 
     LineBox[NCache[{{41, Rational[136, 3]}, {
        Rational[131, 3], Rational[136, 3]}}, {{41, 45.333333333333336`}, {
        43.666666666666664`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[131, 3], 48}, {
        Rational[131, 3], Rational[136, 3]}}, {{43.666666666666664`, 48}, {
        43.666666666666664`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[221, 5], 50}, {Rational[131, 3], 48}}, {{
        44.2, 50}, {43.666666666666664`, 48}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[258, 5]}, {
        Rational[221, 5], 50}}, {{44.2, 51.6}, {44.2, 50}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[258, 5]}, {
        Rational[221, 5], Rational[258, 5]}}, {{42.6, 51.6}, {44.2, 51.6}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[266, 5]}, {
        Rational[213, 5], Rational[258, 5]}}, {{42.6, 53.2}, {42.6, 51.6}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[274, 5]}, {
        Rational[213, 5], Rational[266, 5]}}, {{42.6, 54.8}, {42.6, 53.2}}]], 
     LineBox[NCache[{{41, Rational[274, 5]}, {
        Rational[213, 5], Rational[274, 5]}}, {{41, 54.8}, {42.6, 54.8}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[274, 5]}, {
        Rational[179, 5], Rational[266, 5]}}, {{35.8, 54.8}, {35.8, 53.2}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[274, 5]}, {
        Rational[179, 5], Rational[274, 5]}}, {{34.2, 54.8}, {35.8, 54.8}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[274, 5]}, {
        Rational[171, 5], Rational[266, 5]}}, {{34.2, 54.8}, {34.2, 53.2}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[266, 5]}, {
        Rational[171, 5], Rational[258, 5]}}, {{34.2, 53.2}, {34.2, 51.6}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[258, 5]}, {
        Rational[171, 5], 50}}, {{34.2, 51.6}, {34.2, 50}}]], 
     LineBox[NCache[{{Rational[171, 5], 50}, {Rational[101, 3], 48}}, {{
        34.2, 50}, {33.666666666666664`, 48}}]], 
     LineBox[NCache[{{Rational[101, 3], 48}, {
        Rational[101, 3], Rational[136, 3]}}, {{33.666666666666664`, 48}, {
        33.666666666666664`, 45.333333333333336`}}]], 
     LineBox[{{21, 24}, {23, 24}}], LineBox[{{23, 26}, {23, 24}}], 
     LineBox[{{21, 26}, {23, 26}}], LineBox[{{21, 28}, {21, 26}}], 
     LineBox[{{21, 28}, {23, 28}}], LineBox[{{21, 32}, {23, 32}}], 
     LineBox[{{21, 34}, {21, 32}}], 
     LineBox[NCache[{{Rational[41, 3], Rational[68, 3]}, {
        Rational[41, 3], 20}}, {{13.666666666666666`, 22.666666666666668`}, {
        13.666666666666666`, 20}}]], 
     LineBox[NCache[{{Rational[41, 3], Rational[68, 3]}, {
        Rational[49, 3], Rational[68, 3]}}, {{13.666666666666666`, 
       22.666666666666668`}, {16.333333333333332`, 22.666666666666668`}}]], 
     LineBox[NCache[{{11, Rational[68, 3]}, {
        Rational[41, 3], Rational[68, 3]}}, {{11, 22.666666666666668`}, {
        13.666666666666666`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[41, 3], Rational[76, 3]}, {
        Rational[41, 3], Rational[68, 3]}}, {{13.666666666666666`, 
       25.333333333333332`}, {13.666666666666666`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[41, 3], Rational[76, 3]}, {
        Rational[49, 3], Rational[76, 3]}}, {{13.666666666666666`, 
       25.333333333333332`}, {16.333333333333332`, 25.333333333333332`}}]], 
     LineBox[NCache[{{11, Rational[76, 3]}, {
        Rational[41, 3], Rational[76, 3]}}, {{11, 25.333333333333332`}, {
        13.666666666666666`, 25.333333333333332`}}]], 
     LineBox[NCache[{{11, 28}, {11, Rational[76, 3]}}, {{11, 28}, {
        11, 25.333333333333332`}}]], 
     LineBox[NCache[{{11, 28}, {Rational[41, 3], 28}}, {{11, 28}, {
        13.666666666666666`, 28}}]], 
     LineBox[NCache[{{11, 30}, {Rational[41, 3], 28}}, {{11, 30}, {
        13.666666666666666`, 28}}]], LineBox[{{11, 34}, {11, 30}}], 
     LineBox[{{11, 38}, {11, 34}}], LineBox[{{11, 38}, {15, 38}}], 
     LineBox[{{15, 40}, {15, 38}}], LineBox[{{11, 40}, {15, 40}}], 
     LineBox[{{11, 44}, {11, 40}}], 
     LineBox[NCache[{{31, Rational[184, 3]}, {31, 60}}, {{
        31, 61.333333333333336`}, {31, 60}}]], 
     LineBox[NCache[{{31, Rational[184, 3]}, {
        Rational[97, 3], Rational[184, 3]}}, {{31, 61.333333333333336`}, {
        32.333333333333336`, 61.333333333333336`}}]], 
     LineBox[NCache[{{31, Rational[188, 3]}, {31, Rational[184, 3]}}, {{
        31, 62.666666666666664`}, {31, 61.333333333333336`}}]], 
     LineBox[
      NCache[{{29, 60}, {31, Rational[184, 3]}}, {{29, 60}, {
        31, 61.333333333333336`}}]], LineBox[{{29, 64}, {31, 64}}], 
     LineBox[{{29, 64}, {29, 60}}], LineBox[{{29, 60}, {29, 58}}], 
     LineBox[NCache[{{31, Rational[274, 5]}, {31, Rational[266, 5]}}, {{
        31, 54.8}, {31, 53.2}}]], 
     LineBox[NCache[{{31, Rational[266, 5]}, {31, Rational[258, 5]}}, {{
        31, 53.2}, {31, 51.6}}]], 
     LineBox[NCache[{{29, 54}, {31, Rational[266, 5]}}, {{29, 54}, {
        31, 53.2}}]], LineBox[{{29, 50}, {29, 48}}], 
     LineBox[{{25, 50}, {29, 50}}], LineBox[{{29, 50}, {31, 50}}], 
     LineBox[{{29, 54}, {29, 50}}], LineBox[{{21, 54}, {25, 54}}], 
     LineBox[{{25, 54}, {29, 54}}], LineBox[{{29, 58}, {29, 54}}], 
     LineBox[NCache[{{Rational[97, 3], 60}, {31, 58}}, {{
        32.333333333333336`, 60}, {31, 58}}]], 
     LineBox[NCache[{{31, 58}, {Rational[163, 5], 58}}, {{31, 58}, {
        32.6, 58}}]], 
     LineBox[NCache[{{31, 58}, {31, Rational[282, 5]}}, {{31, 58}, {
        31, 56.4}}]], 
     LineBox[NCache[{{29, 58}, {31, Rational[282, 5]}}, {{29, 58}, {
        31, 56.4}}]], LineBox[{{25, 58}, {29, 58}}], 
     LineBox[{{21, 58}, {25, 58}}], LineBox[{{19, 58}, {21, 58}}], 
     LineBox[{{25, 48}, {25, 46}}], LineBox[{{25, 48}, {27, 48}}], 
     LineBox[{{23, 48}, {25, 48}}], LineBox[{{21, 46}, {23, 46}}], 
     LineBox[{{23, 46}, {23, 44}}], LineBox[{{23, 48}, {23, 46}}], 
     LineBox[{{19, 48}, {21, 48}}], LineBox[{{21, 48}, {23, 48}}], 
     LineBox[{{21, 50}, {23, 48}}], LineBox[{{19, 50}, {21, 50}}], 
     LineBox[{{19, 54}, {19, 50}}], LineBox[{{19, 58}, {19, 54}}], 
     LineBox[{{11, 68}, {15, 68}}], LineBox[{{11, 70}, {11, 68}}], 
     LineBox[{{11, 68}, {11, 64}}], LineBox[{{15, 64}, {19, 64}}], 
     LineBox[{{11, 64}, {15, 64}}], LineBox[{{11, 64}, {11, 60}}], 
     LineBox[{{11, 58}, {11, 54}}], LineBox[{{11, 60}, {11, 58}}], 
     LineBox[{{11, 60}, {15, 60}}], LineBox[{{15, 60}, {19, 60}}], 
     LineBox[{{19, 60}, {19, 58}}], LineBox[{{15, 58}, {19, 58}}], 
     LineBox[{{15, 58}, {15, 54}}], LineBox[{{15, 54}, {15, 50}}], 
     LineBox[{{15, 50}, {15, 48}}], LineBox[{{11, 50}, {15, 50}}], 
     LineBox[{{11, 50}, {11, 48}}], LineBox[{{11, 48}, {11, 44}}], 
     LineBox[{{11, 44}, {15, 44}}], LineBox[{{15, 44}, {19, 44}}], 
     LineBox[{{21, 44}, {21, 42}}], LineBox[{{21, 40}, {21, 38}}], 
     LineBox[{{21, 40}, {23, 40}}], LineBox[{{23, 40}, {25, 40}}], 
     LineBox[{{25, 42}, {25, 40}}], LineBox[{{27, 46}, {27, 44}}], 
     LineBox[{{25, 44}, {27, 44}}], LineBox[{{25, 44}, {25, 42}}], 
     LineBox[{{23, 42}, {25, 42}}], LineBox[{{21, 42}, {23, 42}}], 
     LineBox[{{19, 44}, {21, 42}}], LineBox[{{19, 44}, {19, 40}}], 
     LineBox[{{19, 40}, {19, 38}}], LineBox[{{19, 38}, {21, 36}}], 
     LineBox[{{21, 36}, {21, 34}}], LineBox[{{21, 34}, {23, 34}}], 
     LineBox[{{23, 34}, {25, 34}}], LineBox[{{25, 34}, {25, 32}}], 
     LineBox[{{25, 32}, {25, 30}}], LineBox[{{25, 30}, {25, 28}}], 
     LineBox[{{25, 28}, {27, 28}}], LineBox[{{23, 28}, {25, 28}}], 
     LineBox[{{23, 30}, {23, 28}}], LineBox[{{21, 30}, {23, 30}}], 
     LineBox[{{19, 30}, {21, 30}}], LineBox[{{19, 34}, {19, 30}}], 
     LineBox[{{15, 34}, {19, 34}}], LineBox[{{15, 34}, {15, 30}}], 
     LineBox[NCache[{{15, 30}, {Rational[49, 3], 28}}, {{15, 30}, {
        16.333333333333332`, 28}}]], 
     LineBox[NCache[{{Rational[49, 3], 28}, {19, 28}}, {{
        16.333333333333332`, 28}, {19, 28}}]], 
     LineBox[NCache[{{19, 28}, {19, Rational[76, 3]}}, {{19, 28}, {
        19, 25.333333333333332`}}]], 
     LineBox[NCache[{{19, Rational[76, 3]}, {19, Rational[68, 3]}}, {{
        19, 25.333333333333332`}, {19, 22.666666666666668`}}]], 
     LineBox[NCache[{{19, Rational[68, 3]}, {19, 20}}, {{
        19, 22.666666666666668`}, {19, 20}}]], 
     LineBox[NCache[{{Rational[49, 3], 20}, {19, 20}}, {{
        16.333333333333332`, 20}, {19, 20}}]], 
     LineBox[NCache[{{Rational[49, 3], 20}, {17, 18}}, {{
        16.333333333333332`, 20}, {17, 18}}]], LineBox[{{17, 18}, {17, 16}}], 
     LineBox[{{15, 18}, {17, 18}}], LineBox[{{15, 18}, {15, 16}}], 
     LineBox[{{15, 16}, {15, 14}}], LineBox[{{13, 12}, {15, 12}}], 
     LineBox[{{15, 14}, {15, 12}}], LineBox[{{13, 14}, {15, 14}}], 
     LineBox[{{13, 16}, {13, 14}}], LineBox[{{13, 18}, {13, 16}}], 
     LineBox[{{11, 20}, {13, 18}}], LineBox[{{11, 18}, {13, 18}}], 
     LineBox[{{11, 18}, {11, 16}}], LineBox[{{11, 16}, {11, 14}}], 
     LineBox[{{11, 14}, {11, 12}}], LineBox[{{11, 12}, {11, 10}}], 
     LineBox[{{11, 2}, {11, 0}}], LineBox[{{11, 4}, {11, 2}}], 
     LineBox[{{11, 4}, {13, 4}}], LineBox[{{13, 4}, {13, 2}}], 
     LineBox[{{13, 2}, {13, 0}}], LineBox[{{13, 0}, {15, 0}}], 
     LineBox[{{25, 0}, {27, 0}}], 
     LineBox[NCache[{{Rational[187, 5], Rational[8, 5]}, {
        Rational[187, 5], 0}}, {{37.4, 1.6}, {37.4, 0}}]], 
     LineBox[NCache[{{Rational[187, 5], 0}, {39, 0}}, {{37.4, 0}, {39, 0}}]], 
     LineBox[NCache[{{Rational[213, 5], 8}, {Rational[221, 5], 8}}, {{
        42.6, 8}, {44.2, 8}}]], 
     LineBox[NCache[{{41, 8}, {Rational[213, 5], 8}}, {{41, 8}, {42.6, 8}}]], 
     LineBox[NCache[{{41, 10}, {Rational[213, 5], 8}}, {{41, 10}, {
        42.6, 8}}]], 
     LineBox[NCache[{{Rational[213, 5], 8}, {
        Rational[213, 5], Rational[32, 5]}}, {{42.6, 8}, {42.6, 6.4}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[32, 5]}, {
        Rational[221, 5], Rational[24, 5]}}, {{44.2, 6.4}, {44.2, 4.8}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[32, 5]}, {
        Rational[229, 5], Rational[32, 5]}}, {{44.2, 6.4}, {45.8, 6.4}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[32, 5]}, {
        Rational[221, 5], Rational[32, 5]}}, {{42.6, 6.4}, {44.2, 6.4}}]], 
     LineBox[NCache[{{39, Rational[32, 5]}, {41, Rational[32, 5]}}, {{
        39, 6.4}, {41, 6.4}}]], 
     LineBox[NCache[{{41, Rational[32, 5]}, {
        Rational[213, 5], Rational[32, 5]}}, {{41, 6.4}, {42.6, 6.4}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[32, 5]}, {
        Rational[213, 5], Rational[24, 5]}}, {{42.6, 6.4}, {42.6, 4.8}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[16, 5]}, {
        Rational[229, 5], Rational[16, 5]}}, {{44.2, 3.2}, {45.8, 3.2}}]], 
     LineBox[NCache[{{Rational[221, 5], Rational[16, 5]}, {
        Rational[221, 5], Rational[8, 5]}}, {{44.2, 3.2}, {44.2, 1.6}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[16, 5]}, {
        Rational[221, 5], Rational[16, 5]}}, {{42.6, 3.2}, {44.2, 3.2}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[8, 5]}, {
        Rational[213, 5], 0}}, {{42.6, 1.6}, {42.6, 0}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[16, 5]}, {
        Rational[213, 5], Rational[8, 5]}}, {{42.6, 3.2}, {42.6, 1.6}}]], 
     LineBox[NCache[{{Rational[213, 5], Rational[24, 5]}, {
        Rational[213, 5], Rational[16, 5]}}, {{42.6, 4.8}, {42.6, 3.2}}]], 
     LineBox[NCache[{{41, Rational[24, 5]}, {
        Rational[213, 5], Rational[24, 5]}}, {{41, 4.8}, {42.6, 4.8}}]], 
     LineBox[NCache[{{39, Rational[24, 5]}, {41, Rational[24, 5]}}, {{
        39, 4.8}, {41, 4.8}}]], 
     LineBox[NCache[{{41, Rational[24, 5]}, {41, Rational[16, 5]}}, {{
        41, 4.8}, {41, 3.2}}]], 
     LineBox[NCache[{{41, Rational[16, 5]}, {41, Rational[8, 5]}}, {{
        41, 3.2}, {41, 1.6}}]], 
     LineBox[NCache[{{41, Rational[8, 5]}, {41, 0}}, {{41, 1.6}, {41, 0}}]], 
     LineBox[{{39, 0}, {41, 0}}], 
     LineBox[NCache[{{39, Rational[8, 5]}, {39, 0}}, {{39, 1.6}, {39, 0}}]], 
     LineBox[NCache[{{39, Rational[16, 5]}, {39, Rational[8, 5]}}, {{
        39, 3.2}, {39, 1.6}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[16, 5]}, {
        39, Rational[16, 5]}}, {{37.4, 3.2}, {39, 3.2}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[24, 5]}, {
        Rational[187, 5], Rational[16, 5]}}, {{37.4, 4.8}, {37.4, 3.2}}]], 
     LineBox[{{27, 14}, {27, 12}}], LineBox[{{27, 12}, {29, 12}}], 
     LineBox[{{27, 12}, {27, 10}}], LineBox[{{29, 10}, {31, 10}}], 
     LineBox[{{27, 10}, {29, 10}}], LineBox[{{27, 10}, {27, 8}}], 
     LineBox[{{27, 4}, {29, 4}}], LineBox[{{27, 6}, {27, 4}}], 
     LineBox[{{23, 6}, {25, 6}}], LineBox[{{25, 6}, {27, 6}}], 
     LineBox[{{27, 8}, {27, 6}}], LineBox[{{27, 8}, {29, 8}}], 
     LineBox[NCache[{{Rational[171, 5], 8}, {Rational[179, 5], 8}}, {{
        34.2, 8}, {35.8, 8}}]], 
     LineBox[NCache[{{Rational[101, 3], 10}, {Rational[171, 5], 8}}, {{
        33.666666666666664`, 10}, {34.2, 8}}]], 
     LineBox[NCache[{{Rational[163, 5], 8}, {Rational[171, 5], 8}}, {{
        32.6, 8}, {34.2, 8}}]], 
     LineBox[NCache[{{31, 8}, {Rational[163, 5], 8}}, {{31, 8}, {32.6, 8}}]], 
     LineBox[{{29, 8}, {31, 8}}], LineBox[{{29, 8}, {29, 6}}], 
     LineBox[NCache[{{29, 6}, {31, Rational[24, 5]}}, {{29, 6}, {31, 4.8}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[16, 5]}, {
        Rational[171, 5], Rational[8, 5]}}, {{34.2, 3.2}, {34.2, 1.6}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[24, 5]}, {
        Rational[171, 5], Rational[16, 5]}}, {{34.2, 4.8}, {34.2, 3.2}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[24, 5]}, {
        Rational[171, 5], Rational[24, 5]}}, {{32.6, 4.8}, {34.2, 4.8}}]], 
     LineBox[NCache[{{31, Rational[24, 5]}, {
        Rational[163, 5], Rational[24, 5]}}, {{31, 4.8}, {32.6, 4.8}}]], 
     LineBox[NCache[{{31, Rational[32, 5]}, {31, Rational[24, 5]}}, {{
        31, 6.4}, {31, 4.8}}]], 
     LineBox[NCache[{{31, Rational[32, 5]}, {
        Rational[163, 5], Rational[32, 5]}}, {{31, 6.4}, {32.6, 6.4}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[32, 5]}, {
        Rational[171, 5], Rational[32, 5]}}, {{32.6, 6.4}, {34.2, 6.4}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[32, 5]}, {
        Rational[179, 5], Rational[32, 5]}}, {{34.2, 6.4}, {35.8, 6.4}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[32, 5]}, {
        Rational[187, 5], Rational[32, 5]}}, {{35.8, 6.4}, {37.4, 6.4}}]], 
     LineBox[{{25, 16}, {25, 14}}], LineBox[{{23, 16}, {25, 16}}], 
     LineBox[{{25, 16}, {27, 16}}], LineBox[{{27, 18}, {29, 18}}], 
     LineBox[{{27, 18}, {27, 16}}], LineBox[{{27, 16}, {29, 16}}], 
     LineBox[NCache[{{31, 20}, {Rational[101, 3], 18}}, {{31, 20}, {
        33.666666666666664`, 18}}]], LineBox[{{31, 24}, {31, 20}}], 
     LineBox[{{31, 20}, {35, 20}}], LineBox[{{31, 20}, {31, 18}}], 
     LineBox[{{29, 16}, {31, 18}}], LineBox[{{29, 16}, {29, 14}}], 
     LineBox[NCache[{{29, 14}, {31, Rational[46, 3]}}, {{29, 14}, {
        31, 15.333333333333334`}}]], 
     LineBox[NCache[{{41, Rational[46, 3]}, {41, Rational[38, 3]}}, {{
        41, 15.333333333333334`}, {41, 12.666666666666666`}}]], 
     LineBox[NCache[{{41, 18}, {41, Rational[46, 3]}}, {{41, 18}, {
        41, 15.333333333333334`}}]], 
     LineBox[NCache[{{41, Rational[46, 3]}, {
        Rational[131, 3], Rational[46, 3]}}, {{41, 15.333333333333334`}, {
        43.666666666666664`, 15.333333333333334`}}]], 
     LineBox[NCache[{{39, Rational[46, 3]}, {41, Rational[46, 3]}}, {{
        39, 15.333333333333334`}, {41, 15.333333333333334`}}]], 
     LineBox[NCache[{{39, Rational[38, 3]}, {39, 10}}, {{
        39, 12.666666666666666`}, {39, 10}}]], 
     LineBox[NCache[{{39, Rational[46, 3]}, {39, Rational[38, 3]}}, {{
        39, 15.333333333333334`}, {39, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[109, 3], 18}, {39, 18}}, {{
        36.333333333333336`, 18}, {39, 18}}]], LineBox[{{39, 20}, {39, 18}}], 
     LineBox[NCache[{{39, 18}, {39, Rational[46, 3]}}, {{39, 18}, {
        39, 15.333333333333334`}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[46, 3]}, {
        39, Rational[46, 3]}}, {{36.333333333333336`, 15.333333333333334`}, {
        39, 15.333333333333334`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[46, 3]}, {
        Rational[109, 3], Rational[46, 3]}}, {{33.666666666666664`, 
       15.333333333333334`}, {36.333333333333336`, 15.333333333333334`}}]], 
     LineBox[NCache[{{31, Rational[46, 3]}, {
        Rational[101, 3], Rational[46, 3]}}, {{31, 15.333333333333334`}, {
        33.666666666666664`, 15.333333333333334`}}]], 
     LineBox[NCache[{{31, Rational[46, 3]}, {31, Rational[38, 3]}}, {{
        31, 15.333333333333334`}, {31, 12.666666666666666`}}]], 
     LineBox[NCache[{{31, Rational[38, 3]}, {
        Rational[101, 3], Rational[38, 3]}}, {{31, 12.666666666666666`}, {
        33.666666666666664`, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[38, 3]}, {
        Rational[109, 3], Rational[38, 3]}}, {{33.666666666666664`, 
       12.666666666666666`}, {36.333333333333336`, 12.666666666666666`}}]], 
     LineBox[
      NCache[{{Rational[109, 3], Rational[38, 3]}, {Rational[109, 3], 10}}, {{
        36.333333333333336`, 12.666666666666666`}, {
        36.333333333333336`, 10}}]], 
     LineBox[NCache[{{Rational[109, 3], 10}, {Rational[187, 5], 8}}, {{
        36.333333333333336`, 10}, {37.4, 8}}]], 
     LineBox[NCache[{{Rational[187, 5], 8}, {39, 8}}, {{37.4, 8}, {39, 8}}]], 
     LineBox[NCache[{{Rational[187, 5], 8}, {
        Rational[187, 5], Rational[32, 5]}}, {{37.4, 8}, {37.4, 6.4}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[32, 5]}, {
        Rational[187, 5], Rational[24, 5]}}, {{37.4, 6.4}, {37.4, 4.8}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[24, 5]}, {
        Rational[187, 5], Rational[24, 5]}}, {{35.8, 4.8}, {37.4, 4.8}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[24, 5]}, {
        Rational[179, 5], Rational[16, 5]}}, {{35.8, 4.8}, {35.8, 3.2}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[16, 5]}, {
        Rational[179, 5], Rational[8, 5]}}, {{35.8, 3.2}, {35.8, 1.6}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[8, 5]}, {
        Rational[179, 5], 0}}, {{35.8, 1.6}, {35.8, 0}}]], 
     LineBox[NCache[{{Rational[171, 5], 0}, {Rational[179, 5], 0}}, {{
        34.2, 0}, {35.8, 0}}]], 
     LineBox[NCache[{{Rational[163, 5], 0}, {Rational[171, 5], 0}}, {{
        32.6, 0}, {34.2, 0}}]], 
     LineBox[NCache[{{31, 0}, {Rational[163, 5], 0}}, {{31, 0}, {32.6, 0}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[8, 5]}, {
        Rational[163, 5], 0}}, {{32.6, 1.6}, {32.6, 0}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[16, 5]}, {
        Rational[163, 5], Rational[8, 5]}}, {{32.6, 3.2}, {32.6, 1.6}}]], 
     LineBox[NCache[{{31, Rational[16, 5]}, {
        Rational[163, 5], Rational[16, 5]}}, {{31, 3.2}, {32.6, 3.2}}]], 
     LineBox[NCache[{{31, Rational[16, 5]}, {31, Rational[8, 5]}}, {{
        31, 3.2}, {31, 1.6}}]], 
     LineBox[NCache[{{29, 2}, {31, Rational[8, 5]}}, {{29, 2}, {31, 1.6}}]], 
     LineBox[{{29, 2}, {29, 0}}], LineBox[{{27, 0}, {29, 0}}], 
     LineBox[{{27, 2}, {27, 0}}], LineBox[{{25, 2}, {27, 2}}], 
     LineBox[{{25, 4}, {25, 2}}], LineBox[{{23, 4}, {25, 4}}], 
     LineBox[{{21, 4}, {21, 2}}], LineBox[{{21, 4}, {23, 4}}], 
     LineBox[{{23, 4}, {23, 2}}], LineBox[{{23, 2}, {23, 0}}], 
     LineBox[{{21, 0}, {23, 0}}], LineBox[{{19, 0}, {21, 0}}], 
     LineBox[{{17, 0}, {19, 0}}], LineBox[{{15, 0}, {17, 0}}], 
     LineBox[{{15, 2}, {15, 0}}], LineBox[{{15, 2}, {17, 2}}], 
     LineBox[{{17, 2}, {19, 2}}], LineBox[{{19, 4}, {19, 2}}], 
     LineBox[{{17, 4}, {19, 4}}], LineBox[{{15, 4}, {17, 4}}], 
     LineBox[{{15, 6}, {15, 4}}], LineBox[{{15, 8}, {15, 6}}], 
     LineBox[{{13, 8}, {15, 8}}], LineBox[{{13, 8}, {13, 6}}], 
     LineBox[{{11, 6}, {13, 6}}], LineBox[{{11, 8}, {11, 6}}], 
     LineBox[{{11, 10}, {11, 8}}], LineBox[{{11, 10}, {13, 10}}], 
     LineBox[{{13, 10}, {15, 10}}], LineBox[{{15, 10}, {17, 10}}], 
     LineBox[{{17, 10}, {19, 10}}], LineBox[{{19, 10}, {19, 8}}], 
     LineBox[{{17, 8}, {19, 8}}], LineBox[{{17, 8}, {17, 6}}], 
     LineBox[{{17, 6}, {19, 6}}], LineBox[{{19, 6}, {21, 6}}], 
     LineBox[{{21, 8}, {21, 6}}], LineBox[{{21, 8}, {23, 8}}], 
     LineBox[{{23, 8}, {25, 8}}], LineBox[{{25, 10}, {25, 8}}], 
     LineBox[{{25, 12}, {25, 10}}], LineBox[{{23, 12}, {25, 12}}], 
     LineBox[{{23, 14}, {23, 12}}], LineBox[{{23, 12}, {23, 10}}], 
     LineBox[{{21, 10}, {23, 10}}], LineBox[{{21, 12}, {21, 10}}], 
     LineBox[{{19, 12}, {21, 12}}], LineBox[{{17, 12}, {19, 12}}], 
     LineBox[{{17, 14}, {17, 12}}], LineBox[{{17, 14}, {19, 14}}], 
     LineBox[{{19, 14}, {21, 14}}], LineBox[{{21, 16}, {21, 14}}], 
     LineBox[{{19, 16}, {21, 16}}], LineBox[{{19, 18}, {19, 16}}], 
     LineBox[{{19, 18}, {21, 18}}], LineBox[{{21, 20}, {21, 18}}], 
     LineBox[{{21, 22}, {21, 20}}], LineBox[{{21, 22}, {23, 22}}], 
     LineBox[{{23, 22}, {23, 20}}], LineBox[{{23, 20}, {23, 18}}], 
     LineBox[{{23, 18}, {25, 18}}], LineBox[{{25, 20}, {25, 18}}], 
     LineBox[{{25, 20}, {27, 20}}], LineBox[{{27, 20}, {29, 20}}], 
     LineBox[{{29, 22}, {29, 20}}], LineBox[{{27, 24}, {29, 24}}], 
     LineBox[{{29, 24}, {29, 22}}], LineBox[{{27, 22}, {29, 22}}], 
     LineBox[{{25, 22}, {27, 22}}], LineBox[{{25, 24}, {25, 22}}], 
     LineBox[{{25, 26}, {25, 24}}], LineBox[{{25, 26}, {27, 26}}], 
     LineBox[{{27, 26}, {29, 26}}], 
     LineBox[NCache[{{Rational[101, 3], 40}, {31, 38}}, {{
        33.666666666666664`, 40}, {31, 38}}]], 
     LineBox[NCache[{{31, 40}, {Rational[101, 3], 40}}, {{31, 40}, {
        33.666666666666664`, 40}}]], LineBox[{{29, 40}, {31, 40}}], 
     LineBox[{{29, 40}, {29, 38}}], LineBox[{{29, 38}, {29, 36}}], 
     LineBox[{{29, 36}, {29, 34}}], LineBox[{{29, 34}, {29, 32}}], 
     LineBox[{{29, 34}, {31, 34}}], LineBox[{{31, 34}, {31, 30}}], 
     LineBox[{{31, 30}, {35, 30}}], LineBox[{{61, 20}, {63, 20}}], 
     LineBox[{{63, 20}, {63, 18}}], LineBox[{{61, 18}, {63, 18}}], 
     LineBox[{{59, 18}, {61, 18}}], 
     LineBox[NCache[{{Rational[229, 5], Rational[24, 5]}, {
        Rational[237, 5], Rational[24, 5]}}, {{45.8, 4.8}, {47.4, 4.8}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[32, 5]}, {
        Rational[237, 5], Rational[24, 5]}}, {{47.4, 6.4}, {47.4, 4.8}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[24, 5]}, {
        Rational[237, 5], Rational[16, 5]}}, {{47.4, 4.8}, {47.4, 3.2}}]], 
     LineBox[NCache[{{Rational[237, 5], Rational[16, 5]}, {
        Rational[237, 5], Rational[8, 5]}}, {{47.4, 3.2}, {47.4, 1.6}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[8, 5]}, {
        Rational[237, 5], Rational[8, 5]}}, {{45.8, 1.6}, {47.4, 1.6}}]], 
     LineBox[NCache[{{Rational[229, 5], Rational[8, 5]}, {
        Rational[229, 5], 0}}, {{45.8, 1.6}, {45.8, 0}}]], 
     LineBox[NCache[{{Rational[221, 5], 0}, {Rational[229, 5], 0}}, {{
        44.2, 0}, {45.8, 0}}]], 
     LineBox[NCache[{{Rational[229, 5], 0}, {Rational[237, 5], 0}}, {{
        45.8, 0}, {47.4, 0}}]], 
     LineBox[NCache[{{Rational[237, 5], 0}, {49, 0}}, {{47.4, 0}, {49, 0}}]], 
     LineBox[{{49, 0}, {51, 0}}], 
     LineBox[NCache[{{69, 8}, {69, Rational[16, 3]}}, {{69, 8}, {
        69, 5.333333333333333}}]], 
     LineBox[NCache[{{Rational[199, 3], Rational[16, 3]}, {
        69, Rational[16, 3]}}, {{66.33333333333333, 5.333333333333333}, {
        69, 5.333333333333333}}]], 
     LineBox[NCache[{{Rational[191, 3], Rational[16, 3]}, {
        Rational[199, 3], Rational[16, 3]}}, {{63.666666666666664`, 
       5.333333333333333}, {66.33333333333333, 5.333333333333333}}]], 
     LineBox[NCache[{{Rational[199, 3], Rational[16, 3]}, {
        Rational[199, 3], Rational[8, 3]}}, {{66.33333333333333, 
       5.333333333333333}, {66.33333333333333, 2.6666666666666665`}}]], 
     LineBox[NCache[{{Rational[199, 3], Rational[8, 3]}, {
        69, Rational[8, 3]}}, {{66.33333333333333, 2.6666666666666665`}, {
        69, 2.6666666666666665`}}]], 
     LineBox[NCache[{{69, Rational[8, 3]}, {69, 0}}, {{
        69, 2.6666666666666665`}, {69, 0}}]], 
     LineBox[NCache[{{Rational[199, 3], 0}, {69, 0}}, {{
        66.33333333333333, 0}, {69, 0}}]], 
     LineBox[NCache[{{Rational[191, 3], 0}, {Rational[199, 3], 0}}, {{
        63.666666666666664`, 0}, {66.33333333333333, 0}}]], 
     LineBox[NCache[{{59, Rational[16, 5]}, {59, Rational[8, 5]}}, {{
        59, 3.2}, {59, 1.6}}]], 
     LineBox[NCache[{{Rational[287, 5], Rational[16, 5]}, {
        59, Rational[16, 5]}}, {{57.4, 3.2}, {59, 3.2}}]], 
     LineBox[NCache[{{Rational[287, 5], Rational[24, 5]}, {
        Rational[287, 5], Rational[16, 5]}}, {{57.4, 4.8}, {57.4, 3.2}}]], 
     LineBox[NCache[{{Rational[279, 5], Rational[16, 5]}, {
        Rational[287, 5], Rational[16, 5]}}, {{55.8, 3.2}, {57.4, 3.2}}]], 
     LineBox[NCache[{{Rational[271, 5], Rational[16, 5]}, {
        Rational[279, 5], Rational[16, 5]}}, {{54.2, 3.2}, {55.8, 3.2}}]], 
     LineBox[NCache[{{Rational[271, 5], Rational[16, 5]}, {
        Rational[271, 5], Rational[8, 5]}}, {{54.2, 3.2}, {54.2, 1.6}}]], 
     LineBox[NCache[{{Rational[271, 5], Rational[8, 5]}, {
        Rational[271, 5], 0}}, {{54.2, 1.6}, {54.2, 0}}]], 
     LineBox[NCache[{{Rational[271, 5], 0}, {Rational[279, 5], 0}}, {{
        54.2, 0}, {55.8, 0}}]], 
     LineBox[NCache[{{Rational[279, 5], Rational[8, 5]}, {
        Rational[279, 5], 0}}, {{55.8, 1.6}, {55.8, 0}}]], 
     LineBox[
      NCache[{{Rational[279, 5], Rational[8, 5]}, {
        Rational[287, 5], Rational[8, 5]}}, {{55.8, 1.6}, {57.4, 1.6}}]], 
     LineBox[NCache[{{Rational[287, 5], Rational[8, 5]}, {
        Rational[287, 5], 0}}, {{57.4, 1.6}, {57.4, 0}}]], 
     LineBox[NCache[{{Rational[287, 5], 0}, {59, 0}}, {{57.4, 0}, {59, 0}}]], 
     LineBox[{{59, 0}, {61, 0}}], 
     LineBox[NCache[{{61, 0}, {Rational[191, 3], 0}}, {{61, 0}, {
        63.666666666666664`, 0}}]], 
     LineBox[NCache[{{Rational[191, 3], Rational[8, 3]}, {
        Rational[191, 3], 0}}, {{63.666666666666664`, 2.6666666666666665`}, {
        63.666666666666664`, 0}}]], 
     LineBox[NCache[{{61, Rational[8, 3]}, {
        Rational[191, 3], Rational[8, 3]}}, {{61, 2.6666666666666665`}, {
        63.666666666666664`, 2.6666666666666665`}}]], 
     LineBox[NCache[{{61, Rational[16, 3]}, {61, Rational[8, 3]}}, {{
        61, 5.333333333333333}, {61, 2.6666666666666665`}}]], 
     LineBox[NCache[{{59, Rational[24, 5]}, {61, Rational[16, 3]}}, {{
        59, 4.8}, {61, 5.333333333333333}}]], 
     LineBox[NCache[{{59, Rational[32, 5]}, {59, Rational[24, 5]}}, {{
        59, 6.4}, {59, 4.8}}]], 
     LineBox[NCache[{{Rational[287, 5], Rational[32, 5]}, {
        59, Rational[32, 5]}}, {{57.4, 6.4}, {59, 6.4}}]], 
     LineBox[{{59, 12}, {61, 12}}], LineBox[{{59, 14}, {59, 12}}], 
     LineBox[{{57, 12}, {59, 12}}], LineBox[{{55, 12}, {57, 12}}], 
     LineBox[{{55, 12}, {55, 10}}], 
     LineBox[NCache[{{55, 10}, {Rational[279, 5], 8}}, {{55, 10}, {
        55.8, 8}}]], LineBox[{{55, 10}, {57, 10}}], 
     LineBox[NCache[{{57, 10}, {Rational[287, 5], 8}}, {{57, 10}, {
        57.4, 8}}]], 
     LineBox[NCache[{{Rational[287, 5], 8}, {
        Rational[287, 5], Rational[32, 5]}}, {{57.4, 8}, {57.4, 6.4}}]], 
     LineBox[NCache[{{Rational[279, 5], Rational[32, 5]}, {
        Rational[287, 5], Rational[32, 5]}}, {{55.8, 6.4}, {57.4, 6.4}}]], 
     LineBox[NCache[{{Rational[279, 5], Rational[32, 5]}, {
        Rational[279, 5], Rational[24, 5]}}, {{55.8, 6.4}, {55.8, 4.8}}]], 
     LineBox[NCache[{{Rational[271, 5], Rational[24, 5]}, {
        Rational[279, 5], Rational[24, 5]}}, {{54.2, 4.8}, {55.8, 4.8}}]], 
     LineBox[NCache[{{Rational[263, 5], Rational[24, 5]}, {
        Rational[271, 5], Rational[24, 5]}}, {{52.6, 4.8}, {54.2, 4.8}}]], 
     LineBox[NCache[{{51, Rational[24, 5]}, {
        Rational[263, 5], Rational[24, 5]}}, {{51, 4.8}, {52.6, 4.8}}]], 
     LineBox[NCache[{{51, Rational[24, 5]}, {51, Rational[16, 5]}}, {{
        51, 4.8}, {51, 3.2}}]], 
     LineBox[NCache[{{51, Rational[16, 5]}, {
        Rational[263, 5], Rational[16, 5]}}, {{51, 3.2}, {52.6, 3.2}}]], 
     LineBox[NCache[{{Rational[263, 5], Rational[16, 5]}, {
        Rational[263, 5], Rational[8, 5]}}, {{52.6, 3.2}, {52.6, 1.6}}]], 
     LineBox[NCache[{{Rational[263, 5], Rational[8, 5]}, {
        Rational[263, 5], 0}}, {{52.6, 1.6}, {52.6, 0}}]], 
     LineBox[NCache[{{51, 0}, {Rational[263, 5], 0}}, {{51, 0}, {52.6, 0}}]], 
     LineBox[NCache[{{51, Rational[8, 5]}, {51, 0}}, {{51, 1.6}, {51, 0}}]], 
     LineBox[NCache[{{49, Rational[8, 5]}, {51, Rational[8, 5]}}, {{
        49, 1.6}, {51, 1.6}}]], 
     LineBox[NCache[{{49, Rational[16, 5]}, {49, Rational[8, 5]}}, {{
        49, 3.2}, {49, 1.6}}]], 
     LineBox[NCache[{{49, Rational[24, 5]}, {49, Rational[16, 5]}}, {{
        49, 4.8}, {49, 3.2}}]], 
     LineBox[NCache[{{49, Rational[32, 5]}, {49, Rational[24, 5]}}, {{
        49, 6.4}, {49, 4.8}}]], 
     LineBox[NCache[{{49, Rational[32, 5]}, {51, Rational[32, 5]}}, {{
        49, 6.4}, {51, 6.4}}]], 
     LineBox[NCache[{{51, 8}, {51, Rational[32, 5]}}, {{51, 8}, {51, 6.4}}]], 
     LineBox[{{49, 8}, {51, 8}}], 
     LineBox[NCache[{{Rational[237, 5], 8}, {49, 8}}, {{47.4, 8}, {49, 8}}]], 
     LineBox[NCache[{{Rational[229, 5], 8}, {Rational[237, 5], 8}}, {{
        45.8, 8}, {47.4, 8}}]], 
     LineBox[NCache[{{Rational[139, 3], 10}, {Rational[237, 5], 8}}, {{
        46.333333333333336`, 10}, {47.4, 8}}]], 
     LineBox[NCache[{{41, 20}, {Rational[131, 3], 18}}, {{41, 20}, {
        43.666666666666664`, 18}}]], 
     LineBox[NCache[{{Rational[131, 3], 18}, {Rational[139, 3], 18}}, {{
        43.666666666666664`, 18}, {46.333333333333336`, 18}}]], 
     LineBox[
      NCache[{{Rational[139, 3], 18}, {49, 18}}, {{46.333333333333336`, 18}, {
        49, 18}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[64, 3]}, {
        Rational[173, 3], 20}}, {{57.666666666666664`, 21.333333333333332`}, {
        57.666666666666664`, 20}}]], 
     LineBox[NCache[{{Rational[157, 3], 20}, {Rational[161, 3], 20}}, {{
        52.333333333333336`, 20}, {53.666666666666664`, 20}}]], 
     LineBox[NCache[{{Rational[161, 3], 20}, {55, 20}}, {{
        53.666666666666664`, 20}, {55, 20}}]], 
     LineBox[NCache[{{55, 20}, {Rational[169, 3], 20}}, {{55, 20}, {
        56.333333333333336`, 20}}]], 
     LineBox[NCache[{{Rational[169, 3], 20}, {Rational[173, 3], 20}}, {{
        56.333333333333336`, 20}, {57.666666666666664`, 20}}]], 
     LineBox[NCache[{{Rational[173, 3], 20}, {57, 18}}, {{
        57.666666666666664`, 20}, {57, 18}}]], LineBox[{{55, 18}, {57, 18}}], 
     LineBox[{{55, 18}, {55, 16}}], LineBox[{{53, 16}, {55, 16}}], 
     LineBox[{{53, 18}, {53, 16}}], LineBox[{{51, 18}, {53, 18}}], 
     LineBox[{{51, 18}, {51, 16}}], 
     LineBox[NCache[{{49, Rational[38, 3]}, {51, 12}}, {{
        49, 12.666666666666666`}, {51, 12}}]], LineBox[{{51, 14}, {51, 12}}], 
     LineBox[{{51, 16}, {51, 14}}], LineBox[{{49, 18}, {51, 16}}], 
     LineBox[NCache[{{49, 18}, {49, Rational[46, 3]}}, {{49, 18}, {
        49, 15.333333333333334`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[46, 3]}, {
        49, Rational[46, 3]}}, {{46.333333333333336`, 15.333333333333334`}, {
        49, 15.333333333333334`}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[46, 3]}, {
        Rational[139, 3], Rational[38, 3]}}, {{46.333333333333336`, 
       15.333333333333334`}, {46.333333333333336`, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[38, 3]}, {
        Rational[139, 3], Rational[38, 3]}}, {{43.666666666666664`, 
       12.666666666666666`}, {46.333333333333336`, 12.666666666666666`}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[38, 3]}, {
        Rational[131, 3], 10}}, {{43.666666666666664`, 12.666666666666666`}, {
        43.666666666666664`, 10}}]], 
     LineBox[NCache[{{Rational[131, 3], 10}, {Rational[139, 3], 10}}, {{
        43.666666666666664`, 10}, {46.333333333333336`, 10}}]], 
     LineBox[NCache[{{Rational[139, 3], 10}, {49, 10}}, {{
        46.333333333333336`, 10}, {49, 10}}]], LineBox[{{49, 10}, {51, 10}}], 
     LineBox[NCache[{{51, 10}, {Rational[263, 5], 8}}, {{51, 10}, {
        52.6, 8}}]], 
     LineBox[NCache[{{Rational[263, 5], 8}, {
        Rational[263, 5], Rational[32, 5]}}, {{52.6, 8}, {52.6, 6.4}}]], 
     LineBox[NCache[{{Rational[263, 5], Rational[32, 5]}, {
        Rational[271, 5], Rational[32, 5]}}, {{52.6, 6.4}, {54.2, 6.4}}]], 
     LineBox[NCache[{{Rational[271, 5], 8}, {
        Rational[271, 5], Rational[32, 5]}}, {{54.2, 8}, {54.2, 6.4}}]], 
     LineBox[NCache[{{53, 10}, {Rational[271, 5], 8}}, {{53, 10}, {
        54.2, 8}}]], LineBox[{{53, 12}, {53, 10}}], 
     LineBox[{{53, 14}, {53, 12}}], LineBox[{{53, 14}, {55, 14}}], 
     LineBox[{{55, 14}, {57, 14}}], LineBox[{{57, 16}, {57, 14}}], 
     LineBox[{{57, 16}, {59, 16}}], LineBox[{{59, 18}, {59, 16}}], 
     LineBox[{{59, 20}, {59, 18}}], 
     LineBox[NCache[{{59, Rational[64, 3]}, {59, 20}}, {{
        59, 21.333333333333332`}, {59, 20}}]], 
     LineBox[NCache[{{59, Rational[68, 3]}, {59, Rational[64, 3]}}, {{
        59, 22.666666666666668`}, {59, 21.333333333333332`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[68, 3]}, {
        59, Rational[68, 3]}}, {{57.666666666666664`, 22.666666666666668`}, {
        59, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[68, 3]}, {
        Rational[173, 3], Rational[68, 3]}}, {{56.333333333333336`, 
       22.666666666666668`}, {57.666666666666664`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[76, 3]}, {
        Rational[157, 3], 24}}, {{52.333333333333336`, 25.333333333333332`}, {
        52.333333333333336`, 24}}]], 
     LineBox[NCache[{{Rational[157, 3], 24}, {
        Rational[157, 3], Rational[68, 3]}}, {{52.333333333333336`, 24}, {
        52.333333333333336`, 22.666666666666668`}}]], 
     LineBox[
      NCache[{{Rational[157, 3], Rational[68, 3]}, {
        Rational[161, 3], Rational[68, 3]}}, {{52.333333333333336`, 
       22.666666666666668`}, {53.666666666666664`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[68, 3]}, {
        55, Rational[68, 3]}}, {{53.666666666666664`, 22.666666666666668`}, {
        55, 22.666666666666668`}}]], 
     LineBox[NCache[{{55, Rational[68, 3]}, {
        Rational[169, 3], Rational[68, 3]}}, {{55, 22.666666666666668`}, {
        56.333333333333336`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[169, 3], 24}, {
        Rational[169, 3], Rational[68, 3]}}, {{56.333333333333336`, 24}, {
        56.333333333333336`, 22.666666666666668`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[68, 3]}, {
        Rational[169, 3], Rational[64, 3]}}, {{56.333333333333336`, 
       22.666666666666668`}, {56.333333333333336`, 21.333333333333332`}}]], 
     LineBox[NCache[{{55, Rational[64, 3]}, {
        Rational[169, 3], Rational[64, 3]}}, {{55, 21.333333333333332`}, {
        56.333333333333336`, 21.333333333333332`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[64, 3]}, {
        55, Rational[64, 3]}}, {{53.666666666666664`, 21.333333333333332`}, {
        55, 21.333333333333332`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[64, 3]}, {
        Rational[161, 3], Rational[64, 3]}}, {{52.333333333333336`, 
       21.333333333333332`}, {53.666666666666664`, 21.333333333333332`}}]], 
     LineBox[NCache[{{51, Rational[64, 3]}, {
        Rational[157, 3], Rational[64, 3]}}, {{51, 21.333333333333332`}, {
        52.333333333333336`, 21.333333333333332`}}]], 
     LineBox[NCache[{{51, Rational[64, 3]}, {51, 20}}, {{
        51, 21.333333333333332`}, {51, 20}}]], LineBox[{{49, 20}, {51, 20}}], 
     LineBox[{{45, 20}, {49, 20}}], LineBox[{{45, 24}, {45, 20}}], 
     LineBox[{{41, 24}, {45, 24}}], LineBox[{{35, 24}, {39, 24}}], 
     LineBox[{{39, 24}, {41, 24}}], LineBox[{{41, 28}, {41, 24}}], 
     LineBox[{{41, 30}, {41, 28}}], LineBox[{{39, 28}, {41, 28}}], 
     LineBox[{{39, 30}, {39, 28}}], LineBox[{{35, 30}, {39, 30}}], 
     LineBox[{{35, 30}, {35, 28}}], LineBox[{{31, 28}, {35, 28}}], 
     LineBox[{{29, 26}, {31, 28}}], LineBox[{{29, 28}, {29, 26}}], 
     LineBox[{{29, 30}, {29, 28}}], LineBox[{{27, 30}, {29, 30}}], 
     LineBox[{{27, 32}, {27, 30}}], LineBox[{{27, 34}, {27, 32}}], 
     LineBox[{{27, 36}, {27, 34}}], LineBox[{{25, 36}, {27, 36}}], 
     LineBox[{{23, 36}, {25, 36}}], LineBox[{{23, 38}, {23, 36}}], 
     LineBox[{{23, 38}, {25, 38}}], LineBox[{{25, 38}, {27, 38}}], 
     LineBox[{{27, 40}, {27, 38}}], LineBox[{{27, 42}, {27, 40}}], 
     LineBox[{{27, 42}, {29, 42}}], 
     LineBox[NCache[{{29, 42}, {31, Rational[128, 3]}}, {{29, 42}, {
        31, 42.666666666666664`}}]], 
     LineBox[NCache[{{31, Rational[128, 3]}, {
        Rational[101, 3], Rational[128, 3]}}, {{31, 42.666666666666664`}, {
        33.666666666666664`, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[136, 3]}, {
        Rational[101, 3], Rational[128, 3]}}, {{33.666666666666664`, 
       45.333333333333336`}, {33.666666666666664`, 42.666666666666664`}}]], 
     LineBox[NCache[{{31, Rational[136, 3]}, {
        Rational[101, 3], Rational[136, 3]}}, {{31, 45.333333333333336`}, {
        33.666666666666664`, 45.333333333333336`}}]], 
     LineBox[NCache[{{29, 44}, {31, Rational[136, 3]}}, {{29, 44}, {
        31, 45.333333333333336`}}]], LineBox[{{29, 46}, {29, 44}}], 
     LineBox[{{29, 46}, {31, 48}}], 
     LineBox[NCache[{{Rational[163, 5], 50}, {31, 48}}, {{32.6, 50}, {31, 
        48}}]], LineBox[
      NCache[{{Rational[163, 5], Rational[258, 5]}, {
        Rational[163, 5], 50}}, {{32.6, 51.6}, {32.6, 50}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[266, 5]}, {
        Rational[163, 5], Rational[258, 5]}}, {{32.6, 53.2}, {32.6, 51.6}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[274, 5]}, {
        Rational[163, 5], Rational[266, 5]}}, {{32.6, 54.8}, {32.6, 53.2}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[282, 5]}, {
        Rational[163, 5], Rational[274, 5]}}, {{32.6, 56.4}, {32.6, 54.8}}]], 
     LineBox[NCache[{{Rational[163, 5], Rational[282, 5]}, {
        Rational[171, 5], Rational[282, 5]}}, {{32.6, 56.4}, {34.2, 56.4}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[184, 3]}, {
        Rational[101, 3], 60}}, {{33.666666666666664`, 61.333333333333336`}, {
        33.666666666666664`, 60}}]], 
     LineBox[NCache[{{Rational[101, 3], 64}, {35, 64}}, {{
        33.666666666666664`, 64}, {35, 64}}]], 
     LineBox[NCache[{{35, Rational[196, 3]}, {35, 64}}, {{
        35, 65.33333333333333}, {35, 64}}]], 
     LineBox[NCache[{{35, Rational[196, 3]}, {
        Rational[109, 3], Rational[196, 3]}}, {{35, 65.33333333333333}, {
        36.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[196, 3]}, {
        35, Rational[196, 3]}}, {{33.666666666666664`, 65.33333333333333}, {
        35, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[97, 3], Rational[196, 3]}, {
        Rational[101, 3], Rational[196, 3]}}, {{32.333333333333336`, 
       65.33333333333333}, {33.666666666666664`, 65.33333333333333}}]], 
     LineBox[NCache[{{31, Rational[200, 3]}, {
        Rational[97, 3], Rational[200, 3]}}, {{31, 66.66666666666667}, {
        32.333333333333336`, 66.66666666666667}}]], 
     LineBox[NCache[{{31, Rational[200, 3]}, {31, Rational[196, 3]}}, {{
        31, 66.66666666666667}, {31, 65.33333333333333}}]], 
     LineBox[NCache[{{31, Rational[196, 3]}, {
        Rational[97, 3], Rational[196, 3]}}, {{31, 65.33333333333333}, {
        32.333333333333336`, 65.33333333333333}}]], 
     LineBox[NCache[{{Rational[97, 3], Rational[196, 3]}, {
        Rational[97, 3], 64}}, {{32.333333333333336`, 65.33333333333333}, {
        32.333333333333336`, 64}}]], 
     LineBox[NCache[{{Rational[97, 3], 64}, {
        Rational[97, 3], Rational[188, 3]}}, {{32.333333333333336`, 64}, {
        32.333333333333336`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[97, 3], Rational[188, 3]}, {
        Rational[101, 3], Rational[188, 3]}}, {{32.333333333333336`, 
       62.666666666666664`}, {33.666666666666664`, 62.666666666666664`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[188, 3]}, {
        Rational[101, 3], Rational[184, 3]}}, {{33.666666666666664`, 
       62.666666666666664`}, {33.666666666666664`, 61.333333333333336`}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[184, 3]}, {
        35, Rational[184, 3]}}, {{33.666666666666664`, 61.333333333333336`}, {
        35, 61.333333333333336`}}]], 
     LineBox[NCache[{{35, Rational[184, 3]}, {35, 60}}, {{
        35, 61.333333333333336`}, {35, 60}}]], 
     LineBox[NCache[{{35, 60}, {Rational[109, 3], 60}}, {{35, 60}, {
        36.333333333333336`, 60}}]], 
     LineBox[NCache[{{Rational[109, 3], 60}, {Rational[179, 5], 58}}, {{
        36.333333333333336`, 60}, {35.8, 58}}]], 
     LineBox[NCache[{{Rational[171, 5], 58}, {Rational[179, 5], 58}}, {{
        34.2, 58}, {35.8, 58}}]], 
     LineBox[NCache[{{Rational[171, 5], 58}, {
        Rational[171, 5], Rational[282, 5]}}, {{34.2, 58}, {34.2, 56.4}}]], 
     LineBox[NCache[{{Rational[171, 5], Rational[282, 5]}, {
        Rational[179, 5], Rational[282, 5]}}, {{34.2, 56.4}, {35.8, 56.4}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[282, 5]}, {
        Rational[187, 5], Rational[282, 5]}}, {{35.8, 56.4}, {37.4, 56.4}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[282, 5]}, {
        Rational[187, 5], Rational[274, 5]}}, {{37.4, 56.4}, {37.4, 54.8}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[274, 5]}, {
        Rational[187, 5], Rational[266, 5]}}, {{37.4, 54.8}, {37.4, 53.2}}]], 
     LineBox[NCache[{{Rational[187, 5], Rational[266, 5]}, {
        39, Rational[266, 5]}}, {{37.4, 53.2}, {39, 53.2}}]], 
     LineBox[NCache[{{39, Rational[274, 5]}, {39, Rational[266, 5]}}, {{
        39, 54.8}, {39, 53.2}}]], 
     LineBox[NCache[{{39, Rational[274, 5]}, {41, Rational[274, 5]}}, {{
        39, 54.8}, {41, 54.8}}]], 
     LineBox[NCache[{{41, Rational[274, 5]}, {41, Rational[266, 5]}}, {{
        41, 54.8}, {41, 53.2}}]], 
     LineBox[NCache[{{41, Rational[266, 5]}, {41, Rational[258, 5]}}, {{
        41, 53.2}, {41, 51.6}}]], 
     LineBox[NCache[{{39, Rational[258, 5]}, {41, Rational[258, 5]}}, {{
        39, 51.6}, {41, 51.6}}]], 
     LineBox[NCache[{{39, Rational[258, 5]}, {39, 50}}, {{39, 51.6}, {39, 
        50}}]], 
     LineBox[NCache[{{Rational[187, 5], 50}, {39, 50}}, {{37.4, 50}, {39, 
        50}}]], LineBox[
      NCache[{{Rational[187, 5], Rational[258, 5]}, {
        Rational[187, 5], 50}}, {{37.4, 51.6}, {37.4, 50}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[258, 5]}, {
        Rational[187, 5], Rational[258, 5]}}, {{35.8, 51.6}, {37.4, 51.6}}]], 
     LineBox[NCache[{{Rational[179, 5], Rational[258, 5]}, {
        Rational[179, 5], 50}}, {{35.8, 51.6}, {35.8, 50}}]], 
     LineBox[NCache[{{Rational[179, 5], 50}, {Rational[109, 3], 48}}, {{
        35.8, 50}, {36.333333333333336`, 48}}]], 
     LineBox[NCache[{{Rational[109, 3], 48}, {
        Rational[109, 3], Rational[136, 3]}}, {{36.333333333333336`, 48}, {
        36.333333333333336`, 45.333333333333336`}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[136, 3]}, {
        39, Rational[136, 3]}}, {{36.333333333333336`, 45.333333333333336`}, {
        39, 45.333333333333336`}}]], 
     LineBox[NCache[{{39, Rational[136, 3]}, {39, Rational[128, 3]}}, {{
        39, 45.333333333333336`}, {39, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[128, 3]}, {
        39, Rational[128, 3]}}, {{36.333333333333336`, 42.666666666666664`}, {
        39, 42.666666666666664`}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[128, 3]}, {
        Rational[109, 3], 40}}, {{36.333333333333336`, 42.666666666666664`}, {
        36.333333333333336`, 40}}]], 
     LineBox[NCache[{{Rational[109, 3], 40}, {39, 40}}, {{
        36.333333333333336`, 40}, {39, 40}}]], LineBox[{{39, 40}, {39, 38}}], 
     LineBox[{{35, 38}, {39, 38}}], LineBox[{{35, 38}, {35, 34}}], 
     LineBox[{{35, 34}, {39, 34}}], LineBox[{{39, 34}, {41, 34}}], 
     LineBox[{{41, 34}, {45, 34}}], LineBox[{{45, 34}, {45, 30}}], 
     LineBox[{{45, 30}, {45, 28}}], LineBox[{{45, 28}, {49, 28}}], 
     LineBox[{{49, 28}, {49, 24}}], 
     LineBox[NCache[{{49, 24}, {51, Rational[68, 3]}}, {{49, 24}, {
        51, 22.666666666666668`}}]], 
     LineBox[NCache[{{51, 24}, {51, Rational[68, 3]}}, {{51, 24}, {
        51, 22.666666666666668`}}]], 
     LineBox[
      NCache[{{51, Rational[76, 3]}, {51, 24}}, {{51, 25.333333333333332`}, {
        51, 24}}]], 
     LineBox[NCache[{{51, Rational[80, 3]}, {51, Rational[76, 3]}}, {{
        51, 26.666666666666668`}, {51, 25.333333333333332`}}]], 
     LineBox[NCache[{{51, Rational[80, 3]}, {
        Rational[157, 3], Rational[80, 3]}}, {{51, 26.666666666666668`}, {
        52.333333333333336`, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[157, 3], 28}, {
        Rational[157, 3], Rational[80, 3]}}, {{52.333333333333336`, 28}, {
        52.333333333333336`, 26.666666666666668`}}]], 
     LineBox[NCache[{{51, 28}, {Rational[157, 3], 28}}, {{51, 28}, {
        52.333333333333336`, 28}}]], LineBox[{{51, 30}, {51, 28}}], 
     LineBox[NCache[{{51, 30}, {Rational[157, 3], 30}}, {{51, 30}, {
        52.333333333333336`, 30}}]], 
     LineBox[NCache[{{Rational[157, 3], 30}, {Rational[161, 3], 30}}, {{
        52.333333333333336`, 30}, {53.666666666666664`, 30}}]], 
     LineBox[NCache[{{Rational[161, 3], 30}, {Rational[161, 3], 28}}, {{
        53.666666666666664`, 30}, {53.666666666666664`, 28}}]], 
     LineBox[NCache[{{Rational[161, 3], 28}, {
        Rational[161, 3], Rational[80, 3]}}, {{53.666666666666664`, 28}, {
        53.666666666666664`, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[80, 3]}, {
        Rational[161, 3], Rational[76, 3]}}, {{53.666666666666664`, 
       26.666666666666668`}, {53.666666666666664`, 25.333333333333332`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[76, 3]}, {
        Rational[161, 3], 24}}, {{53.666666666666664`, 25.333333333333332`}, {
        53.666666666666664`, 24}}]], 
     LineBox[NCache[{{Rational[161, 3], 24}, {55, 24}}, {{
        53.666666666666664`, 24}, {55, 24}}]], 
     LineBox[NCache[{{55, Rational[76, 3]}, {55, 24}}, {{
        55, 25.333333333333332`}, {55, 24}}]], 
     LineBox[NCache[{{55, Rational[76, 3]}, {
        Rational[169, 3], Rational[76, 3]}}, {{55, 25.333333333333332`}, {
        56.333333333333336`, 25.333333333333332`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[76, 3]}, {
        Rational[173, 3], Rational[76, 3]}}, {{56.333333333333336`, 
       25.333333333333332`}, {57.666666666666664`, 25.333333333333332`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[76, 3]}, {
        Rational[173, 3], 24}}, {{57.666666666666664`, 25.333333333333332`}, {
        57.666666666666664`, 24}}]], 
     LineBox[NCache[{{Rational[173, 3], 24}, {59, 24}}, {{
        57.666666666666664`, 24}, {59, 24}}]], LineBox[{{59, 24}, {61, 24}}], 
     LineBox[{{61, 24}, {63, 24}}], LineBox[{{61, 24}, {61, 22}}], 
     LineBox[{{61, 22}, {63, 22}}], LineBox[{{63, 22}, {65, 22}}], 
     LineBox[{{65, 22}, {65, 20}}], LineBox[{{65, 20}, {65, 18}}], 
     LineBox[{{65, 18}, {65, 16}}], LineBox[{{65, 12}, {67, 12}}], 
     LineBox[{{65, 12}, {65, 10}}], LineBox[{{65, 14}, {65, 12}}], 
     LineBox[{{65, 14}, {67, 14}}], LineBox[{{67, 16}, {67, 14}}], 
     LineBox[{{65, 16}, {67, 16}}], LineBox[{{63, 16}, {65, 16}}], 
     LineBox[{{61, 16}, {63, 16}}], LineBox[{{61, 16}, {61, 14}}], 
     LineBox[{{61, 14}, {63, 14}}], LineBox[{{63, 14}, {63, 12}}], 
     LineBox[{{63, 12}, {63, 10}}], LineBox[{{61, 10}, {63, 10}}], 
     LineBox[{{59, 10}, {61, 10}}], LineBox[{{59, 10}, {59, 8}}], 
     LineBox[{{59, 8}, {61, 8}}], 
     LineBox[NCache[{{61, 8}, {Rational[191, 3], 8}}, {{61, 8}, {
        63.666666666666664`, 8}}]], 
     LineBox[NCache[{{Rational[191, 3], 8}, {Rational[199, 3], 8}}, {{
        63.666666666666664`, 8}, {66.33333333333333, 8}}]], 
     LineBox[NCache[{{67, 10}, {Rational[199, 3], 8}}, {{67, 10}, {
        66.33333333333333, 8}}]], LineBox[{{67, 10}, {69, 10}}], 
     LineBox[{{69, 12}, {69, 10}}], LineBox[{{69, 14}, {69, 12}}], 
     LineBox[{{69, 16}, {69, 14}}], LineBox[{{69, 18}, {69, 16}}], 
     LineBox[{{67, 18}, {69, 18}}], LineBox[{{67, 20}, {67, 18}}], 
     LineBox[{{67, 20}, {69, 20}}], LineBox[{{69, 22}, {69, 20}}], 
     LineBox[{{67, 22}, {69, 22}}], LineBox[{{67, 24}, {67, 22}}], 
     LineBox[{{65, 24}, {67, 24}}], LineBox[{{65, 26}, {65, 24}}], 
     LineBox[{{63, 26}, {65, 26}}], LineBox[{{61, 26}, {63, 26}}], 
     LineBox[{{61, 28}, {61, 26}}], 
     LineBox[NCache[{{59, Rational[80, 3]}, {61, 28}}, {{
        59, 26.666666666666668`}, {61, 28}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[80, 3]}, {
        59, Rational[80, 3]}}, {{57.666666666666664`, 26.666666666666668`}, {
        59, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[80, 3]}, {
        Rational[173, 3], Rational[80, 3]}}, {{56.333333333333336`, 
       26.666666666666668`}, {57.666666666666664`, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[169, 3], 28}, {
        Rational[169, 3], Rational[80, 3]}}, {{56.333333333333336`, 28}, {
        56.333333333333336`, 26.666666666666668`}}]], 
     LineBox[NCache[{{Rational[169, 3], 28}, {Rational[173, 3], 28}}, {{
        56.333333333333336`, 28}, {57.666666666666664`, 28}}]], 
     LineBox[NCache[{{Rational[173, 3], 28}, {59, 28}}, {{
        57.666666666666664`, 28}, {59, 28}}]], LineBox[{{59, 30}, {59, 28}}], 
     LineBox[{{59, 30}, {61, 30}}], LineBox[{{61, 32}, {61, 30}}], 
     LineBox[{{61, 34}, {61, 32}}], 
     LineBox[NCache[{{59, Rational[98, 3]}, {61, 34}}, {{
        59, 32.666666666666664`}, {61, 34}}]], 
     LineBox[NCache[{{59, 34}, {59, Rational[98, 3]}}, {{59, 34}, {
        59, 32.666666666666664`}}]], 
     LineBox[NCache[{{Rational[173, 3], 34}, {59, 34}}, {{
        57.666666666666664`, 34}, {59, 34}}]], 
     LineBox[NCache[{{55, Rational[106, 3]}, {55, 34}}, {{
        55, 35.333333333333336`}, {55, 34}}]], 
     LineBox[NCache[{{55, Rational[106, 3]}, {
        Rational[169, 3], Rational[106, 3]}}, {{55, 35.333333333333336`}, {
        56.333333333333336`, 35.333333333333336`}}]], 
     LineBox[NCache[{{Rational[169, 3], Rational[106, 3]}, {
        Rational[173, 3], Rational[106, 3]}}, {{56.333333333333336`, 
       35.333333333333336`}, {57.666666666666664`, 35.333333333333336`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[110, 3]}, {
        Rational[173, 3], Rational[106, 3]}}, {{57.666666666666664`, 
       36.666666666666664`}, {57.666666666666664`, 35.333333333333336`}}]], 
     LineBox[NCache[{{Rational[173, 3], Rational[106, 3]}, {
        Rational[173, 3], 34}}, {{57.666666666666664`, 35.333333333333336`}, {
        57.666666666666664`, 34}}]], 
     LineBox[NCache[{{Rational[169, 3], 34}, {Rational[173, 3], 34}}, {{
        56.333333333333336`, 34}, {57.666666666666664`, 34}}]], 
     LineBox[NCache[{{Rational[169, 3], 34}, {
        Rational[169, 3], Rational[98, 3]}}, {{56.333333333333336`, 34}, {
        56.333333333333336`, 32.666666666666664`}}]], 
     LineBox[NCache[{{55, Rational[98, 3]}, {
        Rational[169, 3], Rational[98, 3]}}, {{55, 32.666666666666664`}, {
        56.333333333333336`, 32.666666666666664`}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[98, 3]}, {
        55, Rational[98, 3]}}, {{53.666666666666664`, 32.666666666666664`}, {
        55, 32.666666666666664`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[98, 3]}, {
        Rational[161, 3], Rational[98, 3]}}, {{52.333333333333336`, 
       32.666666666666664`}, {53.666666666666664`, 32.666666666666664`}}]], 
     LineBox[NCache[{{51, Rational[98, 3]}, {
        Rational[157, 3], Rational[98, 3]}}, {{51, 32.666666666666664`}, {
        52.333333333333336`, 32.666666666666664`}}]], 
     LineBox[NCache[{{51, Rational[98, 3]}, {51, Rational[94, 3]}}, {{
        51, 32.666666666666664`}, {51, 31.333333333333332`}}]], 
     LineBox[NCache[{{49, 30}, {51, Rational[94, 3]}}, {{49, 30}, {
        51, 31.333333333333332`}}]], LineBox[{{49, 34}, {49, 30}}], 
     LineBox[{{49, 34}, {51, 34}}], 
     LineBox[NCache[{{51, Rational[106, 3]}, {51, 34}}, {{
        51, 35.333333333333336`}, {51, 34}}]], 
     LineBox[NCache[{{51, Rational[106, 3]}, {
        Rational[157, 3], Rational[106, 3]}}, {{51, 35.333333333333336`}, {
        52.333333333333336`, 35.333333333333336`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[106, 3]}, {
        Rational[157, 3], 34}}, {{52.333333333333336`, 35.333333333333336`}, {
        52.333333333333336`, 34}}]], 
     LineBox[NCache[{{Rational[157, 3], 34}, {Rational[161, 3], 34}}, {{
        52.333333333333336`, 34}, {53.666666666666664`, 34}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[106, 3]}, {
        Rational[161, 3], 34}}, {{53.666666666666664`, 35.333333333333336`}, {
        53.666666666666664`, 34}}]], 
     LineBox[NCache[{{Rational[161, 3], Rational[110, 3]}, {
        Rational[161, 3], Rational[106, 3]}}, {{53.666666666666664`, 
       36.666666666666664`}, {53.666666666666664`, 35.333333333333336`}}]], 
     LineBox[NCache[{{Rational[157, 3], Rational[110, 3]}, {
        Rational[161, 3], Rational[110, 3]}}, {{52.333333333333336`, 
       36.666666666666664`}, {53.666666666666664`, 36.666666666666664`}}]], 
     LineBox[NCache[{{51, Rational[110, 3]}, {
        Rational[157, 3], Rational[110, 3]}}, {{51, 36.666666666666664`}, {
        52.333333333333336`, 36.666666666666664`}}]], 
     LineBox[NCache[{{51, 38}, {51, Rational[110, 3]}}, {{51, 38}, {
        51, 36.666666666666664`}}]], LineBox[{{51, 40}, {51, 38}}], 
     LineBox[NCache[{{51, 40}, {Rational[157, 3], 40}}, {{51, 40}, {
        52.333333333333336`, 40}}]], 
     LineBox[NCache[{{Rational[157, 3], 40}, {Rational[157, 3], 38}}, {{
        52.333333333333336`, 40}, {52.333333333333336`, 38}}]], 
     LineBox[NCache[{{Rational[157, 3], 38}, {Rational[161, 3], 38}}, {{
        52.333333333333336`, 38}, {53.666666666666664`, 38}}]], 
     LineBox[NCache[{{Rational[161, 3], 38}, {55, 38}}, {{
        53.666666666666664`, 38}, {55, 38}}]], 
     LineBox[NCache[{{55, 38}, {55, Rational[110, 3]}}, {{55, 38}, {
        55, 36.666666666666664`}}]], 
     LineBox[NCache[{{55, Rational[110, 3]}, {
        Rational[169, 3], Rational[110, 3]}}, {{55, 36.666666666666664`}, {
        56.333333333333336`, 36.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], 38}, {
        Rational[169, 3], Rational[110, 3]}}, {{56.333333333333336`, 38}, {
        56.333333333333336`, 36.666666666666664`}}]], 
     LineBox[NCache[{{Rational[169, 3], 38}, {Rational[173, 3], 38}}, {{
        56.333333333333336`, 38}, {57.666666666666664`, 38}}]], 
     LineBox[NCache[{{Rational[173, 3], 38}, {59, 38}}, {{
        57.666666666666664`, 38}, {59, 38}}]], 
     LineBox[NCache[{{59, 38}, {59, Rational[110, 3]}}, {{59, 38}, {
        59, 36.666666666666664`}}]], 
     LineBox[NCache[{{59, Rational[110, 3]}, {59, Rational[106, 3]}}, {{
        59, 36.666666666666664`}, {59, 35.333333333333336`}}]], 
     LineBox[NCache[{{59, Rational[106, 3]}, {61, 36}}, {{
        59, 35.333333333333336`}, {61, 36}}]], LineBox[{{61, 36}, {63, 36}}], 
     LineBox[{{63, 38}, {63, 36}}], LineBox[{{61, 40}, {63, 38}}], 
     LineBox[{{59, 40}, {61, 40}}], 
     LineBox[NCache[{{59, Rational[124, 3]}, {59, 40}}, {{
        59, 41.333333333333336`}, {59, 40}}]], 
     LineBox[NCache[{{59, Rational[128, 3]}, {59, Rational[124, 3]}}, {{
        59, 42.666666666666664`}, {59, 41.333333333333336`}}]], 
     LineBox[NCache[{{59, Rational[128, 3]}, {61, 44}}, {{
        59, 42.666666666666664`}, {61, 44}}]], LineBox[{{61, 44}, {65, 44}}], 
     LineBox[{{65, 48}, {65, 44}}], LineBox[{{65, 50}, {65, 48}}], 
     LineBox[{{65, 50}, {69, 50}}], LineBox[{{69, 54}, {69, 50}}], 
     LineBox[{{69, 58}, {69, 54}}], LineBox[{{69, 60}, {69, 58}}], 
     LineBox[{{69, 64}, {69, 60}}], LineBox[{{65, 60}, {69, 60}}], 
     LineBox[{{65, 64}, {65, 60}}], LineBox[{{65, 68}, {65, 64}}], 
     LineBox[{{65, 68}, {69, 68}}], LineBox[{{69, 70}, {69, 68}}], 
     LineBox[{{65, 70}, {69, 70}}], LineBox[{{61, 70}, {65, 70}}], 
     LineBox[{{59, 70}, {61, 70}}], LineBox[{{55, 70}, {59, 70}}], 
     LineBox[{{55, 74}, {55, 70}}], LineBox[{{55, 74}, {59, 74}}], 
     LineBox[{{59, 78}, {59, 74}}], LineBox[{{55, 78}, {59, 78}}], 
     LineBox[{{51, 78}, {55, 78}}], LineBox[{{51, 78}, {51, 74}}], 
     LineBox[{{49, 74}, {51, 74}}], 
     LineBox[NCache[{{Rational[143, 3], 74}, {49, 74}}, {{
        47.666666666666664`, 74}, {49, 74}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[226, 3]}, {
        Rational[143, 3], 74}}, {{47.666666666666664`, 75.33333333333333}, {
        47.666666666666664`, 74}}]], 
     LineBox[NCache[{{Rational[143, 3], Rational[226, 3]}, {
        49, Rational[226, 3]}}, {{47.666666666666664`, 75.33333333333333}, {
        49, 75.33333333333333}}]], 
     LineBox[NCache[{{49, Rational[230, 3]}, {49, Rational[226, 3]}}, {{
        49, 76.66666666666667}, {49, 75.33333333333333}}]], 
     LineBox[NCache[{{49, 78}, {49, Rational[230, 3]}}, {{49, 78}, {
        49, 76.66666666666667}}]], 
     LineBox[NCache[{{Rational[143, 3], 78}, {49, 78}}, {{
        47.666666666666664`, 78}, {49, 78}}]], 
     LineBox[NCache[{{Rational[139, 3], 78}, {Rational[143, 3], 78}}, {{
        46.333333333333336`, 78}, {47.666666666666664`, 78}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[230, 3]}, {
        45, Rational[230, 3]}}, {{43.666666666666664`, 76.66666666666667}, {
        45, 76.66666666666667}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[230, 3]}, {
        Rational[131, 3], Rational[230, 3]}}, {{42.333333333333336`, 
       76.66666666666667}, {43.666666666666664`, 76.66666666666667}}]], 
     LineBox[NCache[{{41, Rational[230, 3]}, {
        Rational[127, 3], Rational[230, 3]}}, {{41, 76.66666666666667}, {
        42.333333333333336`, 76.66666666666667}}]], 
     LineBox[NCache[{{39, Rational[530, 7]}, {41, Rational[230, 3]}}, {{
        39, 75.71428571428571}, {41, 76.66666666666667}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[530, 7]}, {
        39, Rational[530, 7]}}, {{37.857142857142854`, 75.71428571428571}, {
        39, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[522, 7]}, {
        Rational[265, 7], Rational[514, 7]}}, {{37.857142857142854`, 
       74.57142857142857}, {37.857142857142854`, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[522, 7]}, {
        Rational[265, 7], Rational[522, 7]}}, {{36.714285714285715`, 
       74.57142857142857}, {37.857142857142854`, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[530, 7]}, {
        Rational[257, 7], Rational[522, 7]}}, {{36.714285714285715`, 
       75.71428571428571}, {36.714285714285715`, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[257, 7], 78}, {
        Rational[257, 7], Rational[538, 7]}}, {{36.714285714285715`, 78}, {
        36.714285714285715`, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[249, 7], 78}, {Rational[257, 7], 78}}, {{
        35.57142857142857, 78}, {36.714285714285715`, 78}}]], 
     LineBox[{{25, 78}, {29, 78}}], 
     LineBox[NCache[{{Rational[233, 7], Rational[498, 7]}, {
        Rational[241, 7], Rational[498, 7]}}, {{33.285714285714285`, 
       71.14285714285714}, {34.42857142857143, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[506, 7]}, {
        Rational[233, 7], Rational[498, 7]}}, {{33.285714285714285`, 
       72.28571428571429}, {33.285714285714285`, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[538, 7]}, {
        Rational[225, 7], Rational[530, 7]}}, {{32.142857142857146`, 
       76.85714285714286}, {32.142857142857146`, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[538, 7]}, {
        Rational[233, 7], Rational[538, 7]}}, {{32.142857142857146`, 
       76.85714285714286}, {33.285714285714285`, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[538, 7]}, {
        Rational[241, 7], Rational[538, 7]}}, {{33.285714285714285`, 
       76.85714285714286}, {34.42857142857143, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[538, 7]}, {
        Rational[241, 7], Rational[530, 7]}}, {{34.42857142857143, 
       76.85714285714286}, {34.42857142857143, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[530, 7]}, {
        Rational[241, 7], Rational[530, 7]}}, {{33.285714285714285`, 
       75.71428571428571}, {34.42857142857143, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[530, 7]}, {
        Rational[233, 7], Rational[522, 7]}}, {{33.285714285714285`, 
       75.71428571428571}, {33.285714285714285`, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[522, 7]}, {
        Rational[233, 7], Rational[522, 7]}}, {{32.142857142857146`, 
       74.57142857142857}, {33.285714285714285`, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[522, 7]}, {
        Rational[225, 7], Rational[514, 7]}}, {{32.142857142857146`, 
       74.57142857142857}, {32.142857142857146`, 73.42857142857143}}]], 
     LineBox[
      NCache[{{31, Rational[514, 7]}, {31, Rational[506, 7]}}, {{
        31, 73.42857142857143}, {31, 72.28571428571429}}]], 
     LineBox[NCache[{{31, Rational[514, 7]}, {
        Rational[225, 7], Rational[514, 7]}}, {{31, 73.42857142857143}, {
        32.142857142857146`, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[514, 7]}, {
        Rational[233, 7], Rational[514, 7]}}, {{32.142857142857146`, 
       73.42857142857143}, {33.285714285714285`, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[233, 7], Rational[514, 7]}, {
        Rational[233, 7], Rational[506, 7]}}, {{33.285714285714285`, 
       73.42857142857143}, {33.285714285714285`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[506, 7]}, {
        Rational[233, 7], Rational[506, 7]}}, {{32.142857142857146`, 
       72.28571428571429}, {33.285714285714285`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[506, 7]}, {
        Rational[225, 7], Rational[498, 7]}}, {{32.142857142857146`, 
       72.28571428571429}, {32.142857142857146`, 71.14285714285714}}]], 
     LineBox[NCache[{{31, 70}, {Rational[225, 7], 70}}, {{31, 70}, {
        32.142857142857146`, 70}}]], 
     LineBox[NCache[{{Rational[225, 7], Rational[498, 7]}, {
        Rational[225, 7], 70}}, {{32.142857142857146`, 71.14285714285714}, {
        32.142857142857146`, 70}}]], 
     LineBox[NCache[{{31, Rational[498, 7]}, {
        Rational[225, 7], Rational[498, 7]}}, {{31, 71.14285714285714}, {
        32.142857142857146`, 71.14285714285714}}]], 
     LineBox[NCache[{{29, 70}, {31, Rational[498, 7]}}, {{29, 70}, {
        31, 71.14285714285714}}]], LineBox[{{29, 74}, {29, 70}}], 
     LineBox[NCache[{{29, 74}, {31, Rational[522, 7]}}, {{29, 74}, {
        31, 74.57142857142857}}]], 
     LineBox[NCache[{{31, Rational[530, 7]}, {31, Rational[522, 7]}}, {{
        31, 75.71428571428571}, {31, 74.57142857142857}}]], 
     LineBox[NCache[{{31, Rational[538, 7]}, {31, Rational[530, 7]}}, {{
        31, 76.85714285714286}, {31, 75.71428571428571}}]], 
     LineBox[NCache[{{29, 78}, {31, Rational[538, 7]}}, {{29, 78}, {
        31, 76.85714285714286}}]], LineBox[{{29, 78}, {31, 78}}], 
     LineBox[NCache[{{31, 78}, {Rational[225, 7], 78}}, {{31, 78}, {
        32.142857142857146`, 78}}]], 
     LineBox[NCache[{{Rational[225, 7], 78}, {Rational[233, 7], 78}}, {{
        32.142857142857146`, 78}, {33.285714285714285`, 78}}]], 
     LineBox[NCache[{{Rational[233, 7], 78}, {Rational[241, 7], 78}}, {{
        33.285714285714285`, 78}, {34.42857142857143, 78}}]], 
     LineBox[NCache[{{Rational[241, 7], 78}, {Rational[249, 7], 78}}, {{
        34.42857142857143, 78}, {35.57142857142857, 78}}]], 
     LineBox[NCache[{{Rational[249, 7], 78}, {
        Rational[249, 7], Rational[538, 7]}}, {{35.57142857142857, 78}, {
        35.57142857142857, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[538, 7]}, {
        Rational[249, 7], Rational[530, 7]}}, {{35.57142857142857, 
       76.85714285714286}, {35.57142857142857, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[530, 7]}, {
        Rational[257, 7], Rational[530, 7]}}, {{35.57142857142857, 
       75.71428571428571}, {36.714285714285715`, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[530, 7]}, {
        Rational[265, 7], Rational[530, 7]}}, {{36.714285714285715`, 
       75.71428571428571}, {37.857142857142854`, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[538, 7]}, {
        Rational[265, 7], Rational[530, 7]}}, {{37.857142857142854`, 
       76.85714285714286}, {37.857142857142854`, 75.71428571428571}}]], 
     LineBox[NCache[{{Rational[265, 7], 78}, {
        Rational[265, 7], Rational[538, 7]}}, {{37.857142857142854`, 78}, {
        37.857142857142854`, 76.85714285714286}}]], 
     LineBox[NCache[{{Rational[265, 7], 78}, {39, 78}}, {{
        37.857142857142854`, 78}, {39, 78}}]], 
     LineBox[NCache[{{39, 78}, {39, Rational[538, 7]}}, {{39, 78}, {
        39, 76.85714285714286}}]], 
     LineBox[NCache[{{39, Rational[538, 7]}, {41, 78}}, {{
        39, 76.85714285714286}, {41, 78}}]], 
     LineBox[NCache[{{41, 78}, {Rational[127, 3], 78}}, {{41, 78}, {
        42.333333333333336`, 78}}]], 
     LineBox[NCache[{{Rational[127, 3], 78}, {Rational[131, 3], 78}}, {{
        42.333333333333336`, 78}, {43.666666666666664`, 78}}]], 
     LineBox[NCache[{{Rational[131, 3], 78}, {45, 78}}, {{
        43.666666666666664`, 78}, {45, 78}}]], 
     LineBox[NCache[{{45, 78}, {Rational[139, 3], 78}}, {{45, 78}, {
        46.333333333333336`, 78}}]], 
     LineBox[NCache[{{Rational[139, 3], 78}, {
        Rational[139, 3], Rational[230, 3]}}, {{46.333333333333336`, 78}, {
        46.333333333333336`, 76.66666666666667}}]], 
     LineBox[NCache[{{Rational[139, 3], Rational[230, 3]}, {
        Rational[139, 3], Rational[226, 3]}}, {{46.333333333333336`, 
       76.66666666666667}, {46.333333333333336`, 75.33333333333333}}]], 
     LineBox[NCache[{{45, Rational[226, 3]}, {
        Rational[139, 3], Rational[226, 3]}}, {{45, 75.33333333333333}, {
        46.333333333333336`, 75.33333333333333}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[226, 3]}, {
        45, Rational[226, 3]}}, {{43.666666666666664`, 75.33333333333333}, {
        45, 75.33333333333333}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[226, 3]}, {
        Rational[131, 3], Rational[226, 3]}}, {{42.333333333333336`, 
       75.33333333333333}, {43.666666666666664`, 75.33333333333333}}]], 
     LineBox[NCache[{{41, Rational[226, 3]}, {
        Rational[127, 3], Rational[226, 3]}}, {{41, 75.33333333333333}, {
        42.333333333333336`, 75.33333333333333}}]], 
     LineBox[NCache[{{39, Rational[522, 7]}, {41, Rational[226, 3]}}, {{
        39, 74.57142857142857}, {41, 75.33333333333333}}]], 
     LineBox[NCache[{{39, Rational[522, 7]}, {39, Rational[514, 7]}}, {{
        39, 74.57142857142857}, {39, 73.42857142857143}}]], 
     LineBox[NCache[{{39, Rational[514, 7]}, {41, 74}}, {{
        39, 73.42857142857143}, {41, 74}}]], 
     LineBox[NCache[{{41, 74}, {Rational[127, 3], 74}}, {{41, 74}, {
        42.333333333333336`, 74}}]], 
     LineBox[NCache[{{Rational[127, 3], 74}, {Rational[131, 3], 74}}, {{
        42.333333333333336`, 74}, {43.666666666666664`, 74}}]], 
     LineBox[NCache[{{Rational[131, 3], 74}, {45, 74}}, {{
        43.666666666666664`, 74}, {45, 74}}]], 
     LineBox[NCache[{{45, 74}, {45, Rational[218, 3]}}, {{45, 74}, {
        45, 72.66666666666667}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[218, 3]}, {
        45, Rational[218, 3]}}, {{43.666666666666664`, 72.66666666666667}, {
        45, 72.66666666666667}}]], 
     LineBox[NCache[{{Rational[131, 3], Rational[218, 3]}, {
        Rational[131, 3], Rational[214, 3]}}, {{43.666666666666664`, 
       72.66666666666667}, {43.666666666666664`, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[214, 3]}, {
        Rational[131, 3], Rational[214, 3]}}, {{42.333333333333336`, 
       71.33333333333333}, {43.666666666666664`, 71.33333333333333}}]], 
     LineBox[NCache[{{Rational[127, 3], Rational[218, 3]}, {
        Rational[127, 3], Rational[214, 3]}}, {{42.333333333333336`, 
       72.66666666666667}, {42.333333333333336`, 71.33333333333333}}]], 
     LineBox[NCache[{{41, Rational[218, 3]}, {
        Rational[127, 3], Rational[218, 3]}}, {{41, 72.66666666666667}, {
        42.333333333333336`, 72.66666666666667}}]], 
     LineBox[NCache[{{39, Rational[506, 7]}, {41, Rational[218, 3]}}, {{
        39, 72.28571428571429}, {41, 72.66666666666667}}]], 
     LineBox[NCache[{{Rational[265, 7], Rational[506, 7]}, {
        39, Rational[506, 7]}}, {{37.857142857142854`, 72.28571428571429}, {
        39, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[506, 7]}, {
        Rational[265, 7], Rational[506, 7]}}, {{36.714285714285715`, 
       72.28571428571429}, {37.857142857142854`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[514, 7]}, {
        Rational[257, 7], Rational[506, 7]}}, {{36.714285714285715`, 
       73.42857142857143}, {36.714285714285715`, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[514, 7]}, {
        Rational[257, 7], Rational[514, 7]}}, {{35.57142857142857, 
       73.42857142857143}, {36.714285714285715`, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[522, 7]}, {
        Rational[249, 7], Rational[514, 7]}}, {{35.57142857142857, 
       74.57142857142857}, {35.57142857142857, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[522, 7]}, {
        Rational[249, 7], Rational[522, 7]}}, {{34.42857142857143, 
       74.57142857142857}, {35.57142857142857, 74.57142857142857}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[522, 7]}, {
        Rational[241, 7], Rational[514, 7]}}, {{34.42857142857143, 
       74.57142857142857}, {34.42857142857143, 73.42857142857143}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[514, 7]}, {
        Rational[241, 7], Rational[506, 7]}}, {{34.42857142857143, 
       73.42857142857143}, {34.42857142857143, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[241, 7], Rational[506, 7]}, {
        Rational[249, 7], Rational[506, 7]}}, {{34.42857142857143, 
       72.28571428571429}, {35.57142857142857, 72.28571428571429}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[506, 7]}, {
        Rational[249, 7], Rational[498, 7]}}, {{35.57142857142857, 
       72.28571428571429}, {35.57142857142857, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[249, 7], Rational[498, 7]}, {
        Rational[257, 7], Rational[498, 7]}}, {{35.57142857142857, 
       71.14285714285714}, {36.714285714285715`, 71.14285714285714}}]], 
     LineBox[NCache[{{Rational[257, 7], Rational[498, 7]}, {
        Rational[257, 7], 70}}, {{36.714285714285715`, 71.14285714285714}, {
        36.714285714285715`, 70}}]], 
     LineBox[NCache[{{Rational[257, 7], 70}, {Rational[109, 3], 68}}, {{
        36.714285714285715`, 70}, {36.333333333333336`, 68}}]], 
     LineBox[NCache[{{Rational[109, 3], 68}, {Rational[113, 3], 68}}, {{
        36.333333333333336`, 68}, {37.666666666666664`, 68}}]], 
     LineBox[NCache[{{Rational[113, 3], 68}, {
        Rational[113, 3], Rational[200, 3]}}, {{37.666666666666664`, 68}, {
        37.666666666666664`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[109, 3], Rational[200, 3]}, {
        Rational[113, 3], Rational[200, 3]}}, {{36.333333333333336`, 
       66.66666666666667}, {37.666666666666664`, 66.66666666666667}}]], 
     LineBox[
      NCache[{{35, Rational[200, 3]}, {
        Rational[109, 3], Rational[200, 3]}}, {{35, 66.66666666666667}, {
        36.333333333333336`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[101, 3], Rational[200, 3]}, {
        35, Rational[200, 3]}}, {{33.666666666666664`, 66.66666666666667}, {
        35, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[101, 3], 68}, {
        Rational[101, 3], Rational[200, 3]}}, {{33.666666666666664`, 68}, {
        33.666666666666664`, 66.66666666666667}}]], 
     LineBox[NCache[{{Rational[101, 3], 68}, {35, 68}}, {{
        33.666666666666664`, 68}, {35, 68}}]], 
     LineBox[NCache[{{Rational[249, 7], 70}, {35, 68}}, {{
        35.57142857142857, 70}, {35, 68}}]], 
     LineBox[NCache[{{Rational[241, 7], 70}, {Rational[249, 7], 70}}, {{
        34.42857142857143, 70}, {35.57142857142857, 70}}]], 
     LineBox[NCache[{{Rational[233, 7], 70}, {Rational[241, 7], 70}}, {{
        33.285714285714285`, 70}, {34.42857142857143, 70}}]], 
     LineBox[NCache[{{Rational[233, 7], 70}, {Rational[97, 3], 68}}, {{
        33.285714285714285`, 70}, {32.333333333333336`, 68}}]], 
     LineBox[NCache[{{31, 68}, {Rational[97, 3], 68}}, {{31, 68}, {
        32.333333333333336`, 68}}]], LineBox[{{29, 68}, {31, 68}}], 
     LineBox[{{25, 68}, {29, 68}}], LineBox[{{25, 68}, {25, 64}}], 
     LineBox[{{25, 64}, {25, 60}}], LineBox[{{21, 60}, {25, 60}}], 
     LineBox[{{21, 64}, {21, 60}}], LineBox[{{21, 68}, {21, 64}}], 
     LineBox[{{15, 70}, {19, 70}}], LineBox[{{19, 70}, {19, 68}}], 
     LineBox[{{19, 68}, {21, 68}}], LineBox[{{21, 70}, {21, 68}}], 
     LineBox[{{21, 70}, {25, 70}}], LineBox[{{25, 74}, {25, 70}}], 
     LineBox[{{21, 74}, {25, 74}}], LineBox[{{21, 78}, {21, 74}}], 
     LineBox[{{19, 78}, {21, 78}}], LineBox[{{19, 78}, {19, 74}}], 
     LineBox[{{15, 74}, {19, 74}}], LineBox[{{11, 74}, {15, 74}}], 
     LineBox[{{15, 78}, {15, 74}}], LineBox[{{11, 78}, {15, 78}}]}, 
    {RGBColor[0, 1, 0], DiskBox[{11, 78}]}, 
    {RGBColor[1, 0, 0], DiskBox[{69, 0}]}}},
  ImageSize->NCache[
    Rational[1125, 2], 562.5]]], "Output",
 CellChangeTimes->{3.470843012640946*^9, 3.470846061549371*^9, 
  3.470846151308453*^9, 3.470849684154012*^9, 3.470867721153508*^9, 
  3.470867803773879*^9, 3.470874478152297*^9, 3.470878269933137*^9, 
  3.470881812073462*^9, 3.4709121006492*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["lattice examples", "Subsubsection",
 CellChangeTimes->{{3.470839104449401*^9, 3.470839108030074*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"resolutions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.470839121653429*^9, 3.4708391330401*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.470839134731691*^9, 3.47084301283877*^9, 3.470846061641808*^9, 
   3.470846151564322*^9, 3.470846441623132*^9, 3.470849684366702*^9, {
   3.470850736293993*^9, 3.47085075252443*^9}, 3.470867721223922*^9, 
   3.470867803840611*^9, 3.470874478401591*^9, 3.470878270116672*^9, 
   3.470881812275387*^9, 3.470912100763578*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"todo", ":", " ", 
    RowBox[{
    "rewrite", " ", "so", " ", "that", " ", "no", " ", "code", " ", "from", 
     " ", "generateMazeFromImage", " ", "is", " ", "repeated", " ", 
     RowBox[{"(", 
      RowBox[{
      "maybe", " ", "add", " ", "as", " ", "parameter", " ", "to", " ", 
       "generateMazeFromImage"}], ")"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"generateGraphicFromResolutionGrid", "[", 
    RowBox[{"resolutionGrid_", ",", 
     RowBox[{"showConnections_:", "True"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "fullgraph", ",", "graphgrid", ",", "fullgraph2", ",", "graphxy", ",", 
       "graphic", ",", "gridw", ",", "gridh"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fullgraph", ",", "graphgrid"}], "}"}], "=", 
       RowBox[{
       "createGraphFromResolutionGrid", "[", "resolutionGrid", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"gridw", "=", 
       RowBox[{"Length", "@", 
        RowBox[{"resolutionGrid", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gridh", "=", 
       RowBox[{"Length", "@", "resolutionGrid"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"graphxy", "=", 
       RowBox[{"computeXYForFullMegaGrid", "[", 
        RowBox[{"graphgrid", ",", "0", ",", "0", ",", 
         RowBox[{"10", " ", "gridw"}], ",", 
         RowBox[{"10", "gridh"}], ",", "1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{"showConnections", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"fullgraph", "=", 
          RowBox[{"Rule", "@@@", 
           RowBox[{"(", 
            RowBox[{"Sort", "/@", 
             RowBox[{"List", "@@@", "fullgraph"}]}], ")"}]}]}], ";", 
         RowBox[{"(*", "sort", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"fullgraph2", "=", 
          RowBox[{"ReplaceAll", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], "&"}], "/@",
              "fullgraph"}], ",", "graphxy"}], "]"}]}], ";"}], 
        "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"fullgraph", "=", 
          RowBox[{"Rule", "@@@", 
           RowBox[{"(", 
            RowBox[{"Sort", "/@", 
             RowBox[{"List", "@@@", 
              RowBox[{"Flatten", "@", "graphgrid"}]}]}], ")"}]}]}], ";", 
         RowBox[{"(*", "sort", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"fullgraph2", "=", 
          RowBox[{"ReplaceAll", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], "&"}], "/@",
              "fullgraph"}], ",", "graphxy"}], "]"}]}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"graphic", "=", 
       RowBox[{"{", 
        RowBox[{"Gray", ",", 
         RowBox[{"AbsoluteThickness", "[", "3", "]"}], ",", "fullgraph2"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"graphic", "=", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"AbsoluteThickness", "[", "5", "]"}], ",", "fullgraph2"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"graphic", ",", 
        RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.470839338124489*^9, 3.470839519608563*^9}, {
  3.470839573198804*^9, 3.470839594983152*^9}, {3.470850652818*^9, 
  3.470850707691763*^9}, {3.470850748386552*^9, 3.470850748980588*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateGraphicFromResolutionGrid", "@", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3", ",", "0.3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "0.3"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.470839628806847*^9, 3.470839662826371*^9}, {
  3.470839735681244*^9, 3.470839748423918*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.470839524322955*^9, 3.470839534347509*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], 
   LineBox[NCache[{{11, 18}, {Rational[107, 9], 18}}, {{11, 18}, {
      11.88888888888889, 18}}]], 
   LineBox[NCache[{{11, Rational[154, 9]}, {
      Rational[107, 9], Rational[154, 9]}}, {{11, 17.11111111111111}, {
      11.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{11, Rational[146, 9]}, {
      Rational[107, 9], Rational[146, 9]}}, {{11, 16.22222222222222}, {
      11.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{11, Rational[46, 3]}, {
      Rational[107, 9], Rational[46, 3]}}, {{11, 15.333333333333334`}, {
      11.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{11, Rational[130, 9]}, {
      Rational[107, 9], Rational[130, 9]}}, {{11, 14.444444444444445`}, {
      11.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{11, Rational[122, 9]}, {
      Rational[107, 9], Rational[122, 9]}}, {{11, 13.555555555555555`}, {
      11.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {
      Rational[107, 9], Rational[38, 3]}}, {{11, 12.666666666666666`}, {
      11.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[106, 9]}, {
      Rational[107, 9], Rational[106, 9]}}, {{11, 11.777777777777779`}, {
      11.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{11, Rational[98, 9]}, {
      Rational[107, 9], Rational[98, 9]}}, {{11, 10.88888888888889}, {
      11.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{11, 10}, {Rational[107, 9], 10}}, {{11, 10}, {
      11.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[107, 9], 18}, {Rational[115, 9], 18}}, {{
      11.88888888888889, 18}, {12.777777777777779`, 18}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[154, 9]}, {
      Rational[115, 9], Rational[154, 9]}}, {{11.88888888888889, 
     17.11111111111111}, {12.777777777777779`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[146, 9]}, {
      Rational[115, 9], Rational[146, 9]}}, {{11.88888888888889, 
     16.22222222222222}, {12.777777777777779`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[46, 3]}, {
      Rational[115, 9], Rational[46, 3]}}, {{11.88888888888889, 
     15.333333333333334`}, {12.777777777777779`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[130, 9]}, {
      Rational[115, 9], Rational[130, 9]}}, {{11.88888888888889, 
     14.444444444444445`}, {12.777777777777779`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[122, 9]}, {
      Rational[115, 9], Rational[122, 9]}}, {{11.88888888888889, 
     13.555555555555555`}, {12.777777777777779`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[38, 3]}, {
      Rational[115, 9], Rational[38, 3]}}, {{11.88888888888889, 
     12.666666666666666`}, {12.777777777777779`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[106, 9]}, {
      Rational[115, 9], Rational[106, 9]}}, {{11.88888888888889, 
     11.777777777777779`}, {12.777777777777779`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[98, 9]}, {
      Rational[115, 9], Rational[98, 9]}}, {{11.88888888888889, 
     10.88888888888889}, {12.777777777777779`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[107, 9], 10}, {Rational[115, 9], 10}}, {{
      11.88888888888889, 10}, {12.777777777777779`, 10}}]], 
   LineBox[NCache[{{Rational[115, 9], 18}, {Rational[41, 3], 18}}, {{
      12.777777777777779`, 18}, {13.666666666666666`, 18}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[154, 9]}, {
      Rational[41, 3], Rational[154, 9]}}, {{12.777777777777779`, 
     17.11111111111111}, {13.666666666666666`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[146, 9]}, {
      Rational[41, 3], Rational[146, 9]}}, {{12.777777777777779`, 
     16.22222222222222}, {13.666666666666666`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[46, 3]}, {
      Rational[41, 3], Rational[46, 3]}}, {{12.777777777777779`, 
     15.333333333333334`}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[130, 9]}, {
      Rational[41, 3], Rational[130, 9]}}, {{12.777777777777779`, 
     14.444444444444445`}, {13.666666666666666`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[122, 9]}, {
      Rational[41, 3], Rational[122, 9]}}, {{12.777777777777779`, 
     13.555555555555555`}, {13.666666666666666`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[38, 3]}, {
      Rational[41, 3], Rational[38, 3]}}, {{12.777777777777779`, 
     12.666666666666666`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[106, 9]}, {
      Rational[41, 3], Rational[106, 9]}}, {{12.777777777777779`, 
     11.777777777777779`}, {13.666666666666666`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[98, 9]}, {
      Rational[41, 3], Rational[98, 9]}}, {{12.777777777777779`, 
     10.88888888888889}, {13.666666666666666`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[115, 9], 10}, {Rational[41, 3], 10}}, {{
      12.777777777777779`, 10}, {13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {Rational[131, 9], 18}}, {{
      13.666666666666666`, 18}, {14.555555555555555`, 18}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[154, 9]}, {
      Rational[131, 9], Rational[154, 9]}}, {{13.666666666666666`, 
     17.11111111111111}, {14.555555555555555`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[146, 9]}, {
      Rational[131, 9], Rational[146, 9]}}, {{13.666666666666666`, 
     16.22222222222222}, {14.555555555555555`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[131, 9], Rational[46, 3]}}, {{13.666666666666666`, 
     15.333333333333334`}, {14.555555555555555`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[130, 9]}, {
      Rational[131, 9], Rational[130, 9]}}, {{13.666666666666666`, 
     14.444444444444445`}, {14.555555555555555`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[122, 9]}, {
      Rational[131, 9], Rational[122, 9]}}, {{13.666666666666666`, 
     13.555555555555555`}, {14.555555555555555`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[131, 9], Rational[38, 3]}}, {{13.666666666666666`, 
     12.666666666666666`}, {14.555555555555555`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[106, 9]}, {
      Rational[131, 9], Rational[106, 9]}}, {{13.666666666666666`, 
     11.777777777777779`}, {14.555555555555555`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[98, 9]}, {
      Rational[131, 9], Rational[98, 9]}}, {{13.666666666666666`, 
     10.88888888888889}, {14.555555555555555`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[41, 3], 10}, {Rational[131, 9], 10}}, {{
      13.666666666666666`, 10}, {14.555555555555555`, 10}}]], 
   LineBox[NCache[{{Rational[131, 9], 18}, {Rational[139, 9], 18}}, {{
      14.555555555555555`, 18}, {15.444444444444445`, 18}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[154, 9]}, {
      Rational[139, 9], Rational[154, 9]}}, {{14.555555555555555`, 
     17.11111111111111}, {15.444444444444445`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[146, 9]}, {
      Rational[139, 9], Rational[146, 9]}}, {{14.555555555555555`, 
     16.22222222222222}, {15.444444444444445`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[46, 3]}, {
      Rational[139, 9], Rational[46, 3]}}, {{14.555555555555555`, 
     15.333333333333334`}, {15.444444444444445`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[130, 9]}, {
      Rational[139, 9], Rational[130, 9]}}, {{14.555555555555555`, 
     14.444444444444445`}, {15.444444444444445`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[122, 9]}, {
      Rational[139, 9], Rational[122, 9]}}, {{14.555555555555555`, 
     13.555555555555555`}, {15.444444444444445`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[38, 3]}, {
      Rational[139, 9], Rational[38, 3]}}, {{14.555555555555555`, 
     12.666666666666666`}, {15.444444444444445`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[106, 9]}, {
      Rational[139, 9], Rational[106, 9]}}, {{14.555555555555555`, 
     11.777777777777779`}, {15.444444444444445`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[98, 9]}, {
      Rational[139, 9], Rational[98, 9]}}, {{14.555555555555555`, 
     10.88888888888889}, {15.444444444444445`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[131, 9], 10}, {Rational[139, 9], 10}}, {{
      14.555555555555555`, 10}, {15.444444444444445`, 10}}]], 
   LineBox[NCache[{{Rational[139, 9], 18}, {Rational[49, 3], 18}}, {{
      15.444444444444445`, 18}, {16.333333333333332`, 18}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[154, 9]}, {
      Rational[49, 3], Rational[154, 9]}}, {{15.444444444444445`, 
     17.11111111111111}, {16.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[146, 9]}, {
      Rational[49, 3], Rational[146, 9]}}, {{15.444444444444445`, 
     16.22222222222222}, {16.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[46, 3]}, {
      Rational[49, 3], Rational[46, 3]}}, {{15.444444444444445`, 
     15.333333333333334`}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[130, 9]}, {
      Rational[49, 3], Rational[130, 9]}}, {{15.444444444444445`, 
     14.444444444444445`}, {16.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[122, 9]}, {
      Rational[49, 3], Rational[122, 9]}}, {{15.444444444444445`, 
     13.555555555555555`}, {16.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[38, 3]}, {
      Rational[49, 3], Rational[38, 3]}}, {{15.444444444444445`, 
     12.666666666666666`}, {16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[106, 9]}, {
      Rational[49, 3], Rational[106, 9]}}, {{15.444444444444445`, 
     11.777777777777779`}, {16.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[98, 9]}, {
      Rational[49, 3], Rational[98, 9]}}, {{15.444444444444445`, 
     10.88888888888889}, {16.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[139, 9], 10}, {Rational[49, 3], 10}}, {{
      15.444444444444445`, 10}, {16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {Rational[155, 9], 18}}, {{
      16.333333333333332`, 18}, {17.22222222222222, 18}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[154, 9]}, {
      Rational[155, 9], Rational[154, 9]}}, {{16.333333333333332`, 
     17.11111111111111}, {17.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[146, 9]}, {
      Rational[155, 9], Rational[146, 9]}}, {{16.333333333333332`, 
     16.22222222222222}, {17.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[155, 9], Rational[46, 3]}}, {{16.333333333333332`, 
     15.333333333333334`}, {17.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[130, 9]}, {
      Rational[155, 9], Rational[130, 9]}}, {{16.333333333333332`, 
     14.444444444444445`}, {17.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[122, 9]}, {
      Rational[155, 9], Rational[122, 9]}}, {{16.333333333333332`, 
     13.555555555555555`}, {17.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[155, 9], Rational[38, 3]}}, {{16.333333333333332`, 
     12.666666666666666`}, {17.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[106, 9]}, {
      Rational[155, 9], Rational[106, 9]}}, {{16.333333333333332`, 
     11.777777777777779`}, {17.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[98, 9]}, {
      Rational[155, 9], Rational[98, 9]}}, {{16.333333333333332`, 
     10.88888888888889}, {17.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[49, 3], 10}, {Rational[155, 9], 10}}, {{
      16.333333333333332`, 10}, {17.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[155, 9], 18}, {Rational[163, 9], 18}}, {{
      17.22222222222222, 18}, {18.11111111111111, 18}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[154, 9]}, {
      Rational[163, 9], Rational[154, 9]}}, {{17.22222222222222, 
     17.11111111111111}, {18.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[146, 9]}, {
      Rational[163, 9], Rational[146, 9]}}, {{17.22222222222222, 
     16.22222222222222}, {18.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[46, 3]}, {
      Rational[163, 9], Rational[46, 3]}}, {{17.22222222222222, 
     15.333333333333334`}, {18.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[130, 9]}, {
      Rational[163, 9], Rational[130, 9]}}, {{17.22222222222222, 
     14.444444444444445`}, {18.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[122, 9]}, {
      Rational[163, 9], Rational[122, 9]}}, {{17.22222222222222, 
     13.555555555555555`}, {18.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[38, 3]}, {
      Rational[163, 9], Rational[38, 3]}}, {{17.22222222222222, 
     12.666666666666666`}, {18.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[106, 9]}, {
      Rational[163, 9], Rational[106, 9]}}, {{17.22222222222222, 
     11.777777777777779`}, {18.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[98, 9]}, {
      Rational[163, 9], Rational[98, 9]}}, {{17.22222222222222, 
     10.88888888888889}, {18.11111111111111, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[155, 9], 10}, {Rational[163, 9], 10}}, {{
      17.22222222222222, 10}, {18.11111111111111, 10}}]], 
   LineBox[NCache[{{Rational[163, 9], 18}, {19, 18}}, {{
      18.11111111111111, 18}, {19, 18}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[154, 9]}, {
      19, Rational[154, 9]}}, {{18.11111111111111, 17.11111111111111}, {
      19, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[146, 9]}, {
      19, Rational[146, 9]}}, {{18.11111111111111, 16.22222222222222}, {
      19, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[46, 3]}, {
      19, Rational[46, 3]}}, {{18.11111111111111, 15.333333333333334`}, {
      19, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[130, 9]}, {
      19, Rational[130, 9]}}, {{18.11111111111111, 14.444444444444445`}, {
      19, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[122, 9]}, {
      19, Rational[122, 9]}}, {{18.11111111111111, 13.555555555555555`}, {
      19, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[38, 3]}, {
      19, Rational[38, 3]}}, {{18.11111111111111, 12.666666666666666`}, {
      19, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[106, 9]}, {
      19, Rational[106, 9]}}, {{18.11111111111111, 11.777777777777779`}, {
      19, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[98, 9]}, {
      19, Rational[98, 9]}}, {{18.11111111111111, 10.88888888888889}, {
      19, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[163, 9], 10}, {19, 10}}, {{
      18.11111111111111, 10}, {19, 10}}]], 
   LineBox[NCache[{{11, 18}, {11, Rational[154, 9]}}, {{11, 18}, {
      11, 17.11111111111111}}]], 
   LineBox[NCache[{{11, Rational[154, 9]}, {11, Rational[146, 9]}}, {{
      11, 17.11111111111111}, {11, 16.22222222222222}}]], 
   LineBox[NCache[{{11, Rational[146, 9]}, {11, Rational[46, 3]}}, {{
      11, 16.22222222222222}, {11, 15.333333333333334`}}]], 
   LineBox[
    NCache[{{11, Rational[46, 3]}, {11, Rational[130, 9]}}, {{
      11, 15.333333333333334`}, {11, 14.444444444444445`}}]], 
   LineBox[NCache[{{11, Rational[130, 9]}, {11, Rational[122, 9]}}, {{
      11, 14.444444444444445`}, {11, 13.555555555555555`}}]], 
   LineBox[NCache[{{11, Rational[122, 9]}, {11, Rational[38, 3]}}, {{
      11, 13.555555555555555`}, {11, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {11, Rational[106, 9]}}, {{
      11, 12.666666666666666`}, {11, 11.777777777777779`}}]], 
   LineBox[NCache[{{11, Rational[106, 9]}, {11, Rational[98, 9]}}, {{
      11, 11.777777777777779`}, {11, 10.88888888888889}}]], 
   LineBox[NCache[{{11, Rational[98, 9]}, {11, 10}}, {{
      11, 10.88888888888889}, {11, 10}}]], 
   LineBox[NCache[{{Rational[107, 9], 18}, {
      Rational[107, 9], Rational[154, 9]}}, {{11.88888888888889, 18}, {
      11.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[154, 9]}, {
      Rational[107, 9], Rational[146, 9]}}, {{11.88888888888889, 
     17.11111111111111}, {11.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[146, 9]}, {
      Rational[107, 9], Rational[46, 3]}}, {{11.88888888888889, 
     16.22222222222222}, {11.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[46, 3]}, {
      Rational[107, 9], Rational[130, 9]}}, {{11.88888888888889, 
     15.333333333333334`}, {11.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[130, 9]}, {
      Rational[107, 9], Rational[122, 9]}}, {{11.88888888888889, 
     14.444444444444445`}, {11.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[122, 9]}, {
      Rational[107, 9], Rational[38, 3]}}, {{11.88888888888889, 
     13.555555555555555`}, {11.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[38, 3]}, {
      Rational[107, 9], Rational[106, 9]}}, {{11.88888888888889, 
     12.666666666666666`}, {11.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[106, 9]}, {
      Rational[107, 9], Rational[98, 9]}}, {{11.88888888888889, 
     11.777777777777779`}, {11.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[98, 9]}, {
      Rational[107, 9], 10}}, {{11.88888888888889, 10.88888888888889}, {
      11.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[115, 9], 18}, {
      Rational[115, 9], Rational[154, 9]}}, {{12.777777777777779`, 18}, {
      12.777777777777779`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[154, 9]}, {
      Rational[115, 9], Rational[146, 9]}}, {{12.777777777777779`, 
     17.11111111111111}, {12.777777777777779`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[146, 9]}, {
      Rational[115, 9], Rational[46, 3]}}, {{12.777777777777779`, 
     16.22222222222222}, {12.777777777777779`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[46, 3]}, {
      Rational[115, 9], Rational[130, 9]}}, {{12.777777777777779`, 
     15.333333333333334`}, {12.777777777777779`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[130, 9]}, {
      Rational[115, 9], Rational[122, 9]}}, {{12.777777777777779`, 
     14.444444444444445`}, {12.777777777777779`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[122, 9]}, {
      Rational[115, 9], Rational[38, 3]}}, {{12.777777777777779`, 
     13.555555555555555`}, {12.777777777777779`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[38, 3]}, {
      Rational[115, 9], Rational[106, 9]}}, {{12.777777777777779`, 
     12.666666666666666`}, {12.777777777777779`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[106, 9]}, {
      Rational[115, 9], Rational[98, 9]}}, {{12.777777777777779`, 
     11.777777777777779`}, {12.777777777777779`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[98, 9]}, {
      Rational[115, 9], 10}}, {{12.777777777777779`, 10.88888888888889}, {
      12.777777777777779`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {
      Rational[41, 3], Rational[154, 9]}}, {{13.666666666666666`, 18}, {
      13.666666666666666`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[154, 9]}, {
      Rational[41, 3], Rational[146, 9]}}, {{13.666666666666666`, 
     17.11111111111111}, {13.666666666666666`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[146, 9]}, {
      Rational[41, 3], Rational[46, 3]}}, {{13.666666666666666`, 
     16.22222222222222}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[41, 3], Rational[130, 9]}}, {{13.666666666666666`, 
     15.333333333333334`}, {13.666666666666666`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[130, 9]}, {
      Rational[41, 3], Rational[122, 9]}}, {{13.666666666666666`, 
     14.444444444444445`}, {13.666666666666666`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[122, 9]}, {
      Rational[41, 3], Rational[38, 3]}}, {{13.666666666666666`, 
     13.555555555555555`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[41, 3], Rational[106, 9]}}, {{13.666666666666666`, 
     12.666666666666666`}, {13.666666666666666`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[106, 9]}, {
      Rational[41, 3], Rational[98, 9]}}, {{13.666666666666666`, 
     11.777777777777779`}, {13.666666666666666`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[98, 9]}, {
      Rational[41, 3], 10}}, {{13.666666666666666`, 10.88888888888889}, {
      13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[131, 9], 18}, {
      Rational[131, 9], Rational[154, 9]}}, {{14.555555555555555`, 18}, {
      14.555555555555555`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[154, 9]}, {
      Rational[131, 9], Rational[146, 9]}}, {{14.555555555555555`, 
     17.11111111111111}, {14.555555555555555`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[146, 9]}, {
      Rational[131, 9], Rational[46, 3]}}, {{14.555555555555555`, 
     16.22222222222222}, {14.555555555555555`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[46, 3]}, {
      Rational[131, 9], Rational[130, 9]}}, {{14.555555555555555`, 
     15.333333333333334`}, {14.555555555555555`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[130, 9]}, {
      Rational[131, 9], Rational[122, 9]}}, {{14.555555555555555`, 
     14.444444444444445`}, {14.555555555555555`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[122, 9]}, {
      Rational[131, 9], Rational[38, 3]}}, {{14.555555555555555`, 
     13.555555555555555`}, {14.555555555555555`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[38, 3]}, {
      Rational[131, 9], Rational[106, 9]}}, {{14.555555555555555`, 
     12.666666666666666`}, {14.555555555555555`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[106, 9]}, {
      Rational[131, 9], Rational[98, 9]}}, {{14.555555555555555`, 
     11.777777777777779`}, {14.555555555555555`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[98, 9]}, {
      Rational[131, 9], 10}}, {{14.555555555555555`, 10.88888888888889}, {
      14.555555555555555`, 10}}]], 
   LineBox[NCache[{{Rational[139, 9], 18}, {
      Rational[139, 9], Rational[154, 9]}}, {{15.444444444444445`, 18}, {
      15.444444444444445`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[154, 9]}, {
      Rational[139, 9], Rational[146, 9]}}, {{15.444444444444445`, 
     17.11111111111111}, {15.444444444444445`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[146, 9]}, {
      Rational[139, 9], Rational[46, 3]}}, {{15.444444444444445`, 
     16.22222222222222}, {15.444444444444445`, 15.333333333333334`}}]], 
   LineBox[
    NCache[{{Rational[139, 9], Rational[46, 3]}, {
      Rational[139, 9], Rational[130, 9]}}, {{15.444444444444445`, 
     15.333333333333334`}, {15.444444444444445`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[130, 9]}, {
      Rational[139, 9], Rational[122, 9]}}, {{15.444444444444445`, 
     14.444444444444445`}, {15.444444444444445`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[122, 9]}, {
      Rational[139, 9], Rational[38, 3]}}, {{15.444444444444445`, 
     13.555555555555555`}, {15.444444444444445`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[38, 3]}, {
      Rational[139, 9], Rational[106, 9]}}, {{15.444444444444445`, 
     12.666666666666666`}, {15.444444444444445`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[106, 9]}, {
      Rational[139, 9], Rational[98, 9]}}, {{15.444444444444445`, 
     11.777777777777779`}, {15.444444444444445`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[98, 9]}, {
      Rational[139, 9], 10}}, {{15.444444444444445`, 10.88888888888889}, {
      15.444444444444445`, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {
      Rational[49, 3], Rational[154, 9]}}, {{16.333333333333332`, 18}, {
      16.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[154, 9]}, {
      Rational[49, 3], Rational[146, 9]}}, {{16.333333333333332`, 
     17.11111111111111}, {16.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[146, 9]}, {
      Rational[49, 3], Rational[46, 3]}}, {{16.333333333333332`, 
     16.22222222222222}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[49, 3], Rational[130, 9]}}, {{16.333333333333332`, 
     15.333333333333334`}, {16.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[130, 9]}, {
      Rational[49, 3], Rational[122, 9]}}, {{16.333333333333332`, 
     14.444444444444445`}, {16.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[122, 9]}, {
      Rational[49, 3], Rational[38, 3]}}, {{16.333333333333332`, 
     13.555555555555555`}, {16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[49, 3], Rational[106, 9]}}, {{16.333333333333332`, 
     12.666666666666666`}, {16.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[106, 9]}, {
      Rational[49, 3], Rational[98, 9]}}, {{16.333333333333332`, 
     11.777777777777779`}, {16.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[98, 9]}, {
      Rational[49, 3], 10}}, {{16.333333333333332`, 10.88888888888889}, {
      16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[155, 9], 18}, {
      Rational[155, 9], Rational[154, 9]}}, {{17.22222222222222, 18}, {
      17.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[154, 9]}, {
      Rational[155, 9], Rational[146, 9]}}, {{17.22222222222222, 
     17.11111111111111}, {17.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[146, 9]}, {
      Rational[155, 9], Rational[46, 3]}}, {{17.22222222222222, 
     16.22222222222222}, {17.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[46, 3]}, {
      Rational[155, 9], Rational[130, 9]}}, {{17.22222222222222, 
     15.333333333333334`}, {17.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[130, 9]}, {
      Rational[155, 9], Rational[122, 9]}}, {{17.22222222222222, 
     14.444444444444445`}, {17.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[122, 9]}, {
      Rational[155, 9], Rational[38, 3]}}, {{17.22222222222222, 
     13.555555555555555`}, {17.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[38, 3]}, {
      Rational[155, 9], Rational[106, 9]}}, {{17.22222222222222, 
     12.666666666666666`}, {17.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[106, 9]}, {
      Rational[155, 9], Rational[98, 9]}}, {{17.22222222222222, 
     11.777777777777779`}, {17.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[98, 9]}, {
      Rational[155, 9], 10}}, {{17.22222222222222, 10.88888888888889}, {
      17.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[163, 9], 18}, {
      Rational[163, 9], Rational[154, 9]}}, {{18.11111111111111, 18}, {
      18.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[154, 9]}, {
      Rational[163, 9], Rational[146, 9]}}, {{18.11111111111111, 
     17.11111111111111}, {18.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[146, 9]}, {
      Rational[163, 9], Rational[46, 3]}}, {{18.11111111111111, 
     16.22222222222222}, {18.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[46, 3]}, {
      Rational[163, 9], Rational[130, 9]}}, {{18.11111111111111, 
     15.333333333333334`}, {18.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[130, 9]}, {
      Rational[163, 9], Rational[122, 9]}}, {{18.11111111111111, 
     14.444444444444445`}, {18.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[122, 9]}, {
      Rational[163, 9], Rational[38, 3]}}, {{18.11111111111111, 
     13.555555555555555`}, {18.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[38, 3]}, {
      Rational[163, 9], Rational[106, 9]}}, {{18.11111111111111, 
     12.666666666666666`}, {18.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[106, 9]}, {
      Rational[163, 9], Rational[98, 9]}}, {{18.11111111111111, 
     11.777777777777779`}, {18.11111111111111, 10.88888888888889}}]], 
   LineBox[
    NCache[{{Rational[163, 9], Rational[98, 9]}, {Rational[163, 9], 10}}, {{
      18.11111111111111, 10.88888888888889}, {18.11111111111111, 10}}]], 
   LineBox[NCache[{{19, 18}, {19, Rational[154, 9]}}, {{19, 18}, {
      19, 17.11111111111111}}]], 
   LineBox[NCache[{{19, Rational[154, 9]}, {19, Rational[146, 9]}}, {{
      19, 17.11111111111111}, {19, 16.22222222222222}}]], 
   LineBox[NCache[{{19, Rational[146, 9]}, {19, Rational[46, 3]}}, {{
      19, 16.22222222222222}, {19, 15.333333333333334`}}]], 
   LineBox[NCache[{{19, Rational[46, 3]}, {19, Rational[130, 9]}}, {{
      19, 15.333333333333334`}, {19, 14.444444444444445`}}]], 
   LineBox[NCache[{{19, Rational[130, 9]}, {19, Rational[122, 9]}}, {{
      19, 14.444444444444445`}, {19, 13.555555555555555`}}]], 
   LineBox[NCache[{{19, Rational[122, 9]}, {19, Rational[38, 3]}}, {{
      19, 13.555555555555555`}, {19, 12.666666666666666`}}]], 
   LineBox[NCache[{{19, Rational[38, 3]}, {19, Rational[106, 9]}}, {{
      19, 12.666666666666666`}, {19, 11.777777777777779`}}]], 
   LineBox[NCache[{{19, Rational[106, 9]}, {19, Rational[98, 9]}}, {{
      19, 11.777777777777779`}, {19, 10.88888888888889}}]], 
   LineBox[NCache[{{19, Rational[98, 9]}, {19, 10}}, {{
      19, 10.88888888888889}, {19, 10}}]], 
   LineBox[NCache[{{21, 18}, {Rational[197, 9], 18}}, {{21, 18}, {
      21.88888888888889, 18}}]], 
   LineBox[NCache[{{21, Rational[154, 9]}, {
      Rational[197, 9], Rational[154, 9]}}, {{21, 17.11111111111111}, {
      21.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{21, Rational[146, 9]}, {
      Rational[197, 9], Rational[146, 9]}}, {{21, 16.22222222222222}, {
      21.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{21, Rational[46, 3]}, {
      Rational[197, 9], Rational[46, 3]}}, {{21, 15.333333333333334`}, {
      21.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{21, Rational[130, 9]}, {
      Rational[197, 9], Rational[130, 9]}}, {{21, 14.444444444444445`}, {
      21.88888888888889, 14.444444444444445`}}]], 
   LineBox[
    NCache[{{21, Rational[122, 9]}, {Rational[197, 9], Rational[122, 9]}}, {{
      21, 13.555555555555555`}, {21.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{21, Rational[38, 3]}, {
      Rational[197, 9], Rational[38, 3]}}, {{21, 12.666666666666666`}, {
      21.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{21, Rational[106, 9]}, {
      Rational[197, 9], Rational[106, 9]}}, {{21, 11.777777777777779`}, {
      21.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{21, Rational[98, 9]}, {
      Rational[197, 9], Rational[98, 9]}}, {{21, 10.88888888888889}, {
      21.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{21, 10}, {Rational[197, 9], 10}}, {{21, 10}, {
      21.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[197, 9], 18}, {Rational[205, 9], 18}}, {{
      21.88888888888889, 18}, {22.77777777777778, 18}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[154, 9]}, {
      Rational[205, 9], Rational[154, 9]}}, {{21.88888888888889, 
     17.11111111111111}, {22.77777777777778, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[146, 9]}, {
      Rational[205, 9], Rational[146, 9]}}, {{21.88888888888889, 
     16.22222222222222}, {22.77777777777778, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[46, 3]}, {
      Rational[205, 9], Rational[46, 3]}}, {{21.88888888888889, 
     15.333333333333334`}, {22.77777777777778, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[130, 9]}, {
      Rational[205, 9], Rational[130, 9]}}, {{21.88888888888889, 
     14.444444444444445`}, {22.77777777777778, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[122, 9]}, {
      Rational[205, 9], Rational[122, 9]}}, {{21.88888888888889, 
     13.555555555555555`}, {22.77777777777778, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[38, 3]}, {
      Rational[205, 9], Rational[38, 3]}}, {{21.88888888888889, 
     12.666666666666666`}, {22.77777777777778, 12.666666666666666`}}]], 
   LineBox[
    NCache[{{Rational[197, 9], Rational[106, 9]}, {
      Rational[205, 9], Rational[106, 9]}}, {{21.88888888888889, 
     11.777777777777779`}, {22.77777777777778, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[98, 9]}, {
      Rational[205, 9], Rational[98, 9]}}, {{21.88888888888889, 
     10.88888888888889}, {22.77777777777778, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[197, 9], 10}, {Rational[205, 9], 10}}, {{
      21.88888888888889, 10}, {22.77777777777778, 10}}]], 
   LineBox[NCache[{{Rational[205, 9], 18}, {Rational[71, 3], 18}}, {{
      22.77777777777778, 18}, {23.666666666666668`, 18}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[154, 9]}, {
      Rational[71, 3], Rational[154, 9]}}, {{22.77777777777778, 
     17.11111111111111}, {23.666666666666668`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[146, 9]}, {
      Rational[71, 3], Rational[146, 9]}}, {{22.77777777777778, 
     16.22222222222222}, {23.666666666666668`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[46, 3]}, {
      Rational[71, 3], Rational[46, 3]}}, {{22.77777777777778, 
     15.333333333333334`}, {23.666666666666668`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[130, 9]}, {
      Rational[71, 3], Rational[130, 9]}}, {{22.77777777777778, 
     14.444444444444445`}, {23.666666666666668`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[122, 9]}, {
      Rational[71, 3], Rational[122, 9]}}, {{22.77777777777778, 
     13.555555555555555`}, {23.666666666666668`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[38, 3]}, {
      Rational[71, 3], Rational[38, 3]}}, {{22.77777777777778, 
     12.666666666666666`}, {23.666666666666668`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[106, 9]}, {
      Rational[71, 3], Rational[106, 9]}}, {{22.77777777777778, 
     11.777777777777779`}, {23.666666666666668`, 11.777777777777779`}}]], 
   LineBox[
    NCache[{{Rational[205, 9], Rational[98, 9]}, {
      Rational[71, 3], Rational[98, 9]}}, {{22.77777777777778, 
     10.88888888888889}, {23.666666666666668`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[205, 9], 10}, {Rational[71, 3], 10}}, {{
      22.77777777777778, 10}, {23.666666666666668`, 10}}]], 
   LineBox[NCache[{{Rational[71, 3], 18}, {Rational[221, 9], 18}}, {{
      23.666666666666668`, 18}, {24.555555555555557`, 18}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[154, 9]}, {
      Rational[221, 9], Rational[154, 9]}}, {{23.666666666666668`, 
     17.11111111111111}, {24.555555555555557`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[146, 9]}, {
      Rational[221, 9], Rational[146, 9]}}, {{23.666666666666668`, 
     16.22222222222222}, {24.555555555555557`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[46, 3]}, {
      Rational[221, 9], Rational[46, 3]}}, {{23.666666666666668`, 
     15.333333333333334`}, {24.555555555555557`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[130, 9]}, {
      Rational[221, 9], Rational[130, 9]}}, {{23.666666666666668`, 
     14.444444444444445`}, {24.555555555555557`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[122, 9]}, {
      Rational[221, 9], Rational[122, 9]}}, {{23.666666666666668`, 
     13.555555555555555`}, {24.555555555555557`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[38, 3]}, {
      Rational[221, 9], Rational[38, 3]}}, {{23.666666666666668`, 
     12.666666666666666`}, {24.555555555555557`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[106, 9]}, {
      Rational[221, 9], Rational[106, 9]}}, {{23.666666666666668`, 
     11.777777777777779`}, {24.555555555555557`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[98, 9]}, {
      Rational[221, 9], Rational[98, 9]}}, {{23.666666666666668`, 
     10.88888888888889}, {24.555555555555557`, 10.88888888888889}}]], 
   LineBox[
    NCache[{{Rational[71, 3], 10}, {Rational[221, 9], 10}}, {{
      23.666666666666668`, 10}, {24.555555555555557`, 10}}]], 
   LineBox[NCache[{{Rational[221, 9], 18}, {Rational[229, 9], 18}}, {{
      24.555555555555557`, 18}, {25.444444444444443`, 18}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[154, 9]}, {
      Rational[229, 9], Rational[154, 9]}}, {{24.555555555555557`, 
     17.11111111111111}, {25.444444444444443`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[146, 9]}, {
      Rational[229, 9], Rational[146, 9]}}, {{24.555555555555557`, 
     16.22222222222222}, {25.444444444444443`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[46, 3]}, {
      Rational[229, 9], Rational[46, 3]}}, {{24.555555555555557`, 
     15.333333333333334`}, {25.444444444444443`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[130, 9]}, {
      Rational[229, 9], Rational[130, 9]}}, {{24.555555555555557`, 
     14.444444444444445`}, {25.444444444444443`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[122, 9]}, {
      Rational[229, 9], Rational[122, 9]}}, {{24.555555555555557`, 
     13.555555555555555`}, {25.444444444444443`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[38, 3]}, {
      Rational[229, 9], Rational[38, 3]}}, {{24.555555555555557`, 
     12.666666666666666`}, {25.444444444444443`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[106, 9]}, {
      Rational[229, 9], Rational[106, 9]}}, {{24.555555555555557`, 
     11.777777777777779`}, {25.444444444444443`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[98, 9]}, {
      Rational[229, 9], Rational[98, 9]}}, {{24.555555555555557`, 
     10.88888888888889}, {25.444444444444443`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[221, 9], 10}, {Rational[229, 9], 10}}, {{
      24.555555555555557`, 10}, {25.444444444444443`, 10}}]], 
   LineBox[NCache[{{Rational[229, 9], 18}, {Rational[79, 3], 18}}, {{
      25.444444444444443`, 18}, {26.333333333333332`, 18}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[154, 9]}, {
      Rational[79, 3], Rational[154, 9]}}, {{25.444444444444443`, 
     17.11111111111111}, {26.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[146, 9]}, {
      Rational[79, 3], Rational[146, 9]}}, {{25.444444444444443`, 
     16.22222222222222}, {26.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[46, 3]}, {
      Rational[79, 3], Rational[46, 3]}}, {{25.444444444444443`, 
     15.333333333333334`}, {26.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[130, 9]}, {
      Rational[79, 3], Rational[130, 9]}}, {{25.444444444444443`, 
     14.444444444444445`}, {26.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[122, 9]}, {
      Rational[79, 3], Rational[122, 9]}}, {{25.444444444444443`, 
     13.555555555555555`}, {26.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[38, 3]}, {
      Rational[79, 3], Rational[38, 3]}}, {{25.444444444444443`, 
     12.666666666666666`}, {26.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[106, 9]}, {
      Rational[79, 3], Rational[106, 9]}}, {{25.444444444444443`, 
     11.777777777777779`}, {26.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[98, 9]}, {
      Rational[79, 3], Rational[98, 9]}}, {{25.444444444444443`, 
     10.88888888888889}, {26.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[229, 9], 10}, {Rational[79, 3], 10}}, {{
      25.444444444444443`, 10}, {26.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[79, 3], 18}, {Rational[245, 9], 18}}, {{
      26.333333333333332`, 18}, {27.22222222222222, 18}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[154, 9]}, {
      Rational[245, 9], Rational[154, 9]}}, {{26.333333333333332`, 
     17.11111111111111}, {27.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[146, 9]}, {
      Rational[245, 9], Rational[146, 9]}}, {{26.333333333333332`, 
     16.22222222222222}, {27.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[46, 3]}, {
      Rational[245, 9], Rational[46, 3]}}, {{26.333333333333332`, 
     15.333333333333334`}, {27.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[130, 9]}, {
      Rational[245, 9], Rational[130, 9]}}, {{26.333333333333332`, 
     14.444444444444445`}, {27.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[122, 9]}, {
      Rational[245, 9], Rational[122, 9]}}, {{26.333333333333332`, 
     13.555555555555555`}, {27.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[38, 3]}, {
      Rational[245, 9], Rational[38, 3]}}, {{26.333333333333332`, 
     12.666666666666666`}, {27.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[106, 9]}, {
      Rational[245, 9], Rational[106, 9]}}, {{26.333333333333332`, 
     11.777777777777779`}, {27.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[98, 9]}, {
      Rational[245, 9], Rational[98, 9]}}, {{26.333333333333332`, 
     10.88888888888889}, {27.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[79, 3], 10}, {Rational[245, 9], 10}}, {{
      26.333333333333332`, 10}, {27.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[245, 9], 18}, {Rational[253, 9], 18}}, {{
      27.22222222222222, 18}, {28.11111111111111, 18}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[154, 9]}, {
      Rational[253, 9], Rational[154, 9]}}, {{27.22222222222222, 
     17.11111111111111}, {28.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[146, 9]}, {
      Rational[253, 9], Rational[146, 9]}}, {{27.22222222222222, 
     16.22222222222222}, {28.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[46, 3]}, {
      Rational[253, 9], Rational[46, 3]}}, {{27.22222222222222, 
     15.333333333333334`}, {28.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[130, 9]}, {
      Rational[253, 9], Rational[130, 9]}}, {{27.22222222222222, 
     14.444444444444445`}, {28.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[122, 9]}, {
      Rational[253, 9], Rational[122, 9]}}, {{27.22222222222222, 
     13.555555555555555`}, {28.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[38, 3]}, {
      Rational[253, 9], Rational[38, 3]}}, {{27.22222222222222, 
     12.666666666666666`}, {28.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[106, 9]}, {
      Rational[253, 9], Rational[106, 9]}}, {{27.22222222222222, 
     11.777777777777779`}, {28.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[98, 9]}, {
      Rational[253, 9], Rational[98, 9]}}, {{27.22222222222222, 
     10.88888888888889}, {28.11111111111111, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[245, 9], 10}, {Rational[253, 9], 10}}, {{
      27.22222222222222, 10}, {28.11111111111111, 10}}]], 
   LineBox[NCache[{{Rational[253, 9], 18}, {29, 18}}, {{
      28.11111111111111, 18}, {29, 18}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[154, 9]}, {
      29, Rational[154, 9]}}, {{28.11111111111111, 17.11111111111111}, {
      29, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[146, 9]}, {
      29, Rational[146, 9]}}, {{28.11111111111111, 16.22222222222222}, {
      29, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[46, 3]}, {
      29, Rational[46, 3]}}, {{28.11111111111111, 15.333333333333334`}, {
      29, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[130, 9]}, {
      29, Rational[130, 9]}}, {{28.11111111111111, 14.444444444444445`}, {
      29, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[122, 9]}, {
      29, Rational[122, 9]}}, {{28.11111111111111, 13.555555555555555`}, {
      29, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[38, 3]}, {
      29, Rational[38, 3]}}, {{28.11111111111111, 12.666666666666666`}, {
      29, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[106, 9]}, {
      29, Rational[106, 9]}}, {{28.11111111111111, 11.777777777777779`}, {
      29, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[98, 9]}, {
      29, Rational[98, 9]}}, {{28.11111111111111, 10.88888888888889}, {
      29, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[253, 9], 10}, {29, 10}}, {{
      28.11111111111111, 10}, {29, 10}}]], 
   LineBox[NCache[{{21, 18}, {21, Rational[154, 9]}}, {{21, 18}, {
      21, 17.11111111111111}}]], 
   LineBox[NCache[{{21, Rational[154, 9]}, {21, Rational[146, 9]}}, {{
      21, 17.11111111111111}, {21, 16.22222222222222}}]], 
   LineBox[NCache[{{21, Rational[146, 9]}, {21, Rational[46, 3]}}, {{
      21, 16.22222222222222}, {21, 15.333333333333334`}}]], 
   LineBox[NCache[{{21, Rational[46, 3]}, {21, Rational[130, 9]}}, {{
      21, 15.333333333333334`}, {21, 14.444444444444445`}}]], 
   LineBox[NCache[{{21, Rational[130, 9]}, {21, Rational[122, 9]}}, {{
      21, 14.444444444444445`}, {21, 13.555555555555555`}}]], 
   LineBox[NCache[{{21, Rational[122, 9]}, {21, Rational[38, 3]}}, {{
      21, 13.555555555555555`}, {21, 12.666666666666666`}}]], 
   LineBox[NCache[{{21, Rational[38, 3]}, {21, Rational[106, 9]}}, {{
      21, 12.666666666666666`}, {21, 11.777777777777779`}}]], 
   LineBox[NCache[{{21, Rational[106, 9]}, {21, Rational[98, 9]}}, {{
      21, 11.777777777777779`}, {21, 10.88888888888889}}]], 
   LineBox[NCache[{{21, Rational[98, 9]}, {21, 10}}, {{
      21, 10.88888888888889}, {21, 10}}]], 
   LineBox[NCache[{{Rational[197, 9], 18}, {
      Rational[197, 9], Rational[154, 9]}}, {{21.88888888888889, 18}, {
      21.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[154, 9]}, {
      Rational[197, 9], Rational[146, 9]}}, {{21.88888888888889, 
     17.11111111111111}, {21.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[146, 9]}, {
      Rational[197, 9], Rational[46, 3]}}, {{21.88888888888889, 
     16.22222222222222}, {21.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[46, 3]}, {
      Rational[197, 9], Rational[130, 9]}}, {{21.88888888888889, 
     15.333333333333334`}, {21.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[130, 9]}, {
      Rational[197, 9], Rational[122, 9]}}, {{21.88888888888889, 
     14.444444444444445`}, {21.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[122, 9]}, {
      Rational[197, 9], Rational[38, 3]}}, {{21.88888888888889, 
     13.555555555555555`}, {21.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[38, 3]}, {
      Rational[197, 9], Rational[106, 9]}}, {{21.88888888888889, 
     12.666666666666666`}, {21.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[106, 9]}, {
      Rational[197, 9], Rational[98, 9]}}, {{21.88888888888889, 
     11.777777777777779`}, {21.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[98, 9]}, {
      Rational[197, 9], 10}}, {{21.88888888888889, 10.88888888888889}, {
      21.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[205, 9], 18}, {
      Rational[205, 9], Rational[154, 9]}}, {{22.77777777777778, 18}, {
      22.77777777777778, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[154, 9]}, {
      Rational[205, 9], Rational[146, 9]}}, {{22.77777777777778, 
     17.11111111111111}, {22.77777777777778, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[146, 9]}, {
      Rational[205, 9], Rational[46, 3]}}, {{22.77777777777778, 
     16.22222222222222}, {22.77777777777778, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[46, 3]}, {
      Rational[205, 9], Rational[130, 9]}}, {{22.77777777777778, 
     15.333333333333334`}, {22.77777777777778, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[130, 9]}, {
      Rational[205, 9], Rational[122, 9]}}, {{22.77777777777778, 
     14.444444444444445`}, {22.77777777777778, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[122, 9]}, {
      Rational[205, 9], Rational[38, 3]}}, {{22.77777777777778, 
     13.555555555555555`}, {22.77777777777778, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[38, 3]}, {
      Rational[205, 9], Rational[106, 9]}}, {{22.77777777777778, 
     12.666666666666666`}, {22.77777777777778, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[106, 9]}, {
      Rational[205, 9], Rational[98, 9]}}, {{22.77777777777778, 
     11.777777777777779`}, {22.77777777777778, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[98, 9]}, {
      Rational[205, 9], 10}}, {{22.77777777777778, 10.88888888888889}, {
      22.77777777777778, 10}}]], 
   LineBox[NCache[{{Rational[71, 3], 18}, {
      Rational[71, 3], Rational[154, 9]}}, {{23.666666666666668`, 18}, {
      23.666666666666668`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[154, 9]}, {
      Rational[71, 3], Rational[146, 9]}}, {{23.666666666666668`, 
     17.11111111111111}, {23.666666666666668`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[146, 9]}, {
      Rational[71, 3], Rational[46, 3]}}, {{23.666666666666668`, 
     16.22222222222222}, {23.666666666666668`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[46, 3]}, {
      Rational[71, 3], Rational[130, 9]}}, {{23.666666666666668`, 
     15.333333333333334`}, {23.666666666666668`, 14.444444444444445`}}]], 
   LineBox[
    NCache[{{Rational[71, 3], Rational[130, 9]}, {
      Rational[71, 3], Rational[122, 9]}}, {{23.666666666666668`, 
     14.444444444444445`}, {23.666666666666668`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[122, 9]}, {
      Rational[71, 3], Rational[38, 3]}}, {{23.666666666666668`, 
     13.555555555555555`}, {23.666666666666668`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[38, 3]}, {
      Rational[71, 3], Rational[106, 9]}}, {{23.666666666666668`, 
     12.666666666666666`}, {23.666666666666668`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[106, 9]}, {
      Rational[71, 3], Rational[98, 9]}}, {{23.666666666666668`, 
     11.777777777777779`}, {23.666666666666668`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[98, 9]}, {
      Rational[71, 3], 10}}, {{23.666666666666668`, 10.88888888888889}, {
      23.666666666666668`, 10}}]], 
   LineBox[NCache[{{Rational[221, 9], 18}, {
      Rational[221, 9], Rational[154, 9]}}, {{24.555555555555557`, 18}, {
      24.555555555555557`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[154, 9]}, {
      Rational[221, 9], Rational[146, 9]}}, {{24.555555555555557`, 
     17.11111111111111}, {24.555555555555557`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[146, 9]}, {
      Rational[221, 9], Rational[46, 3]}}, {{24.555555555555557`, 
     16.22222222222222}, {24.555555555555557`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[46, 3]}, {
      Rational[221, 9], Rational[130, 9]}}, {{24.555555555555557`, 
     15.333333333333334`}, {24.555555555555557`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[130, 9]}, {
      Rational[221, 9], Rational[122, 9]}}, {{24.555555555555557`, 
     14.444444444444445`}, {24.555555555555557`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[122, 9]}, {
      Rational[221, 9], Rational[38, 3]}}, {{24.555555555555557`, 
     13.555555555555555`}, {24.555555555555557`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[38, 3]}, {
      Rational[221, 9], Rational[106, 9]}}, {{24.555555555555557`, 
     12.666666666666666`}, {24.555555555555557`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[106, 9]}, {
      Rational[221, 9], Rational[98, 9]}}, {{24.555555555555557`, 
     11.777777777777779`}, {24.555555555555557`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[98, 9]}, {
      Rational[221, 9], 10}}, {{24.555555555555557`, 10.88888888888889}, {
      24.555555555555557`, 10}}]], 
   LineBox[NCache[{{Rational[229, 9], 18}, {
      Rational[229, 9], Rational[154, 9]}}, {{25.444444444444443`, 18}, {
      25.444444444444443`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[154, 9]}, {
      Rational[229, 9], Rational[146, 9]}}, {{25.444444444444443`, 
     17.11111111111111}, {25.444444444444443`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[146, 9]}, {
      Rational[229, 9], Rational[46, 3]}}, {{25.444444444444443`, 
     16.22222222222222}, {25.444444444444443`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[46, 3]}, {
      Rational[229, 9], Rational[130, 9]}}, {{25.444444444444443`, 
     15.333333333333334`}, {25.444444444444443`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[130, 9]}, {
      Rational[229, 9], Rational[122, 9]}}, {{25.444444444444443`, 
     14.444444444444445`}, {25.444444444444443`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[122, 9]}, {
      Rational[229, 9], Rational[38, 3]}}, {{25.444444444444443`, 
     13.555555555555555`}, {25.444444444444443`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[38, 3]}, {
      Rational[229, 9], Rational[106, 9]}}, {{25.444444444444443`, 
     12.666666666666666`}, {25.444444444444443`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[106, 9]}, {
      Rational[229, 9], Rational[98, 9]}}, {{25.444444444444443`, 
     11.777777777777779`}, {25.444444444444443`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[98, 9]}, {
      Rational[229, 9], 10}}, {{25.444444444444443`, 10.88888888888889}, {
      25.444444444444443`, 10}}]], 
   LineBox[NCache[{{Rational[79, 3], 18}, {
      Rational[79, 3], Rational[154, 9]}}, {{26.333333333333332`, 18}, {
      26.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[154, 9]}, {
      Rational[79, 3], Rational[146, 9]}}, {{26.333333333333332`, 
     17.11111111111111}, {26.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[146, 9]}, {
      Rational[79, 3], Rational[46, 3]}}, {{26.333333333333332`, 
     16.22222222222222}, {26.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[46, 3]}, {
      Rational[79, 3], Rational[130, 9]}}, {{26.333333333333332`, 
     15.333333333333334`}, {26.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[130, 9]}, {
      Rational[79, 3], Rational[122, 9]}}, {{26.333333333333332`, 
     14.444444444444445`}, {26.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[122, 9]}, {
      Rational[79, 3], Rational[38, 3]}}, {{26.333333333333332`, 
     13.555555555555555`}, {26.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[38, 3]}, {
      Rational[79, 3], Rational[106, 9]}}, {{26.333333333333332`, 
     12.666666666666666`}, {26.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[106, 9]}, {
      Rational[79, 3], Rational[98, 9]}}, {{26.333333333333332`, 
     11.777777777777779`}, {26.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[98, 9]}, {
      Rational[79, 3], 10}}, {{26.333333333333332`, 10.88888888888889}, {
      26.333333333333332`, 10}}]], 
   LineBox[
    NCache[{{Rational[245, 9], 18}, {Rational[245, 9], Rational[154, 9]}}, {{
      27.22222222222222, 18}, {27.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[154, 9]}, {
      Rational[245, 9], Rational[146, 9]}}, {{27.22222222222222, 
     17.11111111111111}, {27.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[146, 9]}, {
      Rational[245, 9], Rational[46, 3]}}, {{27.22222222222222, 
     16.22222222222222}, {27.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[46, 3]}, {
      Rational[245, 9], Rational[130, 9]}}, {{27.22222222222222, 
     15.333333333333334`}, {27.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[130, 9]}, {
      Rational[245, 9], Rational[122, 9]}}, {{27.22222222222222, 
     14.444444444444445`}, {27.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[122, 9]}, {
      Rational[245, 9], Rational[38, 3]}}, {{27.22222222222222, 
     13.555555555555555`}, {27.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[38, 3]}, {
      Rational[245, 9], Rational[106, 9]}}, {{27.22222222222222, 
     12.666666666666666`}, {27.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[106, 9]}, {
      Rational[245, 9], Rational[98, 9]}}, {{27.22222222222222, 
     11.777777777777779`}, {27.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[98, 9]}, {
      Rational[245, 9], 10}}, {{27.22222222222222, 10.88888888888889}, {
      27.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[253, 9], 18}, {
      Rational[253, 9], Rational[154, 9]}}, {{28.11111111111111, 18}, {
      28.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[154, 9]}, {
      Rational[253, 9], Rational[146, 9]}}, {{28.11111111111111, 
     17.11111111111111}, {28.11111111111111, 16.22222222222222}}]], 
   LineBox[
    NCache[{{Rational[253, 9], Rational[146, 9]}, {
      Rational[253, 9], Rational[46, 3]}}, {{28.11111111111111, 
     16.22222222222222}, {28.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[46, 3]}, {
      Rational[253, 9], Rational[130, 9]}}, {{28.11111111111111, 
     15.333333333333334`}, {28.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[130, 9]}, {
      Rational[253, 9], Rational[122, 9]}}, {{28.11111111111111, 
     14.444444444444445`}, {28.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[122, 9]}, {
      Rational[253, 9], Rational[38, 3]}}, {{28.11111111111111, 
     13.555555555555555`}, {28.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[38, 3]}, {
      Rational[253, 9], Rational[106, 9]}}, {{28.11111111111111, 
     12.666666666666666`}, {28.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[106, 9]}, {
      Rational[253, 9], Rational[98, 9]}}, {{28.11111111111111, 
     11.777777777777779`}, {28.11111111111111, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[98, 9]}, {
      Rational[253, 9], 10}}, {{28.11111111111111, 10.88888888888889}, {
      28.11111111111111, 10}}]], 
   LineBox[NCache[{{29, 18}, {29, Rational[154, 9]}}, {{29, 18}, {
      29, 17.11111111111111}}]], 
   LineBox[NCache[{{29, Rational[154, 9]}, {29, Rational[146, 9]}}, {{
      29, 17.11111111111111}, {29, 16.22222222222222}}]], 
   LineBox[NCache[{{29, Rational[146, 9]}, {29, Rational[46, 3]}}, {{
      29, 16.22222222222222}, {29, 15.333333333333334`}}]], 
   LineBox[NCache[{{29, Rational[46, 3]}, {29, Rational[130, 9]}}, {{
      29, 15.333333333333334`}, {29, 14.444444444444445`}}]], 
   LineBox[NCache[{{29, Rational[130, 9]}, {29, Rational[122, 9]}}, {{
      29, 14.444444444444445`}, {29, 13.555555555555555`}}]], 
   LineBox[NCache[{{29, Rational[122, 9]}, {29, Rational[38, 3]}}, {{
      29, 13.555555555555555`}, {29, 12.666666666666666`}}]], 
   LineBox[NCache[{{29, Rational[38, 3]}, {29, Rational[106, 9]}}, {{
      29, 12.666666666666666`}, {29, 11.777777777777779`}}]], 
   LineBox[NCache[{{29, Rational[106, 9]}, {29, Rational[98, 9]}}, {{
      29, 11.777777777777779`}, {29, 10.88888888888889}}]], 
   LineBox[NCache[{{29, Rational[98, 9]}, {29, 10}}, {{
      29, 10.88888888888889}, {29, 10}}]], 
   LineBox[NCache[{{11, 8}, {Rational[107, 9], 8}}, {{11, 8}, {
      11.88888888888889, 8}}]], 
   LineBox[NCache[{{11, Rational[64, 9]}, {
      Rational[107, 9], Rational[64, 9]}}, {{11, 7.111111111111111}, {
      11.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{11, Rational[56, 9]}, {
      Rational[107, 9], Rational[56, 9]}}, {{11, 6.222222222222222}, {
      11.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{11, Rational[16, 3]}, {
      Rational[107, 9], Rational[16, 3]}}, {{11, 5.333333333333333}, {
      11.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{11, Rational[40, 9]}, {
      Rational[107, 9], Rational[40, 9]}}, {{11, 4.444444444444445}, {
      11.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{11, Rational[32, 9]}, {
      Rational[107, 9], Rational[32, 9]}}, {{11, 3.5555555555555554`}, {
      11.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{11, Rational[8, 3]}, {
      Rational[107, 9], Rational[8, 3]}}, {{11, 2.6666666666666665`}, {
      11.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{11, Rational[16, 9]}, {
      Rational[107, 9], Rational[16, 9]}}, {{11, 1.7777777777777777`}, {
      11.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{11, Rational[8, 9]}, {
      Rational[107, 9], Rational[8, 9]}}, {{11, 0.8888888888888888}, {
      11.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{11, 0}, {Rational[107, 9], 0}}, {{11, 0}, {
      11.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[107, 9], 8}, {Rational[115, 9], 8}}, {{
      11.88888888888889, 8}, {12.777777777777779`, 8}}]], 
   LineBox[
    NCache[{{Rational[107, 9], Rational[64, 9]}, {
      Rational[115, 9], Rational[64, 9]}}, {{11.88888888888889, 
     7.111111111111111}, {12.777777777777779`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[56, 9]}, {
      Rational[115, 9], Rational[56, 9]}}, {{11.88888888888889, 
     6.222222222222222}, {12.777777777777779`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 3]}, {
      Rational[115, 9], Rational[16, 3]}}, {{11.88888888888889, 
     5.333333333333333}, {12.777777777777779`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[40, 9]}, {
      Rational[115, 9], Rational[40, 9]}}, {{11.88888888888889, 
     4.444444444444445}, {12.777777777777779`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[32, 9]}, {
      Rational[115, 9], Rational[32, 9]}}, {{11.88888888888889, 
     3.5555555555555554`}, {12.777777777777779`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 3]}, {
      Rational[115, 9], Rational[8, 3]}}, {{11.88888888888889, 
     2.6666666666666665`}, {12.777777777777779`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 9]}, {
      Rational[115, 9], Rational[16, 9]}}, {{11.88888888888889, 
     1.7777777777777777`}, {12.777777777777779`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 9]}, {
      Rational[115, 9], Rational[8, 9]}}, {{11.88888888888889, 
     0.8888888888888888}, {12.777777777777779`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[107, 9], 0}, {Rational[115, 9], 0}}, {{
      11.88888888888889, 0}, {12.777777777777779`, 0}}]], 
   LineBox[NCache[{{Rational[115, 9], 8}, {Rational[41, 3], 8}}, {{
      12.777777777777779`, 8}, {13.666666666666666`, 8}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[64, 9]}, {
      Rational[41, 3], Rational[64, 9]}}, {{12.777777777777779`, 
     7.111111111111111}, {13.666666666666666`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[56, 9]}, {
      Rational[41, 3], Rational[56, 9]}}, {{12.777777777777779`, 
     6.222222222222222}, {13.666666666666666`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 3]}, {
      Rational[41, 3], Rational[16, 3]}}, {{12.777777777777779`, 
     5.333333333333333}, {13.666666666666666`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[40, 9]}, {
      Rational[41, 3], Rational[40, 9]}}, {{12.777777777777779`, 
     4.444444444444445}, {13.666666666666666`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[32, 9]}, {
      Rational[41, 3], Rational[32, 9]}}, {{12.777777777777779`, 
     3.5555555555555554`}, {13.666666666666666`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 3]}, {
      Rational[41, 3], Rational[8, 3]}}, {{12.777777777777779`, 
     2.6666666666666665`}, {13.666666666666666`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 9]}, {
      Rational[41, 3], Rational[16, 9]}}, {{12.777777777777779`, 
     1.7777777777777777`}, {13.666666666666666`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 9]}, {
      Rational[41, 3], Rational[8, 9]}}, {{12.777777777777779`, 
     0.8888888888888888}, {13.666666666666666`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[115, 9], 0}, {Rational[41, 3], 0}}, {{
      12.777777777777779`, 0}, {13.666666666666666`, 0}}]], 
   LineBox[NCache[{{Rational[41, 3], 8}, {Rational[131, 9], 8}}, {{
      13.666666666666666`, 8}, {14.555555555555555`, 8}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[64, 9]}, {
      Rational[131, 9], Rational[64, 9]}}, {{13.666666666666666`, 
     7.111111111111111}, {14.555555555555555`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[56, 9]}, {
      Rational[131, 9], Rational[56, 9]}}, {{13.666666666666666`, 
     6.222222222222222}, {14.555555555555555`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 3]}, {
      Rational[131, 9], Rational[16, 3]}}, {{13.666666666666666`, 
     5.333333333333333}, {14.555555555555555`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[40, 9]}, {
      Rational[131, 9], Rational[40, 9]}}, {{13.666666666666666`, 
     4.444444444444445}, {14.555555555555555`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[32, 9]}, {
      Rational[131, 9], Rational[32, 9]}}, {{13.666666666666666`, 
     3.5555555555555554`}, {14.555555555555555`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 3]}, {
      Rational[131, 9], Rational[8, 3]}}, {{13.666666666666666`, 
     2.6666666666666665`}, {14.555555555555555`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 9]}, {
      Rational[131, 9], Rational[16, 9]}}, {{13.666666666666666`, 
     1.7777777777777777`}, {14.555555555555555`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 9]}, {
      Rational[131, 9], Rational[8, 9]}}, {{13.666666666666666`, 
     0.8888888888888888}, {14.555555555555555`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[41, 3], 0}, {Rational[131, 9], 0}}, {{
      13.666666666666666`, 0}, {14.555555555555555`, 0}}]], 
   LineBox[NCache[{{Rational[131, 9], 8}, {Rational[139, 9], 8}}, {{
      14.555555555555555`, 8}, {15.444444444444445`, 8}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[64, 9]}, {
      Rational[139, 9], Rational[64, 9]}}, {{14.555555555555555`, 
     7.111111111111111}, {15.444444444444445`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[56, 9]}, {
      Rational[139, 9], Rational[56, 9]}}, {{14.555555555555555`, 
     6.222222222222222}, {15.444444444444445`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 3]}, {
      Rational[139, 9], Rational[16, 3]}}, {{14.555555555555555`, 
     5.333333333333333}, {15.444444444444445`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[40, 9]}, {
      Rational[139, 9], Rational[40, 9]}}, {{14.555555555555555`, 
     4.444444444444445}, {15.444444444444445`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[32, 9]}, {
      Rational[139, 9], Rational[32, 9]}}, {{14.555555555555555`, 
     3.5555555555555554`}, {15.444444444444445`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 3]}, {
      Rational[139, 9], Rational[8, 3]}}, {{14.555555555555555`, 
     2.6666666666666665`}, {15.444444444444445`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 9]}, {
      Rational[139, 9], Rational[16, 9]}}, {{14.555555555555555`, 
     1.7777777777777777`}, {15.444444444444445`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 9]}, {
      Rational[139, 9], Rational[8, 9]}}, {{14.555555555555555`, 
     0.8888888888888888}, {15.444444444444445`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[131, 9], 0}, {Rational[139, 9], 0}}, {{
      14.555555555555555`, 0}, {15.444444444444445`, 0}}]], 
   LineBox[NCache[{{Rational[139, 9], 8}, {Rational[49, 3], 8}}, {{
      15.444444444444445`, 8}, {16.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[64, 9]}, {
      Rational[49, 3], Rational[64, 9]}}, {{15.444444444444445`, 
     7.111111111111111}, {16.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[56, 9]}, {
      Rational[49, 3], Rational[56, 9]}}, {{15.444444444444445`, 
     6.222222222222222}, {16.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 3]}, {
      Rational[49, 3], Rational[16, 3]}}, {{15.444444444444445`, 
     5.333333333333333}, {16.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[40, 9]}, {
      Rational[49, 3], Rational[40, 9]}}, {{15.444444444444445`, 
     4.444444444444445}, {16.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[32, 9]}, {
      Rational[49, 3], Rational[32, 9]}}, {{15.444444444444445`, 
     3.5555555555555554`}, {16.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 3]}, {
      Rational[49, 3], Rational[8, 3]}}, {{15.444444444444445`, 
     2.6666666666666665`}, {16.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 9]}, {
      Rational[49, 3], Rational[16, 9]}}, {{15.444444444444445`, 
     1.7777777777777777`}, {16.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 9]}, {
      Rational[49, 3], Rational[8, 9]}}, {{15.444444444444445`, 
     0.8888888888888888}, {16.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[139, 9], 0}, {Rational[49, 3], 0}}, {{
      15.444444444444445`, 0}, {16.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[49, 3], 8}, {Rational[155, 9], 8}}, {{
      16.333333333333332`, 8}, {17.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[64, 9]}, {
      Rational[155, 9], Rational[64, 9]}}, {{16.333333333333332`, 
     7.111111111111111}, {17.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[56, 9]}, {
      Rational[155, 9], Rational[56, 9]}}, {{16.333333333333332`, 
     6.222222222222222}, {17.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 3]}, {
      Rational[155, 9], Rational[16, 3]}}, {{16.333333333333332`, 
     5.333333333333333}, {17.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[40, 9]}, {
      Rational[155, 9], Rational[40, 9]}}, {{16.333333333333332`, 
     4.444444444444445}, {17.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[32, 9]}, {
      Rational[155, 9], Rational[32, 9]}}, {{16.333333333333332`, 
     3.5555555555555554`}, {17.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 3]}, {
      Rational[155, 9], Rational[8, 3]}}, {{16.333333333333332`, 
     2.6666666666666665`}, {17.22222222222222, 2.6666666666666665`}}]], 
   LineBox[
    NCache[{{Rational[49, 3], Rational[16, 9]}, {
      Rational[155, 9], Rational[16, 9]}}, {{16.333333333333332`, 
     1.7777777777777777`}, {17.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 9]}, {
      Rational[155, 9], Rational[8, 9]}}, {{16.333333333333332`, 
     0.8888888888888888}, {17.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[49, 3], 0}, {Rational[155, 9], 0}}, {{
      16.333333333333332`, 0}, {17.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[155, 9], 8}, {Rational[163, 9], 8}}, {{
      17.22222222222222, 8}, {18.11111111111111, 8}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[64, 9]}, {
      Rational[163, 9], Rational[64, 9]}}, {{17.22222222222222, 
     7.111111111111111}, {18.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[56, 9]}, {
      Rational[163, 9], Rational[56, 9]}}, {{17.22222222222222, 
     6.222222222222222}, {18.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 3]}, {
      Rational[163, 9], Rational[16, 3]}}, {{17.22222222222222, 
     5.333333333333333}, {18.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[40, 9]}, {
      Rational[163, 9], Rational[40, 9]}}, {{17.22222222222222, 
     4.444444444444445}, {18.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[32, 9]}, {
      Rational[163, 9], Rational[32, 9]}}, {{17.22222222222222, 
     3.5555555555555554`}, {18.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 3]}, {
      Rational[163, 9], Rational[8, 3]}}, {{17.22222222222222, 
     2.6666666666666665`}, {18.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 9]}, {
      Rational[163, 9], Rational[16, 9]}}, {{17.22222222222222, 
     1.7777777777777777`}, {18.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 9]}, {
      Rational[163, 9], Rational[8, 9]}}, {{17.22222222222222, 
     0.8888888888888888}, {18.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[155, 9], 0}, {Rational[163, 9], 0}}, {{
      17.22222222222222, 0}, {18.11111111111111, 0}}]], 
   LineBox[NCache[{{Rational[163, 9], 8}, {19, 8}}, {{18.11111111111111, 8}, {
      19, 8}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[64, 9]}, {
      19, Rational[64, 9]}}, {{18.11111111111111, 7.111111111111111}, {
      19, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[56, 9]}, {
      19, Rational[56, 9]}}, {{18.11111111111111, 6.222222222222222}, {
      19, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 3]}, {
      19, Rational[16, 3]}}, {{18.11111111111111, 5.333333333333333}, {
      19, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[40, 9]}, {
      19, Rational[40, 9]}}, {{18.11111111111111, 4.444444444444445}, {
      19, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[32, 9]}, {
      19, Rational[32, 9]}}, {{18.11111111111111, 3.5555555555555554`}, {
      19, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 3]}, {
      19, Rational[8, 3]}}, {{18.11111111111111, 2.6666666666666665`}, {
      19, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 9]}, {
      19, Rational[16, 9]}}, {{18.11111111111111, 1.7777777777777777`}, {
      19, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 9]}, {
      19, Rational[8, 9]}}, {{18.11111111111111, 0.8888888888888888}, {
      19, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[163, 9], 0}, {19, 0}}, {{18.11111111111111, 0}, {
      19, 0}}]], 
   LineBox[NCache[{{11, 8}, {11, Rational[64, 9]}}, {{11, 8}, {
      11, 7.111111111111111}}]], 
   LineBox[NCache[{{11, Rational[64, 9]}, {11, Rational[56, 9]}}, {{
      11, 7.111111111111111}, {11, 6.222222222222222}}]], 
   LineBox[NCache[{{11, Rational[56, 9]}, {11, Rational[16, 3]}}, {{
      11, 6.222222222222222}, {11, 5.333333333333333}}]], 
   LineBox[NCache[{{11, Rational[16, 3]}, {11, Rational[40, 9]}}, {{
      11, 5.333333333333333}, {11, 4.444444444444445}}]], 
   LineBox[NCache[{{11, Rational[40, 9]}, {11, Rational[32, 9]}}, {{
      11, 4.444444444444445}, {11, 3.5555555555555554`}}]], 
   LineBox[NCache[{{11, Rational[32, 9]}, {11, Rational[8, 3]}}, {{
      11, 3.5555555555555554`}, {11, 2.6666666666666665`}}]], 
   LineBox[NCache[{{11, Rational[8, 3]}, {11, Rational[16, 9]}}, {{
      11, 2.6666666666666665`}, {11, 1.7777777777777777`}}]], 
   LineBox[NCache[{{11, Rational[16, 9]}, {11, Rational[8, 9]}}, {{
      11, 1.7777777777777777`}, {11, 0.8888888888888888}}]], 
   LineBox[NCache[{{11, Rational[8, 9]}, {11, 0}}, {{
      11, 0.8888888888888888}, {11, 0}}]], 
   LineBox[NCache[{{Rational[107, 9], 8}, {
      Rational[107, 9], Rational[64, 9]}}, {{11.88888888888889, 8}, {
      11.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[64, 9]}, {
      Rational[107, 9], Rational[56, 9]}}, {{11.88888888888889, 
     7.111111111111111}, {11.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[56, 9]}, {
      Rational[107, 9], Rational[16, 3]}}, {{11.88888888888889, 
     6.222222222222222}, {11.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 3]}, {
      Rational[107, 9], Rational[40, 9]}}, {{11.88888888888889, 
     5.333333333333333}, {11.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[40, 9]}, {
      Rational[107, 9], Rational[32, 9]}}, {{11.88888888888889, 
     4.444444444444445}, {11.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[32, 9]}, {
      Rational[107, 9], Rational[8, 3]}}, {{11.88888888888889, 
     3.5555555555555554`}, {11.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 3]}, {
      Rational[107, 9], Rational[16, 9]}}, {{11.88888888888889, 
     2.6666666666666665`}, {11.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 9]}, {
      Rational[107, 9], Rational[8, 9]}}, {{11.88888888888889, 
     1.7777777777777777`}, {11.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 9]}, {
      Rational[107, 9], 0}}, {{11.88888888888889, 0.8888888888888888}, {
      11.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[115, 9], 8}, {
      Rational[115, 9], Rational[64, 9]}}, {{12.777777777777779`, 8}, {
      12.777777777777779`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[64, 9]}, {
      Rational[115, 9], Rational[56, 9]}}, {{12.777777777777779`, 
     7.111111111111111}, {12.777777777777779`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[56, 9]}, {
      Rational[115, 9], Rational[16, 3]}}, {{12.777777777777779`, 
     6.222222222222222}, {12.777777777777779`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 3]}, {
      Rational[115, 9], Rational[40, 9]}}, {{12.777777777777779`, 
     5.333333333333333}, {12.777777777777779`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[40, 9]}, {
      Rational[115, 9], Rational[32, 9]}}, {{12.777777777777779`, 
     4.444444444444445}, {12.777777777777779`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[32, 9]}, {
      Rational[115, 9], Rational[8, 3]}}, {{12.777777777777779`, 
     3.5555555555555554`}, {12.777777777777779`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 3]}, {
      Rational[115, 9], Rational[16, 9]}}, {{12.777777777777779`, 
     2.6666666666666665`}, {12.777777777777779`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 9]}, {
      Rational[115, 9], Rational[8, 9]}}, {{12.777777777777779`, 
     1.7777777777777777`}, {12.777777777777779`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 9]}, {
      Rational[115, 9], 0}}, {{12.777777777777779`, 0.8888888888888888}, {
      12.777777777777779`, 0}}]], 
   LineBox[NCache[{{Rational[41, 3], 8}, {
      Rational[41, 3], Rational[64, 9]}}, {{13.666666666666666`, 8}, {
      13.666666666666666`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[64, 9]}, {
      Rational[41, 3], Rational[56, 9]}}, {{13.666666666666666`, 
     7.111111111111111}, {13.666666666666666`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[56, 9]}, {
      Rational[41, 3], Rational[16, 3]}}, {{13.666666666666666`, 
     6.222222222222222}, {13.666666666666666`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 3]}, {
      Rational[41, 3], Rational[40, 9]}}, {{13.666666666666666`, 
     5.333333333333333}, {13.666666666666666`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[40, 9]}, {
      Rational[41, 3], Rational[32, 9]}}, {{13.666666666666666`, 
     4.444444444444445}, {13.666666666666666`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[32, 9]}, {
      Rational[41, 3], Rational[8, 3]}}, {{13.666666666666666`, 
     3.5555555555555554`}, {13.666666666666666`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 3]}, {
      Rational[41, 3], Rational[16, 9]}}, {{13.666666666666666`, 
     2.6666666666666665`}, {13.666666666666666`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 9]}, {
      Rational[41, 3], Rational[8, 9]}}, {{13.666666666666666`, 
     1.7777777777777777`}, {13.666666666666666`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 9]}, {
      Rational[41, 3], 0}}, {{13.666666666666666`, 0.8888888888888888}, {
      13.666666666666666`, 0}}]], 
   LineBox[NCache[{{Rational[131, 9], 8}, {
      Rational[131, 9], Rational[64, 9]}}, {{14.555555555555555`, 8}, {
      14.555555555555555`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[64, 9]}, {
      Rational[131, 9], Rational[56, 9]}}, {{14.555555555555555`, 
     7.111111111111111}, {14.555555555555555`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[56, 9]}, {
      Rational[131, 9], Rational[16, 3]}}, {{14.555555555555555`, 
     6.222222222222222}, {14.555555555555555`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 3]}, {
      Rational[131, 9], Rational[40, 9]}}, {{14.555555555555555`, 
     5.333333333333333}, {14.555555555555555`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[40, 9]}, {
      Rational[131, 9], Rational[32, 9]}}, {{14.555555555555555`, 
     4.444444444444445}, {14.555555555555555`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[32, 9]}, {
      Rational[131, 9], Rational[8, 3]}}, {{14.555555555555555`, 
     3.5555555555555554`}, {14.555555555555555`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 3]}, {
      Rational[131, 9], Rational[16, 9]}}, {{14.555555555555555`, 
     2.6666666666666665`}, {14.555555555555555`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 9]}, {
      Rational[131, 9], Rational[8, 9]}}, {{14.555555555555555`, 
     1.7777777777777777`}, {14.555555555555555`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 9]}, {
      Rational[131, 9], 0}}, {{14.555555555555555`, 0.8888888888888888}, {
      14.555555555555555`, 0}}]], 
   LineBox[NCache[{{Rational[139, 9], 8}, {
      Rational[139, 9], Rational[64, 9]}}, {{15.444444444444445`, 8}, {
      15.444444444444445`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[64, 9]}, {
      Rational[139, 9], Rational[56, 9]}}, {{15.444444444444445`, 
     7.111111111111111}, {15.444444444444445`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[56, 9]}, {
      Rational[139, 9], Rational[16, 3]}}, {{15.444444444444445`, 
     6.222222222222222}, {15.444444444444445`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 3]}, {
      Rational[139, 9], Rational[40, 9]}}, {{15.444444444444445`, 
     5.333333333333333}, {15.444444444444445`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[40, 9]}, {
      Rational[139, 9], Rational[32, 9]}}, {{15.444444444444445`, 
     4.444444444444445}, {15.444444444444445`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[32, 9]}, {
      Rational[139, 9], Rational[8, 3]}}, {{15.444444444444445`, 
     3.5555555555555554`}, {15.444444444444445`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 3]}, {
      Rational[139, 9], Rational[16, 9]}}, {{15.444444444444445`, 
     2.6666666666666665`}, {15.444444444444445`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 9]}, {
      Rational[139, 9], Rational[8, 9]}}, {{15.444444444444445`, 
     1.7777777777777777`}, {15.444444444444445`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 9]}, {
      Rational[139, 9], 0}}, {{15.444444444444445`, 0.8888888888888888}, {
      15.444444444444445`, 0}}]], 
   LineBox[NCache[{{Rational[49, 3], 8}, {
      Rational[49, 3], Rational[64, 9]}}, {{16.333333333333332`, 8}, {
      16.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[64, 9]}, {
      Rational[49, 3], Rational[56, 9]}}, {{16.333333333333332`, 
     7.111111111111111}, {16.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[56, 9]}, {
      Rational[49, 3], Rational[16, 3]}}, {{16.333333333333332`, 
     6.222222222222222}, {16.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 3]}, {
      Rational[49, 3], Rational[40, 9]}}, {{16.333333333333332`, 
     5.333333333333333}, {16.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[40, 9]}, {
      Rational[49, 3], Rational[32, 9]}}, {{16.333333333333332`, 
     4.444444444444445}, {16.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{Rational[49, 3], Rational[32, 9]}, {
      Rational[49, 3], Rational[8, 3]}}, {{16.333333333333332`, 
     3.5555555555555554`}, {16.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 3]}, {
      Rational[49, 3], Rational[16, 9]}}, {{16.333333333333332`, 
     2.6666666666666665`}, {16.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 9]}, {
      Rational[49, 3], Rational[8, 9]}}, {{16.333333333333332`, 
     1.7777777777777777`}, {16.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 9]}, {
      Rational[49, 3], 0}}, {{16.333333333333332`, 0.8888888888888888}, {
      16.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[155, 9], 8}, {
      Rational[155, 9], Rational[64, 9]}}, {{17.22222222222222, 8}, {
      17.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[64, 9]}, {
      Rational[155, 9], Rational[56, 9]}}, {{17.22222222222222, 
     7.111111111111111}, {17.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[56, 9]}, {
      Rational[155, 9], Rational[16, 3]}}, {{17.22222222222222, 
     6.222222222222222}, {17.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 3]}, {
      Rational[155, 9], Rational[40, 9]}}, {{17.22222222222222, 
     5.333333333333333}, {17.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[40, 9]}, {
      Rational[155, 9], Rational[32, 9]}}, {{17.22222222222222, 
     4.444444444444445}, {17.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[32, 9]}, {
      Rational[155, 9], Rational[8, 3]}}, {{17.22222222222222, 
     3.5555555555555554`}, {17.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 3]}, {
      Rational[155, 9], Rational[16, 9]}}, {{17.22222222222222, 
     2.6666666666666665`}, {17.22222222222222, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{Rational[155, 9], Rational[16, 9]}, {
      Rational[155, 9], Rational[8, 9]}}, {{17.22222222222222, 
     1.7777777777777777`}, {17.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 9]}, {
      Rational[155, 9], 0}}, {{17.22222222222222, 0.8888888888888888}, {
      17.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[163, 9], 8}, {
      Rational[163, 9], Rational[64, 9]}}, {{18.11111111111111, 8}, {
      18.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[64, 9]}, {
      Rational[163, 9], Rational[56, 9]}}, {{18.11111111111111, 
     7.111111111111111}, {18.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[56, 9]}, {
      Rational[163, 9], Rational[16, 3]}}, {{18.11111111111111, 
     6.222222222222222}, {18.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 3]}, {
      Rational[163, 9], Rational[40, 9]}}, {{18.11111111111111, 
     5.333333333333333}, {18.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[40, 9]}, {
      Rational[163, 9], Rational[32, 9]}}, {{18.11111111111111, 
     4.444444444444445}, {18.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[32, 9]}, {
      Rational[163, 9], Rational[8, 3]}}, {{18.11111111111111, 
     3.5555555555555554`}, {18.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 3]}, {
      Rational[163, 9], Rational[16, 9]}}, {{18.11111111111111, 
     2.6666666666666665`}, {18.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 9]}, {
      Rational[163, 9], Rational[8, 9]}}, {{18.11111111111111, 
     1.7777777777777777`}, {18.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 9]}, {
      Rational[163, 9], 0}}, {{18.11111111111111, 0.8888888888888888}, {
      18.11111111111111, 0}}]], 
   LineBox[NCache[{{19, 8}, {19, Rational[64, 9]}}, {{19, 8}, {
      19, 7.111111111111111}}]], 
   LineBox[NCache[{{19, Rational[64, 9]}, {19, Rational[56, 9]}}, {{
      19, 7.111111111111111}, {19, 6.222222222222222}}]], 
   LineBox[NCache[{{19, Rational[56, 9]}, {19, Rational[16, 3]}}, {{
      19, 6.222222222222222}, {19, 5.333333333333333}}]], 
   LineBox[NCache[{{19, Rational[16, 3]}, {19, Rational[40, 9]}}, {{
      19, 5.333333333333333}, {19, 4.444444444444445}}]], 
   LineBox[NCache[{{19, Rational[40, 9]}, {19, Rational[32, 9]}}, {{
      19, 4.444444444444445}, {19, 3.5555555555555554`}}]], 
   LineBox[NCache[{{19, Rational[32, 9]}, {19, Rational[8, 3]}}, {{
      19, 3.5555555555555554`}, {19, 2.6666666666666665`}}]], 
   LineBox[NCache[{{19, Rational[8, 3]}, {19, Rational[16, 9]}}, {{
      19, 2.6666666666666665`}, {19, 1.7777777777777777`}}]], 
   LineBox[NCache[{{19, Rational[16, 9]}, {19, Rational[8, 9]}}, {{
      19, 1.7777777777777777`}, {19, 0.8888888888888888}}]], 
   LineBox[NCache[{{19, Rational[8, 9]}, {19, 0}}, {{
      19, 0.8888888888888888}, {19, 0}}]], 
   LineBox[NCache[{{21, 8}, {Rational[197, 9], 8}}, {{21, 8}, {
      21.88888888888889, 8}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {
      Rational[197, 9], Rational[64, 9]}}, {{21, 7.111111111111111}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21, 6.222222222222222}, {
      21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21, 5.333333333333333}, {
      21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21, 4.444444444444445}, {
      21.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21, 3.5555555555555554`}, {
      21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21, 2.6666666666666665`}, {
      21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21, 1.7777777777777777`}, {
      21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21, 0.8888888888888888}, {
      21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, 0}, {Rational[197, 9], 0}}, {{21, 0}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {Rational[205, 9], 8}}, {{
      21.88888888888889, 8}, {22.77777777777778, 8}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[64, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{21.88888888888889, 
     6.222222222222222}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[16, 3]}}, {{21.88888888888889, 
     5.333333333333333}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[40, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{21.88888888888889, 
     3.5555555555555554`}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[8, 3]}}, {{21.88888888888889, 
     2.6666666666666665`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[16, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{21.88888888888889, 
     0.8888888888888888}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], 0}, {Rational[205, 9], 0}}, {{
      21.88888888888889, 0}, {22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {Rational[71, 3], 8}}, {{
      22.77777777777778, 8}, {23.666666666666668`, 8}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[71, 3], Rational[64, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{22.77777777777778, 
     6.222222222222222}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[71, 3], Rational[16, 3]}}, {{22.77777777777778, 
     5.333333333333333}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[71, 3], Rational[40, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{22.77777777777778, 
     3.5555555555555554`}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[71, 3], Rational[8, 3]}}, {{22.77777777777778, 
     2.6666666666666665`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[71, 3], Rational[16, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{22.77777777777778, 
     0.8888888888888888}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], 0}, {Rational[71, 3], 0}}, {{
      22.77777777777778, 0}, {23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {Rational[221, 9], 8}}, {{
      23.666666666666668`, 8}, {24.555555555555557`, 8}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[221, 9], Rational[64, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{23.666666666666668`, 
     6.222222222222222}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[221, 9], Rational[16, 3]}}, {{23.666666666666668`, 
     5.333333333333333}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[221, 9], Rational[40, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[221, 9], Rational[8, 3]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[221, 9], Rational[16, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{23.666666666666668`, 
     0.8888888888888888}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[71, 3], 0}, {Rational[221, 9], 0}}, {{
      23.666666666666668`, 0}, {24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {Rational[229, 9], 8}}, {{
      24.555555555555557`, 8}, {25.444444444444443`, 8}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[64, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {25.444444444444443`, 7.111111111111111}}]], 
   LineBox[
    NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     6.222222222222222}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     5.333333333333333}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     0.8888888888888888}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], 0}, {Rational[229, 9], 0}}, {{
      24.555555555555557`, 0}, {25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {Rational[79, 3], 8}}, {{
      25.444444444444443`, 8}, {26.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[79, 3], Rational[64, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{25.444444444444443`, 
     6.222222222222222}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[
    NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[79, 3], Rational[16, 3]}}, {{25.444444444444443`, 
     5.333333333333333}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[79, 3], Rational[40, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[79, 3], Rational[8, 3]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[79, 3], Rational[16, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{25.444444444444443`, 
     0.8888888888888888}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], 0}, {Rational[79, 3], 0}}, {{
      25.444444444444443`, 0}, {26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {Rational[245, 9], 8}}, {{
      26.333333333333332`, 8}, {27.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[245, 9], Rational[64, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{26.333333333333332`, 
     6.222222222222222}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[245, 9], Rational[16, 3]}}, {{26.333333333333332`, 
     5.333333333333333}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[245, 9], Rational[40, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[245, 9], Rational[8, 3]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[245, 9], Rational[16, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{26.333333333333332`, 
     0.8888888888888888}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[79, 3], 0}, {Rational[245, 9], 0}}, {{
      26.333333333333332`, 0}, {27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {Rational[253, 9], 8}}, {{
      27.22222222222222, 8}, {28.11111111111111, 8}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[64, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{27.22222222222222, 
     6.222222222222222}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[16, 3]}}, {{27.22222222222222, 
     5.333333333333333}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[40, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{27.22222222222222, 
     3.5555555555555554`}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[8, 3]}}, {{27.22222222222222, 
     2.6666666666666665`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[16, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{27.22222222222222, 
     0.8888888888888888}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], 0}, {Rational[253, 9], 0}}, {{
      27.22222222222222, 0}, {28.11111111111111, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {29, 8}}, {{28.11111111111111, 8}, {
      29, 8}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      29, Rational[64, 9]}}, {{28.11111111111111, 7.111111111111111}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      29, Rational[56, 9]}}, {{28.11111111111111, 6.222222222222222}, {
      29, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      29, Rational[16, 3]}}, {{28.11111111111111, 5.333333333333333}, {
      29, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      29, Rational[40, 9]}}, {{28.11111111111111, 4.444444444444445}, {
      29, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      29, Rational[32, 9]}}, {{28.11111111111111, 3.5555555555555554`}, {
      29, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      29, Rational[8, 3]}}, {{28.11111111111111, 2.6666666666666665`}, {
      29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 9]}, {
      29, Rational[16, 9]}}, {{28.11111111111111, 1.7777777777777777`}, {
      29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      29, Rational[8, 9]}}, {{28.11111111111111, 0.8888888888888888}, {
      29, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], 0}, {29, 0}}, {{28.11111111111111, 0}, {
      29, 0}}]], 
   LineBox[NCache[{{21, 8}, {21, Rational[64, 9]}}, {{21, 8}, {
      21, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {21, Rational[56, 9]}}, {{
      21, 7.111111111111111}, {21, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {21, Rational[16, 3]}}, {{
      21, 6.222222222222222}, {21, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {21, Rational[40, 9]}}, {{
      21, 5.333333333333333}, {21, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {21, Rational[32, 9]}}, {{
      21, 4.444444444444445}, {21, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {21, Rational[8, 3]}}, {{
      21, 3.5555555555555554`}, {21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {21, Rational[16, 9]}}, {{
      21, 2.6666666666666665`}, {21, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {21, Rational[8, 9]}}, {{
      21, 1.7777777777777777`}, {21, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {21, 0}}, {{
      21, 0.8888888888888888}, {21, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {
      Rational[197, 9], Rational[64, 9]}}, {{21.88888888888889, 8}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21.88888888888889, 
     6.222222222222222}, {21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21.88888888888889, 
     5.333333333333333}, {21.88888888888889, 4.444444444444445}}]], 
   LineBox[
    NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21.88888888888889, 
     3.5555555555555554`}, {21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21.88888888888889, 
     2.6666666666666665`}, {21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[197, 9], 0}}, {{21.88888888888889, 0.8888888888888888}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {
      Rational[205, 9], Rational[64, 9]}}, {{22.77777777777778, 8}, {
      22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[16, 3]}}, {{22.77777777777778, 
     6.222222222222222}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[40, 9]}}, {{22.77777777777778, 
     5.333333333333333}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[8, 3]}}, {{22.77777777777778, 
     3.5555555555555554`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[
    NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[16, 9]}}, {{22.77777777777778, 
     2.6666666666666665`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[205, 9], 0}}, {{22.77777777777778, 0.8888888888888888}, {
      22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {
      Rational[71, 3], Rational[64, 9]}}, {{23.666666666666668`, 8}, {
      23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[71, 3], Rational[16, 3]}}, {{23.666666666666668`, 
     6.222222222222222}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[71, 3], Rational[40, 9]}}, {{23.666666666666668`, 
     5.333333333333333}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[71, 3], Rational[8, 3]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[71, 3], Rational[16, 9]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[
    NCache[{{Rational[71, 3], Rational[8, 9]}, {Rational[71, 3], 0}}, {{
      23.666666666666668`, 0.8888888888888888}, {23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {
      Rational[221, 9], Rational[64, 9]}}, {{24.555555555555557`, 8}, {
      24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[221, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     6.222222222222222}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[221, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     5.333333333333333}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[221, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[221, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[221, 9], 0}}, {{24.555555555555557`, 0.8888888888888888}, {
      24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {
      Rational[229, 9], Rational[64, 9]}}, {{25.444444444444443`, 8}, {
      25.444444444444443`, 7.111111111111111}}]], 
   LineBox[
    NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[16, 3]}}, {{25.444444444444443`, 
     6.222222222222222}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[40, 9]}}, {{25.444444444444443`, 
     5.333333333333333}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[8, 3]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[16, 9]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[229, 9], 0}}, {{25.444444444444443`, 0.8888888888888888}, {
      25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {
      Rational[79, 3], Rational[64, 9]}}, {{26.333333333333332`, 8}, {
      26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[79, 3], Rational[16, 3]}}, {{26.333333333333332`, 
     6.222222222222222}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[
    NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[79, 3], Rational[40, 9]}}, {{26.333333333333332`, 
     5.333333333333333}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[79, 3], Rational[8, 3]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[79, 3], Rational[16, 9]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 9]}, {
      Rational[79, 3], 0}}, {{26.333333333333332`, 0.8888888888888888}, {
      26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {
      Rational[245, 9], Rational[64, 9]}}, {{27.22222222222222, 8}, {
      27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[245, 9], Rational[16, 3]}}, {{27.22222222222222, 
     6.222222222222222}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[245, 9], Rational[40, 9]}}, {{27.22222222222222, 
     5.333333333333333}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[245, 9], Rational[8, 3]}}, {{27.22222222222222, 
     3.5555555555555554`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[245, 9], Rational[16, 9]}}, {{27.22222222222222, 
     2.6666666666666665`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[245, 9], 0}}, {{27.22222222222222, 0.8888888888888888}, {
      27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {
      Rational[253, 9], Rational[64, 9]}}, {{28.11111111111111, 8}, {
      28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{28.11111111111111, 
     7.111111111111111}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[16, 3]}}, {{28.11111111111111, 
     6.222222222222222}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[40, 9]}}, {{28.11111111111111, 
     5.333333333333333}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{28.11111111111111, 
     4.444444444444445}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[8, 3]}}, {{28.11111111111111, 
     3.5555555555555554`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[16, 9]}}, {{28.11111111111111, 
     2.6666666666666665`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{Rational[253, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{28.11111111111111, 
     1.7777777777777777`}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      Rational[253, 9], 0}}, {{28.11111111111111, 0.8888888888888888}, {
      28.11111111111111, 0}}]], 
   LineBox[NCache[{{29, 8}, {29, Rational[64, 9]}}, {{29, 8}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{29, Rational[64, 9]}, {29, Rational[56, 9]}}, {{
      29, 7.111111111111111}, {29, 6.222222222222222}}]], 
   LineBox[NCache[{{29, Rational[56, 9]}, {29, Rational[16, 3]}}, {{
      29, 6.222222222222222}, {29, 5.333333333333333}}]], 
   LineBox[NCache[{{29, Rational[16, 3]}, {29, Rational[40, 9]}}, {{
      29, 5.333333333333333}, {29, 4.444444444444445}}]], 
   LineBox[NCache[{{29, Rational[40, 9]}, {29, Rational[32, 9]}}, {{
      29, 4.444444444444445}, {29, 3.5555555555555554`}}]], 
   LineBox[NCache[{{29, Rational[32, 9]}, {29, Rational[8, 3]}}, {{
      29, 3.5555555555555554`}, {29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{29, Rational[8, 3]}, {29, Rational[16, 9]}}, {{
      29, 2.6666666666666665`}, {29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{29, Rational[16, 9]}, {29, Rational[8, 9]}}, {{
      29, 1.7777777777777777`}, {29, 0.8888888888888888}}]], 
   LineBox[NCache[{{29, Rational[8, 9]}, {29, 0}}, {{
      29, 0.8888888888888888}, {29, 0}}]], LineBox[{{19, 18}, {21, 18}}], 
   LineBox[NCache[{{19, Rational[154, 9]}, {21, Rational[154, 9]}}, {{
      19, 17.11111111111111}, {21, 17.11111111111111}}]], 
   LineBox[NCache[{{19, Rational[146, 9]}, {21, Rational[146, 9]}}, {{
      19, 16.22222222222222}, {21, 16.22222222222222}}]], 
   LineBox[NCache[{{19, Rational[46, 3]}, {21, Rational[46, 3]}}, {{
      19, 15.333333333333334`}, {21, 15.333333333333334`}}]], 
   LineBox[NCache[{{19, Rational[130, 9]}, {21, Rational[130, 9]}}, {{
      19, 14.444444444444445`}, {21, 14.444444444444445`}}]], 
   LineBox[NCache[{{19, Rational[122, 9]}, {21, Rational[122, 9]}}, {{
      19, 13.555555555555555`}, {21, 13.555555555555555`}}]], 
   LineBox[NCache[{{19, Rational[38, 3]}, {21, Rational[38, 3]}}, {{
      19, 12.666666666666666`}, {21, 12.666666666666666`}}]], 
   LineBox[NCache[{{19, Rational[106, 9]}, {21, Rational[106, 9]}}, {{
      19, 11.777777777777779`}, {21, 11.777777777777779`}}]], 
   LineBox[NCache[{{19, Rational[98, 9]}, {21, Rational[98, 9]}}, {{
      19, 10.88888888888889}, {21, 10.88888888888889}}]], 
   LineBox[{{19, 10}, {21, 10}}], LineBox[{{19, 8}, {21, 8}}], 
   LineBox[NCache[{{19, Rational[64, 9]}, {21, Rational[64, 9]}}, {{
      19, 7.111111111111111}, {21, 7.111111111111111}}]], 
   LineBox[NCache[{{19, Rational[56, 9]}, {21, Rational[56, 9]}}, {{
      19, 6.222222222222222}, {21, 6.222222222222222}}]], 
   LineBox[NCache[{{19, Rational[16, 3]}, {21, Rational[16, 3]}}, {{
      19, 5.333333333333333}, {21, 5.333333333333333}}]], 
   LineBox[NCache[{{19, Rational[40, 9]}, {21, Rational[40, 9]}}, {{
      19, 4.444444444444445}, {21, 4.444444444444445}}]], 
   LineBox[NCache[{{19, Rational[32, 9]}, {21, Rational[32, 9]}}, {{
      19, 3.5555555555555554`}, {21, 3.5555555555555554`}}]], 
   LineBox[NCache[{{19, Rational[8, 3]}, {21, Rational[8, 3]}}, {{
      19, 2.6666666666666665`}, {21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{19, Rational[16, 9]}, {21, Rational[16, 9]}}, {{
      19, 1.7777777777777777`}, {21, 1.7777777777777777`}}]], 
   LineBox[NCache[{{19, Rational[8, 9]}, {21, Rational[8, 9]}}, {{
      19, 0.8888888888888888}, {21, 0.8888888888888888}}]], 
   LineBox[{{19, 0}, {21, 0}}], LineBox[{{11, 10}, {11, 8}}], 
   LineBox[NCache[{{Rational[107, 9], 10}, {Rational[107, 9], 8}}, {{
      11.88888888888889, 10}, {11.88888888888889, 8}}]], 
   LineBox[NCache[{{Rational[115, 9], 10}, {Rational[115, 9], 8}}, {{
      12.777777777777779`, 10}, {12.777777777777779`, 8}}]], 
   LineBox[NCache[{{Rational[41, 3], 10}, {Rational[41, 3], 8}}, {{
      13.666666666666666`, 10}, {13.666666666666666`, 8}}]], 
   LineBox[NCache[{{Rational[131, 9], 10}, {Rational[131, 9], 8}}, {{
      14.555555555555555`, 10}, {14.555555555555555`, 8}}]], 
   LineBox[NCache[{{Rational[139, 9], 10}, {Rational[139, 9], 8}}, {{
      15.444444444444445`, 10}, {15.444444444444445`, 8}}]], 
   LineBox[NCache[{{Rational[49, 3], 10}, {Rational[49, 3], 8}}, {{
      16.333333333333332`, 10}, {16.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[155, 9], 10}, {Rational[155, 9], 8}}, {{
      17.22222222222222, 10}, {17.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[163, 9], 10}, {Rational[163, 9], 8}}, {{
      18.11111111111111, 10}, {18.11111111111111, 8}}]], 
   LineBox[{{19, 10}, {19, 8}}], LineBox[{{21, 10}, {21, 8}}], 
   LineBox[NCache[{{Rational[197, 9], 10}, {Rational[197, 9], 8}}, {{
      21.88888888888889, 10}, {21.88888888888889, 8}}]], 
   LineBox[NCache[{{Rational[205, 9], 10}, {Rational[205, 9], 8}}, {{
      22.77777777777778, 10}, {22.77777777777778, 8}}]], 
   LineBox[NCache[{{Rational[71, 3], 10}, {Rational[71, 3], 8}}, {{
      23.666666666666668`, 10}, {23.666666666666668`, 8}}]], 
   LineBox[NCache[{{Rational[221, 9], 10}, {Rational[221, 9], 8}}, {{
      24.555555555555557`, 10}, {24.555555555555557`, 8}}]], 
   LineBox[NCache[{{Rational[229, 9], 10}, {Rational[229, 9], 8}}, {{
      25.444444444444443`, 10}, {25.444444444444443`, 8}}]], 
   LineBox[NCache[{{Rational[79, 3], 10}, {Rational[79, 3], 8}}, {{
      26.333333333333332`, 10}, {26.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[245, 9], 10}, {Rational[245, 9], 8}}, {{
      27.22222222222222, 10}, {27.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[253, 9], 10}, {Rational[253, 9], 8}}, {{
      28.11111111111111, 10}, {28.11111111111111, 8}}]], 
   LineBox[{{29, 10}, {29, 8}}]},
  ImageSize->400]], "Output",
 CellChangeTimes->{{3.470839535141005*^9, 3.470839538199673*^9}, 
   3.470839606755871*^9, 3.4708430134263*^9, 3.47084606230296*^9, 
   3.470846152163096*^9, 3.470846442261803*^9, 3.470849685038463*^9, {
   3.470850736859699*^9, 3.470850753229565*^9}, 3.470867722007346*^9, 
   3.470867804399878*^9, 3.470874479224133*^9, 3.470878270865595*^9, 
   3.470881812968481*^9, 3.470912101429021*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnduPVNW2hxuKi1TTiAgCCkIoARGVQIsQkIuA3BQSFUEkIEggmIgQjgYV
JERJFAMcNyQmoInx9kKIUaMPBrxEX3wgPvgOif+A8T+Ye/265qrTPcasptaC
9jTmM1lzs9f65m30/Krmw1iz1u14Zc+uvTteeXHnjsmrDuzYv+fFnf8zeeW+
A9mtyoC2tgHvZ9f/Tm7Tv0NbW150/fcfFfH/FPj34K7/qYTLly+Hzz77TFfb
wK6yEr7//vuu+9nV1t5VVsKHH34Y3nrrLV0Zp7ISvv76a8d98MEHjvvuu+8c
d+bMGcel+n3vvfcc98svvzjunXfecdxvv/3W4KqR0z3Lqa5tT31YTmOxnMZs
Oc3NcoqB5RSrnKtF7vTp0y3F5dSpU4778ccfy8VvsB50FIyQerOcRtVXEcq5
CxcuOO7jjz9O9mtXtpj4X9ugniLMnz8//J9ZWfFW1z/rD27COo899lijzsCI
33XXXaGzs1NXFiaVlTBs2DDHjRs3znFDhgxx3IQJExw3ePBgx02aNMlxAwcO
dNyMGTMcN2DAAMc9+OCDDa4aOd2znOra9tSH5TQWy2nMltPcLKcYWG7o0KEN
rtZLXCZPnuzaq1QqjrvnnnvKxa+ry46CEVJvltOobmSEtJosN3r0aMe1t7c7
TqvYclrtTUR47bXXHK7Psxxvj9xzzz3nuC+++MJxjz/+uOO+/fZbxz3yyCOO
+/XXXx139913O+7PP/903K233uq4v//+u8FVI6d7llNd2576sJzGYjmN2XKa
m+UUA8spVjlXKxiXBx54wHF//PFHufhFEYpFSL1ZTqPqqwjlnL71LPfiiy86
TqvYclrtOYcIiIAIiIAIiFDnEAEREAEREAER6hwiIAIiIAIiIEKdQwREQARE
QAREqHOIgAiIgAiIgAh1DhEQAREQAREQoc4ZEZ599lmHb9y4MVy8eFFX1qzK
dOB37tzpuFRO4r59+xyXyjV88803HdfR0eG4c+fOOS6V9Xr+/PkGV42c7llO
dW176sNyGovlNGbLaW6W279/v+MUq5yr9RKXI0eOuPZSOZgnTpwoF78oQrEI
qTfLaVRlI6RV0luEcm7Tpk2OmzdvnuO0ii2n1d5EhDvvvLOB634jdVsPbsI6
KWGVLr5ixQpdWZhU1lOgW+FSadETJ050XLO0aMul0sXnzJnTkxscHyxYsKDx
oBob0L28gUp9AdcfqBXbsnqzI2iWPm251HeJopFztYIzTyWEz5w58zoi1HGt
kKh525SGUTYk+sP3FpKcS31K6T0Gy2nBWa77lyq7N8exe6sv8GIR+pft3hAB
ERABERBBJSIgAiIEREAERECEiCMCIiACIiCCSkRABEQIiIAIiIAIEUcEREAE
REAElYiACIgQEAEREAERIv7kk086/IknnujKF86urFmVlTB16lTHPfPMM45L
5RDu2LHDcXfccYfjlCtsuWq16jgdqm25VCKrMqJzrhq5VAa46tr21IflNBbL
pfKbNTfLKQaWU6xyrlYwLiNHjnTc4cOHy8UvilAsQurNchpVX0Uo51IftRLQ
clrFltNqbyJCf876LlMnlS+tI6MlbXZlYVKZXiA6GNtyqYzy6dOnOy4loo6+
tlwqX3rp0qWOS+VLr127tsFVI6d7llNd2576sJzGYrnUcd2am+UUA8spVjlX
KxiXVL65XoQoFb8odrEIqTfLaVR9FaGc677Kc04vulgudfC5VnsTEdjqsdVj
q4cIiKASERABEQIiIAIiIELEEQEREAEREEElIiACIgREQAREQISIIwIiIAIi
IIJKREAERAiIgAiIgAgRRwREQIS2+tGyFp8/f3549913dWXNqqyEsWPHOm7R
okWOGzVqlONWrVrluNTB2E8//bTjUgeLv/TSS45LZWNq2jlXjVxKfNW17akP
y2ksltOYLae5WW716tWOU6xyrlYwLjrG13LPP/98ufhFEYpFSL1ZTqMqGyGt
kt4ilHMPPfRQ8iPKclrFltNqbyJCf04RL1Nn8eLFbvqzZs0KBw8e1JWFSWVa
2M7OTseNGDEi+XlmudTCXLlypeMGDRrkuK1btzoulVauz72cq0ZO9yynurY9
9WE5jcVyGnNqeVsu9c2lWOVcLXKp9P1UXFLp+3obolT8otjFIpR600ij6qsI
5VzqlHR97VhOq9hyWu1NRGCrx1aPrR4iIIJKREAERAiIgAiIgAgRRwREQARE
QASViIAIiBAQAREQAREijgiIgAiIgAgqEQERECEgAiIgAiJEHBEQARHa/pns
04ULFzqu1SzLVrNPU4f37tmzx2Wf6p7lVPdGZp9qbjdv9mmrEbqe7NNUhLRK
eotQH2ef9ucU8TJ1Wn1fZNy4cckwtfK+iN6VKPu+SOr07tT7IimxX3/9dfe+
iO6llm0r74toLP35fZFt27aVi1+P90VajZB6s9z1vC9yrQjl3Ny5cx13A94X
YavHVo+tHiIggkpEQARECIiACIiACBFHBERABERABJWIgAiIEBABERABESKO
CIiACIiACCoRAREQISACIiACIkQcERABEdrSOXrTp08Pu3fv1pU1qzKdFTlj
xgzHpdKiZ8+e7bhUWvSCBQsclzqFfP369Y5LHWq8efPmBleNnO5ZTnVte+rD
chqL5TRmy2lullMMLKdY5VytYFxSWaXLly8vF78oQrEIqTfLaVR9FaGcmzJl
iuOUpWo5rWLLabU3EaE/p4iXqZP6Rlq2bFk4e/asrixMKtOflGvWrHFc6ucK
NmzY4LjbbrvNcdu3b3fcLbfc4rhDhw45LvVexPHjxxtcNXK6ZznVte2pD8tp
LJbTmC2nuVlOMbCcYpVztYJxGT58uOP27t1bLn5R7GIRUm+W06j6KkI5t2TJ
EsdNnTrVcVrFluv+jclWz3Fs9eoiFIvQv2yrhwiIgAiIgAgqEQERECEgAiIg
AiJEHBEQAREQARFUIgIiIEJABERABESIOCIgAiIgAiKoRAREQISACIiACIgQ
8Tlz5jh80qRJ4ZlnntGVNasynS4+efJkx6XSopXga7lUWrTOl7Zc6rDipUuX
Oi6VVr527doGV42c7llOdW176sNyGovlUmdia26WSyU5K1Y5V+slLg8++KBr
L5Uu/vDDD5eLXxShWITUm+U0qr6KUM51z7HOOb30YDmtYstptTcRoT+niJep
89RTT7npP/HEE+H8+fO6sjCprCfuWm7jxo2OmzhxouN27NjhuDvuuMNx+/bt
c1zqA+W9995zXEqIc+fONbhq5HQvtcxse+rDchqL5TRmy2lullMMLKdY5Vwt
cqm0/FRcRo4c6bjDhw+Xi18Uu1iE1JvlNKq+ilDOpT549M1qOa1iy2m1NxGB
rR5bPbZ6iIAIKhEBERAhIAIiIAIiRBwREAEREAERVCICIiBCQAREQAREiDgi
IAIiIAIiqEQERECEgAiIgAiIEHFEQAREyB7de++9DteRs52dnbqyZlWmDw1O
cal05zFjxjgule48fvz4ntzg+ECpr8kH999/f+NBNbase3nLlfpfuP6gewJt
jwfq145F47Nj1jwsp/nmXK3I3NrSqfBKhi4Qg45rTTqVXK1+7VhuVAxybsSI
EY4bMmSI41KHOGtNNlmu/TmRu0yd1InPL7zwQrh8+bKuLEwqK2HevHmOO3Dg
gOO6r4OcO3r0qONqtZrjTp486bhUkvOFCxcclzo7+9KlSw2uGjnds5zq2vbU
h+U0FstpzJbT3CynGFhOscq5WuRSR+GfOnXKtZfS5aOPPioXv2hysQipN8tp
VH0VoZzbtWuX4x599FHHaRVbTqu9iQhsyNiQsSFDBERQiQiIgAgBERABERAh
4oiACIiACIigEhEQARECIiACIiBCxBEBERABERBBJSIgAiIEREAERECEiCMC
IiBCWzoLtL29vSsLMrvauv7Vlk5oTnGphGad+NwKp0zJHlye+KykxuSDCRMm
NB5UY8u6l7cc86DrD7onbPZ4kMrQ1PjsmDWP3rhaL3NTknMrMVBydYEYdFxr
0qlk7dTcblQMci6VDawkcctpDVlOa7LJcu3Pidxl6uzZs8dN/+WXXw5XrlzR
lYVJZT291nJvv/224+bOneu4999/33H33Xef4z7++GPHjR492nE//PCD41In
XCsdOOeqkdM9y6mubS+VAq2xWE5jtpzmZjnFwHI6FD/nagXjknqn4ssvvywX
v2hysQipN8tpVDcyQlpNlnvllVcct27dOsdpFVtOq72JCGzI2JCxIUMERFCJ
CIiACAEREAERECHiiIAIiIAIiKASERABEQIiIAIiIELEEQEREAEREEElIiAC
IgREQAREQISIIwIiIEJbOotx8ODBXcnK2ZU1qzKdqNwqpxOfe3B5QrMyhJMP
hg8fnn6gA6XzB9XYZfdDpmPic/2BWkk+6J6Z3OPB0KFD3eg1o7zLWkujV65m
gWl1XGse3TNrW5uHIt7bPPK/Vuo89xSnv7TltHKaLKr+nG5dps7+/fvd9N94
443w119/6crCpLKeBGu5M2fOOG7p0qWO++STTxw3Z84cx3311VeOS51D/fvv
vzuuuxA5d/Xq1QZXjZzuWU51bXvqw3Iai+U0ZstpbpZTDCynWOVcLXI6Pr6V
uEybNs1xP/30U7n4RVeLRUi9WU6j6qsI5dyxY8cct2XLFsdpFVtOq72JCGyb
2DaxbUIERFCJCIiACAEREAERECHiiIAIiIAIiKASERABEQIiIAIiIELEEQER
EAEREEElIiACIgREQAREQISIIwIiIAIiIIJKREAERAiIgAiIgAgRRwREQARE
QASViIAIiBAQAREQAREijgiIgAiIgAgqEQERECEgAiIgAiJEHBEQAREQARFU
IgIiIEJABERABESIOCIgAiIgAiKoRAREQISACIiACIgQcURABERABERQiQiI
gAgBERABERAh4mvXrnX4smXLwtmzZ3VlzapMB3T16tWOGzt2rOM2bNjgOP2m
o+W2b9/uuO4/Kplzhw4dclylUnHcu+++2+CqkdM9y6mubU99WE5jsZzGbDnN
zXKKgeUUq5yrFYxL6scT9+7dWy5+UYRiEVJvltOo+ipCObdkyRLHTZ061XFa
xZbTam8iQn/+xc8ydebPn++mP3369LB7925dWZhUVkJHR4fjZsyY4bjuP/ua
c7Nnz3Zc6kdrFyxY4LiUsOvXr3dc6id8N2/e3OCqkdM9y6mubU99pJa35TRm
y2lullMMLKdY5VytYFxSP267fPnycvGLYheLkHqznEbVVxHKuSlTpiQ/KCyn
VWw5rfYmIrDVY6vHVg8REEElIiACIgREQAREQISIIwIiIAIiIIJKREAERAiI
gAiIgAgRRwREQAREQASViIAIiBAQAREQAREijgiIgAjZoxUrVjhcOXpKLs6u
rFmV6XTxRYsWOW7UqFGOW7VqleNS2axPP/2044YMGeK4l156yXGpLEtNO+eq
kUuJr7q2PfVhOY3Fchqz5TQ3yykF33KKVc7VCsZl2LBhjnv++efLxS+KUCxC
6s1yGlXZCGmV9BahnHvooYeSH1GWS+VVa7U3EaE/p4iXqbN48WI3/VmzZoWD
Bw/qysKkMi1sZ2en40aMGJH8PLNcamGuXLnScYMGDXLc1q1bHZdKK9fnXs5V
I6d7llNd2576sJzGYjmNObW8LZf65lKscq4WuVRafiouqfTzJ598slz8otjF
IqTeLKdR9VWEcm7mzJmO09eO5bSKLafV3kQEtnps9djqIQIiqEQERECEgAiI
gAiIEHFEQAREQAREUIkIiIAIAREQAREQIeKIgAiIgAiIoBIREAERAiIgAiIg
QsQRAREQoe2fyT5duHCh41rNsmw1+3TgwIGO27Nnj8s+1T3Lqe6NzD7V3G7e
7NNWI3Q92aepCGmV9BahPs4+7c8p4mXqtPq+yLhx45JhauV9Eb0rUfZ9kdSp
3Kn3RVJiv/766+59Ed1LLdtW3hfRWPrz+yLbtm0rF78e74u0GiH1ZrnreV/k
WhHKublz5zruBrwvwlaPrR5bPURABJWIgAiIEBABERABESKOCIiACIiACCoR
AREQISACIiACIkQcERABERABEVQiAiIgQkAEREAERIg4IiACIrSlc/SmT58e
du/erStrVmU6K3LGjBmOS6VFz54923GptOgFCxY4LnUK+fr16x2XOtR48+bN
Da4aOd2znOra9tSH5TQWy2nMltPcLKcYWE6xyrlawbikskqXL19eLn5RhGIR
Um+W06j6KkI5N2XKFMcpS9VyWsWW02pvIkJ/ThEvUyf1jbRs2bJw9uxZXVmY
VKY/KdesWeO41M8VbNiwwXG33Xab47Zv3+64W265xXGHDh1yXOq9iOPHjze4
auR0z3Kqa9tTH5bTWCynMVtOc7OcYmA5xSrnagXjMnz4cMft3bu3XPyi2MUi
pN4sp1H1VYRybsmSJY6bOnWq47SKLdf9G5OtnuPY6tVFKBahf9lWDxEQAREQ
ARFUIgIiIEJABERABESIOCIgAiIgAiKoRAREQISACIiACIgQcURABERABERQ
iQiIgAgBERABERChl4DqAGMd/5pdWbMq0+nOKS6V7qw/huVS6c61Ws1xqXTx
OXPm9OQGxwfKYM4fVGMD3bOaK/U/eP2BWrEtqzc7Ao3Kchq95SZOnOg4RSPn
ar3M/J577nHtpY5pvu+++64jQh3XComat01pGGVDkrKwe0hy7vbbb3eczke2
XOpk7e7u3URZ32XqPPvss276mzZtChcvXtSVhUll2umdO3c6Tjm7ltu/f7/j
JkyY4LgjR444LvXqyYcffui4IUOGOO78+fMNrho53bOc6tr21IflNBbLacyW
09wspxhYTrHKuVrBuIwePdpxJ06cKBe/aHKxCKk3y2lUfRWhnNPqtNy8efNa
4rTam4jA7o3dG7s3REAElYiACIgQEAEREAERIo4IiIAIiIAIKhEBERAhIAIi
IAIiRBwREAEREAERVCICIiBCQAREQAREiDgiIAIiZI/uvfdeh+sU2c7OTl1Z
syrT5wCnuFQe9JgxYxyXyoMeP358Ty7PAFcSYvLB/fff33hQjS3rXt5yzIOu
P+ieGNvjgfq1Y9H47Jg1D8tpvjlXKzK3tnSO96RJk4rEoONak1Z7tg/1a8dy
o2KQcyNGjHCcclgtlzqXWWuyyXLtz4ncZeqkDnF+4YUXwuXLl3VlYVJZT6+1
3IEDBxzXfR3k3NGjRx2XyvU/efKk40aOHOm4CxcuOC51HPalS5caXDVyumc5
1bXtqQ/LaSyW05gtp7lZTjGwnGKVc7XIpU63P3XqlGsvpctHH31ULn7R5GIR
Um+W06j6KkI5t2vXLsc9+uijjtMqtpxWexMR2JCxIWNDhgiIoBIREAERAiIg
AiIgQsQRAREQAREQQSUiIAIiBERABERAhIgjAiIgAiIggkpEQARECIiACIiA
CBFHBERAhLZ0crBOclZSbnZlzapMJyq3yinptweXJzQrqTH5oL29Pf1AOcX5
g2rssnuecUx8rj9QK8kH3VNVezxIHWCsGeVd1loafbVaLTKtjmvNQ+3d2Hnk
f61USr9Svi2XOvxdK6fJourP6dZl6qRORX7jjTfCX3/9pSsLk8pKWLduneNO
nz7tuKVLlzruk08+cVzqJPuvvvrKcanj03///XfHDR8+3HFXr15tcNXI6Z7l
VNe2pz4sp7FYTmO2nOZmuU8//dRxS5YsaXC1gnGZNm2a43766ady8YuuFouQ
erOcRlU2QlolltNqstyxY8ccp72M5bSKLafV3kQEtk1sm9g2IQIiqEQERECE
gAiIgAiIEHFEQAREQAREUIkIiIAIAREQAREQIeKIgAiIgAiIoBIREAERAiIg
AiIgQsQRAREQoa1/Z8b+U3X4MODDgA8DREAElYiACIgQEAEREAERIo4IiIAI
iIAIKhEBERAhIAIiIAIiRBwREAEREAERVCICIiBCQAREQAREiDgiIAIitF3f
sZdnzpzp82Mv9Vv3lvv/OvZSY7mRhzr+E8dethS/m/7Yyy1btlzvsZf9OTO2
TJ3+eeizFtL1H/rcXfbWDkseOnSoG/0NPPQ5Pa1+duhziit46DPbJrZNbJsQ
ARFUIgIiIEJABERABESIOCIgAiIgAiKoRAREQISACIiACIgQcURABERABERQ
iQiIgAgBERABERAh4oiACIjQlk7RfvXVV8OVK1d0Zc2qrIRVq1Y57vjx445b
uHCh4zR0y82aNctxn3/+uePGjh3ruJ9//tlx7e3tjlMqcs5VI5dKvVZd214q
AVljsZzGbDnNzXKpP59ilXO1gnGp1WqO++abb8rFL4pQLELqzXIaVV9FKOcO
HTrkuA0bNjhOq9hyvaRoz58/v4HrfiMNWg9uwjr6DFECbnZl01dZCaNHjw5T
pkzRlYVJZT15Wcm72ZVxKitdibyWU1uWu/322x2n5GDLjRkzxnEDBw503IQJ
E3pyg+MDfZznD6qxAd3LG+jKP+6ID9SKbVm92RFoVJbT6C2nWVpO0ci5WsGZ
VyoVx+lNivIR6rhWSNS8bUrD6KuQ5JyS0y2n9HPLaWHaxdr9SzCu7a7/859y
/24b8F++zMeI\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", "False"}], "]"}]], "Input",\

 CellChangeTimes->{{3.470850765689768*^9, 3.470850768890102*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], 
   LineBox[NCache[{{11, 18}, {Rational[107, 9], 18}}, {{11, 18}, {
      11.88888888888889, 18}}]], 
   LineBox[NCache[{{11, Rational[154, 9]}, {
      Rational[107, 9], Rational[154, 9]}}, {{11, 17.11111111111111}, {
      11.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{11, Rational[146, 9]}, {
      Rational[107, 9], Rational[146, 9]}}, {{11, 16.22222222222222}, {
      11.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{11, Rational[46, 3]}, {
      Rational[107, 9], Rational[46, 3]}}, {{11, 15.333333333333334`}, {
      11.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{11, Rational[130, 9]}, {
      Rational[107, 9], Rational[130, 9]}}, {{11, 14.444444444444445`}, {
      11.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{11, Rational[122, 9]}, {
      Rational[107, 9], Rational[122, 9]}}, {{11, 13.555555555555555`}, {
      11.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {
      Rational[107, 9], Rational[38, 3]}}, {{11, 12.666666666666666`}, {
      11.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[106, 9]}, {
      Rational[107, 9], Rational[106, 9]}}, {{11, 11.777777777777779`}, {
      11.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{11, Rational[98, 9]}, {
      Rational[107, 9], Rational[98, 9]}}, {{11, 10.88888888888889}, {
      11.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{11, 10}, {Rational[107, 9], 10}}, {{11, 10}, {
      11.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[107, 9], 18}, {Rational[115, 9], 18}}, {{
      11.88888888888889, 18}, {12.777777777777779`, 18}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[154, 9]}, {
      Rational[115, 9], Rational[154, 9]}}, {{11.88888888888889, 
     17.11111111111111}, {12.777777777777779`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[146, 9]}, {
      Rational[115, 9], Rational[146, 9]}}, {{11.88888888888889, 
     16.22222222222222}, {12.777777777777779`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[46, 3]}, {
      Rational[115, 9], Rational[46, 3]}}, {{11.88888888888889, 
     15.333333333333334`}, {12.777777777777779`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[130, 9]}, {
      Rational[115, 9], Rational[130, 9]}}, {{11.88888888888889, 
     14.444444444444445`}, {12.777777777777779`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[122, 9]}, {
      Rational[115, 9], Rational[122, 9]}}, {{11.88888888888889, 
     13.555555555555555`}, {12.777777777777779`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[38, 3]}, {
      Rational[115, 9], Rational[38, 3]}}, {{11.88888888888889, 
     12.666666666666666`}, {12.777777777777779`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[106, 9]}, {
      Rational[115, 9], Rational[106, 9]}}, {{11.88888888888889, 
     11.777777777777779`}, {12.777777777777779`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[98, 9]}, {
      Rational[115, 9], Rational[98, 9]}}, {{11.88888888888889, 
     10.88888888888889}, {12.777777777777779`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[107, 9], 10}, {Rational[115, 9], 10}}, {{
      11.88888888888889, 10}, {12.777777777777779`, 10}}]], 
   LineBox[NCache[{{Rational[115, 9], 18}, {Rational[41, 3], 18}}, {{
      12.777777777777779`, 18}, {13.666666666666666`, 18}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[154, 9]}, {
      Rational[41, 3], Rational[154, 9]}}, {{12.777777777777779`, 
     17.11111111111111}, {13.666666666666666`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[146, 9]}, {
      Rational[41, 3], Rational[146, 9]}}, {{12.777777777777779`, 
     16.22222222222222}, {13.666666666666666`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[46, 3]}, {
      Rational[41, 3], Rational[46, 3]}}, {{12.777777777777779`, 
     15.333333333333334`}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[130, 9]}, {
      Rational[41, 3], Rational[130, 9]}}, {{12.777777777777779`, 
     14.444444444444445`}, {13.666666666666666`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[122, 9]}, {
      Rational[41, 3], Rational[122, 9]}}, {{12.777777777777779`, 
     13.555555555555555`}, {13.666666666666666`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[38, 3]}, {
      Rational[41, 3], Rational[38, 3]}}, {{12.777777777777779`, 
     12.666666666666666`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[106, 9]}, {
      Rational[41, 3], Rational[106, 9]}}, {{12.777777777777779`, 
     11.777777777777779`}, {13.666666666666666`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[98, 9]}, {
      Rational[41, 3], Rational[98, 9]}}, {{12.777777777777779`, 
     10.88888888888889}, {13.666666666666666`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[115, 9], 10}, {Rational[41, 3], 10}}, {{
      12.777777777777779`, 10}, {13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {Rational[131, 9], 18}}, {{
      13.666666666666666`, 18}, {14.555555555555555`, 18}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[154, 9]}, {
      Rational[131, 9], Rational[154, 9]}}, {{13.666666666666666`, 
     17.11111111111111}, {14.555555555555555`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[146, 9]}, {
      Rational[131, 9], Rational[146, 9]}}, {{13.666666666666666`, 
     16.22222222222222}, {14.555555555555555`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[131, 9], Rational[46, 3]}}, {{13.666666666666666`, 
     15.333333333333334`}, {14.555555555555555`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[130, 9]}, {
      Rational[131, 9], Rational[130, 9]}}, {{13.666666666666666`, 
     14.444444444444445`}, {14.555555555555555`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[122, 9]}, {
      Rational[131, 9], Rational[122, 9]}}, {{13.666666666666666`, 
     13.555555555555555`}, {14.555555555555555`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[131, 9], Rational[38, 3]}}, {{13.666666666666666`, 
     12.666666666666666`}, {14.555555555555555`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[106, 9]}, {
      Rational[131, 9], Rational[106, 9]}}, {{13.666666666666666`, 
     11.777777777777779`}, {14.555555555555555`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[98, 9]}, {
      Rational[131, 9], Rational[98, 9]}}, {{13.666666666666666`, 
     10.88888888888889}, {14.555555555555555`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[41, 3], 10}, {Rational[131, 9], 10}}, {{
      13.666666666666666`, 10}, {14.555555555555555`, 10}}]], 
   LineBox[NCache[{{Rational[131, 9], 18}, {Rational[139, 9], 18}}, {{
      14.555555555555555`, 18}, {15.444444444444445`, 18}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[154, 9]}, {
      Rational[139, 9], Rational[154, 9]}}, {{14.555555555555555`, 
     17.11111111111111}, {15.444444444444445`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[146, 9]}, {
      Rational[139, 9], Rational[146, 9]}}, {{14.555555555555555`, 
     16.22222222222222}, {15.444444444444445`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[46, 3]}, {
      Rational[139, 9], Rational[46, 3]}}, {{14.555555555555555`, 
     15.333333333333334`}, {15.444444444444445`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[130, 9]}, {
      Rational[139, 9], Rational[130, 9]}}, {{14.555555555555555`, 
     14.444444444444445`}, {15.444444444444445`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[122, 9]}, {
      Rational[139, 9], Rational[122, 9]}}, {{14.555555555555555`, 
     13.555555555555555`}, {15.444444444444445`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[38, 3]}, {
      Rational[139, 9], Rational[38, 3]}}, {{14.555555555555555`, 
     12.666666666666666`}, {15.444444444444445`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[106, 9]}, {
      Rational[139, 9], Rational[106, 9]}}, {{14.555555555555555`, 
     11.777777777777779`}, {15.444444444444445`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[98, 9]}, {
      Rational[139, 9], Rational[98, 9]}}, {{14.555555555555555`, 
     10.88888888888889}, {15.444444444444445`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[131, 9], 10}, {Rational[139, 9], 10}}, {{
      14.555555555555555`, 10}, {15.444444444444445`, 10}}]], 
   LineBox[NCache[{{Rational[139, 9], 18}, {Rational[49, 3], 18}}, {{
      15.444444444444445`, 18}, {16.333333333333332`, 18}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[154, 9]}, {
      Rational[49, 3], Rational[154, 9]}}, {{15.444444444444445`, 
     17.11111111111111}, {16.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[146, 9]}, {
      Rational[49, 3], Rational[146, 9]}}, {{15.444444444444445`, 
     16.22222222222222}, {16.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[46, 3]}, {
      Rational[49, 3], Rational[46, 3]}}, {{15.444444444444445`, 
     15.333333333333334`}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[130, 9]}, {
      Rational[49, 3], Rational[130, 9]}}, {{15.444444444444445`, 
     14.444444444444445`}, {16.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[122, 9]}, {
      Rational[49, 3], Rational[122, 9]}}, {{15.444444444444445`, 
     13.555555555555555`}, {16.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[38, 3]}, {
      Rational[49, 3], Rational[38, 3]}}, {{15.444444444444445`, 
     12.666666666666666`}, {16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[106, 9]}, {
      Rational[49, 3], Rational[106, 9]}}, {{15.444444444444445`, 
     11.777777777777779`}, {16.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[98, 9]}, {
      Rational[49, 3], Rational[98, 9]}}, {{15.444444444444445`, 
     10.88888888888889}, {16.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[139, 9], 10}, {Rational[49, 3], 10}}, {{
      15.444444444444445`, 10}, {16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {Rational[155, 9], 18}}, {{
      16.333333333333332`, 18}, {17.22222222222222, 18}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[154, 9]}, {
      Rational[155, 9], Rational[154, 9]}}, {{16.333333333333332`, 
     17.11111111111111}, {17.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[146, 9]}, {
      Rational[155, 9], Rational[146, 9]}}, {{16.333333333333332`, 
     16.22222222222222}, {17.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[155, 9], Rational[46, 3]}}, {{16.333333333333332`, 
     15.333333333333334`}, {17.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[130, 9]}, {
      Rational[155, 9], Rational[130, 9]}}, {{16.333333333333332`, 
     14.444444444444445`}, {17.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[122, 9]}, {
      Rational[155, 9], Rational[122, 9]}}, {{16.333333333333332`, 
     13.555555555555555`}, {17.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[155, 9], Rational[38, 3]}}, {{16.333333333333332`, 
     12.666666666666666`}, {17.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[106, 9]}, {
      Rational[155, 9], Rational[106, 9]}}, {{16.333333333333332`, 
     11.777777777777779`}, {17.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[98, 9]}, {
      Rational[155, 9], Rational[98, 9]}}, {{16.333333333333332`, 
     10.88888888888889}, {17.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[49, 3], 10}, {Rational[155, 9], 10}}, {{
      16.333333333333332`, 10}, {17.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[155, 9], 18}, {Rational[163, 9], 18}}, {{
      17.22222222222222, 18}, {18.11111111111111, 18}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[154, 9]}, {
      Rational[163, 9], Rational[154, 9]}}, {{17.22222222222222, 
     17.11111111111111}, {18.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[146, 9]}, {
      Rational[163, 9], Rational[146, 9]}}, {{17.22222222222222, 
     16.22222222222222}, {18.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[46, 3]}, {
      Rational[163, 9], Rational[46, 3]}}, {{17.22222222222222, 
     15.333333333333334`}, {18.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[130, 9]}, {
      Rational[163, 9], Rational[130, 9]}}, {{17.22222222222222, 
     14.444444444444445`}, {18.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[122, 9]}, {
      Rational[163, 9], Rational[122, 9]}}, {{17.22222222222222, 
     13.555555555555555`}, {18.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[38, 3]}, {
      Rational[163, 9], Rational[38, 3]}}, {{17.22222222222222, 
     12.666666666666666`}, {18.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[106, 9]}, {
      Rational[163, 9], Rational[106, 9]}}, {{17.22222222222222, 
     11.777777777777779`}, {18.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[98, 9]}, {
      Rational[163, 9], Rational[98, 9]}}, {{17.22222222222222, 
     10.88888888888889}, {18.11111111111111, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[155, 9], 10}, {Rational[163, 9], 10}}, {{
      17.22222222222222, 10}, {18.11111111111111, 10}}]], 
   LineBox[NCache[{{Rational[163, 9], 18}, {19, 18}}, {{
      18.11111111111111, 18}, {19, 18}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[154, 9]}, {
      19, Rational[154, 9]}}, {{18.11111111111111, 17.11111111111111}, {
      19, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[146, 9]}, {
      19, Rational[146, 9]}}, {{18.11111111111111, 16.22222222222222}, {
      19, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[46, 3]}, {
      19, Rational[46, 3]}}, {{18.11111111111111, 15.333333333333334`}, {
      19, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[130, 9]}, {
      19, Rational[130, 9]}}, {{18.11111111111111, 14.444444444444445`}, {
      19, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[122, 9]}, {
      19, Rational[122, 9]}}, {{18.11111111111111, 13.555555555555555`}, {
      19, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[38, 3]}, {
      19, Rational[38, 3]}}, {{18.11111111111111, 12.666666666666666`}, {
      19, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[106, 9]}, {
      19, Rational[106, 9]}}, {{18.11111111111111, 11.777777777777779`}, {
      19, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[98, 9]}, {
      19, Rational[98, 9]}}, {{18.11111111111111, 10.88888888888889}, {
      19, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[163, 9], 10}, {19, 10}}, {{
      18.11111111111111, 10}, {19, 10}}]], 
   LineBox[NCache[{{11, 18}, {11, Rational[154, 9]}}, {{11, 18}, {
      11, 17.11111111111111}}]], 
   LineBox[NCache[{{11, Rational[154, 9]}, {11, Rational[146, 9]}}, {{
      11, 17.11111111111111}, {11, 16.22222222222222}}]], 
   LineBox[NCache[{{11, Rational[146, 9]}, {11, Rational[46, 3]}}, {{
      11, 16.22222222222222}, {11, 15.333333333333334`}}]], 
   LineBox[
    NCache[{{11, Rational[46, 3]}, {11, Rational[130, 9]}}, {{
      11, 15.333333333333334`}, {11, 14.444444444444445`}}]], 
   LineBox[NCache[{{11, Rational[130, 9]}, {11, Rational[122, 9]}}, {{
      11, 14.444444444444445`}, {11, 13.555555555555555`}}]], 
   LineBox[NCache[{{11, Rational[122, 9]}, {11, Rational[38, 3]}}, {{
      11, 13.555555555555555`}, {11, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {11, Rational[106, 9]}}, {{
      11, 12.666666666666666`}, {11, 11.777777777777779`}}]], 
   LineBox[NCache[{{11, Rational[106, 9]}, {11, Rational[98, 9]}}, {{
      11, 11.777777777777779`}, {11, 10.88888888888889}}]], 
   LineBox[NCache[{{11, Rational[98, 9]}, {11, 10}}, {{
      11, 10.88888888888889}, {11, 10}}]], 
   LineBox[NCache[{{Rational[107, 9], 18}, {
      Rational[107, 9], Rational[154, 9]}}, {{11.88888888888889, 18}, {
      11.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[154, 9]}, {
      Rational[107, 9], Rational[146, 9]}}, {{11.88888888888889, 
     17.11111111111111}, {11.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[146, 9]}, {
      Rational[107, 9], Rational[46, 3]}}, {{11.88888888888889, 
     16.22222222222222}, {11.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[46, 3]}, {
      Rational[107, 9], Rational[130, 9]}}, {{11.88888888888889, 
     15.333333333333334`}, {11.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[130, 9]}, {
      Rational[107, 9], Rational[122, 9]}}, {{11.88888888888889, 
     14.444444444444445`}, {11.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[122, 9]}, {
      Rational[107, 9], Rational[38, 3]}}, {{11.88888888888889, 
     13.555555555555555`}, {11.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[38, 3]}, {
      Rational[107, 9], Rational[106, 9]}}, {{11.88888888888889, 
     12.666666666666666`}, {11.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[106, 9]}, {
      Rational[107, 9], Rational[98, 9]}}, {{11.88888888888889, 
     11.777777777777779`}, {11.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[98, 9]}, {
      Rational[107, 9], 10}}, {{11.88888888888889, 10.88888888888889}, {
      11.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[115, 9], 18}, {
      Rational[115, 9], Rational[154, 9]}}, {{12.777777777777779`, 18}, {
      12.777777777777779`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[154, 9]}, {
      Rational[115, 9], Rational[146, 9]}}, {{12.777777777777779`, 
     17.11111111111111}, {12.777777777777779`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[146, 9]}, {
      Rational[115, 9], Rational[46, 3]}}, {{12.777777777777779`, 
     16.22222222222222}, {12.777777777777779`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[46, 3]}, {
      Rational[115, 9], Rational[130, 9]}}, {{12.777777777777779`, 
     15.333333333333334`}, {12.777777777777779`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[130, 9]}, {
      Rational[115, 9], Rational[122, 9]}}, {{12.777777777777779`, 
     14.444444444444445`}, {12.777777777777779`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[122, 9]}, {
      Rational[115, 9], Rational[38, 3]}}, {{12.777777777777779`, 
     13.555555555555555`}, {12.777777777777779`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[38, 3]}, {
      Rational[115, 9], Rational[106, 9]}}, {{12.777777777777779`, 
     12.666666666666666`}, {12.777777777777779`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[106, 9]}, {
      Rational[115, 9], Rational[98, 9]}}, {{12.777777777777779`, 
     11.777777777777779`}, {12.777777777777779`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[98, 9]}, {
      Rational[115, 9], 10}}, {{12.777777777777779`, 10.88888888888889}, {
      12.777777777777779`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {
      Rational[41, 3], Rational[154, 9]}}, {{13.666666666666666`, 18}, {
      13.666666666666666`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[154, 9]}, {
      Rational[41, 3], Rational[146, 9]}}, {{13.666666666666666`, 
     17.11111111111111}, {13.666666666666666`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[146, 9]}, {
      Rational[41, 3], Rational[46, 3]}}, {{13.666666666666666`, 
     16.22222222222222}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[41, 3], Rational[130, 9]}}, {{13.666666666666666`, 
     15.333333333333334`}, {13.666666666666666`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[130, 9]}, {
      Rational[41, 3], Rational[122, 9]}}, {{13.666666666666666`, 
     14.444444444444445`}, {13.666666666666666`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[122, 9]}, {
      Rational[41, 3], Rational[38, 3]}}, {{13.666666666666666`, 
     13.555555555555555`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[41, 3], Rational[106, 9]}}, {{13.666666666666666`, 
     12.666666666666666`}, {13.666666666666666`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[106, 9]}, {
      Rational[41, 3], Rational[98, 9]}}, {{13.666666666666666`, 
     11.777777777777779`}, {13.666666666666666`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[98, 9]}, {
      Rational[41, 3], 10}}, {{13.666666666666666`, 10.88888888888889}, {
      13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[131, 9], 18}, {
      Rational[131, 9], Rational[154, 9]}}, {{14.555555555555555`, 18}, {
      14.555555555555555`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[154, 9]}, {
      Rational[131, 9], Rational[146, 9]}}, {{14.555555555555555`, 
     17.11111111111111}, {14.555555555555555`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[146, 9]}, {
      Rational[131, 9], Rational[46, 3]}}, {{14.555555555555555`, 
     16.22222222222222}, {14.555555555555555`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[46, 3]}, {
      Rational[131, 9], Rational[130, 9]}}, {{14.555555555555555`, 
     15.333333333333334`}, {14.555555555555555`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[130, 9]}, {
      Rational[131, 9], Rational[122, 9]}}, {{14.555555555555555`, 
     14.444444444444445`}, {14.555555555555555`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[122, 9]}, {
      Rational[131, 9], Rational[38, 3]}}, {{14.555555555555555`, 
     13.555555555555555`}, {14.555555555555555`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[38, 3]}, {
      Rational[131, 9], Rational[106, 9]}}, {{14.555555555555555`, 
     12.666666666666666`}, {14.555555555555555`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[106, 9]}, {
      Rational[131, 9], Rational[98, 9]}}, {{14.555555555555555`, 
     11.777777777777779`}, {14.555555555555555`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[98, 9]}, {
      Rational[131, 9], 10}}, {{14.555555555555555`, 10.88888888888889}, {
      14.555555555555555`, 10}}]], 
   LineBox[NCache[{{Rational[139, 9], 18}, {
      Rational[139, 9], Rational[154, 9]}}, {{15.444444444444445`, 18}, {
      15.444444444444445`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[154, 9]}, {
      Rational[139, 9], Rational[146, 9]}}, {{15.444444444444445`, 
     17.11111111111111}, {15.444444444444445`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[146, 9]}, {
      Rational[139, 9], Rational[46, 3]}}, {{15.444444444444445`, 
     16.22222222222222}, {15.444444444444445`, 15.333333333333334`}}]], 
   LineBox[
    NCache[{{Rational[139, 9], Rational[46, 3]}, {
      Rational[139, 9], Rational[130, 9]}}, {{15.444444444444445`, 
     15.333333333333334`}, {15.444444444444445`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[130, 9]}, {
      Rational[139, 9], Rational[122, 9]}}, {{15.444444444444445`, 
     14.444444444444445`}, {15.444444444444445`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[122, 9]}, {
      Rational[139, 9], Rational[38, 3]}}, {{15.444444444444445`, 
     13.555555555555555`}, {15.444444444444445`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[38, 3]}, {
      Rational[139, 9], Rational[106, 9]}}, {{15.444444444444445`, 
     12.666666666666666`}, {15.444444444444445`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[106, 9]}, {
      Rational[139, 9], Rational[98, 9]}}, {{15.444444444444445`, 
     11.777777777777779`}, {15.444444444444445`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[98, 9]}, {
      Rational[139, 9], 10}}, {{15.444444444444445`, 10.88888888888889}, {
      15.444444444444445`, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {
      Rational[49, 3], Rational[154, 9]}}, {{16.333333333333332`, 18}, {
      16.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[154, 9]}, {
      Rational[49, 3], Rational[146, 9]}}, {{16.333333333333332`, 
     17.11111111111111}, {16.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[146, 9]}, {
      Rational[49, 3], Rational[46, 3]}}, {{16.333333333333332`, 
     16.22222222222222}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[49, 3], Rational[130, 9]}}, {{16.333333333333332`, 
     15.333333333333334`}, {16.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[130, 9]}, {
      Rational[49, 3], Rational[122, 9]}}, {{16.333333333333332`, 
     14.444444444444445`}, {16.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[122, 9]}, {
      Rational[49, 3], Rational[38, 3]}}, {{16.333333333333332`, 
     13.555555555555555`}, {16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[49, 3], Rational[106, 9]}}, {{16.333333333333332`, 
     12.666666666666666`}, {16.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[106, 9]}, {
      Rational[49, 3], Rational[98, 9]}}, {{16.333333333333332`, 
     11.777777777777779`}, {16.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[98, 9]}, {
      Rational[49, 3], 10}}, {{16.333333333333332`, 10.88888888888889}, {
      16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[155, 9], 18}, {
      Rational[155, 9], Rational[154, 9]}}, {{17.22222222222222, 18}, {
      17.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[154, 9]}, {
      Rational[155, 9], Rational[146, 9]}}, {{17.22222222222222, 
     17.11111111111111}, {17.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[146, 9]}, {
      Rational[155, 9], Rational[46, 3]}}, {{17.22222222222222, 
     16.22222222222222}, {17.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[46, 3]}, {
      Rational[155, 9], Rational[130, 9]}}, {{17.22222222222222, 
     15.333333333333334`}, {17.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[130, 9]}, {
      Rational[155, 9], Rational[122, 9]}}, {{17.22222222222222, 
     14.444444444444445`}, {17.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[122, 9]}, {
      Rational[155, 9], Rational[38, 3]}}, {{17.22222222222222, 
     13.555555555555555`}, {17.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[38, 3]}, {
      Rational[155, 9], Rational[106, 9]}}, {{17.22222222222222, 
     12.666666666666666`}, {17.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[106, 9]}, {
      Rational[155, 9], Rational[98, 9]}}, {{17.22222222222222, 
     11.777777777777779`}, {17.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[98, 9]}, {
      Rational[155, 9], 10}}, {{17.22222222222222, 10.88888888888889}, {
      17.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[163, 9], 18}, {
      Rational[163, 9], Rational[154, 9]}}, {{18.11111111111111, 18}, {
      18.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[154, 9]}, {
      Rational[163, 9], Rational[146, 9]}}, {{18.11111111111111, 
     17.11111111111111}, {18.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[146, 9]}, {
      Rational[163, 9], Rational[46, 3]}}, {{18.11111111111111, 
     16.22222222222222}, {18.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[46, 3]}, {
      Rational[163, 9], Rational[130, 9]}}, {{18.11111111111111, 
     15.333333333333334`}, {18.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[130, 9]}, {
      Rational[163, 9], Rational[122, 9]}}, {{18.11111111111111, 
     14.444444444444445`}, {18.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[122, 9]}, {
      Rational[163, 9], Rational[38, 3]}}, {{18.11111111111111, 
     13.555555555555555`}, {18.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[38, 3]}, {
      Rational[163, 9], Rational[106, 9]}}, {{18.11111111111111, 
     12.666666666666666`}, {18.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[106, 9]}, {
      Rational[163, 9], Rational[98, 9]}}, {{18.11111111111111, 
     11.777777777777779`}, {18.11111111111111, 10.88888888888889}}]], 
   LineBox[
    NCache[{{Rational[163, 9], Rational[98, 9]}, {Rational[163, 9], 10}}, {{
      18.11111111111111, 10.88888888888889}, {18.11111111111111, 10}}]], 
   LineBox[NCache[{{19, 18}, {19, Rational[154, 9]}}, {{19, 18}, {
      19, 17.11111111111111}}]], 
   LineBox[NCache[{{19, Rational[154, 9]}, {19, Rational[146, 9]}}, {{
      19, 17.11111111111111}, {19, 16.22222222222222}}]], 
   LineBox[NCache[{{19, Rational[146, 9]}, {19, Rational[46, 3]}}, {{
      19, 16.22222222222222}, {19, 15.333333333333334`}}]], 
   LineBox[NCache[{{19, Rational[46, 3]}, {19, Rational[130, 9]}}, {{
      19, 15.333333333333334`}, {19, 14.444444444444445`}}]], 
   LineBox[NCache[{{19, Rational[130, 9]}, {19, Rational[122, 9]}}, {{
      19, 14.444444444444445`}, {19, 13.555555555555555`}}]], 
   LineBox[NCache[{{19, Rational[122, 9]}, {19, Rational[38, 3]}}, {{
      19, 13.555555555555555`}, {19, 12.666666666666666`}}]], 
   LineBox[NCache[{{19, Rational[38, 3]}, {19, Rational[106, 9]}}, {{
      19, 12.666666666666666`}, {19, 11.777777777777779`}}]], 
   LineBox[NCache[{{19, Rational[106, 9]}, {19, Rational[98, 9]}}, {{
      19, 11.777777777777779`}, {19, 10.88888888888889}}]], 
   LineBox[NCache[{{19, Rational[98, 9]}, {19, 10}}, {{
      19, 10.88888888888889}, {19, 10}}]], 
   LineBox[NCache[{{21, 18}, {Rational[197, 9], 18}}, {{21, 18}, {
      21.88888888888889, 18}}]], 
   LineBox[NCache[{{21, Rational[154, 9]}, {
      Rational[197, 9], Rational[154, 9]}}, {{21, 17.11111111111111}, {
      21.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{21, Rational[146, 9]}, {
      Rational[197, 9], Rational[146, 9]}}, {{21, 16.22222222222222}, {
      21.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{21, Rational[46, 3]}, {
      Rational[197, 9], Rational[46, 3]}}, {{21, 15.333333333333334`}, {
      21.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{21, Rational[130, 9]}, {
      Rational[197, 9], Rational[130, 9]}}, {{21, 14.444444444444445`}, {
      21.88888888888889, 14.444444444444445`}}]], 
   LineBox[
    NCache[{{21, Rational[122, 9]}, {Rational[197, 9], Rational[122, 9]}}, {{
      21, 13.555555555555555`}, {21.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{21, Rational[38, 3]}, {
      Rational[197, 9], Rational[38, 3]}}, {{21, 12.666666666666666`}, {
      21.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{21, Rational[106, 9]}, {
      Rational[197, 9], Rational[106, 9]}}, {{21, 11.777777777777779`}, {
      21.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{21, Rational[98, 9]}, {
      Rational[197, 9], Rational[98, 9]}}, {{21, 10.88888888888889}, {
      21.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{21, 10}, {Rational[197, 9], 10}}, {{21, 10}, {
      21.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[197, 9], 18}, {Rational[205, 9], 18}}, {{
      21.88888888888889, 18}, {22.77777777777778, 18}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[154, 9]}, {
      Rational[205, 9], Rational[154, 9]}}, {{21.88888888888889, 
     17.11111111111111}, {22.77777777777778, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[146, 9]}, {
      Rational[205, 9], Rational[146, 9]}}, {{21.88888888888889, 
     16.22222222222222}, {22.77777777777778, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[46, 3]}, {
      Rational[205, 9], Rational[46, 3]}}, {{21.88888888888889, 
     15.333333333333334`}, {22.77777777777778, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[130, 9]}, {
      Rational[205, 9], Rational[130, 9]}}, {{21.88888888888889, 
     14.444444444444445`}, {22.77777777777778, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[122, 9]}, {
      Rational[205, 9], Rational[122, 9]}}, {{21.88888888888889, 
     13.555555555555555`}, {22.77777777777778, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[38, 3]}, {
      Rational[205, 9], Rational[38, 3]}}, {{21.88888888888889, 
     12.666666666666666`}, {22.77777777777778, 12.666666666666666`}}]], 
   LineBox[
    NCache[{{Rational[197, 9], Rational[106, 9]}, {
      Rational[205, 9], Rational[106, 9]}}, {{21.88888888888889, 
     11.777777777777779`}, {22.77777777777778, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[98, 9]}, {
      Rational[205, 9], Rational[98, 9]}}, {{21.88888888888889, 
     10.88888888888889}, {22.77777777777778, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[197, 9], 10}, {Rational[205, 9], 10}}, {{
      21.88888888888889, 10}, {22.77777777777778, 10}}]], 
   LineBox[NCache[{{Rational[205, 9], 18}, {Rational[71, 3], 18}}, {{
      22.77777777777778, 18}, {23.666666666666668`, 18}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[154, 9]}, {
      Rational[71, 3], Rational[154, 9]}}, {{22.77777777777778, 
     17.11111111111111}, {23.666666666666668`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[146, 9]}, {
      Rational[71, 3], Rational[146, 9]}}, {{22.77777777777778, 
     16.22222222222222}, {23.666666666666668`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[46, 3]}, {
      Rational[71, 3], Rational[46, 3]}}, {{22.77777777777778, 
     15.333333333333334`}, {23.666666666666668`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[130, 9]}, {
      Rational[71, 3], Rational[130, 9]}}, {{22.77777777777778, 
     14.444444444444445`}, {23.666666666666668`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[122, 9]}, {
      Rational[71, 3], Rational[122, 9]}}, {{22.77777777777778, 
     13.555555555555555`}, {23.666666666666668`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[38, 3]}, {
      Rational[71, 3], Rational[38, 3]}}, {{22.77777777777778, 
     12.666666666666666`}, {23.666666666666668`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[106, 9]}, {
      Rational[71, 3], Rational[106, 9]}}, {{22.77777777777778, 
     11.777777777777779`}, {23.666666666666668`, 11.777777777777779`}}]], 
   LineBox[
    NCache[{{Rational[205, 9], Rational[98, 9]}, {
      Rational[71, 3], Rational[98, 9]}}, {{22.77777777777778, 
     10.88888888888889}, {23.666666666666668`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[205, 9], 10}, {Rational[71, 3], 10}}, {{
      22.77777777777778, 10}, {23.666666666666668`, 10}}]], 
   LineBox[NCache[{{Rational[71, 3], 18}, {Rational[221, 9], 18}}, {{
      23.666666666666668`, 18}, {24.555555555555557`, 18}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[154, 9]}, {
      Rational[221, 9], Rational[154, 9]}}, {{23.666666666666668`, 
     17.11111111111111}, {24.555555555555557`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[146, 9]}, {
      Rational[221, 9], Rational[146, 9]}}, {{23.666666666666668`, 
     16.22222222222222}, {24.555555555555557`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[46, 3]}, {
      Rational[221, 9], Rational[46, 3]}}, {{23.666666666666668`, 
     15.333333333333334`}, {24.555555555555557`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[130, 9]}, {
      Rational[221, 9], Rational[130, 9]}}, {{23.666666666666668`, 
     14.444444444444445`}, {24.555555555555557`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[122, 9]}, {
      Rational[221, 9], Rational[122, 9]}}, {{23.666666666666668`, 
     13.555555555555555`}, {24.555555555555557`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[38, 3]}, {
      Rational[221, 9], Rational[38, 3]}}, {{23.666666666666668`, 
     12.666666666666666`}, {24.555555555555557`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[106, 9]}, {
      Rational[221, 9], Rational[106, 9]}}, {{23.666666666666668`, 
     11.777777777777779`}, {24.555555555555557`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[98, 9]}, {
      Rational[221, 9], Rational[98, 9]}}, {{23.666666666666668`, 
     10.88888888888889}, {24.555555555555557`, 10.88888888888889}}]], 
   LineBox[
    NCache[{{Rational[71, 3], 10}, {Rational[221, 9], 10}}, {{
      23.666666666666668`, 10}, {24.555555555555557`, 10}}]], 
   LineBox[NCache[{{Rational[221, 9], 18}, {Rational[229, 9], 18}}, {{
      24.555555555555557`, 18}, {25.444444444444443`, 18}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[154, 9]}, {
      Rational[229, 9], Rational[154, 9]}}, {{24.555555555555557`, 
     17.11111111111111}, {25.444444444444443`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[146, 9]}, {
      Rational[229, 9], Rational[146, 9]}}, {{24.555555555555557`, 
     16.22222222222222}, {25.444444444444443`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[46, 3]}, {
      Rational[229, 9], Rational[46, 3]}}, {{24.555555555555557`, 
     15.333333333333334`}, {25.444444444444443`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[130, 9]}, {
      Rational[229, 9], Rational[130, 9]}}, {{24.555555555555557`, 
     14.444444444444445`}, {25.444444444444443`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[122, 9]}, {
      Rational[229, 9], Rational[122, 9]}}, {{24.555555555555557`, 
     13.555555555555555`}, {25.444444444444443`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[38, 3]}, {
      Rational[229, 9], Rational[38, 3]}}, {{24.555555555555557`, 
     12.666666666666666`}, {25.444444444444443`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[106, 9]}, {
      Rational[229, 9], Rational[106, 9]}}, {{24.555555555555557`, 
     11.777777777777779`}, {25.444444444444443`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[98, 9]}, {
      Rational[229, 9], Rational[98, 9]}}, {{24.555555555555557`, 
     10.88888888888889}, {25.444444444444443`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[221, 9], 10}, {Rational[229, 9], 10}}, {{
      24.555555555555557`, 10}, {25.444444444444443`, 10}}]], 
   LineBox[NCache[{{Rational[229, 9], 18}, {Rational[79, 3], 18}}, {{
      25.444444444444443`, 18}, {26.333333333333332`, 18}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[154, 9]}, {
      Rational[79, 3], Rational[154, 9]}}, {{25.444444444444443`, 
     17.11111111111111}, {26.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[146, 9]}, {
      Rational[79, 3], Rational[146, 9]}}, {{25.444444444444443`, 
     16.22222222222222}, {26.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[46, 3]}, {
      Rational[79, 3], Rational[46, 3]}}, {{25.444444444444443`, 
     15.333333333333334`}, {26.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[130, 9]}, {
      Rational[79, 3], Rational[130, 9]}}, {{25.444444444444443`, 
     14.444444444444445`}, {26.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[122, 9]}, {
      Rational[79, 3], Rational[122, 9]}}, {{25.444444444444443`, 
     13.555555555555555`}, {26.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[38, 3]}, {
      Rational[79, 3], Rational[38, 3]}}, {{25.444444444444443`, 
     12.666666666666666`}, {26.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[106, 9]}, {
      Rational[79, 3], Rational[106, 9]}}, {{25.444444444444443`, 
     11.777777777777779`}, {26.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[98, 9]}, {
      Rational[79, 3], Rational[98, 9]}}, {{25.444444444444443`, 
     10.88888888888889}, {26.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[229, 9], 10}, {Rational[79, 3], 10}}, {{
      25.444444444444443`, 10}, {26.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[79, 3], 18}, {Rational[245, 9], 18}}, {{
      26.333333333333332`, 18}, {27.22222222222222, 18}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[154, 9]}, {
      Rational[245, 9], Rational[154, 9]}}, {{26.333333333333332`, 
     17.11111111111111}, {27.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[146, 9]}, {
      Rational[245, 9], Rational[146, 9]}}, {{26.333333333333332`, 
     16.22222222222222}, {27.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[46, 3]}, {
      Rational[245, 9], Rational[46, 3]}}, {{26.333333333333332`, 
     15.333333333333334`}, {27.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[130, 9]}, {
      Rational[245, 9], Rational[130, 9]}}, {{26.333333333333332`, 
     14.444444444444445`}, {27.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[122, 9]}, {
      Rational[245, 9], Rational[122, 9]}}, {{26.333333333333332`, 
     13.555555555555555`}, {27.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[38, 3]}, {
      Rational[245, 9], Rational[38, 3]}}, {{26.333333333333332`, 
     12.666666666666666`}, {27.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[106, 9]}, {
      Rational[245, 9], Rational[106, 9]}}, {{26.333333333333332`, 
     11.777777777777779`}, {27.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[98, 9]}, {
      Rational[245, 9], Rational[98, 9]}}, {{26.333333333333332`, 
     10.88888888888889}, {27.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[79, 3], 10}, {Rational[245, 9], 10}}, {{
      26.333333333333332`, 10}, {27.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[245, 9], 18}, {Rational[253, 9], 18}}, {{
      27.22222222222222, 18}, {28.11111111111111, 18}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[154, 9]}, {
      Rational[253, 9], Rational[154, 9]}}, {{27.22222222222222, 
     17.11111111111111}, {28.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[146, 9]}, {
      Rational[253, 9], Rational[146, 9]}}, {{27.22222222222222, 
     16.22222222222222}, {28.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[46, 3]}, {
      Rational[253, 9], Rational[46, 3]}}, {{27.22222222222222, 
     15.333333333333334`}, {28.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[130, 9]}, {
      Rational[253, 9], Rational[130, 9]}}, {{27.22222222222222, 
     14.444444444444445`}, {28.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[122, 9]}, {
      Rational[253, 9], Rational[122, 9]}}, {{27.22222222222222, 
     13.555555555555555`}, {28.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[38, 3]}, {
      Rational[253, 9], Rational[38, 3]}}, {{27.22222222222222, 
     12.666666666666666`}, {28.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[106, 9]}, {
      Rational[253, 9], Rational[106, 9]}}, {{27.22222222222222, 
     11.777777777777779`}, {28.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[98, 9]}, {
      Rational[253, 9], Rational[98, 9]}}, {{27.22222222222222, 
     10.88888888888889}, {28.11111111111111, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[245, 9], 10}, {Rational[253, 9], 10}}, {{
      27.22222222222222, 10}, {28.11111111111111, 10}}]], 
   LineBox[NCache[{{Rational[253, 9], 18}, {29, 18}}, {{
      28.11111111111111, 18}, {29, 18}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[154, 9]}, {
      29, Rational[154, 9]}}, {{28.11111111111111, 17.11111111111111}, {
      29, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[146, 9]}, {
      29, Rational[146, 9]}}, {{28.11111111111111, 16.22222222222222}, {
      29, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[46, 3]}, {
      29, Rational[46, 3]}}, {{28.11111111111111, 15.333333333333334`}, {
      29, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[130, 9]}, {
      29, Rational[130, 9]}}, {{28.11111111111111, 14.444444444444445`}, {
      29, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[122, 9]}, {
      29, Rational[122, 9]}}, {{28.11111111111111, 13.555555555555555`}, {
      29, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[38, 3]}, {
      29, Rational[38, 3]}}, {{28.11111111111111, 12.666666666666666`}, {
      29, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[106, 9]}, {
      29, Rational[106, 9]}}, {{28.11111111111111, 11.777777777777779`}, {
      29, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[98, 9]}, {
      29, Rational[98, 9]}}, {{28.11111111111111, 10.88888888888889}, {
      29, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[253, 9], 10}, {29, 10}}, {{
      28.11111111111111, 10}, {29, 10}}]], 
   LineBox[NCache[{{21, 18}, {21, Rational[154, 9]}}, {{21, 18}, {
      21, 17.11111111111111}}]], 
   LineBox[NCache[{{21, Rational[154, 9]}, {21, Rational[146, 9]}}, {{
      21, 17.11111111111111}, {21, 16.22222222222222}}]], 
   LineBox[NCache[{{21, Rational[146, 9]}, {21, Rational[46, 3]}}, {{
      21, 16.22222222222222}, {21, 15.333333333333334`}}]], 
   LineBox[NCache[{{21, Rational[46, 3]}, {21, Rational[130, 9]}}, {{
      21, 15.333333333333334`}, {21, 14.444444444444445`}}]], 
   LineBox[NCache[{{21, Rational[130, 9]}, {21, Rational[122, 9]}}, {{
      21, 14.444444444444445`}, {21, 13.555555555555555`}}]], 
   LineBox[NCache[{{21, Rational[122, 9]}, {21, Rational[38, 3]}}, {{
      21, 13.555555555555555`}, {21, 12.666666666666666`}}]], 
   LineBox[NCache[{{21, Rational[38, 3]}, {21, Rational[106, 9]}}, {{
      21, 12.666666666666666`}, {21, 11.777777777777779`}}]], 
   LineBox[NCache[{{21, Rational[106, 9]}, {21, Rational[98, 9]}}, {{
      21, 11.777777777777779`}, {21, 10.88888888888889}}]], 
   LineBox[NCache[{{21, Rational[98, 9]}, {21, 10}}, {{
      21, 10.88888888888889}, {21, 10}}]], 
   LineBox[NCache[{{Rational[197, 9], 18}, {
      Rational[197, 9], Rational[154, 9]}}, {{21.88888888888889, 18}, {
      21.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[154, 9]}, {
      Rational[197, 9], Rational[146, 9]}}, {{21.88888888888889, 
     17.11111111111111}, {21.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[146, 9]}, {
      Rational[197, 9], Rational[46, 3]}}, {{21.88888888888889, 
     16.22222222222222}, {21.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[46, 3]}, {
      Rational[197, 9], Rational[130, 9]}}, {{21.88888888888889, 
     15.333333333333334`}, {21.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[130, 9]}, {
      Rational[197, 9], Rational[122, 9]}}, {{21.88888888888889, 
     14.444444444444445`}, {21.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[122, 9]}, {
      Rational[197, 9], Rational[38, 3]}}, {{21.88888888888889, 
     13.555555555555555`}, {21.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[38, 3]}, {
      Rational[197, 9], Rational[106, 9]}}, {{21.88888888888889, 
     12.666666666666666`}, {21.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[106, 9]}, {
      Rational[197, 9], Rational[98, 9]}}, {{21.88888888888889, 
     11.777777777777779`}, {21.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[98, 9]}, {
      Rational[197, 9], 10}}, {{21.88888888888889, 10.88888888888889}, {
      21.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[205, 9], 18}, {
      Rational[205, 9], Rational[154, 9]}}, {{22.77777777777778, 18}, {
      22.77777777777778, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[154, 9]}, {
      Rational[205, 9], Rational[146, 9]}}, {{22.77777777777778, 
     17.11111111111111}, {22.77777777777778, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[146, 9]}, {
      Rational[205, 9], Rational[46, 3]}}, {{22.77777777777778, 
     16.22222222222222}, {22.77777777777778, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[46, 3]}, {
      Rational[205, 9], Rational[130, 9]}}, {{22.77777777777778, 
     15.333333333333334`}, {22.77777777777778, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[130, 9]}, {
      Rational[205, 9], Rational[122, 9]}}, {{22.77777777777778, 
     14.444444444444445`}, {22.77777777777778, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[122, 9]}, {
      Rational[205, 9], Rational[38, 3]}}, {{22.77777777777778, 
     13.555555555555555`}, {22.77777777777778, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[38, 3]}, {
      Rational[205, 9], Rational[106, 9]}}, {{22.77777777777778, 
     12.666666666666666`}, {22.77777777777778, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[106, 9]}, {
      Rational[205, 9], Rational[98, 9]}}, {{22.77777777777778, 
     11.777777777777779`}, {22.77777777777778, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[98, 9]}, {
      Rational[205, 9], 10}}, {{22.77777777777778, 10.88888888888889}, {
      22.77777777777778, 10}}]], 
   LineBox[NCache[{{Rational[71, 3], 18}, {
      Rational[71, 3], Rational[154, 9]}}, {{23.666666666666668`, 18}, {
      23.666666666666668`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[154, 9]}, {
      Rational[71, 3], Rational[146, 9]}}, {{23.666666666666668`, 
     17.11111111111111}, {23.666666666666668`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[146, 9]}, {
      Rational[71, 3], Rational[46, 3]}}, {{23.666666666666668`, 
     16.22222222222222}, {23.666666666666668`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[46, 3]}, {
      Rational[71, 3], Rational[130, 9]}}, {{23.666666666666668`, 
     15.333333333333334`}, {23.666666666666668`, 14.444444444444445`}}]], 
   LineBox[
    NCache[{{Rational[71, 3], Rational[130, 9]}, {
      Rational[71, 3], Rational[122, 9]}}, {{23.666666666666668`, 
     14.444444444444445`}, {23.666666666666668`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[122, 9]}, {
      Rational[71, 3], Rational[38, 3]}}, {{23.666666666666668`, 
     13.555555555555555`}, {23.666666666666668`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[38, 3]}, {
      Rational[71, 3], Rational[106, 9]}}, {{23.666666666666668`, 
     12.666666666666666`}, {23.666666666666668`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[106, 9]}, {
      Rational[71, 3], Rational[98, 9]}}, {{23.666666666666668`, 
     11.777777777777779`}, {23.666666666666668`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[98, 9]}, {
      Rational[71, 3], 10}}, {{23.666666666666668`, 10.88888888888889}, {
      23.666666666666668`, 10}}]], 
   LineBox[NCache[{{Rational[221, 9], 18}, {
      Rational[221, 9], Rational[154, 9]}}, {{24.555555555555557`, 18}, {
      24.555555555555557`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[154, 9]}, {
      Rational[221, 9], Rational[146, 9]}}, {{24.555555555555557`, 
     17.11111111111111}, {24.555555555555557`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[146, 9]}, {
      Rational[221, 9], Rational[46, 3]}}, {{24.555555555555557`, 
     16.22222222222222}, {24.555555555555557`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[46, 3]}, {
      Rational[221, 9], Rational[130, 9]}}, {{24.555555555555557`, 
     15.333333333333334`}, {24.555555555555557`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[130, 9]}, {
      Rational[221, 9], Rational[122, 9]}}, {{24.555555555555557`, 
     14.444444444444445`}, {24.555555555555557`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[122, 9]}, {
      Rational[221, 9], Rational[38, 3]}}, {{24.555555555555557`, 
     13.555555555555555`}, {24.555555555555557`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[38, 3]}, {
      Rational[221, 9], Rational[106, 9]}}, {{24.555555555555557`, 
     12.666666666666666`}, {24.555555555555557`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[106, 9]}, {
      Rational[221, 9], Rational[98, 9]}}, {{24.555555555555557`, 
     11.777777777777779`}, {24.555555555555557`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[98, 9]}, {
      Rational[221, 9], 10}}, {{24.555555555555557`, 10.88888888888889}, {
      24.555555555555557`, 10}}]], 
   LineBox[NCache[{{Rational[229, 9], 18}, {
      Rational[229, 9], Rational[154, 9]}}, {{25.444444444444443`, 18}, {
      25.444444444444443`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[154, 9]}, {
      Rational[229, 9], Rational[146, 9]}}, {{25.444444444444443`, 
     17.11111111111111}, {25.444444444444443`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[146, 9]}, {
      Rational[229, 9], Rational[46, 3]}}, {{25.444444444444443`, 
     16.22222222222222}, {25.444444444444443`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[46, 3]}, {
      Rational[229, 9], Rational[130, 9]}}, {{25.444444444444443`, 
     15.333333333333334`}, {25.444444444444443`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[130, 9]}, {
      Rational[229, 9], Rational[122, 9]}}, {{25.444444444444443`, 
     14.444444444444445`}, {25.444444444444443`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[122, 9]}, {
      Rational[229, 9], Rational[38, 3]}}, {{25.444444444444443`, 
     13.555555555555555`}, {25.444444444444443`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[38, 3]}, {
      Rational[229, 9], Rational[106, 9]}}, {{25.444444444444443`, 
     12.666666666666666`}, {25.444444444444443`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[106, 9]}, {
      Rational[229, 9], Rational[98, 9]}}, {{25.444444444444443`, 
     11.777777777777779`}, {25.444444444444443`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[98, 9]}, {
      Rational[229, 9], 10}}, {{25.444444444444443`, 10.88888888888889}, {
      25.444444444444443`, 10}}]], 
   LineBox[NCache[{{Rational[79, 3], 18}, {
      Rational[79, 3], Rational[154, 9]}}, {{26.333333333333332`, 18}, {
      26.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[154, 9]}, {
      Rational[79, 3], Rational[146, 9]}}, {{26.333333333333332`, 
     17.11111111111111}, {26.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[146, 9]}, {
      Rational[79, 3], Rational[46, 3]}}, {{26.333333333333332`, 
     16.22222222222222}, {26.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[46, 3]}, {
      Rational[79, 3], Rational[130, 9]}}, {{26.333333333333332`, 
     15.333333333333334`}, {26.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[130, 9]}, {
      Rational[79, 3], Rational[122, 9]}}, {{26.333333333333332`, 
     14.444444444444445`}, {26.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[122, 9]}, {
      Rational[79, 3], Rational[38, 3]}}, {{26.333333333333332`, 
     13.555555555555555`}, {26.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[38, 3]}, {
      Rational[79, 3], Rational[106, 9]}}, {{26.333333333333332`, 
     12.666666666666666`}, {26.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[106, 9]}, {
      Rational[79, 3], Rational[98, 9]}}, {{26.333333333333332`, 
     11.777777777777779`}, {26.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[98, 9]}, {
      Rational[79, 3], 10}}, {{26.333333333333332`, 10.88888888888889}, {
      26.333333333333332`, 10}}]], 
   LineBox[
    NCache[{{Rational[245, 9], 18}, {Rational[245, 9], Rational[154, 9]}}, {{
      27.22222222222222, 18}, {27.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[154, 9]}, {
      Rational[245, 9], Rational[146, 9]}}, {{27.22222222222222, 
     17.11111111111111}, {27.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[146, 9]}, {
      Rational[245, 9], Rational[46, 3]}}, {{27.22222222222222, 
     16.22222222222222}, {27.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[46, 3]}, {
      Rational[245, 9], Rational[130, 9]}}, {{27.22222222222222, 
     15.333333333333334`}, {27.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[130, 9]}, {
      Rational[245, 9], Rational[122, 9]}}, {{27.22222222222222, 
     14.444444444444445`}, {27.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[122, 9]}, {
      Rational[245, 9], Rational[38, 3]}}, {{27.22222222222222, 
     13.555555555555555`}, {27.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[38, 3]}, {
      Rational[245, 9], Rational[106, 9]}}, {{27.22222222222222, 
     12.666666666666666`}, {27.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[106, 9]}, {
      Rational[245, 9], Rational[98, 9]}}, {{27.22222222222222, 
     11.777777777777779`}, {27.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[98, 9]}, {
      Rational[245, 9], 10}}, {{27.22222222222222, 10.88888888888889}, {
      27.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[253, 9], 18}, {
      Rational[253, 9], Rational[154, 9]}}, {{28.11111111111111, 18}, {
      28.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[154, 9]}, {
      Rational[253, 9], Rational[146, 9]}}, {{28.11111111111111, 
     17.11111111111111}, {28.11111111111111, 16.22222222222222}}]], 
   LineBox[
    NCache[{{Rational[253, 9], Rational[146, 9]}, {
      Rational[253, 9], Rational[46, 3]}}, {{28.11111111111111, 
     16.22222222222222}, {28.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[46, 3]}, {
      Rational[253, 9], Rational[130, 9]}}, {{28.11111111111111, 
     15.333333333333334`}, {28.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[130, 9]}, {
      Rational[253, 9], Rational[122, 9]}}, {{28.11111111111111, 
     14.444444444444445`}, {28.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[122, 9]}, {
      Rational[253, 9], Rational[38, 3]}}, {{28.11111111111111, 
     13.555555555555555`}, {28.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[38, 3]}, {
      Rational[253, 9], Rational[106, 9]}}, {{28.11111111111111, 
     12.666666666666666`}, {28.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[106, 9]}, {
      Rational[253, 9], Rational[98, 9]}}, {{28.11111111111111, 
     11.777777777777779`}, {28.11111111111111, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[98, 9]}, {
      Rational[253, 9], 10}}, {{28.11111111111111, 10.88888888888889}, {
      28.11111111111111, 10}}]], 
   LineBox[NCache[{{29, 18}, {29, Rational[154, 9]}}, {{29, 18}, {
      29, 17.11111111111111}}]], 
   LineBox[NCache[{{29, Rational[154, 9]}, {29, Rational[146, 9]}}, {{
      29, 17.11111111111111}, {29, 16.22222222222222}}]], 
   LineBox[NCache[{{29, Rational[146, 9]}, {29, Rational[46, 3]}}, {{
      29, 16.22222222222222}, {29, 15.333333333333334`}}]], 
   LineBox[NCache[{{29, Rational[46, 3]}, {29, Rational[130, 9]}}, {{
      29, 15.333333333333334`}, {29, 14.444444444444445`}}]], 
   LineBox[NCache[{{29, Rational[130, 9]}, {29, Rational[122, 9]}}, {{
      29, 14.444444444444445`}, {29, 13.555555555555555`}}]], 
   LineBox[NCache[{{29, Rational[122, 9]}, {29, Rational[38, 3]}}, {{
      29, 13.555555555555555`}, {29, 12.666666666666666`}}]], 
   LineBox[NCache[{{29, Rational[38, 3]}, {29, Rational[106, 9]}}, {{
      29, 12.666666666666666`}, {29, 11.777777777777779`}}]], 
   LineBox[NCache[{{29, Rational[106, 9]}, {29, Rational[98, 9]}}, {{
      29, 11.777777777777779`}, {29, 10.88888888888889}}]], 
   LineBox[NCache[{{29, Rational[98, 9]}, {29, 10}}, {{
      29, 10.88888888888889}, {29, 10}}]], 
   LineBox[NCache[{{11, 8}, {Rational[107, 9], 8}}, {{11, 8}, {
      11.88888888888889, 8}}]], 
   LineBox[NCache[{{11, Rational[64, 9]}, {
      Rational[107, 9], Rational[64, 9]}}, {{11, 7.111111111111111}, {
      11.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{11, Rational[56, 9]}, {
      Rational[107, 9], Rational[56, 9]}}, {{11, 6.222222222222222}, {
      11.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{11, Rational[16, 3]}, {
      Rational[107, 9], Rational[16, 3]}}, {{11, 5.333333333333333}, {
      11.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{11, Rational[40, 9]}, {
      Rational[107, 9], Rational[40, 9]}}, {{11, 4.444444444444445}, {
      11.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{11, Rational[32, 9]}, {
      Rational[107, 9], Rational[32, 9]}}, {{11, 3.5555555555555554`}, {
      11.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{11, Rational[8, 3]}, {
      Rational[107, 9], Rational[8, 3]}}, {{11, 2.6666666666666665`}, {
      11.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{11, Rational[16, 9]}, {
      Rational[107, 9], Rational[16, 9]}}, {{11, 1.7777777777777777`}, {
      11.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{11, Rational[8, 9]}, {
      Rational[107, 9], Rational[8, 9]}}, {{11, 0.8888888888888888}, {
      11.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{11, 0}, {Rational[107, 9], 0}}, {{11, 0}, {
      11.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[107, 9], 8}, {Rational[115, 9], 8}}, {{
      11.88888888888889, 8}, {12.777777777777779`, 8}}]], 
   LineBox[
    NCache[{{Rational[107, 9], Rational[64, 9]}, {
      Rational[115, 9], Rational[64, 9]}}, {{11.88888888888889, 
     7.111111111111111}, {12.777777777777779`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[56, 9]}, {
      Rational[115, 9], Rational[56, 9]}}, {{11.88888888888889, 
     6.222222222222222}, {12.777777777777779`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 3]}, {
      Rational[115, 9], Rational[16, 3]}}, {{11.88888888888889, 
     5.333333333333333}, {12.777777777777779`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[40, 9]}, {
      Rational[115, 9], Rational[40, 9]}}, {{11.88888888888889, 
     4.444444444444445}, {12.777777777777779`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[32, 9]}, {
      Rational[115, 9], Rational[32, 9]}}, {{11.88888888888889, 
     3.5555555555555554`}, {12.777777777777779`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 3]}, {
      Rational[115, 9], Rational[8, 3]}}, {{11.88888888888889, 
     2.6666666666666665`}, {12.777777777777779`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 9]}, {
      Rational[115, 9], Rational[16, 9]}}, {{11.88888888888889, 
     1.7777777777777777`}, {12.777777777777779`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 9]}, {
      Rational[115, 9], Rational[8, 9]}}, {{11.88888888888889, 
     0.8888888888888888}, {12.777777777777779`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[107, 9], 0}, {Rational[115, 9], 0}}, {{
      11.88888888888889, 0}, {12.777777777777779`, 0}}]], 
   LineBox[NCache[{{Rational[115, 9], 8}, {Rational[41, 3], 8}}, {{
      12.777777777777779`, 8}, {13.666666666666666`, 8}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[64, 9]}, {
      Rational[41, 3], Rational[64, 9]}}, {{12.777777777777779`, 
     7.111111111111111}, {13.666666666666666`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[56, 9]}, {
      Rational[41, 3], Rational[56, 9]}}, {{12.777777777777779`, 
     6.222222222222222}, {13.666666666666666`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 3]}, {
      Rational[41, 3], Rational[16, 3]}}, {{12.777777777777779`, 
     5.333333333333333}, {13.666666666666666`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[40, 9]}, {
      Rational[41, 3], Rational[40, 9]}}, {{12.777777777777779`, 
     4.444444444444445}, {13.666666666666666`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[32, 9]}, {
      Rational[41, 3], Rational[32, 9]}}, {{12.777777777777779`, 
     3.5555555555555554`}, {13.666666666666666`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 3]}, {
      Rational[41, 3], Rational[8, 3]}}, {{12.777777777777779`, 
     2.6666666666666665`}, {13.666666666666666`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 9]}, {
      Rational[41, 3], Rational[16, 9]}}, {{12.777777777777779`, 
     1.7777777777777777`}, {13.666666666666666`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 9]}, {
      Rational[41, 3], Rational[8, 9]}}, {{12.777777777777779`, 
     0.8888888888888888}, {13.666666666666666`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[115, 9], 0}, {Rational[41, 3], 0}}, {{
      12.777777777777779`, 0}, {13.666666666666666`, 0}}]], 
   LineBox[NCache[{{Rational[41, 3], 8}, {Rational[131, 9], 8}}, {{
      13.666666666666666`, 8}, {14.555555555555555`, 8}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[64, 9]}, {
      Rational[131, 9], Rational[64, 9]}}, {{13.666666666666666`, 
     7.111111111111111}, {14.555555555555555`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[56, 9]}, {
      Rational[131, 9], Rational[56, 9]}}, {{13.666666666666666`, 
     6.222222222222222}, {14.555555555555555`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 3]}, {
      Rational[131, 9], Rational[16, 3]}}, {{13.666666666666666`, 
     5.333333333333333}, {14.555555555555555`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[40, 9]}, {
      Rational[131, 9], Rational[40, 9]}}, {{13.666666666666666`, 
     4.444444444444445}, {14.555555555555555`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[32, 9]}, {
      Rational[131, 9], Rational[32, 9]}}, {{13.666666666666666`, 
     3.5555555555555554`}, {14.555555555555555`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 3]}, {
      Rational[131, 9], Rational[8, 3]}}, {{13.666666666666666`, 
     2.6666666666666665`}, {14.555555555555555`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 9]}, {
      Rational[131, 9], Rational[16, 9]}}, {{13.666666666666666`, 
     1.7777777777777777`}, {14.555555555555555`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 9]}, {
      Rational[131, 9], Rational[8, 9]}}, {{13.666666666666666`, 
     0.8888888888888888}, {14.555555555555555`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[41, 3], 0}, {Rational[131, 9], 0}}, {{
      13.666666666666666`, 0}, {14.555555555555555`, 0}}]], 
   LineBox[NCache[{{Rational[131, 9], 8}, {Rational[139, 9], 8}}, {{
      14.555555555555555`, 8}, {15.444444444444445`, 8}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[64, 9]}, {
      Rational[139, 9], Rational[64, 9]}}, {{14.555555555555555`, 
     7.111111111111111}, {15.444444444444445`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[56, 9]}, {
      Rational[139, 9], Rational[56, 9]}}, {{14.555555555555555`, 
     6.222222222222222}, {15.444444444444445`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 3]}, {
      Rational[139, 9], Rational[16, 3]}}, {{14.555555555555555`, 
     5.333333333333333}, {15.444444444444445`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[40, 9]}, {
      Rational[139, 9], Rational[40, 9]}}, {{14.555555555555555`, 
     4.444444444444445}, {15.444444444444445`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[32, 9]}, {
      Rational[139, 9], Rational[32, 9]}}, {{14.555555555555555`, 
     3.5555555555555554`}, {15.444444444444445`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 3]}, {
      Rational[139, 9], Rational[8, 3]}}, {{14.555555555555555`, 
     2.6666666666666665`}, {15.444444444444445`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 9]}, {
      Rational[139, 9], Rational[16, 9]}}, {{14.555555555555555`, 
     1.7777777777777777`}, {15.444444444444445`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 9]}, {
      Rational[139, 9], Rational[8, 9]}}, {{14.555555555555555`, 
     0.8888888888888888}, {15.444444444444445`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[131, 9], 0}, {Rational[139, 9], 0}}, {{
      14.555555555555555`, 0}, {15.444444444444445`, 0}}]], 
   LineBox[NCache[{{Rational[139, 9], 8}, {Rational[49, 3], 8}}, {{
      15.444444444444445`, 8}, {16.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[64, 9]}, {
      Rational[49, 3], Rational[64, 9]}}, {{15.444444444444445`, 
     7.111111111111111}, {16.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[56, 9]}, {
      Rational[49, 3], Rational[56, 9]}}, {{15.444444444444445`, 
     6.222222222222222}, {16.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 3]}, {
      Rational[49, 3], Rational[16, 3]}}, {{15.444444444444445`, 
     5.333333333333333}, {16.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[40, 9]}, {
      Rational[49, 3], Rational[40, 9]}}, {{15.444444444444445`, 
     4.444444444444445}, {16.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[32, 9]}, {
      Rational[49, 3], Rational[32, 9]}}, {{15.444444444444445`, 
     3.5555555555555554`}, {16.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 3]}, {
      Rational[49, 3], Rational[8, 3]}}, {{15.444444444444445`, 
     2.6666666666666665`}, {16.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 9]}, {
      Rational[49, 3], Rational[16, 9]}}, {{15.444444444444445`, 
     1.7777777777777777`}, {16.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 9]}, {
      Rational[49, 3], Rational[8, 9]}}, {{15.444444444444445`, 
     0.8888888888888888}, {16.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[139, 9], 0}, {Rational[49, 3], 0}}, {{
      15.444444444444445`, 0}, {16.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[49, 3], 8}, {Rational[155, 9], 8}}, {{
      16.333333333333332`, 8}, {17.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[64, 9]}, {
      Rational[155, 9], Rational[64, 9]}}, {{16.333333333333332`, 
     7.111111111111111}, {17.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[56, 9]}, {
      Rational[155, 9], Rational[56, 9]}}, {{16.333333333333332`, 
     6.222222222222222}, {17.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 3]}, {
      Rational[155, 9], Rational[16, 3]}}, {{16.333333333333332`, 
     5.333333333333333}, {17.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[40, 9]}, {
      Rational[155, 9], Rational[40, 9]}}, {{16.333333333333332`, 
     4.444444444444445}, {17.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[32, 9]}, {
      Rational[155, 9], Rational[32, 9]}}, {{16.333333333333332`, 
     3.5555555555555554`}, {17.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 3]}, {
      Rational[155, 9], Rational[8, 3]}}, {{16.333333333333332`, 
     2.6666666666666665`}, {17.22222222222222, 2.6666666666666665`}}]], 
   LineBox[
    NCache[{{Rational[49, 3], Rational[16, 9]}, {
      Rational[155, 9], Rational[16, 9]}}, {{16.333333333333332`, 
     1.7777777777777777`}, {17.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 9]}, {
      Rational[155, 9], Rational[8, 9]}}, {{16.333333333333332`, 
     0.8888888888888888}, {17.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[49, 3], 0}, {Rational[155, 9], 0}}, {{
      16.333333333333332`, 0}, {17.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[155, 9], 8}, {Rational[163, 9], 8}}, {{
      17.22222222222222, 8}, {18.11111111111111, 8}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[64, 9]}, {
      Rational[163, 9], Rational[64, 9]}}, {{17.22222222222222, 
     7.111111111111111}, {18.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[56, 9]}, {
      Rational[163, 9], Rational[56, 9]}}, {{17.22222222222222, 
     6.222222222222222}, {18.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 3]}, {
      Rational[163, 9], Rational[16, 3]}}, {{17.22222222222222, 
     5.333333333333333}, {18.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[40, 9]}, {
      Rational[163, 9], Rational[40, 9]}}, {{17.22222222222222, 
     4.444444444444445}, {18.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[32, 9]}, {
      Rational[163, 9], Rational[32, 9]}}, {{17.22222222222222, 
     3.5555555555555554`}, {18.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 3]}, {
      Rational[163, 9], Rational[8, 3]}}, {{17.22222222222222, 
     2.6666666666666665`}, {18.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 9]}, {
      Rational[163, 9], Rational[16, 9]}}, {{17.22222222222222, 
     1.7777777777777777`}, {18.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 9]}, {
      Rational[163, 9], Rational[8, 9]}}, {{17.22222222222222, 
     0.8888888888888888}, {18.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[155, 9], 0}, {Rational[163, 9], 0}}, {{
      17.22222222222222, 0}, {18.11111111111111, 0}}]], 
   LineBox[NCache[{{Rational[163, 9], 8}, {19, 8}}, {{18.11111111111111, 8}, {
      19, 8}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[64, 9]}, {
      19, Rational[64, 9]}}, {{18.11111111111111, 7.111111111111111}, {
      19, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[56, 9]}, {
      19, Rational[56, 9]}}, {{18.11111111111111, 6.222222222222222}, {
      19, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 3]}, {
      19, Rational[16, 3]}}, {{18.11111111111111, 5.333333333333333}, {
      19, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[40, 9]}, {
      19, Rational[40, 9]}}, {{18.11111111111111, 4.444444444444445}, {
      19, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[32, 9]}, {
      19, Rational[32, 9]}}, {{18.11111111111111, 3.5555555555555554`}, {
      19, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 3]}, {
      19, Rational[8, 3]}}, {{18.11111111111111, 2.6666666666666665`}, {
      19, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 9]}, {
      19, Rational[16, 9]}}, {{18.11111111111111, 1.7777777777777777`}, {
      19, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 9]}, {
      19, Rational[8, 9]}}, {{18.11111111111111, 0.8888888888888888}, {
      19, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[163, 9], 0}, {19, 0}}, {{18.11111111111111, 0}, {
      19, 0}}]], 
   LineBox[NCache[{{11, 8}, {11, Rational[64, 9]}}, {{11, 8}, {
      11, 7.111111111111111}}]], 
   LineBox[NCache[{{11, Rational[64, 9]}, {11, Rational[56, 9]}}, {{
      11, 7.111111111111111}, {11, 6.222222222222222}}]], 
   LineBox[NCache[{{11, Rational[56, 9]}, {11, Rational[16, 3]}}, {{
      11, 6.222222222222222}, {11, 5.333333333333333}}]], 
   LineBox[NCache[{{11, Rational[16, 3]}, {11, Rational[40, 9]}}, {{
      11, 5.333333333333333}, {11, 4.444444444444445}}]], 
   LineBox[NCache[{{11, Rational[40, 9]}, {11, Rational[32, 9]}}, {{
      11, 4.444444444444445}, {11, 3.5555555555555554`}}]], 
   LineBox[NCache[{{11, Rational[32, 9]}, {11, Rational[8, 3]}}, {{
      11, 3.5555555555555554`}, {11, 2.6666666666666665`}}]], 
   LineBox[NCache[{{11, Rational[8, 3]}, {11, Rational[16, 9]}}, {{
      11, 2.6666666666666665`}, {11, 1.7777777777777777`}}]], 
   LineBox[NCache[{{11, Rational[16, 9]}, {11, Rational[8, 9]}}, {{
      11, 1.7777777777777777`}, {11, 0.8888888888888888}}]], 
   LineBox[NCache[{{11, Rational[8, 9]}, {11, 0}}, {{
      11, 0.8888888888888888}, {11, 0}}]], 
   LineBox[NCache[{{Rational[107, 9], 8}, {
      Rational[107, 9], Rational[64, 9]}}, {{11.88888888888889, 8}, {
      11.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[64, 9]}, {
      Rational[107, 9], Rational[56, 9]}}, {{11.88888888888889, 
     7.111111111111111}, {11.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[56, 9]}, {
      Rational[107, 9], Rational[16, 3]}}, {{11.88888888888889, 
     6.222222222222222}, {11.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 3]}, {
      Rational[107, 9], Rational[40, 9]}}, {{11.88888888888889, 
     5.333333333333333}, {11.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[40, 9]}, {
      Rational[107, 9], Rational[32, 9]}}, {{11.88888888888889, 
     4.444444444444445}, {11.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[32, 9]}, {
      Rational[107, 9], Rational[8, 3]}}, {{11.88888888888889, 
     3.5555555555555554`}, {11.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 3]}, {
      Rational[107, 9], Rational[16, 9]}}, {{11.88888888888889, 
     2.6666666666666665`}, {11.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 9]}, {
      Rational[107, 9], Rational[8, 9]}}, {{11.88888888888889, 
     1.7777777777777777`}, {11.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 9]}, {
      Rational[107, 9], 0}}, {{11.88888888888889, 0.8888888888888888}, {
      11.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[115, 9], 8}, {
      Rational[115, 9], Rational[64, 9]}}, {{12.777777777777779`, 8}, {
      12.777777777777779`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[64, 9]}, {
      Rational[115, 9], Rational[56, 9]}}, {{12.777777777777779`, 
     7.111111111111111}, {12.777777777777779`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[56, 9]}, {
      Rational[115, 9], Rational[16, 3]}}, {{12.777777777777779`, 
     6.222222222222222}, {12.777777777777779`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 3]}, {
      Rational[115, 9], Rational[40, 9]}}, {{12.777777777777779`, 
     5.333333333333333}, {12.777777777777779`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[40, 9]}, {
      Rational[115, 9], Rational[32, 9]}}, {{12.777777777777779`, 
     4.444444444444445}, {12.777777777777779`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[32, 9]}, {
      Rational[115, 9], Rational[8, 3]}}, {{12.777777777777779`, 
     3.5555555555555554`}, {12.777777777777779`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 3]}, {
      Rational[115, 9], Rational[16, 9]}}, {{12.777777777777779`, 
     2.6666666666666665`}, {12.777777777777779`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 9]}, {
      Rational[115, 9], Rational[8, 9]}}, {{12.777777777777779`, 
     1.7777777777777777`}, {12.777777777777779`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 9]}, {
      Rational[115, 9], 0}}, {{12.777777777777779`, 0.8888888888888888}, {
      12.777777777777779`, 0}}]], 
   LineBox[NCache[{{Rational[41, 3], 8}, {
      Rational[41, 3], Rational[64, 9]}}, {{13.666666666666666`, 8}, {
      13.666666666666666`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[64, 9]}, {
      Rational[41, 3], Rational[56, 9]}}, {{13.666666666666666`, 
     7.111111111111111}, {13.666666666666666`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[56, 9]}, {
      Rational[41, 3], Rational[16, 3]}}, {{13.666666666666666`, 
     6.222222222222222}, {13.666666666666666`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 3]}, {
      Rational[41, 3], Rational[40, 9]}}, {{13.666666666666666`, 
     5.333333333333333}, {13.666666666666666`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[40, 9]}, {
      Rational[41, 3], Rational[32, 9]}}, {{13.666666666666666`, 
     4.444444444444445}, {13.666666666666666`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[32, 9]}, {
      Rational[41, 3], Rational[8, 3]}}, {{13.666666666666666`, 
     3.5555555555555554`}, {13.666666666666666`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 3]}, {
      Rational[41, 3], Rational[16, 9]}}, {{13.666666666666666`, 
     2.6666666666666665`}, {13.666666666666666`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 9]}, {
      Rational[41, 3], Rational[8, 9]}}, {{13.666666666666666`, 
     1.7777777777777777`}, {13.666666666666666`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 9]}, {
      Rational[41, 3], 0}}, {{13.666666666666666`, 0.8888888888888888}, {
      13.666666666666666`, 0}}]], 
   LineBox[NCache[{{Rational[131, 9], 8}, {
      Rational[131, 9], Rational[64, 9]}}, {{14.555555555555555`, 8}, {
      14.555555555555555`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[64, 9]}, {
      Rational[131, 9], Rational[56, 9]}}, {{14.555555555555555`, 
     7.111111111111111}, {14.555555555555555`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[56, 9]}, {
      Rational[131, 9], Rational[16, 3]}}, {{14.555555555555555`, 
     6.222222222222222}, {14.555555555555555`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 3]}, {
      Rational[131, 9], Rational[40, 9]}}, {{14.555555555555555`, 
     5.333333333333333}, {14.555555555555555`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[40, 9]}, {
      Rational[131, 9], Rational[32, 9]}}, {{14.555555555555555`, 
     4.444444444444445}, {14.555555555555555`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[32, 9]}, {
      Rational[131, 9], Rational[8, 3]}}, {{14.555555555555555`, 
     3.5555555555555554`}, {14.555555555555555`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 3]}, {
      Rational[131, 9], Rational[16, 9]}}, {{14.555555555555555`, 
     2.6666666666666665`}, {14.555555555555555`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 9]}, {
      Rational[131, 9], Rational[8, 9]}}, {{14.555555555555555`, 
     1.7777777777777777`}, {14.555555555555555`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 9]}, {
      Rational[131, 9], 0}}, {{14.555555555555555`, 0.8888888888888888}, {
      14.555555555555555`, 0}}]], 
   LineBox[NCache[{{Rational[139, 9], 8}, {
      Rational[139, 9], Rational[64, 9]}}, {{15.444444444444445`, 8}, {
      15.444444444444445`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[64, 9]}, {
      Rational[139, 9], Rational[56, 9]}}, {{15.444444444444445`, 
     7.111111111111111}, {15.444444444444445`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[56, 9]}, {
      Rational[139, 9], Rational[16, 3]}}, {{15.444444444444445`, 
     6.222222222222222}, {15.444444444444445`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 3]}, {
      Rational[139, 9], Rational[40, 9]}}, {{15.444444444444445`, 
     5.333333333333333}, {15.444444444444445`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[40, 9]}, {
      Rational[139, 9], Rational[32, 9]}}, {{15.444444444444445`, 
     4.444444444444445}, {15.444444444444445`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[32, 9]}, {
      Rational[139, 9], Rational[8, 3]}}, {{15.444444444444445`, 
     3.5555555555555554`}, {15.444444444444445`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 3]}, {
      Rational[139, 9], Rational[16, 9]}}, {{15.444444444444445`, 
     2.6666666666666665`}, {15.444444444444445`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 9]}, {
      Rational[139, 9], Rational[8, 9]}}, {{15.444444444444445`, 
     1.7777777777777777`}, {15.444444444444445`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 9]}, {
      Rational[139, 9], 0}}, {{15.444444444444445`, 0.8888888888888888}, {
      15.444444444444445`, 0}}]], 
   LineBox[NCache[{{Rational[49, 3], 8}, {
      Rational[49, 3], Rational[64, 9]}}, {{16.333333333333332`, 8}, {
      16.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[64, 9]}, {
      Rational[49, 3], Rational[56, 9]}}, {{16.333333333333332`, 
     7.111111111111111}, {16.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[56, 9]}, {
      Rational[49, 3], Rational[16, 3]}}, {{16.333333333333332`, 
     6.222222222222222}, {16.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 3]}, {
      Rational[49, 3], Rational[40, 9]}}, {{16.333333333333332`, 
     5.333333333333333}, {16.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[40, 9]}, {
      Rational[49, 3], Rational[32, 9]}}, {{16.333333333333332`, 
     4.444444444444445}, {16.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{Rational[49, 3], Rational[32, 9]}, {
      Rational[49, 3], Rational[8, 3]}}, {{16.333333333333332`, 
     3.5555555555555554`}, {16.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 3]}, {
      Rational[49, 3], Rational[16, 9]}}, {{16.333333333333332`, 
     2.6666666666666665`}, {16.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 9]}, {
      Rational[49, 3], Rational[8, 9]}}, {{16.333333333333332`, 
     1.7777777777777777`}, {16.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 9]}, {
      Rational[49, 3], 0}}, {{16.333333333333332`, 0.8888888888888888}, {
      16.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[155, 9], 8}, {
      Rational[155, 9], Rational[64, 9]}}, {{17.22222222222222, 8}, {
      17.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[64, 9]}, {
      Rational[155, 9], Rational[56, 9]}}, {{17.22222222222222, 
     7.111111111111111}, {17.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[56, 9]}, {
      Rational[155, 9], Rational[16, 3]}}, {{17.22222222222222, 
     6.222222222222222}, {17.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 3]}, {
      Rational[155, 9], Rational[40, 9]}}, {{17.22222222222222, 
     5.333333333333333}, {17.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[40, 9]}, {
      Rational[155, 9], Rational[32, 9]}}, {{17.22222222222222, 
     4.444444444444445}, {17.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[32, 9]}, {
      Rational[155, 9], Rational[8, 3]}}, {{17.22222222222222, 
     3.5555555555555554`}, {17.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 3]}, {
      Rational[155, 9], Rational[16, 9]}}, {{17.22222222222222, 
     2.6666666666666665`}, {17.22222222222222, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{Rational[155, 9], Rational[16, 9]}, {
      Rational[155, 9], Rational[8, 9]}}, {{17.22222222222222, 
     1.7777777777777777`}, {17.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 9]}, {
      Rational[155, 9], 0}}, {{17.22222222222222, 0.8888888888888888}, {
      17.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[163, 9], 8}, {
      Rational[163, 9], Rational[64, 9]}}, {{18.11111111111111, 8}, {
      18.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[64, 9]}, {
      Rational[163, 9], Rational[56, 9]}}, {{18.11111111111111, 
     7.111111111111111}, {18.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[56, 9]}, {
      Rational[163, 9], Rational[16, 3]}}, {{18.11111111111111, 
     6.222222222222222}, {18.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 3]}, {
      Rational[163, 9], Rational[40, 9]}}, {{18.11111111111111, 
     5.333333333333333}, {18.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[40, 9]}, {
      Rational[163, 9], Rational[32, 9]}}, {{18.11111111111111, 
     4.444444444444445}, {18.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[32, 9]}, {
      Rational[163, 9], Rational[8, 3]}}, {{18.11111111111111, 
     3.5555555555555554`}, {18.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 3]}, {
      Rational[163, 9], Rational[16, 9]}}, {{18.11111111111111, 
     2.6666666666666665`}, {18.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 9]}, {
      Rational[163, 9], Rational[8, 9]}}, {{18.11111111111111, 
     1.7777777777777777`}, {18.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 9]}, {
      Rational[163, 9], 0}}, {{18.11111111111111, 0.8888888888888888}, {
      18.11111111111111, 0}}]], 
   LineBox[NCache[{{19, 8}, {19, Rational[64, 9]}}, {{19, 8}, {
      19, 7.111111111111111}}]], 
   LineBox[NCache[{{19, Rational[64, 9]}, {19, Rational[56, 9]}}, {{
      19, 7.111111111111111}, {19, 6.222222222222222}}]], 
   LineBox[NCache[{{19, Rational[56, 9]}, {19, Rational[16, 3]}}, {{
      19, 6.222222222222222}, {19, 5.333333333333333}}]], 
   LineBox[NCache[{{19, Rational[16, 3]}, {19, Rational[40, 9]}}, {{
      19, 5.333333333333333}, {19, 4.444444444444445}}]], 
   LineBox[NCache[{{19, Rational[40, 9]}, {19, Rational[32, 9]}}, {{
      19, 4.444444444444445}, {19, 3.5555555555555554`}}]], 
   LineBox[NCache[{{19, Rational[32, 9]}, {19, Rational[8, 3]}}, {{
      19, 3.5555555555555554`}, {19, 2.6666666666666665`}}]], 
   LineBox[NCache[{{19, Rational[8, 3]}, {19, Rational[16, 9]}}, {{
      19, 2.6666666666666665`}, {19, 1.7777777777777777`}}]], 
   LineBox[NCache[{{19, Rational[16, 9]}, {19, Rational[8, 9]}}, {{
      19, 1.7777777777777777`}, {19, 0.8888888888888888}}]], 
   LineBox[NCache[{{19, Rational[8, 9]}, {19, 0}}, {{
      19, 0.8888888888888888}, {19, 0}}]], 
   LineBox[NCache[{{21, 8}, {Rational[197, 9], 8}}, {{21, 8}, {
      21.88888888888889, 8}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {
      Rational[197, 9], Rational[64, 9]}}, {{21, 7.111111111111111}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21, 6.222222222222222}, {
      21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21, 5.333333333333333}, {
      21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21, 4.444444444444445}, {
      21.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21, 3.5555555555555554`}, {
      21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21, 2.6666666666666665`}, {
      21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21, 1.7777777777777777`}, {
      21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21, 0.8888888888888888}, {
      21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, 0}, {Rational[197, 9], 0}}, {{21, 0}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {Rational[205, 9], 8}}, {{
      21.88888888888889, 8}, {22.77777777777778, 8}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[64, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{21.88888888888889, 
     6.222222222222222}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[16, 3]}}, {{21.88888888888889, 
     5.333333333333333}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[40, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{21.88888888888889, 
     3.5555555555555554`}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[8, 3]}}, {{21.88888888888889, 
     2.6666666666666665`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[16, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{21.88888888888889, 
     0.8888888888888888}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], 0}, {Rational[205, 9], 0}}, {{
      21.88888888888889, 0}, {22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {Rational[71, 3], 8}}, {{
      22.77777777777778, 8}, {23.666666666666668`, 8}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[71, 3], Rational[64, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{22.77777777777778, 
     6.222222222222222}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[71, 3], Rational[16, 3]}}, {{22.77777777777778, 
     5.333333333333333}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[71, 3], Rational[40, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{22.77777777777778, 
     3.5555555555555554`}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[71, 3], Rational[8, 3]}}, {{22.77777777777778, 
     2.6666666666666665`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[71, 3], Rational[16, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{22.77777777777778, 
     0.8888888888888888}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], 0}, {Rational[71, 3], 0}}, {{
      22.77777777777778, 0}, {23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {Rational[221, 9], 8}}, {{
      23.666666666666668`, 8}, {24.555555555555557`, 8}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[221, 9], Rational[64, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{23.666666666666668`, 
     6.222222222222222}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[221, 9], Rational[16, 3]}}, {{23.666666666666668`, 
     5.333333333333333}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[221, 9], Rational[40, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[221, 9], Rational[8, 3]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[221, 9], Rational[16, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{23.666666666666668`, 
     0.8888888888888888}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[71, 3], 0}, {Rational[221, 9], 0}}, {{
      23.666666666666668`, 0}, {24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {Rational[229, 9], 8}}, {{
      24.555555555555557`, 8}, {25.444444444444443`, 8}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[64, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {25.444444444444443`, 7.111111111111111}}]], 
   LineBox[
    NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     6.222222222222222}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     5.333333333333333}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     0.8888888888888888}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], 0}, {Rational[229, 9], 0}}, {{
      24.555555555555557`, 0}, {25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {Rational[79, 3], 8}}, {{
      25.444444444444443`, 8}, {26.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[79, 3], Rational[64, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{25.444444444444443`, 
     6.222222222222222}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[
    NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[79, 3], Rational[16, 3]}}, {{25.444444444444443`, 
     5.333333333333333}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[79, 3], Rational[40, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[79, 3], Rational[8, 3]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[79, 3], Rational[16, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{25.444444444444443`, 
     0.8888888888888888}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], 0}, {Rational[79, 3], 0}}, {{
      25.444444444444443`, 0}, {26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {Rational[245, 9], 8}}, {{
      26.333333333333332`, 8}, {27.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[245, 9], Rational[64, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{26.333333333333332`, 
     6.222222222222222}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[245, 9], Rational[16, 3]}}, {{26.333333333333332`, 
     5.333333333333333}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[245, 9], Rational[40, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[245, 9], Rational[8, 3]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[245, 9], Rational[16, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{26.333333333333332`, 
     0.8888888888888888}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[79, 3], 0}, {Rational[245, 9], 0}}, {{
      26.333333333333332`, 0}, {27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {Rational[253, 9], 8}}, {{
      27.22222222222222, 8}, {28.11111111111111, 8}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[64, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{27.22222222222222, 
     6.222222222222222}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[16, 3]}}, {{27.22222222222222, 
     5.333333333333333}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[40, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{27.22222222222222, 
     3.5555555555555554`}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[8, 3]}}, {{27.22222222222222, 
     2.6666666666666665`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[16, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{27.22222222222222, 
     0.8888888888888888}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], 0}, {Rational[253, 9], 0}}, {{
      27.22222222222222, 0}, {28.11111111111111, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {29, 8}}, {{28.11111111111111, 8}, {
      29, 8}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      29, Rational[64, 9]}}, {{28.11111111111111, 7.111111111111111}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      29, Rational[56, 9]}}, {{28.11111111111111, 6.222222222222222}, {
      29, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      29, Rational[16, 3]}}, {{28.11111111111111, 5.333333333333333}, {
      29, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      29, Rational[40, 9]}}, {{28.11111111111111, 4.444444444444445}, {
      29, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      29, Rational[32, 9]}}, {{28.11111111111111, 3.5555555555555554`}, {
      29, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      29, Rational[8, 3]}}, {{28.11111111111111, 2.6666666666666665`}, {
      29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 9]}, {
      29, Rational[16, 9]}}, {{28.11111111111111, 1.7777777777777777`}, {
      29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      29, Rational[8, 9]}}, {{28.11111111111111, 0.8888888888888888}, {
      29, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], 0}, {29, 0}}, {{28.11111111111111, 0}, {
      29, 0}}]], 
   LineBox[NCache[{{21, 8}, {21, Rational[64, 9]}}, {{21, 8}, {
      21, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {21, Rational[56, 9]}}, {{
      21, 7.111111111111111}, {21, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {21, Rational[16, 3]}}, {{
      21, 6.222222222222222}, {21, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {21, Rational[40, 9]}}, {{
      21, 5.333333333333333}, {21, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {21, Rational[32, 9]}}, {{
      21, 4.444444444444445}, {21, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {21, Rational[8, 3]}}, {{
      21, 3.5555555555555554`}, {21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {21, Rational[16, 9]}}, {{
      21, 2.6666666666666665`}, {21, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {21, Rational[8, 9]}}, {{
      21, 1.7777777777777777`}, {21, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {21, 0}}, {{
      21, 0.8888888888888888}, {21, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {
      Rational[197, 9], Rational[64, 9]}}, {{21.88888888888889, 8}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21.88888888888889, 
     6.222222222222222}, {21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21.88888888888889, 
     5.333333333333333}, {21.88888888888889, 4.444444444444445}}]], 
   LineBox[
    NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21.88888888888889, 
     3.5555555555555554`}, {21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21.88888888888889, 
     2.6666666666666665`}, {21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[197, 9], 0}}, {{21.88888888888889, 0.8888888888888888}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {
      Rational[205, 9], Rational[64, 9]}}, {{22.77777777777778, 8}, {
      22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[16, 3]}}, {{22.77777777777778, 
     6.222222222222222}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[40, 9]}}, {{22.77777777777778, 
     5.333333333333333}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[8, 3]}}, {{22.77777777777778, 
     3.5555555555555554`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[
    NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[16, 9]}}, {{22.77777777777778, 
     2.6666666666666665`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[205, 9], 0}}, {{22.77777777777778, 0.8888888888888888}, {
      22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {
      Rational[71, 3], Rational[64, 9]}}, {{23.666666666666668`, 8}, {
      23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[71, 3], Rational[16, 3]}}, {{23.666666666666668`, 
     6.222222222222222}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[71, 3], Rational[40, 9]}}, {{23.666666666666668`, 
     5.333333333333333}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[71, 3], Rational[8, 3]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[71, 3], Rational[16, 9]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[
    NCache[{{Rational[71, 3], Rational[8, 9]}, {Rational[71, 3], 0}}, {{
      23.666666666666668`, 0.8888888888888888}, {23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {
      Rational[221, 9], Rational[64, 9]}}, {{24.555555555555557`, 8}, {
      24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[221, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     6.222222222222222}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[221, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     5.333333333333333}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[221, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[221, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[221, 9], 0}}, {{24.555555555555557`, 0.8888888888888888}, {
      24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {
      Rational[229, 9], Rational[64, 9]}}, {{25.444444444444443`, 8}, {
      25.444444444444443`, 7.111111111111111}}]], 
   LineBox[
    NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[16, 3]}}, {{25.444444444444443`, 
     6.222222222222222}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[40, 9]}}, {{25.444444444444443`, 
     5.333333333333333}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[8, 3]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[16, 9]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[229, 9], 0}}, {{25.444444444444443`, 0.8888888888888888}, {
      25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {
      Rational[79, 3], Rational[64, 9]}}, {{26.333333333333332`, 8}, {
      26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[79, 3], Rational[16, 3]}}, {{26.333333333333332`, 
     6.222222222222222}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[
    NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[79, 3], Rational[40, 9]}}, {{26.333333333333332`, 
     5.333333333333333}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[79, 3], Rational[8, 3]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[79, 3], Rational[16, 9]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 9]}, {
      Rational[79, 3], 0}}, {{26.333333333333332`, 0.8888888888888888}, {
      26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {
      Rational[245, 9], Rational[64, 9]}}, {{27.22222222222222, 8}, {
      27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[245, 9], Rational[16, 3]}}, {{27.22222222222222, 
     6.222222222222222}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[245, 9], Rational[40, 9]}}, {{27.22222222222222, 
     5.333333333333333}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[245, 9], Rational[8, 3]}}, {{27.22222222222222, 
     3.5555555555555554`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[245, 9], Rational[16, 9]}}, {{27.22222222222222, 
     2.6666666666666665`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[245, 9], 0}}, {{27.22222222222222, 0.8888888888888888}, {
      27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {
      Rational[253, 9], Rational[64, 9]}}, {{28.11111111111111, 8}, {
      28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{28.11111111111111, 
     7.111111111111111}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[16, 3]}}, {{28.11111111111111, 
     6.222222222222222}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[40, 9]}}, {{28.11111111111111, 
     5.333333333333333}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{28.11111111111111, 
     4.444444444444445}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[8, 3]}}, {{28.11111111111111, 
     3.5555555555555554`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[16, 9]}}, {{28.11111111111111, 
     2.6666666666666665`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{Rational[253, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{28.11111111111111, 
     1.7777777777777777`}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      Rational[253, 9], 0}}, {{28.11111111111111, 0.8888888888888888}, {
      28.11111111111111, 0}}]], 
   LineBox[NCache[{{29, 8}, {29, Rational[64, 9]}}, {{29, 8}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{29, Rational[64, 9]}, {29, Rational[56, 9]}}, {{
      29, 7.111111111111111}, {29, 6.222222222222222}}]], 
   LineBox[NCache[{{29, Rational[56, 9]}, {29, Rational[16, 3]}}, {{
      29, 6.222222222222222}, {29, 5.333333333333333}}]], 
   LineBox[NCache[{{29, Rational[16, 3]}, {29, Rational[40, 9]}}, {{
      29, 5.333333333333333}, {29, 4.444444444444445}}]], 
   LineBox[NCache[{{29, Rational[40, 9]}, {29, Rational[32, 9]}}, {{
      29, 4.444444444444445}, {29, 3.5555555555555554`}}]], 
   LineBox[NCache[{{29, Rational[32, 9]}, {29, Rational[8, 3]}}, {{
      29, 3.5555555555555554`}, {29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{29, Rational[8, 3]}, {29, Rational[16, 9]}}, {{
      29, 2.6666666666666665`}, {29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{29, Rational[16, 9]}, {29, Rational[8, 9]}}, {{
      29, 1.7777777777777777`}, {29, 0.8888888888888888}}]], 
   LineBox[NCache[{{29, Rational[8, 9]}, {29, 0}}, {{
      29, 0.8888888888888888}, {29, 0}}]]},
  ImageSize->400]], "Output",
 CellChangeTimes->{3.470850771317861*^9, 3.470867722514337*^9, 
  3.470867804895343*^9, 3.47087447971399*^9, 3.47087827134355*^9, 
  3.470881813463799*^9, 3.470912101991946*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "@", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"0.3", ",", "1"}], "}"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.470839701984733*^9, 3.470839715348918*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], LineBox[{{11, 8}, {15, 8}}], 
   LineBox[{{11, 4}, {15, 4}}], LineBox[{{11, 0}, {15, 0}}], 
   LineBox[{{15, 8}, {19, 8}}], LineBox[{{15, 4}, {19, 4}}], 
   LineBox[{{15, 0}, {19, 0}}], LineBox[{{11, 8}, {11, 4}}], 
   LineBox[{{11, 4}, {11, 0}}], LineBox[{{15, 8}, {15, 4}}], 
   LineBox[{{15, 4}, {15, 0}}], LineBox[{{19, 8}, {19, 4}}], 
   LineBox[{{19, 4}, {19, 0}}], 
   LineBox[NCache[{{21, 8}, {Rational[197, 9], 8}}, {{21, 8}, {
      21.88888888888889, 8}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {
      Rational[197, 9], Rational[64, 9]}}, {{21, 7.111111111111111}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21, 6.222222222222222}, {
      21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21, 5.333333333333333}, {
      21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21, 4.444444444444445}, {
      21.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21, 3.5555555555555554`}, {
      21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21, 2.6666666666666665`}, {
      21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21, 1.7777777777777777`}, {
      21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21, 0.8888888888888888}, {
      21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, 0}, {Rational[197, 9], 0}}, {{21, 0}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {Rational[205, 9], 8}}, {{
      21.88888888888889, 8}, {22.77777777777778, 8}}]], 
   LineBox[
    NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[64, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{21.88888888888889, 
     6.222222222222222}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[16, 3]}}, {{21.88888888888889, 
     5.333333333333333}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[40, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{21.88888888888889, 
     3.5555555555555554`}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[8, 3]}}, {{21.88888888888889, 
     2.6666666666666665`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[16, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{21.88888888888889, 
     0.8888888888888888}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], 0}, {Rational[205, 9], 0}}, {{
      21.88888888888889, 0}, {22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {Rational[71, 3], 8}}, {{
      22.77777777777778, 8}, {23.666666666666668`, 8}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[71, 3], Rational[64, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{22.77777777777778, 
     6.222222222222222}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[71, 3], Rational[16, 3]}}, {{22.77777777777778, 
     5.333333333333333}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[71, 3], Rational[40, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{22.77777777777778, 
     3.5555555555555554`}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[71, 3], Rational[8, 3]}}, {{22.77777777777778, 
     2.6666666666666665`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[71, 3], Rational[16, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{22.77777777777778, 
     0.8888888888888888}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], 0}, {Rational[71, 3], 0}}, {{
      22.77777777777778, 0}, {23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {Rational[221, 9], 8}}, {{
      23.666666666666668`, 8}, {24.555555555555557`, 8}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[221, 9], Rational[64, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{23.666666666666668`, 
     6.222222222222222}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[221, 9], Rational[16, 3]}}, {{23.666666666666668`, 
     5.333333333333333}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[221, 9], Rational[40, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[221, 9], Rational[8, 3]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[221, 9], Rational[16, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{23.666666666666668`, 
     0.8888888888888888}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[71, 3], 0}, {Rational[221, 9], 0}}, {{
      23.666666666666668`, 0}, {24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {Rational[229, 9], 8}}, {{
      24.555555555555557`, 8}, {25.444444444444443`, 8}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[64, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {25.444444444444443`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     6.222222222222222}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     5.333333333333333}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     0.8888888888888888}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], 0}, {Rational[229, 9], 0}}, {{
      24.555555555555557`, 0}, {25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {Rational[79, 3], 8}}, {{
      25.444444444444443`, 8}, {26.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[79, 3], Rational[64, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{25.444444444444443`, 
     6.222222222222222}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[79, 3], Rational[16, 3]}}, {{25.444444444444443`, 
     5.333333333333333}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[79, 3], Rational[40, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[79, 3], Rational[8, 3]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[79, 3], Rational[16, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{25.444444444444443`, 
     0.8888888888888888}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], 0}, {Rational[79, 3], 0}}, {{
      25.444444444444443`, 0}, {26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {Rational[245, 9], 8}}, {{
      26.333333333333332`, 8}, {27.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[245, 9], Rational[64, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{26.333333333333332`, 
     6.222222222222222}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[245, 9], Rational[16, 3]}}, {{26.333333333333332`, 
     5.333333333333333}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[245, 9], Rational[40, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[245, 9], Rational[8, 3]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[
    NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[245, 9], Rational[16, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{26.333333333333332`, 
     0.8888888888888888}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[79, 3], 0}, {Rational[245, 9], 0}}, {{
      26.333333333333332`, 0}, {27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {Rational[253, 9], 8}}, {{
      27.22222222222222, 8}, {28.11111111111111, 8}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[64, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{27.22222222222222, 
     6.222222222222222}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[16, 3]}}, {{27.22222222222222, 
     5.333333333333333}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[40, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{27.22222222222222, 
     3.5555555555555554`}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[8, 3]}}, {{27.22222222222222, 
     2.6666666666666665`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[16, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{27.22222222222222, 
     0.8888888888888888}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], 0}, {Rational[253, 9], 0}}, {{
      27.22222222222222, 0}, {28.11111111111111, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {29, 8}}, {{28.11111111111111, 8}, {
      29, 8}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      29, Rational[64, 9]}}, {{28.11111111111111, 7.111111111111111}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      29, Rational[56, 9]}}, {{28.11111111111111, 6.222222222222222}, {
      29, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      29, Rational[16, 3]}}, {{28.11111111111111, 5.333333333333333}, {
      29, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      29, Rational[40, 9]}}, {{28.11111111111111, 4.444444444444445}, {
      29, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      29, Rational[32, 9]}}, {{28.11111111111111, 3.5555555555555554`}, {
      29, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      29, Rational[8, 3]}}, {{28.11111111111111, 2.6666666666666665`}, {
      29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 9]}, {
      29, Rational[16, 9]}}, {{28.11111111111111, 1.7777777777777777`}, {
      29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      29, Rational[8, 9]}}, {{28.11111111111111, 0.8888888888888888}, {
      29, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], 0}, {29, 0}}, {{28.11111111111111, 0}, {
      29, 0}}]], 
   LineBox[NCache[{{21, 8}, {21, Rational[64, 9]}}, {{21, 8}, {
      21, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {21, Rational[56, 9]}}, {{
      21, 7.111111111111111}, {21, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {21, Rational[16, 3]}}, {{
      21, 6.222222222222222}, {21, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {21, Rational[40, 9]}}, {{
      21, 5.333333333333333}, {21, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {21, Rational[32, 9]}}, {{
      21, 4.444444444444445}, {21, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {21, Rational[8, 3]}}, {{
      21, 3.5555555555555554`}, {21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {21, Rational[16, 9]}}, {{
      21, 2.6666666666666665`}, {21, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {21, Rational[8, 9]}}, {{
      21, 1.7777777777777777`}, {21, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {21, 0}}, {{
      21, 0.8888888888888888}, {21, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {
      Rational[197, 9], Rational[64, 9]}}, {{21.88888888888889, 8}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21.88888888888889, 
     6.222222222222222}, {21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21.88888888888889, 
     5.333333333333333}, {21.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21.88888888888889, 
     3.5555555555555554`}, {21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21.88888888888889, 
     2.6666666666666665`}, {21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[197, 9], 0}}, {{21.88888888888889, 0.8888888888888888}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {
      Rational[205, 9], Rational[64, 9]}}, {{22.77777777777778, 8}, {
      22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[16, 3]}}, {{22.77777777777778, 
     6.222222222222222}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[40, 9]}}, {{22.77777777777778, 
     5.333333333333333}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[8, 3]}}, {{22.77777777777778, 
     3.5555555555555554`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[16, 9]}}, {{22.77777777777778, 
     2.6666666666666665`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[205, 9], 0}}, {{22.77777777777778, 0.8888888888888888}, {
      22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {
      Rational[71, 3], Rational[64, 9]}}, {{23.666666666666668`, 8}, {
      23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[71, 3], Rational[16, 3]}}, {{23.666666666666668`, 
     6.222222222222222}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[71, 3], Rational[40, 9]}}, {{23.666666666666668`, 
     5.333333333333333}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[71, 3], Rational[8, 3]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[71, 3], Rational[16, 9]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 9]}, {
      Rational[71, 3], 0}}, {{23.666666666666668`, 0.8888888888888888}, {
      23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {
      Rational[221, 9], Rational[64, 9]}}, {{24.555555555555557`, 8}, {
      24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[
    NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[221, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     6.222222222222222}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[221, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     5.333333333333333}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[221, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[221, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[221, 9], 0}}, {{24.555555555555557`, 0.8888888888888888}, {
      24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {
      Rational[229, 9], Rational[64, 9]}}, {{25.444444444444443`, 8}, {
      25.444444444444443`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[16, 3]}}, {{25.444444444444443`, 
     6.222222222222222}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[40, 9]}}, {{25.444444444444443`, 
     5.333333333333333}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[8, 3]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[16, 9]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[229, 9], 0}}, {{25.444444444444443`, 0.8888888888888888}, {
      25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {
      Rational[79, 3], Rational[64, 9]}}, {{26.333333333333332`, 8}, {
      26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[79, 3], Rational[16, 3]}}, {{26.333333333333332`, 
     6.222222222222222}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[79, 3], Rational[40, 9]}}, {{26.333333333333332`, 
     5.333333333333333}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[79, 3], Rational[8, 3]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[79, 3], Rational[16, 9]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 9]}, {
      Rational[79, 3], 0}}, {{26.333333333333332`, 0.8888888888888888}, {
      26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {
      Rational[245, 9], Rational[64, 9]}}, {{27.22222222222222, 8}, {
      27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[245, 9], Rational[16, 3]}}, {{27.22222222222222, 
     6.222222222222222}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[245, 9], Rational[40, 9]}}, {{27.22222222222222, 
     5.333333333333333}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[245, 9], Rational[8, 3]}}, {{27.22222222222222, 
     3.5555555555555554`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[245, 9], Rational[16, 9]}}, {{27.22222222222222, 
     2.6666666666666665`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[245, 9], 0}}, {{27.22222222222222, 0.8888888888888888}, {
      27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {
      Rational[253, 9], Rational[64, 9]}}, {{28.11111111111111, 8}, {
      28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{28.11111111111111, 
     7.111111111111111}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[16, 3]}}, {{28.11111111111111, 
     6.222222222222222}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[40, 9]}}, {{28.11111111111111, 
     5.333333333333333}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{28.11111111111111, 
     4.444444444444445}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[8, 3]}}, {{28.11111111111111, 
     3.5555555555555554`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[16, 9]}}, {{28.11111111111111, 
     2.6666666666666665`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{28.11111111111111, 
     1.7777777777777777`}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      Rational[253, 9], 0}}, {{28.11111111111111, 0.8888888888888888}, {
      28.11111111111111, 0}}]], 
   LineBox[NCache[{{29, 8}, {29, Rational[64, 9]}}, {{29, 8}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{29, Rational[64, 9]}, {29, Rational[56, 9]}}, {{
      29, 7.111111111111111}, {29, 6.222222222222222}}]], 
   LineBox[NCache[{{29, Rational[56, 9]}, {29, Rational[16, 3]}}, {{
      29, 6.222222222222222}, {29, 5.333333333333333}}]], 
   LineBox[NCache[{{29, Rational[16, 3]}, {29, Rational[40, 9]}}, {{
      29, 5.333333333333333}, {29, 4.444444444444445}}]], 
   LineBox[NCache[{{29, Rational[40, 9]}, {29, Rational[32, 9]}}, {{
      29, 4.444444444444445}, {29, 3.5555555555555554`}}]], 
   LineBox[NCache[{{29, Rational[32, 9]}, {29, Rational[8, 3]}}, {{
      29, 3.5555555555555554`}, {29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{29, Rational[8, 3]}, {29, Rational[16, 9]}}, {{
      29, 2.6666666666666665`}, {29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{29, Rational[16, 9]}, {29, Rational[8, 9]}}, {{
      29, 1.7777777777777777`}, {29, 0.8888888888888888}}]], 
   LineBox[NCache[{{29, Rational[8, 9]}, {29, 0}}, {{
      29, 0.8888888888888888}, {29, 0}}]], LineBox[{{19, 8}, {21, 8}}], 
   LineBox[NCache[{{19, 8}, {21, Rational[64, 9]}}, {{19, 8}, {
      21, 7.111111111111111}}]], 
   LineBox[NCache[{{19, 8}, {21, Rational[56, 9]}}, {{19, 8}, {
      21, 6.222222222222222}}]], 
   LineBox[NCache[{{19, 8}, {21, Rational[16, 3]}}, {{19, 8}, {
      21, 5.333333333333333}}]], 
   LineBox[NCache[{{19, 4}, {21, Rational[40, 9]}}, {{19, 4}, {
      21, 4.444444444444445}}]], 
   LineBox[NCache[{{19, 4}, {21, Rational[32, 9]}}, {{19, 4}, {
      21, 3.5555555555555554`}}]], 
   LineBox[NCache[{{19, 4}, {21, Rational[8, 3]}}, {{19, 4}, {
      21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{19, 0}, {21, Rational[16, 9]}}, {{19, 0}, {
      21, 1.7777777777777777`}}]], 
   LineBox[NCache[{{19, 0}, {21, Rational[8, 9]}}, {{19, 0}, {
      21, 0.8888888888888888}}]], LineBox[{{19, 0}, {21, 0}}]},
  ImageSize->400]], "Output",
 CellChangeTimes->{
  3.470839709112085*^9, 3.47084301357683*^9, 3.470846062448726*^9, 
   3.470846152303541*^9, 3.470846442410143*^9, 3.470849685175266*^9, {
   3.470850736996031*^9, 3.470850753490256*^9}, 3.470867722717267*^9, 
   3.470867805086802*^9, 3.470874479922979*^9, 3.470878271533741*^9, 
   3.47088181365154*^9, 3.470912102342138*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "@", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"0.3", ",", "0.5", ",", "1"}], "}"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.470839792311538*^9, 3.470839794378367*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], LineBox[{{11, 8}, {15, 8}}], 
   LineBox[{{11, 4}, {15, 4}}], LineBox[{{11, 0}, {15, 0}}], 
   LineBox[{{15, 8}, {19, 8}}], LineBox[{{15, 4}, {19, 4}}], 
   LineBox[{{15, 0}, {19, 0}}], LineBox[{{11, 8}, {11, 4}}], 
   LineBox[{{11, 4}, {11, 0}}], LineBox[{{15, 8}, {15, 4}}], 
   LineBox[{{15, 4}, {15, 0}}], LineBox[{{19, 8}, {19, 4}}], 
   LineBox[{{19, 4}, {19, 0}}], LineBox[{{21, 8}, {23, 8}}], 
   LineBox[{{21, 6}, {23, 6}}], LineBox[{{21, 4}, {23, 4}}], 
   LineBox[{{21, 2}, {23, 2}}], LineBox[{{21, 0}, {23, 0}}], 
   LineBox[{{23, 8}, {25, 8}}], LineBox[{{23, 6}, {25, 6}}], 
   LineBox[{{23, 4}, {25, 4}}], LineBox[{{23, 2}, {25, 2}}], 
   LineBox[{{23, 0}, {25, 0}}], LineBox[{{25, 8}, {27, 8}}], 
   LineBox[{{25, 6}, {27, 6}}], LineBox[{{25, 4}, {27, 4}}], 
   LineBox[{{25, 2}, {27, 2}}], LineBox[{{25, 0}, {27, 0}}], 
   LineBox[{{27, 8}, {29, 8}}], LineBox[{{27, 6}, {29, 6}}], 
   LineBox[{{27, 4}, {29, 4}}], LineBox[{{27, 2}, {29, 2}}], 
   LineBox[{{27, 0}, {29, 0}}], LineBox[{{21, 8}, {21, 6}}], 
   LineBox[{{21, 6}, {21, 4}}], LineBox[{{21, 4}, {21, 2}}], 
   LineBox[{{21, 2}, {21, 0}}], LineBox[{{23, 8}, {23, 6}}], 
   LineBox[{{23, 6}, {23, 4}}], LineBox[{{23, 4}, {23, 2}}], 
   LineBox[{{23, 2}, {23, 0}}], LineBox[{{25, 8}, {25, 6}}], 
   LineBox[{{25, 6}, {25, 4}}], LineBox[{{25, 4}, {25, 2}}], 
   LineBox[{{25, 2}, {25, 0}}], LineBox[{{27, 8}, {27, 6}}], 
   LineBox[{{27, 6}, {27, 4}}], LineBox[{{27, 4}, {27, 2}}], 
   LineBox[{{27, 2}, {27, 0}}], LineBox[{{29, 8}, {29, 6}}], 
   LineBox[{{29, 6}, {29, 4}}], LineBox[{{29, 4}, {29, 2}}], 
   LineBox[{{29, 2}, {29, 0}}], 
   LineBox[NCache[{{31, 8}, {Rational[287, 9], 8}}, {{31, 8}, {
      31.88888888888889, 8}}]], 
   LineBox[NCache[{{31, Rational[64, 9]}, {
      Rational[287, 9], Rational[64, 9]}}, {{31, 7.111111111111111}, {
      31.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{31, Rational[56, 9]}, {
      Rational[287, 9], Rational[56, 9]}}, {{31, 6.222222222222222}, {
      31.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{31, Rational[16, 3]}, {
      Rational[287, 9], Rational[16, 3]}}, {{31, 5.333333333333333}, {
      31.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{31, Rational[40, 9]}, {
      Rational[287, 9], Rational[40, 9]}}, {{31, 4.444444444444445}, {
      31.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{31, Rational[32, 9]}, {
      Rational[287, 9], Rational[32, 9]}}, {{31, 3.5555555555555554`}, {
      31.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{31, Rational[8, 3]}, {
      Rational[287, 9], Rational[8, 3]}}, {{31, 2.6666666666666665`}, {
      31.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{31, Rational[16, 9]}, {
      Rational[287, 9], Rational[16, 9]}}, {{31, 1.7777777777777777`}, {
      31.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{31, Rational[8, 9]}, {
      Rational[287, 9], Rational[8, 9]}}, {{31, 0.8888888888888888}, {
      31.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{31, 0}, {Rational[287, 9], 0}}, {{31, 0}, {
      31.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[287, 9], 8}, {Rational[295, 9], 8}}, {{
      31.88888888888889, 8}, {32.77777777777778, 8}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[64, 9]}, {
      Rational[295, 9], Rational[64, 9]}}, {{31.88888888888889, 
     7.111111111111111}, {32.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[56, 9]}, {
      Rational[295, 9], Rational[56, 9]}}, {{31.88888888888889, 
     6.222222222222222}, {32.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[16, 3]}, {
      Rational[295, 9], Rational[16, 3]}}, {{31.88888888888889, 
     5.333333333333333}, {32.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[40, 9]}, {
      Rational[295, 9], Rational[40, 9]}}, {{31.88888888888889, 
     4.444444444444445}, {32.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[32, 9]}, {
      Rational[295, 9], Rational[32, 9]}}, {{31.88888888888889, 
     3.5555555555555554`}, {32.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[8, 3]}, {
      Rational[295, 9], Rational[8, 3]}}, {{31.88888888888889, 
     2.6666666666666665`}, {32.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[16, 9]}, {
      Rational[295, 9], Rational[16, 9]}}, {{31.88888888888889, 
     1.7777777777777777`}, {32.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[8, 9]}, {
      Rational[295, 9], Rational[8, 9]}}, {{31.88888888888889, 
     0.8888888888888888}, {32.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[287, 9], 0}, {Rational[295, 9], 0}}, {{
      31.88888888888889, 0}, {32.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[295, 9], 8}, {Rational[101, 3], 8}}, {{
      32.77777777777778, 8}, {33.666666666666664`, 8}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[64, 9]}, {
      Rational[101, 3], Rational[64, 9]}}, {{32.77777777777778, 
     7.111111111111111}, {33.666666666666664`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[56, 9]}, {
      Rational[101, 3], Rational[56, 9]}}, {{32.77777777777778, 
     6.222222222222222}, {33.666666666666664`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[16, 3]}, {
      Rational[101, 3], Rational[16, 3]}}, {{32.77777777777778, 
     5.333333333333333}, {33.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[40, 9]}, {
      Rational[101, 3], Rational[40, 9]}}, {{32.77777777777778, 
     4.444444444444445}, {33.666666666666664`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[32, 9]}, {
      Rational[101, 3], Rational[32, 9]}}, {{32.77777777777778, 
     3.5555555555555554`}, {33.666666666666664`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[8, 3]}, {
      Rational[101, 3], Rational[8, 3]}}, {{32.77777777777778, 
     2.6666666666666665`}, {33.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[16, 9]}, {
      Rational[101, 3], Rational[16, 9]}}, {{32.77777777777778, 
     1.7777777777777777`}, {33.666666666666664`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[8, 9]}, {
      Rational[101, 3], Rational[8, 9]}}, {{32.77777777777778, 
     0.8888888888888888}, {33.666666666666664`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[295, 9], 0}, {Rational[101, 3], 0}}, {{
      32.77777777777778, 0}, {33.666666666666664`, 0}}]], 
   LineBox[NCache[{{Rational[101, 3], 8}, {Rational[311, 9], 8}}, {{
      33.666666666666664`, 8}, {34.55555555555556, 8}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[64, 9]}, {
      Rational[311, 9], Rational[64, 9]}}, {{33.666666666666664`, 
     7.111111111111111}, {34.55555555555556, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[56, 9]}, {
      Rational[311, 9], Rational[56, 9]}}, {{33.666666666666664`, 
     6.222222222222222}, {34.55555555555556, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[16, 3]}, {
      Rational[311, 9], Rational[16, 3]}}, {{33.666666666666664`, 
     5.333333333333333}, {34.55555555555556, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[40, 9]}, {
      Rational[311, 9], Rational[40, 9]}}, {{33.666666666666664`, 
     4.444444444444445}, {34.55555555555556, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[32, 9]}, {
      Rational[311, 9], Rational[32, 9]}}, {{33.666666666666664`, 
     3.5555555555555554`}, {34.55555555555556, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[8, 3]}, {
      Rational[311, 9], Rational[8, 3]}}, {{33.666666666666664`, 
     2.6666666666666665`}, {34.55555555555556, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[16, 9]}, {
      Rational[311, 9], Rational[16, 9]}}, {{33.666666666666664`, 
     1.7777777777777777`}, {34.55555555555556, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{Rational[101, 3], Rational[8, 9]}, {
      Rational[311, 9], Rational[8, 9]}}, {{33.666666666666664`, 
     0.8888888888888888}, {34.55555555555556, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[101, 3], 0}, {Rational[311, 9], 0}}, {{
      33.666666666666664`, 0}, {34.55555555555556, 0}}]], 
   LineBox[NCache[{{Rational[311, 9], 8}, {Rational[319, 9], 8}}, {{
      34.55555555555556, 8}, {35.44444444444444, 8}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[64, 9]}, {
      Rational[319, 9], Rational[64, 9]}}, {{34.55555555555556, 
     7.111111111111111}, {35.44444444444444, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[56, 9]}, {
      Rational[319, 9], Rational[56, 9]}}, {{34.55555555555556, 
     6.222222222222222}, {35.44444444444444, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[16, 3]}, {
      Rational[319, 9], Rational[16, 3]}}, {{34.55555555555556, 
     5.333333333333333}, {35.44444444444444, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[40, 9]}, {
      Rational[319, 9], Rational[40, 9]}}, {{34.55555555555556, 
     4.444444444444445}, {35.44444444444444, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[32, 9]}, {
      Rational[319, 9], Rational[32, 9]}}, {{34.55555555555556, 
     3.5555555555555554`}, {35.44444444444444, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[8, 3]}, {
      Rational[319, 9], Rational[8, 3]}}, {{34.55555555555556, 
     2.6666666666666665`}, {35.44444444444444, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[16, 9]}, {
      Rational[319, 9], Rational[16, 9]}}, {{34.55555555555556, 
     1.7777777777777777`}, {35.44444444444444, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[8, 9]}, {
      Rational[319, 9], Rational[8, 9]}}, {{34.55555555555556, 
     0.8888888888888888}, {35.44444444444444, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[311, 9], 0}, {Rational[319, 9], 0}}, {{
      34.55555555555556, 0}, {35.44444444444444, 0}}]], 
   LineBox[NCache[{{Rational[319, 9], 8}, {Rational[109, 3], 8}}, {{
      35.44444444444444, 8}, {36.333333333333336`, 8}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[64, 9]}, {
      Rational[109, 3], Rational[64, 9]}}, {{35.44444444444444, 
     7.111111111111111}, {36.333333333333336`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[56, 9]}, {
      Rational[109, 3], Rational[56, 9]}}, {{35.44444444444444, 
     6.222222222222222}, {36.333333333333336`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[16, 3]}, {
      Rational[109, 3], Rational[16, 3]}}, {{35.44444444444444, 
     5.333333333333333}, {36.333333333333336`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[40, 9]}, {
      Rational[109, 3], Rational[40, 9]}}, {{35.44444444444444, 
     4.444444444444445}, {36.333333333333336`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[32, 9]}, {
      Rational[109, 3], Rational[32, 9]}}, {{35.44444444444444, 
     3.5555555555555554`}, {36.333333333333336`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[8, 3]}, {
      Rational[109, 3], Rational[8, 3]}}, {{35.44444444444444, 
     2.6666666666666665`}, {36.333333333333336`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[16, 9]}, {
      Rational[109, 3], Rational[16, 9]}}, {{35.44444444444444, 
     1.7777777777777777`}, {36.333333333333336`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[8, 9]}, {
      Rational[109, 3], Rational[8, 9]}}, {{35.44444444444444, 
     0.8888888888888888}, {36.333333333333336`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[319, 9], 0}, {Rational[109, 3], 0}}, {{
      35.44444444444444, 0}, {36.333333333333336`, 0}}]], 
   LineBox[NCache[{{Rational[109, 3], 8}, {Rational[335, 9], 8}}, {{
      36.333333333333336`, 8}, {37.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[64, 9]}, {
      Rational[335, 9], Rational[64, 9]}}, {{36.333333333333336`, 
     7.111111111111111}, {37.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[56, 9]}, {
      Rational[335, 9], Rational[56, 9]}}, {{36.333333333333336`, 
     6.222222222222222}, {37.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[16, 3]}, {
      Rational[335, 9], Rational[16, 3]}}, {{36.333333333333336`, 
     5.333333333333333}, {37.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[40, 9]}, {
      Rational[335, 9], Rational[40, 9]}}, {{36.333333333333336`, 
     4.444444444444445}, {37.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[32, 9]}, {
      Rational[335, 9], Rational[32, 9]}}, {{36.333333333333336`, 
     3.5555555555555554`}, {37.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[8, 3]}, {
      Rational[335, 9], Rational[8, 3]}}, {{36.333333333333336`, 
     2.6666666666666665`}, {37.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[16, 9]}, {
      Rational[335, 9], Rational[16, 9]}}, {{36.333333333333336`, 
     1.7777777777777777`}, {37.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[8, 9]}, {
      Rational[335, 9], Rational[8, 9]}}, {{36.333333333333336`, 
     0.8888888888888888}, {37.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[109, 3], 0}, {Rational[335, 9], 0}}, {{
      36.333333333333336`, 0}, {37.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[335, 9], 8}, {Rational[343, 9], 8}}, {{
      37.22222222222222, 8}, {38.111111111111114`, 8}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[64, 9]}, {
      Rational[343, 9], Rational[64, 9]}}, {{37.22222222222222, 
     7.111111111111111}, {38.111111111111114`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[56, 9]}, {
      Rational[343, 9], Rational[56, 9]}}, {{37.22222222222222, 
     6.222222222222222}, {38.111111111111114`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[16, 3]}, {
      Rational[343, 9], Rational[16, 3]}}, {{37.22222222222222, 
     5.333333333333333}, {38.111111111111114`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[40, 9]}, {
      Rational[343, 9], Rational[40, 9]}}, {{37.22222222222222, 
     4.444444444444445}, {38.111111111111114`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[32, 9]}, {
      Rational[343, 9], Rational[32, 9]}}, {{37.22222222222222, 
     3.5555555555555554`}, {38.111111111111114`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[8, 3]}, {
      Rational[343, 9], Rational[8, 3]}}, {{37.22222222222222, 
     2.6666666666666665`}, {38.111111111111114`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[16, 9]}, {
      Rational[343, 9], Rational[16, 9]}}, {{37.22222222222222, 
     1.7777777777777777`}, {38.111111111111114`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[8, 9]}, {
      Rational[343, 9], Rational[8, 9]}}, {{37.22222222222222, 
     0.8888888888888888}, {38.111111111111114`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[335, 9], 0}, {Rational[343, 9], 0}}, {{
      37.22222222222222, 0}, {38.111111111111114`, 0}}]], 
   LineBox[NCache[{{Rational[343, 9], 8}, {39, 8}}, {{
      38.111111111111114`, 8}, {39, 8}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[64, 9]}, {
      39, Rational[64, 9]}}, {{38.111111111111114`, 7.111111111111111}, {
      39, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[56, 9]}, {
      39, Rational[56, 9]}}, {{38.111111111111114`, 6.222222222222222}, {
      39, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[16, 3]}, {
      39, Rational[16, 3]}}, {{38.111111111111114`, 5.333333333333333}, {
      39, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[40, 9]}, {
      39, Rational[40, 9]}}, {{38.111111111111114`, 4.444444444444445}, {
      39, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[32, 9]}, {
      39, Rational[32, 9]}}, {{38.111111111111114`, 3.5555555555555554`}, {
      39, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[8, 3]}, {
      39, Rational[8, 3]}}, {{38.111111111111114`, 2.6666666666666665`}, {
      39, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[16, 9]}, {
      39, Rational[16, 9]}}, {{38.111111111111114`, 1.7777777777777777`}, {
      39, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[8, 9]}, {
      39, Rational[8, 9]}}, {{38.111111111111114`, 0.8888888888888888}, {
      39, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[343, 9], 0}, {39, 0}}, {{
      38.111111111111114`, 0}, {39, 0}}]], 
   LineBox[NCache[{{31, 8}, {31, Rational[64, 9]}}, {{31, 8}, {
      31, 7.111111111111111}}]], 
   LineBox[NCache[{{31, Rational[64, 9]}, {31, Rational[56, 9]}}, {{
      31, 7.111111111111111}, {31, 6.222222222222222}}]], 
   LineBox[NCache[{{31, Rational[56, 9]}, {31, Rational[16, 3]}}, {{
      31, 6.222222222222222}, {31, 5.333333333333333}}]], 
   LineBox[NCache[{{31, Rational[16, 3]}, {31, Rational[40, 9]}}, {{
      31, 5.333333333333333}, {31, 4.444444444444445}}]], 
   LineBox[NCache[{{31, Rational[40, 9]}, {31, Rational[32, 9]}}, {{
      31, 4.444444444444445}, {31, 3.5555555555555554`}}]], 
   LineBox[NCache[{{31, Rational[32, 9]}, {31, Rational[8, 3]}}, {{
      31, 3.5555555555555554`}, {31, 2.6666666666666665`}}]], 
   LineBox[NCache[{{31, Rational[8, 3]}, {31, Rational[16, 9]}}, {{
      31, 2.6666666666666665`}, {31, 1.7777777777777777`}}]], 
   LineBox[NCache[{{31, Rational[16, 9]}, {31, Rational[8, 9]}}, {{
      31, 1.7777777777777777`}, {31, 0.8888888888888888}}]], 
   LineBox[NCache[{{31, Rational[8, 9]}, {31, 0}}, {{
      31, 0.8888888888888888}, {31, 0}}]], 
   LineBox[NCache[{{Rational[287, 9], 8}, {
      Rational[287, 9], Rational[64, 9]}}, {{31.88888888888889, 8}, {
      31.88888888888889, 7.111111111111111}}]], 
   LineBox[
    NCache[{{Rational[287, 9], Rational[64, 9]}, {
      Rational[287, 9], Rational[56, 9]}}, {{31.88888888888889, 
     7.111111111111111}, {31.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[56, 9]}, {
      Rational[287, 9], Rational[16, 3]}}, {{31.88888888888889, 
     6.222222222222222}, {31.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[16, 3]}, {
      Rational[287, 9], Rational[40, 9]}}, {{31.88888888888889, 
     5.333333333333333}, {31.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[40, 9]}, {
      Rational[287, 9], Rational[32, 9]}}, {{31.88888888888889, 
     4.444444444444445}, {31.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[32, 9]}, {
      Rational[287, 9], Rational[8, 3]}}, {{31.88888888888889, 
     3.5555555555555554`}, {31.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[8, 3]}, {
      Rational[287, 9], Rational[16, 9]}}, {{31.88888888888889, 
     2.6666666666666665`}, {31.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[16, 9]}, {
      Rational[287, 9], Rational[8, 9]}}, {{31.88888888888889, 
     1.7777777777777777`}, {31.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[8, 9]}, {
      Rational[287, 9], 0}}, {{31.88888888888889, 0.8888888888888888}, {
      31.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[295, 9], 8}, {
      Rational[295, 9], Rational[64, 9]}}, {{32.77777777777778, 8}, {
      32.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[64, 9]}, {
      Rational[295, 9], Rational[56, 9]}}, {{32.77777777777778, 
     7.111111111111111}, {32.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[56, 9]}, {
      Rational[295, 9], Rational[16, 3]}}, {{32.77777777777778, 
     6.222222222222222}, {32.77777777777778, 5.333333333333333}}]], 
   LineBox[
    NCache[{{Rational[295, 9], Rational[16, 3]}, {
      Rational[295, 9], Rational[40, 9]}}, {{32.77777777777778, 
     5.333333333333333}, {32.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[40, 9]}, {
      Rational[295, 9], Rational[32, 9]}}, {{32.77777777777778, 
     4.444444444444445}, {32.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[32, 9]}, {
      Rational[295, 9], Rational[8, 3]}}, {{32.77777777777778, 
     3.5555555555555554`}, {32.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[8, 3]}, {
      Rational[295, 9], Rational[16, 9]}}, {{32.77777777777778, 
     2.6666666666666665`}, {32.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[16, 9]}, {
      Rational[295, 9], Rational[8, 9]}}, {{32.77777777777778, 
     1.7777777777777777`}, {32.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[8, 9]}, {
      Rational[295, 9], 0}}, {{32.77777777777778, 0.8888888888888888}, {
      32.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[101, 3], 8}, {
      Rational[101, 3], Rational[64, 9]}}, {{33.666666666666664`, 8}, {
      33.666666666666664`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[64, 9]}, {
      Rational[101, 3], Rational[56, 9]}}, {{33.666666666666664`, 
     7.111111111111111}, {33.666666666666664`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[56, 9]}, {
      Rational[101, 3], Rational[16, 3]}}, {{33.666666666666664`, 
     6.222222222222222}, {33.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[16, 3]}, {
      Rational[101, 3], Rational[40, 9]}}, {{33.666666666666664`, 
     5.333333333333333}, {33.666666666666664`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[40, 9]}, {
      Rational[101, 3], Rational[32, 9]}}, {{33.666666666666664`, 
     4.444444444444445}, {33.666666666666664`, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{Rational[101, 3], Rational[32, 9]}, {
      Rational[101, 3], Rational[8, 3]}}, {{33.666666666666664`, 
     3.5555555555555554`}, {33.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[8, 3]}, {
      Rational[101, 3], Rational[16, 9]}}, {{33.666666666666664`, 
     2.6666666666666665`}, {33.666666666666664`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[16, 9]}, {
      Rational[101, 3], Rational[8, 9]}}, {{33.666666666666664`, 
     1.7777777777777777`}, {33.666666666666664`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[8, 9]}, {
      Rational[101, 3], 0}}, {{33.666666666666664`, 0.8888888888888888}, {
      33.666666666666664`, 0}}]], 
   LineBox[NCache[{{Rational[311, 9], 8}, {
      Rational[311, 9], Rational[64, 9]}}, {{34.55555555555556, 8}, {
      34.55555555555556, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[64, 9]}, {
      Rational[311, 9], Rational[56, 9]}}, {{34.55555555555556, 
     7.111111111111111}, {34.55555555555556, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[56, 9]}, {
      Rational[311, 9], Rational[16, 3]}}, {{34.55555555555556, 
     6.222222222222222}, {34.55555555555556, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[16, 3]}, {
      Rational[311, 9], Rational[40, 9]}}, {{34.55555555555556, 
     5.333333333333333}, {34.55555555555556, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[40, 9]}, {
      Rational[311, 9], Rational[32, 9]}}, {{34.55555555555556, 
     4.444444444444445}, {34.55555555555556, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[32, 9]}, {
      Rational[311, 9], Rational[8, 3]}}, {{34.55555555555556, 
     3.5555555555555554`}, {34.55555555555556, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[8, 3]}, {
      Rational[311, 9], Rational[16, 9]}}, {{34.55555555555556, 
     2.6666666666666665`}, {34.55555555555556, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{Rational[311, 9], Rational[16, 9]}, {
      Rational[311, 9], Rational[8, 9]}}, {{34.55555555555556, 
     1.7777777777777777`}, {34.55555555555556, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[8, 9]}, {
      Rational[311, 9], 0}}, {{34.55555555555556, 0.8888888888888888}, {
      34.55555555555556, 0}}]], 
   LineBox[NCache[{{Rational[319, 9], 8}, {
      Rational[319, 9], Rational[64, 9]}}, {{35.44444444444444, 8}, {
      35.44444444444444, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[64, 9]}, {
      Rational[319, 9], Rational[56, 9]}}, {{35.44444444444444, 
     7.111111111111111}, {35.44444444444444, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[56, 9]}, {
      Rational[319, 9], Rational[16, 3]}}, {{35.44444444444444, 
     6.222222222222222}, {35.44444444444444, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[16, 3]}, {
      Rational[319, 9], Rational[40, 9]}}, {{35.44444444444444, 
     5.333333333333333}, {35.44444444444444, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[40, 9]}, {
      Rational[319, 9], Rational[32, 9]}}, {{35.44444444444444, 
     4.444444444444445}, {35.44444444444444, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[32, 9]}, {
      Rational[319, 9], Rational[8, 3]}}, {{35.44444444444444, 
     3.5555555555555554`}, {35.44444444444444, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[8, 3]}, {
      Rational[319, 9], Rational[16, 9]}}, {{35.44444444444444, 
     2.6666666666666665`}, {35.44444444444444, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[16, 9]}, {
      Rational[319, 9], Rational[8, 9]}}, {{35.44444444444444, 
     1.7777777777777777`}, {35.44444444444444, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[8, 9]}, {
      Rational[319, 9], 0}}, {{35.44444444444444, 0.8888888888888888}, {
      35.44444444444444, 0}}]], 
   LineBox[NCache[{{Rational[109, 3], 8}, {Rational[109, 3], Rational[64, 9]}}
     , {{36.333333333333336`, 8}, {36.333333333333336`, 7.111111111111111}}]],
    LineBox[NCache[{{Rational[109, 3], Rational[64, 9]}, {
      Rational[109, 3], Rational[56, 9]}}, {{36.333333333333336`, 
     7.111111111111111}, {36.333333333333336`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[56, 9]}, {
      Rational[109, 3], Rational[16, 3]}}, {{36.333333333333336`, 
     6.222222222222222}, {36.333333333333336`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[16, 3]}, {
      Rational[109, 3], Rational[40, 9]}}, {{36.333333333333336`, 
     5.333333333333333}, {36.333333333333336`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[40, 9]}, {
      Rational[109, 3], Rational[32, 9]}}, {{36.333333333333336`, 
     4.444444444444445}, {36.333333333333336`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[32, 9]}, {
      Rational[109, 3], Rational[8, 3]}}, {{36.333333333333336`, 
     3.5555555555555554`}, {36.333333333333336`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[8, 3]}, {
      Rational[109, 3], Rational[16, 9]}}, {{36.333333333333336`, 
     2.6666666666666665`}, {36.333333333333336`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[16, 9]}, {
      Rational[109, 3], Rational[8, 9]}}, {{36.333333333333336`, 
     1.7777777777777777`}, {36.333333333333336`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[8, 9]}, {
      Rational[109, 3], 0}}, {{36.333333333333336`, 0.8888888888888888}, {
      36.333333333333336`, 0}}]], 
   LineBox[NCache[{{Rational[335, 9], 8}, {
      Rational[335, 9], Rational[64, 9]}}, {{37.22222222222222, 8}, {
      37.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[64, 9]}, {
      Rational[335, 9], Rational[56, 9]}}, {{37.22222222222222, 
     7.111111111111111}, {37.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[56, 9]}, {
      Rational[335, 9], Rational[16, 3]}}, {{37.22222222222222, 
     6.222222222222222}, {37.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[16, 3]}, {
      Rational[335, 9], Rational[40, 9]}}, {{37.22222222222222, 
     5.333333333333333}, {37.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[40, 9]}, {
      Rational[335, 9], Rational[32, 9]}}, {{37.22222222222222, 
     4.444444444444445}, {37.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[32, 9]}, {
      Rational[335, 9], Rational[8, 3]}}, {{37.22222222222222, 
     3.5555555555555554`}, {37.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[8, 3]}, {
      Rational[335, 9], Rational[16, 9]}}, {{37.22222222222222, 
     2.6666666666666665`}, {37.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[16, 9]}, {
      Rational[335, 9], Rational[8, 9]}}, {{37.22222222222222, 
     1.7777777777777777`}, {37.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[8, 9]}, {
      Rational[335, 9], 0}}, {{37.22222222222222, 0.8888888888888888}, {
      37.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[343, 9], 8}, {
      Rational[343, 9], Rational[64, 9]}}, {{38.111111111111114`, 8}, {
      38.111111111111114`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[64, 9]}, {
      Rational[343, 9], Rational[56, 9]}}, {{38.111111111111114`, 
     7.111111111111111}, {38.111111111111114`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[56, 9]}, {
      Rational[343, 9], Rational[16, 3]}}, {{38.111111111111114`, 
     6.222222222222222}, {38.111111111111114`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[16, 3]}, {
      Rational[343, 9], Rational[40, 9]}}, {{38.111111111111114`, 
     5.333333333333333}, {38.111111111111114`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[40, 9]}, {
      Rational[343, 9], Rational[32, 9]}}, {{38.111111111111114`, 
     4.444444444444445}, {38.111111111111114`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[32, 9]}, {
      Rational[343, 9], Rational[8, 3]}}, {{38.111111111111114`, 
     3.5555555555555554`}, {38.111111111111114`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[8, 3]}, {
      Rational[343, 9], Rational[16, 9]}}, {{38.111111111111114`, 
     2.6666666666666665`}, {38.111111111111114`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[16, 9]}, {
      Rational[343, 9], Rational[8, 9]}}, {{38.111111111111114`, 
     1.7777777777777777`}, {38.111111111111114`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[8, 9]}, {
      Rational[343, 9], 0}}, {{38.111111111111114`, 0.8888888888888888}, {
      38.111111111111114`, 0}}]], 
   LineBox[NCache[{{39, 8}, {39, Rational[64, 9]}}, {{39, 8}, {
      39, 7.111111111111111}}]], 
   LineBox[NCache[{{39, Rational[64, 9]}, {39, Rational[56, 9]}}, {{
      39, 7.111111111111111}, {39, 6.222222222222222}}]], 
   LineBox[NCache[{{39, Rational[56, 9]}, {39, Rational[16, 3]}}, {{
      39, 6.222222222222222}, {39, 5.333333333333333}}]], 
   LineBox[NCache[{{39, Rational[16, 3]}, {39, Rational[40, 9]}}, {{
      39, 5.333333333333333}, {39, 4.444444444444445}}]], 
   LineBox[NCache[{{39, Rational[40, 9]}, {39, Rational[32, 9]}}, {{
      39, 4.444444444444445}, {39, 3.5555555555555554`}}]], 
   LineBox[NCache[{{39, Rational[32, 9]}, {39, Rational[8, 3]}}, {{
      39, 3.5555555555555554`}, {39, 2.6666666666666665`}}]], 
   LineBox[NCache[{{39, Rational[8, 3]}, {39, Rational[16, 9]}}, {{
      39, 2.6666666666666665`}, {39, 1.7777777777777777`}}]], 
   LineBox[NCache[{{39, Rational[16, 9]}, {39, Rational[8, 9]}}, {{
      39, 1.7777777777777777`}, {39, 0.8888888888888888}}]], 
   LineBox[NCache[{{39, Rational[8, 9]}, {39, 0}}, {{
      39, 0.8888888888888888}, {39, 0}}]], LineBox[{{19, 8}, {21, 8}}], 
   LineBox[{{19, 8}, {21, 6}}], LineBox[{{19, 4}, {21, 4}}], 
   LineBox[{{19, 4}, {21, 2}}], LineBox[{{19, 0}, {21, 0}}], 
   LineBox[{{29, 8}, {31, 8}}], 
   LineBox[NCache[{{29, 8}, {31, Rational[64, 9]}}, {{29, 8}, {
      31, 7.111111111111111}}]], 
   LineBox[NCache[{{29, 6}, {31, Rational[56, 9]}}, {{29, 6}, {
      31, 6.222222222222222}}]], 
   LineBox[NCache[{{29, 6}, {31, Rational[16, 3]}}, {{29, 6}, {
      31, 5.333333333333333}}]], 
   LineBox[NCache[{{29, 4}, {31, Rational[40, 9]}}, {{29, 4}, {
      31, 4.444444444444445}}]], 
   LineBox[NCache[{{29, 4}, {31, Rational[32, 9]}}, {{29, 4}, {
      31, 3.5555555555555554`}}]], 
   LineBox[NCache[{{29, 2}, {31, Rational[8, 3]}}, {{29, 2}, {
      31, 2.6666666666666665`}}]], 
   LineBox[NCache[{{29, 2}, {31, Rational[16, 9]}}, {{29, 2}, {
      31, 1.7777777777777777`}}]], 
   LineBox[NCache[{{29, 0}, {31, Rational[8, 9]}}, {{29, 0}, {
      31, 0.8888888888888888}}]], LineBox[{{29, 0}, {31, 0}}]},
  ImageSize->400]], "Output",
 CellChangeTimes->{
  3.470839795545988*^9, 3.470843013758205*^9, 3.470846062699534*^9, 
   3.470846152475099*^9, 3.470846442680905*^9, 3.470849685369626*^9, {
   3.470850737161112*^9, 3.470850753819416*^9}, 3.470867722920146*^9, 
   3.470867805271393*^9, 3.470874480107663*^9, 3.47087827171208*^9, 
   3.470881813815848*^9, 3.470912102531178*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "@", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"0.3", ",", "0.5", ",", "0.7", ",", "1"}], "}"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.470839801731086*^9, 3.470839803782685*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], LineBox[{{11, 8}, {15, 8}}], 
   LineBox[{{11, 4}, {15, 4}}], LineBox[{{11, 0}, {15, 0}}], 
   LineBox[{{15, 8}, {19, 8}}], LineBox[{{15, 4}, {19, 4}}], 
   LineBox[{{15, 0}, {19, 0}}], LineBox[{{11, 8}, {11, 4}}], 
   LineBox[{{11, 4}, {11, 0}}], LineBox[{{15, 8}, {15, 4}}], 
   LineBox[{{15, 4}, {15, 0}}], LineBox[{{19, 8}, {19, 4}}], 
   LineBox[{{19, 4}, {19, 0}}], LineBox[{{21, 8}, {23, 8}}], 
   LineBox[{{21, 6}, {23, 6}}], LineBox[{{21, 4}, {23, 4}}], 
   LineBox[{{21, 2}, {23, 2}}], LineBox[{{21, 0}, {23, 0}}], 
   LineBox[{{23, 8}, {25, 8}}], LineBox[{{23, 6}, {25, 6}}], 
   LineBox[{{23, 4}, {25, 4}}], LineBox[{{23, 2}, {25, 2}}], 
   LineBox[{{23, 0}, {25, 0}}], LineBox[{{25, 8}, {27, 8}}], 
   LineBox[{{25, 6}, {27, 6}}], LineBox[{{25, 4}, {27, 4}}], 
   LineBox[{{25, 2}, {27, 2}}], LineBox[{{25, 0}, {27, 0}}], 
   LineBox[{{27, 8}, {29, 8}}], LineBox[{{27, 6}, {29, 6}}], 
   LineBox[{{27, 4}, {29, 4}}], LineBox[{{27, 2}, {29, 2}}], 
   LineBox[{{27, 0}, {29, 0}}], LineBox[{{21, 8}, {21, 6}}], 
   LineBox[{{21, 6}, {21, 4}}], LineBox[{{21, 4}, {21, 2}}], 
   LineBox[{{21, 2}, {21, 0}}], LineBox[{{23, 8}, {23, 6}}], 
   LineBox[{{23, 6}, {23, 4}}], LineBox[{{23, 4}, {23, 2}}], 
   LineBox[{{23, 2}, {23, 0}}], LineBox[{{25, 8}, {25, 6}}], 
   LineBox[{{25, 6}, {25, 4}}], LineBox[{{25, 4}, {25, 2}}], 
   LineBox[{{25, 2}, {25, 0}}], LineBox[{{27, 8}, {27, 6}}], 
   LineBox[{{27, 6}, {27, 4}}], LineBox[{{27, 4}, {27, 2}}], 
   LineBox[{{27, 2}, {27, 0}}], LineBox[{{29, 8}, {29, 6}}], 
   LineBox[{{29, 6}, {29, 4}}], LineBox[{{29, 4}, {29, 2}}], 
   LineBox[{{29, 2}, {29, 0}}], 
   LineBox[NCache[{{31, 8}, {Rational[97, 3], 8}}, {{31, 8}, {
      32.333333333333336`, 8}}]], 
   LineBox[NCache[{{31, Rational[20, 3]}, {
      Rational[97, 3], Rational[20, 3]}}, {{31, 6.666666666666667}, {
      32.333333333333336`, 6.666666666666667}}]], 
   LineBox[NCache[{{31, Rational[16, 3]}, {
      Rational[97, 3], Rational[16, 3]}}, {{31, 5.333333333333333}, {
      32.333333333333336`, 5.333333333333333}}]], 
   LineBox[NCache[{{31, 4}, {Rational[97, 3], 4}}, {{31, 4}, {
      32.333333333333336`, 4}}]], 
   LineBox[NCache[{{31, Rational[8, 3]}, {
      Rational[97, 3], Rational[8, 3]}}, {{31, 2.6666666666666665`}, {
      32.333333333333336`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{31, Rational[4, 3]}, {
      Rational[97, 3], Rational[4, 3]}}, {{31, 1.3333333333333333`}, {
      32.333333333333336`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{31, 0}, {Rational[97, 3], 0}}, {{31, 0}, {
      32.333333333333336`, 0}}]], 
   LineBox[NCache[{{Rational[97, 3], 8}, {Rational[101, 3], 8}}, {{
      32.333333333333336`, 8}, {33.666666666666664`, 8}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[20, 3]}, {
      Rational[101, 3], Rational[20, 3]}}, {{32.333333333333336`, 
     6.666666666666667}, {33.666666666666664`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[16, 3]}, {
      Rational[101, 3], Rational[16, 3]}}, {{32.333333333333336`, 
     5.333333333333333}, {33.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[97, 3], 4}, {Rational[101, 3], 4}}, {{
      32.333333333333336`, 4}, {33.666666666666664`, 4}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[8, 3]}, {
      Rational[101, 3], Rational[8, 3]}}, {{32.333333333333336`, 
     2.6666666666666665`}, {33.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[4, 3]}, {
      Rational[101, 3], Rational[4, 3]}}, {{32.333333333333336`, 
     1.3333333333333333`}, {33.666666666666664`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[97, 3], 0}, {Rational[101, 3], 0}}, {{
      32.333333333333336`, 0}, {33.666666666666664`, 0}}]], 
   LineBox[NCache[{{Rational[101, 3], 8}, {35, 8}}, {{
      33.666666666666664`, 8}, {35, 8}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[20, 3]}, {
      35, Rational[20, 3]}}, {{33.666666666666664`, 6.666666666666667}, {
      35, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[16, 3]}, {
      35, Rational[16, 3]}}, {{33.666666666666664`, 5.333333333333333}, {
      35, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[101, 3], 4}, {35, 4}}, {{
      33.666666666666664`, 4}, {35, 4}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[8, 3]}, {
      35, Rational[8, 3]}}, {{33.666666666666664`, 2.6666666666666665`}, {
      35, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[4, 3]}, {
      35, Rational[4, 3]}}, {{33.666666666666664`, 1.3333333333333333`}, {
      35, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[101, 3], 0}, {35, 0}}, {{
      33.666666666666664`, 0}, {35, 0}}]], 
   LineBox[NCache[{{35, 8}, {Rational[109, 3], 8}}, {{35, 8}, {
      36.333333333333336`, 8}}]], 
   LineBox[NCache[{{35, Rational[20, 3]}, {
      Rational[109, 3], Rational[20, 3]}}, {{35, 6.666666666666667}, {
      36.333333333333336`, 6.666666666666667}}]], 
   LineBox[NCache[{{35, Rational[16, 3]}, {
      Rational[109, 3], Rational[16, 3]}}, {{35, 5.333333333333333}, {
      36.333333333333336`, 5.333333333333333}}]], 
   LineBox[NCache[{{35, 4}, {Rational[109, 3], 4}}, {{35, 4}, {
      36.333333333333336`, 4}}]], 
   LineBox[NCache[{{35, Rational[8, 3]}, {
      Rational[109, 3], Rational[8, 3]}}, {{35, 2.6666666666666665`}, {
      36.333333333333336`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{35, Rational[4, 3]}, {
      Rational[109, 3], Rational[4, 3]}}, {{35, 1.3333333333333333`}, {
      36.333333333333336`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{35, 0}, {Rational[109, 3], 0}}, {{35, 0}, {
      36.333333333333336`, 0}}]], 
   LineBox[NCache[{{Rational[109, 3], 8}, {Rational[113, 3], 8}}, {{
      36.333333333333336`, 8}, {37.666666666666664`, 8}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[20, 3]}, {
      Rational[113, 3], Rational[20, 3]}}, {{36.333333333333336`, 
     6.666666666666667}, {37.666666666666664`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[16, 3]}, {
      Rational[113, 3], Rational[16, 3]}}, {{36.333333333333336`, 
     5.333333333333333}, {37.666666666666664`, 5.333333333333333}}]], 
   LineBox[
    NCache[{{Rational[109, 3], 4}, {Rational[113, 3], 4}}, {{
      36.333333333333336`, 4}, {37.666666666666664`, 4}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[8, 3]}, {
      Rational[113, 3], Rational[8, 3]}}, {{36.333333333333336`, 
     2.6666666666666665`}, {37.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[4, 3]}, {
      Rational[113, 3], Rational[4, 3]}}, {{36.333333333333336`, 
     1.3333333333333333`}, {37.666666666666664`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[109, 3], 0}, {Rational[113, 3], 0}}, {{
      36.333333333333336`, 0}, {37.666666666666664`, 0}}]], 
   LineBox[NCache[{{Rational[113, 3], 8}, {39, 8}}, {{
      37.666666666666664`, 8}, {39, 8}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[20, 3]}, {
      39, Rational[20, 3]}}, {{37.666666666666664`, 6.666666666666667}, {
      39, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[16, 3]}, {
      39, Rational[16, 3]}}, {{37.666666666666664`, 5.333333333333333}, {
      39, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[113, 3], 4}, {39, 4}}, {{
      37.666666666666664`, 4}, {39, 4}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[8, 3]}, {
      39, Rational[8, 3]}}, {{37.666666666666664`, 2.6666666666666665`}, {
      39, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[4, 3]}, {
      39, Rational[4, 3]}}, {{37.666666666666664`, 1.3333333333333333`}, {
      39, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[113, 3], 0}, {39, 0}}, {{
      37.666666666666664`, 0}, {39, 0}}]], 
   LineBox[NCache[{{31, 8}, {31, Rational[20, 3]}}, {{31, 8}, {
      31, 6.666666666666667}}]], 
   LineBox[NCache[{{31, Rational[20, 3]}, {31, Rational[16, 3]}}, {{
      31, 6.666666666666667}, {31, 5.333333333333333}}]], 
   LineBox[NCache[{{31, Rational[16, 3]}, {31, 4}}, {{
      31, 5.333333333333333}, {31, 4}}]], 
   LineBox[NCache[{{31, 4}, {31, Rational[8, 3]}}, {{31, 4}, {
      31, 2.6666666666666665`}}]], 
   LineBox[NCache[{{31, Rational[8, 3]}, {31, Rational[4, 3]}}, {{
      31, 2.6666666666666665`}, {31, 1.3333333333333333`}}]], 
   LineBox[NCache[{{31, Rational[4, 3]}, {31, 0}}, {{
      31, 1.3333333333333333`}, {31, 0}}]], 
   LineBox[NCache[{{Rational[97, 3], 8}, {
      Rational[97, 3], Rational[20, 3]}}, {{32.333333333333336`, 8}, {
      32.333333333333336`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[20, 3]}, {
      Rational[97, 3], Rational[16, 3]}}, {{32.333333333333336`, 
     6.666666666666667}, {32.333333333333336`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[16, 3]}, {
      Rational[97, 3], 4}}, {{32.333333333333336`, 5.333333333333333}, {
      32.333333333333336`, 4}}]], 
   LineBox[NCache[{{Rational[97, 3], 4}, {
      Rational[97, 3], Rational[8, 3]}}, {{32.333333333333336`, 4}, {
      32.333333333333336`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[8, 3]}, {
      Rational[97, 3], Rational[4, 3]}}, {{32.333333333333336`, 
     2.6666666666666665`}, {32.333333333333336`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[97, 3], Rational[4, 3]}, {
      Rational[97, 3], 0}}, {{32.333333333333336`, 1.3333333333333333`}, {
      32.333333333333336`, 0}}]], 
   LineBox[NCache[{{Rational[101, 3], 8}, {
      Rational[101, 3], Rational[20, 3]}}, {{33.666666666666664`, 8}, {
      33.666666666666664`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[20, 3]}, {
      Rational[101, 3], Rational[16, 3]}}, {{33.666666666666664`, 
     6.666666666666667}, {33.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[16, 3]}, {
      Rational[101, 3], 4}}, {{33.666666666666664`, 5.333333333333333}, {
      33.666666666666664`, 4}}]], 
   LineBox[NCache[{{Rational[101, 3], 4}, {
      Rational[101, 3], Rational[8, 3]}}, {{33.666666666666664`, 4}, {
      33.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[8, 3]}, {
      Rational[101, 3], Rational[4, 3]}}, {{33.666666666666664`, 
     2.6666666666666665`}, {33.666666666666664`, 1.3333333333333333`}}]], 
   LineBox[
    NCache[{{Rational[101, 3], Rational[4, 3]}, {Rational[101, 3], 0}}, {{
      33.666666666666664`, 1.3333333333333333`}, {33.666666666666664`, 0}}]], 
   LineBox[NCache[{{35, 8}, {35, Rational[20, 3]}}, {{35, 8}, {
      35, 6.666666666666667}}]], 
   LineBox[NCache[{{35, Rational[20, 3]}, {35, Rational[16, 3]}}, {{
      35, 6.666666666666667}, {35, 5.333333333333333}}]], 
   LineBox[NCache[{{35, Rational[16, 3]}, {35, 4}}, {{
      35, 5.333333333333333}, {35, 4}}]], 
   LineBox[NCache[{{35, 4}, {35, Rational[8, 3]}}, {{35, 4}, {
      35, 2.6666666666666665`}}]], 
   LineBox[NCache[{{35, Rational[8, 3]}, {35, Rational[4, 3]}}, {{
      35, 2.6666666666666665`}, {35, 1.3333333333333333`}}]], 
   LineBox[NCache[{{35, Rational[4, 3]}, {35, 0}}, {{
      35, 1.3333333333333333`}, {35, 0}}]], 
   LineBox[NCache[{{Rational[109, 3], 8}, {
      Rational[109, 3], Rational[20, 3]}}, {{36.333333333333336`, 8}, {
      36.333333333333336`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[20, 3]}, {
      Rational[109, 3], Rational[16, 3]}}, {{36.333333333333336`, 
     6.666666666666667}, {36.333333333333336`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[16, 3]}, {
      Rational[109, 3], 4}}, {{36.333333333333336`, 5.333333333333333}, {
      36.333333333333336`, 4}}]], 
   LineBox[NCache[{{Rational[109, 3], 4}, {
      Rational[109, 3], Rational[8, 3]}}, {{36.333333333333336`, 4}, {
      36.333333333333336`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[8, 3]}, {
      Rational[109, 3], Rational[4, 3]}}, {{36.333333333333336`, 
     2.6666666666666665`}, {36.333333333333336`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[4, 3]}, {
      Rational[109, 3], 0}}, {{36.333333333333336`, 1.3333333333333333`}, {
      36.333333333333336`, 0}}]], 
   LineBox[NCache[{{Rational[113, 3], 8}, {
      Rational[113, 3], Rational[20, 3]}}, {{37.666666666666664`, 8}, {
      37.666666666666664`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[20, 3]}, {
      Rational[113, 3], Rational[16, 3]}}, {{37.666666666666664`, 
     6.666666666666667}, {37.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[16, 3]}, {
      Rational[113, 3], 4}}, {{37.666666666666664`, 5.333333333333333}, {
      37.666666666666664`, 4}}]], 
   LineBox[NCache[{{Rational[113, 3], 4}, {
      Rational[113, 3], Rational[8, 3]}}, {{37.666666666666664`, 4}, {
      37.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[8, 3]}, {
      Rational[113, 3], Rational[4, 3]}}, {{37.666666666666664`, 
     2.6666666666666665`}, {37.666666666666664`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[113, 3], Rational[4, 3]}, {
      Rational[113, 3], 0}}, {{37.666666666666664`, 1.3333333333333333`}, {
      37.666666666666664`, 0}}]], 
   LineBox[NCache[{{39, 8}, {39, Rational[20, 3]}}, {{39, 8}, {
      39, 6.666666666666667}}]], 
   LineBox[NCache[{{39, Rational[20, 3]}, {39, Rational[16, 3]}}, {{
      39, 6.666666666666667}, {39, 5.333333333333333}}]], 
   LineBox[NCache[{{39, Rational[16, 3]}, {39, 4}}, {{
      39, 5.333333333333333}, {39, 4}}]], 
   LineBox[NCache[{{39, 4}, {39, Rational[8, 3]}}, {{39, 4}, {
      39, 2.6666666666666665`}}]], 
   LineBox[NCache[{{39, Rational[8, 3]}, {39, Rational[4, 3]}}, {{
      39, 2.6666666666666665`}, {39, 1.3333333333333333`}}]], 
   LineBox[NCache[{{39, Rational[4, 3]}, {39, 0}}, {{
      39, 1.3333333333333333`}, {39, 0}}]], 
   LineBox[NCache[{{41, 8}, {Rational[377, 9], 8}}, {{41, 8}, {
      41.888888888888886`, 8}}]], 
   LineBox[NCache[{{41, Rational[64, 9]}, {
      Rational[377, 9], Rational[64, 9]}}, {{41, 7.111111111111111}, {
      41.888888888888886`, 7.111111111111111}}]], 
   LineBox[NCache[{{41, Rational[56, 9]}, {
      Rational[377, 9], Rational[56, 9]}}, {{41, 6.222222222222222}, {
      41.888888888888886`, 6.222222222222222}}]], 
   LineBox[NCache[{{41, Rational[16, 3]}, {
      Rational[377, 9], Rational[16, 3]}}, {{41, 5.333333333333333}, {
      41.888888888888886`, 5.333333333333333}}]], 
   LineBox[
    NCache[{{41, Rational[40, 9]}, {Rational[377, 9], Rational[40, 9]}}, {{
      41, 4.444444444444445}, {41.888888888888886`, 4.444444444444445}}]], 
   LineBox[NCache[{{41, Rational[32, 9]}, {
      Rational[377, 9], Rational[32, 9]}}, {{41, 3.5555555555555554`}, {
      41.888888888888886`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{41, Rational[8, 3]}, {
      Rational[377, 9], Rational[8, 3]}}, {{41, 2.6666666666666665`}, {
      41.888888888888886`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{41, Rational[16, 9]}, {
      Rational[377, 9], Rational[16, 9]}}, {{41, 1.7777777777777777`}, {
      41.888888888888886`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{41, Rational[8, 9]}, {
      Rational[377, 9], Rational[8, 9]}}, {{41, 0.8888888888888888}, {
      41.888888888888886`, 0.8888888888888888}}]], 
   LineBox[NCache[{{41, 0}, {Rational[377, 9], 0}}, {{41, 0}, {
      41.888888888888886`, 0}}]], 
   LineBox[NCache[{{Rational[377, 9], 8}, {Rational[385, 9], 8}}, {{
      41.888888888888886`, 8}, {42.77777777777778, 8}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[64, 9]}, {
      Rational[385, 9], Rational[64, 9]}}, {{41.888888888888886`, 
     7.111111111111111}, {42.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[56, 9]}, {
      Rational[385, 9], Rational[56, 9]}}, {{41.888888888888886`, 
     6.222222222222222}, {42.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[16, 3]}, {
      Rational[385, 9], Rational[16, 3]}}, {{41.888888888888886`, 
     5.333333333333333}, {42.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[40, 9]}, {
      Rational[385, 9], Rational[40, 9]}}, {{41.888888888888886`, 
     4.444444444444445}, {42.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[32, 9]}, {
      Rational[385, 9], Rational[32, 9]}}, {{41.888888888888886`, 
     3.5555555555555554`}, {42.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[8, 3]}, {
      Rational[385, 9], Rational[8, 3]}}, {{41.888888888888886`, 
     2.6666666666666665`}, {42.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[16, 9]}, {
      Rational[385, 9], Rational[16, 9]}}, {{41.888888888888886`, 
     1.7777777777777777`}, {42.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[8, 9]}, {
      Rational[385, 9], Rational[8, 9]}}, {{41.888888888888886`, 
     0.8888888888888888}, {42.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[377, 9], 0}, {Rational[385, 9], 0}}, {{
      41.888888888888886`, 0}, {42.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[385, 9], 8}, {Rational[131, 3], 8}}, {{
      42.77777777777778, 8}, {43.666666666666664`, 8}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[64, 9]}, {
      Rational[131, 3], Rational[64, 9]}}, {{42.77777777777778, 
     7.111111111111111}, {43.666666666666664`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[56, 9]}, {
      Rational[131, 3], Rational[56, 9]}}, {{42.77777777777778, 
     6.222222222222222}, {43.666666666666664`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[16, 3]}, {
      Rational[131, 3], Rational[16, 3]}}, {{42.77777777777778, 
     5.333333333333333}, {43.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[40, 9]}, {
      Rational[131, 3], Rational[40, 9]}}, {{42.77777777777778, 
     4.444444444444445}, {43.666666666666664`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[32, 9]}, {
      Rational[131, 3], Rational[32, 9]}}, {{42.77777777777778, 
     3.5555555555555554`}, {43.666666666666664`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[8, 3]}, {
      Rational[131, 3], Rational[8, 3]}}, {{42.77777777777778, 
     2.6666666666666665`}, {43.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[16, 9]}, {
      Rational[131, 3], Rational[16, 9]}}, {{42.77777777777778, 
     1.7777777777777777`}, {43.666666666666664`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[8, 9]}, {
      Rational[131, 3], Rational[8, 9]}}, {{42.77777777777778, 
     0.8888888888888888}, {43.666666666666664`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[385, 9], 0}, {Rational[131, 3], 0}}, {{
      42.77777777777778, 0}, {43.666666666666664`, 0}}]], 
   LineBox[NCache[{{Rational[131, 3], 8}, {Rational[401, 9], 8}}, {{
      43.666666666666664`, 8}, {44.55555555555556, 8}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[64, 9]}, {
      Rational[401, 9], Rational[64, 9]}}, {{43.666666666666664`, 
     7.111111111111111}, {44.55555555555556, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[56, 9]}, {
      Rational[401, 9], Rational[56, 9]}}, {{43.666666666666664`, 
     6.222222222222222}, {44.55555555555556, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[16, 3]}, {
      Rational[401, 9], Rational[16, 3]}}, {{43.666666666666664`, 
     5.333333333333333}, {44.55555555555556, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[40, 9]}, {
      Rational[401, 9], Rational[40, 9]}}, {{43.666666666666664`, 
     4.444444444444445}, {44.55555555555556, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[32, 9]}, {
      Rational[401, 9], Rational[32, 9]}}, {{43.666666666666664`, 
     3.5555555555555554`}, {44.55555555555556, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[8, 3]}, {
      Rational[401, 9], Rational[8, 3]}}, {{43.666666666666664`, 
     2.6666666666666665`}, {44.55555555555556, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[16, 9]}, {
      Rational[401, 9], Rational[16, 9]}}, {{43.666666666666664`, 
     1.7777777777777777`}, {44.55555555555556, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[8, 9]}, {
      Rational[401, 9], Rational[8, 9]}}, {{43.666666666666664`, 
     0.8888888888888888}, {44.55555555555556, 0.8888888888888888}}]], 
   LineBox[
    NCache[{{Rational[131, 3], 0}, {Rational[401, 9], 0}}, {{
      43.666666666666664`, 0}, {44.55555555555556, 0}}]], 
   LineBox[NCache[{{Rational[401, 9], 8}, {Rational[409, 9], 8}}, {{
      44.55555555555556, 8}, {45.44444444444444, 8}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[64, 9]}, {
      Rational[409, 9], Rational[64, 9]}}, {{44.55555555555556, 
     7.111111111111111}, {45.44444444444444, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[56, 9]}, {
      Rational[409, 9], Rational[56, 9]}}, {{44.55555555555556, 
     6.222222222222222}, {45.44444444444444, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[16, 3]}, {
      Rational[409, 9], Rational[16, 3]}}, {{44.55555555555556, 
     5.333333333333333}, {45.44444444444444, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[40, 9]}, {
      Rational[409, 9], Rational[40, 9]}}, {{44.55555555555556, 
     4.444444444444445}, {45.44444444444444, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[32, 9]}, {
      Rational[409, 9], Rational[32, 9]}}, {{44.55555555555556, 
     3.5555555555555554`}, {45.44444444444444, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[8, 3]}, {
      Rational[409, 9], Rational[8, 3]}}, {{44.55555555555556, 
     2.6666666666666665`}, {45.44444444444444, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[16, 9]}, {
      Rational[409, 9], Rational[16, 9]}}, {{44.55555555555556, 
     1.7777777777777777`}, {45.44444444444444, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[8, 9]}, {
      Rational[409, 9], Rational[8, 9]}}, {{44.55555555555556, 
     0.8888888888888888}, {45.44444444444444, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[401, 9], 0}, {Rational[409, 9], 0}}, {{
      44.55555555555556, 0}, {45.44444444444444, 0}}]], 
   LineBox[NCache[{{Rational[409, 9], 8}, {Rational[139, 3], 8}}, {{
      45.44444444444444, 8}, {46.333333333333336`, 8}}]], 
   LineBox[
    NCache[{{Rational[409, 9], Rational[64, 9]}, {
      Rational[139, 3], Rational[64, 9]}}, {{45.44444444444444, 
     7.111111111111111}, {46.333333333333336`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[56, 9]}, {
      Rational[139, 3], Rational[56, 9]}}, {{45.44444444444444, 
     6.222222222222222}, {46.333333333333336`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[16, 3]}, {
      Rational[139, 3], Rational[16, 3]}}, {{45.44444444444444, 
     5.333333333333333}, {46.333333333333336`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[40, 9]}, {
      Rational[139, 3], Rational[40, 9]}}, {{45.44444444444444, 
     4.444444444444445}, {46.333333333333336`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[32, 9]}, {
      Rational[139, 3], Rational[32, 9]}}, {{45.44444444444444, 
     3.5555555555555554`}, {46.333333333333336`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[8, 3]}, {
      Rational[139, 3], Rational[8, 3]}}, {{45.44444444444444, 
     2.6666666666666665`}, {46.333333333333336`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[16, 9]}, {
      Rational[139, 3], Rational[16, 9]}}, {{45.44444444444444, 
     1.7777777777777777`}, {46.333333333333336`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[8, 9]}, {
      Rational[139, 3], Rational[8, 9]}}, {{45.44444444444444, 
     0.8888888888888888}, {46.333333333333336`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[409, 9], 0}, {Rational[139, 3], 0}}, {{
      45.44444444444444, 0}, {46.333333333333336`, 0}}]], 
   LineBox[NCache[{{Rational[139, 3], 8}, {Rational[425, 9], 8}}, {{
      46.333333333333336`, 8}, {47.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[64, 9]}, {
      Rational[425, 9], Rational[64, 9]}}, {{46.333333333333336`, 
     7.111111111111111}, {47.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[56, 9]}, {
      Rational[425, 9], Rational[56, 9]}}, {{46.333333333333336`, 
     6.222222222222222}, {47.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[16, 3]}, {
      Rational[425, 9], Rational[16, 3]}}, {{46.333333333333336`, 
     5.333333333333333}, {47.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[40, 9]}, {
      Rational[425, 9], Rational[40, 9]}}, {{46.333333333333336`, 
     4.444444444444445}, {47.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[32, 9]}, {
      Rational[425, 9], Rational[32, 9]}}, {{46.333333333333336`, 
     3.5555555555555554`}, {47.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[8, 3]}, {
      Rational[425, 9], Rational[8, 3]}}, {{46.333333333333336`, 
     2.6666666666666665`}, {47.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[16, 9]}, {
      Rational[425, 9], Rational[16, 9]}}, {{46.333333333333336`, 
     1.7777777777777777`}, {47.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[8, 9]}, {
      Rational[425, 9], Rational[8, 9]}}, {{46.333333333333336`, 
     0.8888888888888888}, {47.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[139, 3], 0}, {Rational[425, 9], 0}}, {{
      46.333333333333336`, 0}, {47.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[425, 9], 8}, {Rational[433, 9], 8}}, {{
      47.22222222222222, 8}, {48.111111111111114`, 8}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[64, 9]}, {
      Rational[433, 9], Rational[64, 9]}}, {{47.22222222222222, 
     7.111111111111111}, {48.111111111111114`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[56, 9]}, {
      Rational[433, 9], Rational[56, 9]}}, {{47.22222222222222, 
     6.222222222222222}, {48.111111111111114`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[16, 3]}, {
      Rational[433, 9], Rational[16, 3]}}, {{47.22222222222222, 
     5.333333333333333}, {48.111111111111114`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[40, 9]}, {
      Rational[433, 9], Rational[40, 9]}}, {{47.22222222222222, 
     4.444444444444445}, {48.111111111111114`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[32, 9]}, {
      Rational[433, 9], Rational[32, 9]}}, {{47.22222222222222, 
     3.5555555555555554`}, {48.111111111111114`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[8, 3]}, {
      Rational[433, 9], Rational[8, 3]}}, {{47.22222222222222, 
     2.6666666666666665`}, {48.111111111111114`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[16, 9]}, {
      Rational[433, 9], Rational[16, 9]}}, {{47.22222222222222, 
     1.7777777777777777`}, {48.111111111111114`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[8, 9]}, {
      Rational[433, 9], Rational[8, 9]}}, {{47.22222222222222, 
     0.8888888888888888}, {48.111111111111114`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[425, 9], 0}, {Rational[433, 9], 0}}, {{
      47.22222222222222, 0}, {48.111111111111114`, 0}}]], 
   LineBox[NCache[{{Rational[433, 9], 8}, {49, 8}}, {{
      48.111111111111114`, 8}, {49, 8}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[64, 9]}, {
      49, Rational[64, 9]}}, {{48.111111111111114`, 7.111111111111111}, {
      49, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[56, 9]}, {
      49, Rational[56, 9]}}, {{48.111111111111114`, 6.222222222222222}, {
      49, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[16, 3]}, {
      49, Rational[16, 3]}}, {{48.111111111111114`, 5.333333333333333}, {
      49, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[40, 9]}, {
      49, Rational[40, 9]}}, {{48.111111111111114`, 4.444444444444445}, {
      49, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[32, 9]}, {
      49, Rational[32, 9]}}, {{48.111111111111114`, 3.5555555555555554`}, {
      49, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[8, 3]}, {
      49, Rational[8, 3]}}, {{48.111111111111114`, 2.6666666666666665`}, {
      49, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[16, 9]}, {
      49, Rational[16, 9]}}, {{48.111111111111114`, 1.7777777777777777`}, {
      49, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[8, 9]}, {
      49, Rational[8, 9]}}, {{48.111111111111114`, 0.8888888888888888}, {
      49, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[433, 9], 0}, {49, 0}}, {{
      48.111111111111114`, 0}, {49, 0}}]], 
   LineBox[NCache[{{41, 8}, {41, Rational[64, 9]}}, {{41, 8}, {
      41, 7.111111111111111}}]], 
   LineBox[NCache[{{41, Rational[64, 9]}, {41, Rational[56, 9]}}, {{
      41, 7.111111111111111}, {41, 6.222222222222222}}]], 
   LineBox[NCache[{{41, Rational[56, 9]}, {41, Rational[16, 3]}}, {{
      41, 6.222222222222222}, {41, 5.333333333333333}}]], 
   LineBox[NCache[{{41, Rational[16, 3]}, {41, Rational[40, 9]}}, {{
      41, 5.333333333333333}, {41, 4.444444444444445}}]], 
   LineBox[NCache[{{41, Rational[40, 9]}, {41, Rational[32, 9]}}, {{
      41, 4.444444444444445}, {41, 3.5555555555555554`}}]], 
   LineBox[NCache[{{41, Rational[32, 9]}, {41, Rational[8, 3]}}, {{
      41, 3.5555555555555554`}, {41, 2.6666666666666665`}}]], 
   LineBox[NCache[{{41, Rational[8, 3]}, {41, Rational[16, 9]}}, {{
      41, 2.6666666666666665`}, {41, 1.7777777777777777`}}]], 
   LineBox[NCache[{{41, Rational[16, 9]}, {41, Rational[8, 9]}}, {{
      41, 1.7777777777777777`}, {41, 0.8888888888888888}}]], 
   LineBox[NCache[{{41, Rational[8, 9]}, {41, 0}}, {{
      41, 0.8888888888888888}, {41, 0}}]], 
   LineBox[NCache[{{Rational[377, 9], 8}, {
      Rational[377, 9], Rational[64, 9]}}, {{41.888888888888886`, 8}, {
      41.888888888888886`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[64, 9]}, {
      Rational[377, 9], Rational[56, 9]}}, {{41.888888888888886`, 
     7.111111111111111}, {41.888888888888886`, 6.222222222222222}}]], 
   LineBox[
    NCache[{{Rational[377, 9], Rational[56, 9]}, {
      Rational[377, 9], Rational[16, 3]}}, {{41.888888888888886`, 
     6.222222222222222}, {41.888888888888886`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[16, 3]}, {
      Rational[377, 9], Rational[40, 9]}}, {{41.888888888888886`, 
     5.333333333333333}, {41.888888888888886`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[40, 9]}, {
      Rational[377, 9], Rational[32, 9]}}, {{41.888888888888886`, 
     4.444444444444445}, {41.888888888888886`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[32, 9]}, {
      Rational[377, 9], Rational[8, 3]}}, {{41.888888888888886`, 
     3.5555555555555554`}, {41.888888888888886`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[8, 3]}, {
      Rational[377, 9], Rational[16, 9]}}, {{41.888888888888886`, 
     2.6666666666666665`}, {41.888888888888886`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[16, 9]}, {
      Rational[377, 9], Rational[8, 9]}}, {{41.888888888888886`, 
     1.7777777777777777`}, {41.888888888888886`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[377, 9], Rational[8, 9]}, {
      Rational[377, 9], 0}}, {{41.888888888888886`, 0.8888888888888888}, {
      41.888888888888886`, 0}}]], 
   LineBox[NCache[{{Rational[385, 9], 8}, {
      Rational[385, 9], Rational[64, 9]}}, {{42.77777777777778, 8}, {
      42.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[64, 9]}, {
      Rational[385, 9], Rational[56, 9]}}, {{42.77777777777778, 
     7.111111111111111}, {42.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[56, 9]}, {
      Rational[385, 9], Rational[16, 3]}}, {{42.77777777777778, 
     6.222222222222222}, {42.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[16, 3]}, {
      Rational[385, 9], Rational[40, 9]}}, {{42.77777777777778, 
     5.333333333333333}, {42.77777777777778, 4.444444444444445}}]], 
   LineBox[
    NCache[{{Rational[385, 9], Rational[40, 9]}, {
      Rational[385, 9], Rational[32, 9]}}, {{42.77777777777778, 
     4.444444444444445}, {42.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[32, 9]}, {
      Rational[385, 9], Rational[8, 3]}}, {{42.77777777777778, 
     3.5555555555555554`}, {42.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[8, 3]}, {
      Rational[385, 9], Rational[16, 9]}}, {{42.77777777777778, 
     2.6666666666666665`}, {42.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[16, 9]}, {
      Rational[385, 9], Rational[8, 9]}}, {{42.77777777777778, 
     1.7777777777777777`}, {42.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[385, 9], Rational[8, 9]}, {
      Rational[385, 9], 0}}, {{42.77777777777778, 0.8888888888888888}, {
      42.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[131, 3], 8}, {
      Rational[131, 3], Rational[64, 9]}}, {{43.666666666666664`, 8}, {
      43.666666666666664`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[64, 9]}, {
      Rational[131, 3], Rational[56, 9]}}, {{43.666666666666664`, 
     7.111111111111111}, {43.666666666666664`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[56, 9]}, {
      Rational[131, 3], Rational[16, 3]}}, {{43.666666666666664`, 
     6.222222222222222}, {43.666666666666664`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[16, 3]}, {
      Rational[131, 3], Rational[40, 9]}}, {{43.666666666666664`, 
     5.333333333333333}, {43.666666666666664`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[40, 9]}, {
      Rational[131, 3], Rational[32, 9]}}, {{43.666666666666664`, 
     4.444444444444445}, {43.666666666666664`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[32, 9]}, {
      Rational[131, 3], Rational[8, 3]}}, {{43.666666666666664`, 
     3.5555555555555554`}, {43.666666666666664`, 2.6666666666666665`}}]], 
   LineBox[
    NCache[{{Rational[131, 3], Rational[8, 3]}, {
      Rational[131, 3], Rational[16, 9]}}, {{43.666666666666664`, 
     2.6666666666666665`}, {43.666666666666664`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[16, 9]}, {
      Rational[131, 3], Rational[8, 9]}}, {{43.666666666666664`, 
     1.7777777777777777`}, {43.666666666666664`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[131, 3], Rational[8, 9]}, {
      Rational[131, 3], 0}}, {{43.666666666666664`, 0.8888888888888888}, {
      43.666666666666664`, 0}}]], 
   LineBox[NCache[{{Rational[401, 9], 8}, {
      Rational[401, 9], Rational[64, 9]}}, {{44.55555555555556, 8}, {
      44.55555555555556, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[64, 9]}, {
      Rational[401, 9], Rational[56, 9]}}, {{44.55555555555556, 
     7.111111111111111}, {44.55555555555556, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[56, 9]}, {
      Rational[401, 9], Rational[16, 3]}}, {{44.55555555555556, 
     6.222222222222222}, {44.55555555555556, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[16, 3]}, {
      Rational[401, 9], Rational[40, 9]}}, {{44.55555555555556, 
     5.333333333333333}, {44.55555555555556, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[40, 9]}, {
      Rational[401, 9], Rational[32, 9]}}, {{44.55555555555556, 
     4.444444444444445}, {44.55555555555556, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[32, 9]}, {
      Rational[401, 9], Rational[8, 3]}}, {{44.55555555555556, 
     3.5555555555555554`}, {44.55555555555556, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[8, 3]}, {
      Rational[401, 9], Rational[16, 9]}}, {{44.55555555555556, 
     2.6666666666666665`}, {44.55555555555556, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[401, 9], Rational[16, 9]}, {
      Rational[401, 9], Rational[8, 9]}}, {{44.55555555555556, 
     1.7777777777777777`}, {44.55555555555556, 0.8888888888888888}}]], 
   LineBox[
    NCache[{{Rational[401, 9], Rational[8, 9]}, {Rational[401, 9], 0}}, {{
      44.55555555555556, 0.8888888888888888}, {44.55555555555556, 0}}]], 
   LineBox[NCache[{{Rational[409, 9], 8}, {
      Rational[409, 9], Rational[64, 9]}}, {{45.44444444444444, 8}, {
      45.44444444444444, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[64, 9]}, {
      Rational[409, 9], Rational[56, 9]}}, {{45.44444444444444, 
     7.111111111111111}, {45.44444444444444, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[56, 9]}, {
      Rational[409, 9], Rational[16, 3]}}, {{45.44444444444444, 
     6.222222222222222}, {45.44444444444444, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[16, 3]}, {
      Rational[409, 9], Rational[40, 9]}}, {{45.44444444444444, 
     5.333333333333333}, {45.44444444444444, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[40, 9]}, {
      Rational[409, 9], Rational[32, 9]}}, {{45.44444444444444, 
     4.444444444444445}, {45.44444444444444, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[32, 9]}, {
      Rational[409, 9], Rational[8, 3]}}, {{45.44444444444444, 
     3.5555555555555554`}, {45.44444444444444, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[8, 3]}, {
      Rational[409, 9], Rational[16, 9]}}, {{45.44444444444444, 
     2.6666666666666665`}, {45.44444444444444, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[16, 9]}, {
      Rational[409, 9], Rational[8, 9]}}, {{45.44444444444444, 
     1.7777777777777777`}, {45.44444444444444, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[409, 9], Rational[8, 9]}, {
      Rational[409, 9], 0}}, {{45.44444444444444, 0.8888888888888888}, {
      45.44444444444444, 0}}]], 
   LineBox[NCache[{{Rational[139, 3], 8}, {
      Rational[139, 3], Rational[64, 9]}}, {{46.333333333333336`, 8}, {
      46.333333333333336`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[64, 9]}, {
      Rational[139, 3], Rational[56, 9]}}, {{46.333333333333336`, 
     7.111111111111111}, {46.333333333333336`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[56, 9]}, {
      Rational[139, 3], Rational[16, 3]}}, {{46.333333333333336`, 
     6.222222222222222}, {46.333333333333336`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[16, 3]}, {
      Rational[139, 3], Rational[40, 9]}}, {{46.333333333333336`, 
     5.333333333333333}, {46.333333333333336`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[40, 9]}, {
      Rational[139, 3], Rational[32, 9]}}, {{46.333333333333336`, 
     4.444444444444445}, {46.333333333333336`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[32, 9]}, {
      Rational[139, 3], Rational[8, 3]}}, {{46.333333333333336`, 
     3.5555555555555554`}, {46.333333333333336`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[8, 3]}, {
      Rational[139, 3], Rational[16, 9]}}, {{46.333333333333336`, 
     2.6666666666666665`}, {46.333333333333336`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[16, 9]}, {
      Rational[139, 3], Rational[8, 9]}}, {{46.333333333333336`, 
     1.7777777777777777`}, {46.333333333333336`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[139, 3], Rational[8, 9]}, {
      Rational[139, 3], 0}}, {{46.333333333333336`, 0.8888888888888888}, {
      46.333333333333336`, 0}}]], 
   LineBox[NCache[{{Rational[425, 9], 8}, {
      Rational[425, 9], Rational[64, 9]}}, {{47.22222222222222, 8}, {
      47.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[64, 9]}, {
      Rational[425, 9], Rational[56, 9]}}, {{47.22222222222222, 
     7.111111111111111}, {47.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[56, 9]}, {
      Rational[425, 9], Rational[16, 3]}}, {{47.22222222222222, 
     6.222222222222222}, {47.22222222222222, 5.333333333333333}}]], 
   LineBox[
    NCache[{{Rational[425, 9], Rational[16, 3]}, {
      Rational[425, 9], Rational[40, 9]}}, {{47.22222222222222, 
     5.333333333333333}, {47.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[40, 9]}, {
      Rational[425, 9], Rational[32, 9]}}, {{47.22222222222222, 
     4.444444444444445}, {47.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[32, 9]}, {
      Rational[425, 9], Rational[8, 3]}}, {{47.22222222222222, 
     3.5555555555555554`}, {47.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[8, 3]}, {
      Rational[425, 9], Rational[16, 9]}}, {{47.22222222222222, 
     2.6666666666666665`}, {47.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[16, 9]}, {
      Rational[425, 9], Rational[8, 9]}}, {{47.22222222222222, 
     1.7777777777777777`}, {47.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[425, 9], Rational[8, 9]}, {
      Rational[425, 9], 0}}, {{47.22222222222222, 0.8888888888888888}, {
      47.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[433, 9], 8}, {
      Rational[433, 9], Rational[64, 9]}}, {{48.111111111111114`, 8}, {
      48.111111111111114`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[64, 9]}, {
      Rational[433, 9], Rational[56, 9]}}, {{48.111111111111114`, 
     7.111111111111111}, {48.111111111111114`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[56, 9]}, {
      Rational[433, 9], Rational[16, 3]}}, {{48.111111111111114`, 
     6.222222222222222}, {48.111111111111114`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[16, 3]}, {
      Rational[433, 9], Rational[40, 9]}}, {{48.111111111111114`, 
     5.333333333333333}, {48.111111111111114`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[40, 9]}, {
      Rational[433, 9], Rational[32, 9]}}, {{48.111111111111114`, 
     4.444444444444445}, {48.111111111111114`, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{Rational[433, 9], Rational[32, 9]}, {
      Rational[433, 9], Rational[8, 3]}}, {{48.111111111111114`, 
     3.5555555555555554`}, {48.111111111111114`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[8, 3]}, {
      Rational[433, 9], Rational[16, 9]}}, {{48.111111111111114`, 
     2.6666666666666665`}, {48.111111111111114`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[16, 9]}, {
      Rational[433, 9], Rational[8, 9]}}, {{48.111111111111114`, 
     1.7777777777777777`}, {48.111111111111114`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[433, 9], Rational[8, 9]}, {
      Rational[433, 9], 0}}, {{48.111111111111114`, 0.8888888888888888}, {
      48.111111111111114`, 0}}]], 
   LineBox[NCache[{{49, 8}, {49, Rational[64, 9]}}, {{49, 8}, {
      49, 7.111111111111111}}]], 
   LineBox[NCache[{{49, Rational[64, 9]}, {49, Rational[56, 9]}}, {{
      49, 7.111111111111111}, {49, 6.222222222222222}}]], 
   LineBox[NCache[{{49, Rational[56, 9]}, {49, Rational[16, 3]}}, {{
      49, 6.222222222222222}, {49, 5.333333333333333}}]], 
   LineBox[NCache[{{49, Rational[16, 3]}, {49, Rational[40, 9]}}, {{
      49, 5.333333333333333}, {49, 4.444444444444445}}]], 
   LineBox[NCache[{{49, Rational[40, 9]}, {49, Rational[32, 9]}}, {{
      49, 4.444444444444445}, {49, 3.5555555555555554`}}]], 
   LineBox[NCache[{{49, Rational[32, 9]}, {49, Rational[8, 3]}}, {{
      49, 3.5555555555555554`}, {49, 2.6666666666666665`}}]], 
   LineBox[NCache[{{49, Rational[8, 3]}, {49, Rational[16, 9]}}, {{
      49, 2.6666666666666665`}, {49, 1.7777777777777777`}}]], 
   LineBox[NCache[{{49, Rational[16, 9]}, {49, Rational[8, 9]}}, {{
      49, 1.7777777777777777`}, {49, 0.8888888888888888}}]], 
   LineBox[NCache[{{49, Rational[8, 9]}, {49, 0}}, {{
      49, 0.8888888888888888}, {49, 0}}]], LineBox[{{19, 8}, {21, 8}}], 
   LineBox[{{19, 8}, {21, 6}}], LineBox[{{19, 4}, {21, 4}}], 
   LineBox[{{19, 4}, {21, 2}}], LineBox[{{19, 0}, {21, 0}}], 
   LineBox[{{29, 8}, {31, 8}}], 
   LineBox[
    NCache[{{29, 8}, {31, Rational[20, 3]}}, {{29, 8}, {
      31, 6.666666666666667}}]], 
   LineBox[NCache[{{29, 6}, {31, Rational[16, 3]}}, {{29, 6}, {
      31, 5.333333333333333}}]], LineBox[{{29, 4}, {31, 4}}], 
   LineBox[NCache[{{29, 4}, {31, Rational[8, 3]}}, {{29, 4}, {
      31, 2.6666666666666665`}}]], 
   LineBox[NCache[{{29, 2}, {31, Rational[4, 3]}}, {{29, 2}, {
      31, 1.3333333333333333`}}]], LineBox[{{29, 0}, {31, 0}}], 
   LineBox[{{39, 8}, {41, 8}}], 
   LineBox[NCache[{{39, 8}, {41, Rational[64, 9]}}, {{39, 8}, {
      41, 7.111111111111111}}]], 
   LineBox[NCache[{{39, Rational[20, 3]}, {41, Rational[56, 9]}}, {{
      39, 6.666666666666667}, {41, 6.222222222222222}}]], 
   LineBox[NCache[{{39, Rational[16, 3]}, {41, Rational[16, 3]}}, {{
      39, 5.333333333333333}, {41, 5.333333333333333}}]], 
   LineBox[NCache[{{39, Rational[16, 3]}, {41, Rational[40, 9]}}, {{
      39, 5.333333333333333}, {41, 4.444444444444445}}]], 
   LineBox[NCache[{{39, 4}, {41, Rational[32, 9]}}, {{39, 4}, {
      41, 3.5555555555555554`}}]], 
   LineBox[NCache[{{39, Rational[8, 3]}, {41, Rational[8, 3]}}, {{
      39, 2.6666666666666665`}, {41, 2.6666666666666665`}}]], 
   LineBox[NCache[{{39, Rational[8, 3]}, {41, Rational[16, 9]}}, {{
      39, 2.6666666666666665`}, {41, 1.7777777777777777`}}]], 
   LineBox[NCache[{{39, Rational[4, 3]}, {41, Rational[8, 9]}}, {{
      39, 1.3333333333333333`}, {41, 0.8888888888888888}}]], 
   LineBox[{{39, 0}, {41, 0}}]},
  ImageSize->400]], "Output",
 CellChangeTimes->{
  3.47083980473907*^9, 3.470843013990356*^9, 3.470846062955296*^9, 
   3.470846152837983*^9, 3.470846443299435*^9, 3.470849685640826*^9, {
   3.470850737377612*^9, 3.470850754110173*^9}, 3.470867723222316*^9, 
   3.470867805511547*^9, 3.47087448034343*^9, 3.470878271943051*^9, 
   3.470881814027972*^9, 3.470912102798163*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.3", ",", "0.5", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0.5", ",", "0.3"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.470839813574656*^9, 3.470839845536092*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], LineBox[{{11, 18}, {15, 18}}], 
   LineBox[{{11, 14}, {15, 14}}], LineBox[{{11, 10}, {15, 10}}], 
   LineBox[{{15, 18}, {19, 18}}], LineBox[{{15, 14}, {19, 14}}], 
   LineBox[{{15, 10}, {19, 10}}], LineBox[{{11, 18}, {11, 14}}], 
   LineBox[{{11, 14}, {11, 10}}], LineBox[{{15, 18}, {15, 14}}], 
   LineBox[{{15, 14}, {15, 10}}], LineBox[{{19, 18}, {19, 14}}], 
   LineBox[{{19, 14}, {19, 10}}], LineBox[{{21, 18}, {23, 18}}], 
   LineBox[{{21, 16}, {23, 16}}], LineBox[{{21, 14}, {23, 14}}], 
   LineBox[{{21, 12}, {23, 12}}], LineBox[{{21, 10}, {23, 10}}], 
   LineBox[{{23, 18}, {25, 18}}], LineBox[{{23, 16}, {25, 16}}], 
   LineBox[{{23, 14}, {25, 14}}], LineBox[{{23, 12}, {25, 12}}], 
   LineBox[{{23, 10}, {25, 10}}], LineBox[{{25, 18}, {27, 18}}], 
   LineBox[{{25, 16}, {27, 16}}], LineBox[{{25, 14}, {27, 14}}], 
   LineBox[{{25, 12}, {27, 12}}], LineBox[{{25, 10}, {27, 10}}], 
   LineBox[{{27, 18}, {29, 18}}], LineBox[{{27, 16}, {29, 16}}], 
   LineBox[{{27, 14}, {29, 14}}], LineBox[{{27, 12}, {29, 12}}], 
   LineBox[{{27, 10}, {29, 10}}], LineBox[{{21, 18}, {21, 16}}], 
   LineBox[{{21, 16}, {21, 14}}], LineBox[{{21, 14}, {21, 12}}], 
   LineBox[{{21, 12}, {21, 10}}], LineBox[{{23, 18}, {23, 16}}], 
   LineBox[{{23, 16}, {23, 14}}], LineBox[{{23, 14}, {23, 12}}], 
   LineBox[{{23, 12}, {23, 10}}], LineBox[{{25, 18}, {25, 16}}], 
   LineBox[{{25, 16}, {25, 14}}], LineBox[{{25, 14}, {25, 12}}], 
   LineBox[{{25, 12}, {25, 10}}], LineBox[{{27, 18}, {27, 16}}], 
   LineBox[{{27, 16}, {27, 14}}], LineBox[{{27, 14}, {27, 12}}], 
   LineBox[{{27, 12}, {27, 10}}], LineBox[{{29, 18}, {29, 16}}], 
   LineBox[{{29, 16}, {29, 14}}], LineBox[{{29, 14}, {29, 12}}], 
   LineBox[{{29, 12}, {29, 10}}], 
   LineBox[NCache[{{31, 18}, {Rational[287, 9], 18}}, {{31, 18}, {
      31.88888888888889, 18}}]], 
   LineBox[NCache[{{31, Rational[154, 9]}, {
      Rational[287, 9], Rational[154, 9]}}, {{31, 17.11111111111111}, {
      31.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{31, Rational[146, 9]}, {
      Rational[287, 9], Rational[146, 9]}}, {{31, 16.22222222222222}, {
      31.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{31, Rational[46, 3]}, {
      Rational[287, 9], Rational[46, 3]}}, {{31, 15.333333333333334`}, {
      31.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{31, Rational[130, 9]}, {
      Rational[287, 9], Rational[130, 9]}}, {{31, 14.444444444444445`}, {
      31.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{31, Rational[122, 9]}, {
      Rational[287, 9], Rational[122, 9]}}, {{31, 13.555555555555555`}, {
      31.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{31, Rational[38, 3]}, {
      Rational[287, 9], Rational[38, 3]}}, {{31, 12.666666666666666`}, {
      31.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{31, Rational[106, 9]}, {
      Rational[287, 9], Rational[106, 9]}}, {{31, 11.777777777777779`}, {
      31.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{31, Rational[98, 9]}, {
      Rational[287, 9], Rational[98, 9]}}, {{31, 10.88888888888889}, {
      31.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{31, 10}, {Rational[287, 9], 10}}, {{31, 10}, {
      31.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[287, 9], 18}, {Rational[295, 9], 18}}, {{
      31.88888888888889, 18}, {32.77777777777778, 18}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[154, 9]}, {
      Rational[295, 9], Rational[154, 9]}}, {{31.88888888888889, 
     17.11111111111111}, {32.77777777777778, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[146, 9]}, {
      Rational[295, 9], Rational[146, 9]}}, {{31.88888888888889, 
     16.22222222222222}, {32.77777777777778, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[46, 3]}, {
      Rational[295, 9], Rational[46, 3]}}, {{31.88888888888889, 
     15.333333333333334`}, {32.77777777777778, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[130, 9]}, {
      Rational[295, 9], Rational[130, 9]}}, {{31.88888888888889, 
     14.444444444444445`}, {32.77777777777778, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[122, 9]}, {
      Rational[295, 9], Rational[122, 9]}}, {{31.88888888888889, 
     13.555555555555555`}, {32.77777777777778, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[38, 3]}, {
      Rational[295, 9], Rational[38, 3]}}, {{31.88888888888889, 
     12.666666666666666`}, {32.77777777777778, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[106, 9]}, {
      Rational[295, 9], Rational[106, 9]}}, {{31.88888888888889, 
     11.777777777777779`}, {32.77777777777778, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[98, 9]}, {
      Rational[295, 9], Rational[98, 9]}}, {{31.88888888888889, 
     10.88888888888889}, {32.77777777777778, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[287, 9], 10}, {Rational[295, 9], 10}}, {{
      31.88888888888889, 10}, {32.77777777777778, 10}}]], 
   LineBox[NCache[{{Rational[295, 9], 18}, {Rational[101, 3], 18}}, {{
      32.77777777777778, 18}, {33.666666666666664`, 18}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[154, 9]}, {
      Rational[101, 3], Rational[154, 9]}}, {{32.77777777777778, 
     17.11111111111111}, {33.666666666666664`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[146, 9]}, {
      Rational[101, 3], Rational[146, 9]}}, {{32.77777777777778, 
     16.22222222222222}, {33.666666666666664`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[46, 3]}, {
      Rational[101, 3], Rational[46, 3]}}, {{32.77777777777778, 
     15.333333333333334`}, {33.666666666666664`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[130, 9]}, {
      Rational[101, 3], Rational[130, 9]}}, {{32.77777777777778, 
     14.444444444444445`}, {33.666666666666664`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[122, 9]}, {
      Rational[101, 3], Rational[122, 9]}}, {{32.77777777777778, 
     13.555555555555555`}, {33.666666666666664`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[38, 3]}, {
      Rational[101, 3], Rational[38, 3]}}, {{32.77777777777778, 
     12.666666666666666`}, {33.666666666666664`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[106, 9]}, {
      Rational[101, 3], Rational[106, 9]}}, {{32.77777777777778, 
     11.777777777777779`}, {33.666666666666664`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[98, 9]}, {
      Rational[101, 3], Rational[98, 9]}}, {{32.77777777777778, 
     10.88888888888889}, {33.666666666666664`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[295, 9], 10}, {Rational[101, 3], 10}}, {{
      32.77777777777778, 10}, {33.666666666666664`, 10}}]], 
   LineBox[NCache[{{Rational[101, 3], 18}, {Rational[311, 9], 18}}, {{
      33.666666666666664`, 18}, {34.55555555555556, 18}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[154, 9]}, {
      Rational[311, 9], Rational[154, 9]}}, {{33.666666666666664`, 
     17.11111111111111}, {34.55555555555556, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[146, 9]}, {
      Rational[311, 9], Rational[146, 9]}}, {{33.666666666666664`, 
     16.22222222222222}, {34.55555555555556, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[46, 3]}, {
      Rational[311, 9], Rational[46, 3]}}, {{33.666666666666664`, 
     15.333333333333334`}, {34.55555555555556, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[130, 9]}, {
      Rational[311, 9], Rational[130, 9]}}, {{33.666666666666664`, 
     14.444444444444445`}, {34.55555555555556, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[122, 9]}, {
      Rational[311, 9], Rational[122, 9]}}, {{33.666666666666664`, 
     13.555555555555555`}, {34.55555555555556, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[38, 3]}, {
      Rational[311, 9], Rational[38, 3]}}, {{33.666666666666664`, 
     12.666666666666666`}, {34.55555555555556, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[106, 9]}, {
      Rational[311, 9], Rational[106, 9]}}, {{33.666666666666664`, 
     11.777777777777779`}, {34.55555555555556, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[98, 9]}, {
      Rational[311, 9], Rational[98, 9]}}, {{33.666666666666664`, 
     10.88888888888889}, {34.55555555555556, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[101, 3], 10}, {Rational[311, 9], 10}}, {{
      33.666666666666664`, 10}, {34.55555555555556, 10}}]], 
   LineBox[NCache[{{Rational[311, 9], 18}, {Rational[319, 9], 18}}, {{
      34.55555555555556, 18}, {35.44444444444444, 18}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[154, 9]}, {
      Rational[319, 9], Rational[154, 9]}}, {{34.55555555555556, 
     17.11111111111111}, {35.44444444444444, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[146, 9]}, {
      Rational[319, 9], Rational[146, 9]}}, {{34.55555555555556, 
     16.22222222222222}, {35.44444444444444, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[46, 3]}, {
      Rational[319, 9], Rational[46, 3]}}, {{34.55555555555556, 
     15.333333333333334`}, {35.44444444444444, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[130, 9]}, {
      Rational[319, 9], Rational[130, 9]}}, {{34.55555555555556, 
     14.444444444444445`}, {35.44444444444444, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[122, 9]}, {
      Rational[319, 9], Rational[122, 9]}}, {{34.55555555555556, 
     13.555555555555555`}, {35.44444444444444, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[38, 3]}, {
      Rational[319, 9], Rational[38, 3]}}, {{34.55555555555556, 
     12.666666666666666`}, {35.44444444444444, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[106, 9]}, {
      Rational[319, 9], Rational[106, 9]}}, {{34.55555555555556, 
     11.777777777777779`}, {35.44444444444444, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[98, 9]}, {
      Rational[319, 9], Rational[98, 9]}}, {{34.55555555555556, 
     10.88888888888889}, {35.44444444444444, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[311, 9], 10}, {Rational[319, 9], 10}}, {{
      34.55555555555556, 10}, {35.44444444444444, 10}}]], 
   LineBox[NCache[{{Rational[319, 9], 18}, {Rational[109, 3], 18}}, {{
      35.44444444444444, 18}, {36.333333333333336`, 18}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[154, 9]}, {
      Rational[109, 3], Rational[154, 9]}}, {{35.44444444444444, 
     17.11111111111111}, {36.333333333333336`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[146, 9]}, {
      Rational[109, 3], Rational[146, 9]}}, {{35.44444444444444, 
     16.22222222222222}, {36.333333333333336`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[46, 3]}, {
      Rational[109, 3], Rational[46, 3]}}, {{35.44444444444444, 
     15.333333333333334`}, {36.333333333333336`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[130, 9]}, {
      Rational[109, 3], Rational[130, 9]}}, {{35.44444444444444, 
     14.444444444444445`}, {36.333333333333336`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[122, 9]}, {
      Rational[109, 3], Rational[122, 9]}}, {{35.44444444444444, 
     13.555555555555555`}, {36.333333333333336`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[38, 3]}, {
      Rational[109, 3], Rational[38, 3]}}, {{35.44444444444444, 
     12.666666666666666`}, {36.333333333333336`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[106, 9]}, {
      Rational[109, 3], Rational[106, 9]}}, {{35.44444444444444, 
     11.777777777777779`}, {36.333333333333336`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[98, 9]}, {
      Rational[109, 3], Rational[98, 9]}}, {{35.44444444444444, 
     10.88888888888889}, {36.333333333333336`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[319, 9], 10}, {Rational[109, 3], 10}}, {{
      35.44444444444444, 10}, {36.333333333333336`, 10}}]], 
   LineBox[NCache[{{Rational[109, 3], 18}, {Rational[335, 9], 18}}, {{
      36.333333333333336`, 18}, {37.22222222222222, 18}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[154, 9]}, {
      Rational[335, 9], Rational[154, 9]}}, {{36.333333333333336`, 
     17.11111111111111}, {37.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[146, 9]}, {
      Rational[335, 9], Rational[146, 9]}}, {{36.333333333333336`, 
     16.22222222222222}, {37.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[46, 3]}, {
      Rational[335, 9], Rational[46, 3]}}, {{36.333333333333336`, 
     15.333333333333334`}, {37.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[130, 9]}, {
      Rational[335, 9], Rational[130, 9]}}, {{36.333333333333336`, 
     14.444444444444445`}, {37.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[122, 9]}, {
      Rational[335, 9], Rational[122, 9]}}, {{36.333333333333336`, 
     13.555555555555555`}, {37.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[38, 3]}, {
      Rational[335, 9], Rational[38, 3]}}, {{36.333333333333336`, 
     12.666666666666666`}, {37.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[106, 9]}, {
      Rational[335, 9], Rational[106, 9]}}, {{36.333333333333336`, 
     11.777777777777779`}, {37.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[98, 9]}, {
      Rational[335, 9], Rational[98, 9]}}, {{36.333333333333336`, 
     10.88888888888889}, {37.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[109, 3], 10}, {Rational[335, 9], 10}}, {{
      36.333333333333336`, 10}, {37.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[335, 9], 18}, {Rational[343, 9], 18}}, {{
      37.22222222222222, 18}, {38.111111111111114`, 18}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[154, 9]}, {
      Rational[343, 9], Rational[154, 9]}}, {{37.22222222222222, 
     17.11111111111111}, {38.111111111111114`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[146, 9]}, {
      Rational[343, 9], Rational[146, 9]}}, {{37.22222222222222, 
     16.22222222222222}, {38.111111111111114`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[46, 3]}, {
      Rational[343, 9], Rational[46, 3]}}, {{37.22222222222222, 
     15.333333333333334`}, {38.111111111111114`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[130, 9]}, {
      Rational[343, 9], Rational[130, 9]}}, {{37.22222222222222, 
     14.444444444444445`}, {38.111111111111114`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[122, 9]}, {
      Rational[343, 9], Rational[122, 9]}}, {{37.22222222222222, 
     13.555555555555555`}, {38.111111111111114`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[38, 3]}, {
      Rational[343, 9], Rational[38, 3]}}, {{37.22222222222222, 
     12.666666666666666`}, {38.111111111111114`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[106, 9]}, {
      Rational[343, 9], Rational[106, 9]}}, {{37.22222222222222, 
     11.777777777777779`}, {38.111111111111114`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[98, 9]}, {
      Rational[343, 9], Rational[98, 9]}}, {{37.22222222222222, 
     10.88888888888889}, {38.111111111111114`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[335, 9], 10}, {Rational[343, 9], 10}}, {{
      37.22222222222222, 10}, {38.111111111111114`, 10}}]], 
   LineBox[NCache[{{Rational[343, 9], 18}, {39, 18}}, {{
      38.111111111111114`, 18}, {39, 18}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[154, 9]}, {
      39, Rational[154, 9]}}, {{38.111111111111114`, 17.11111111111111}, {
      39, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[146, 9]}, {
      39, Rational[146, 9]}}, {{38.111111111111114`, 16.22222222222222}, {
      39, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[46, 3]}, {
      39, Rational[46, 3]}}, {{38.111111111111114`, 15.333333333333334`}, {
      39, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[130, 9]}, {
      39, Rational[130, 9]}}, {{38.111111111111114`, 14.444444444444445`}, {
      39, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[122, 9]}, {
      39, Rational[122, 9]}}, {{38.111111111111114`, 13.555555555555555`}, {
      39, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[38, 3]}, {
      39, Rational[38, 3]}}, {{38.111111111111114`, 12.666666666666666`}, {
      39, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[106, 9]}, {
      39, Rational[106, 9]}}, {{38.111111111111114`, 11.777777777777779`}, {
      39, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[98, 9]}, {
      39, Rational[98, 9]}}, {{38.111111111111114`, 10.88888888888889}, {
      39, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[343, 9], 10}, {39, 10}}, {{
      38.111111111111114`, 10}, {39, 10}}]], 
   LineBox[NCache[{{31, 18}, {31, Rational[154, 9]}}, {{31, 18}, {
      31, 17.11111111111111}}]], 
   LineBox[NCache[{{31, Rational[154, 9]}, {31, Rational[146, 9]}}, {{
      31, 17.11111111111111}, {31, 16.22222222222222}}]], 
   LineBox[NCache[{{31, Rational[146, 9]}, {31, Rational[46, 3]}}, {{
      31, 16.22222222222222}, {31, 15.333333333333334`}}]], 
   LineBox[NCache[{{31, Rational[46, 3]}, {31, Rational[130, 9]}}, {{
      31, 15.333333333333334`}, {31, 14.444444444444445`}}]], 
   LineBox[NCache[{{31, Rational[130, 9]}, {31, Rational[122, 9]}}, {{
      31, 14.444444444444445`}, {31, 13.555555555555555`}}]], 
   LineBox[NCache[{{31, Rational[122, 9]}, {31, Rational[38, 3]}}, {{
      31, 13.555555555555555`}, {31, 12.666666666666666`}}]], 
   LineBox[NCache[{{31, Rational[38, 3]}, {31, Rational[106, 9]}}, {{
      31, 12.666666666666666`}, {31, 11.777777777777779`}}]], 
   LineBox[NCache[{{31, Rational[106, 9]}, {31, Rational[98, 9]}}, {{
      31, 11.777777777777779`}, {31, 10.88888888888889}}]], 
   LineBox[NCache[{{31, Rational[98, 9]}, {31, 10}}, {{
      31, 10.88888888888889}, {31, 10}}]], 
   LineBox[NCache[{{Rational[287, 9], 18}, {
      Rational[287, 9], Rational[154, 9]}}, {{31.88888888888889, 18}, {
      31.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[154, 9]}, {
      Rational[287, 9], Rational[146, 9]}}, {{31.88888888888889, 
     17.11111111111111}, {31.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[146, 9]}, {
      Rational[287, 9], Rational[46, 3]}}, {{31.88888888888889, 
     16.22222222222222}, {31.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[46, 3]}, {
      Rational[287, 9], Rational[130, 9]}}, {{31.88888888888889, 
     15.333333333333334`}, {31.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[130, 9]}, {
      Rational[287, 9], Rational[122, 9]}}, {{31.88888888888889, 
     14.444444444444445`}, {31.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[122, 9]}, {
      Rational[287, 9], Rational[38, 3]}}, {{31.88888888888889, 
     13.555555555555555`}, {31.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[38, 3]}, {
      Rational[287, 9], Rational[106, 9]}}, {{31.88888888888889, 
     12.666666666666666`}, {31.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[106, 9]}, {
      Rational[287, 9], Rational[98, 9]}}, {{31.88888888888889, 
     11.777777777777779`}, {31.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[287, 9], Rational[98, 9]}, {
      Rational[287, 9], 10}}, {{31.88888888888889, 10.88888888888889}, {
      31.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[295, 9], 18}, {
      Rational[295, 9], Rational[154, 9]}}, {{32.77777777777778, 18}, {
      32.77777777777778, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[154, 9]}, {
      Rational[295, 9], Rational[146, 9]}}, {{32.77777777777778, 
     17.11111111111111}, {32.77777777777778, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[146, 9]}, {
      Rational[295, 9], Rational[46, 3]}}, {{32.77777777777778, 
     16.22222222222222}, {32.77777777777778, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[46, 3]}, {
      Rational[295, 9], Rational[130, 9]}}, {{32.77777777777778, 
     15.333333333333334`}, {32.77777777777778, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[130, 9]}, {
      Rational[295, 9], Rational[122, 9]}}, {{32.77777777777778, 
     14.444444444444445`}, {32.77777777777778, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[122, 9]}, {
      Rational[295, 9], Rational[38, 3]}}, {{32.77777777777778, 
     13.555555555555555`}, {32.77777777777778, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[38, 3]}, {
      Rational[295, 9], Rational[106, 9]}}, {{32.77777777777778, 
     12.666666666666666`}, {32.77777777777778, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[106, 9]}, {
      Rational[295, 9], Rational[98, 9]}}, {{32.77777777777778, 
     11.777777777777779`}, {32.77777777777778, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[295, 9], Rational[98, 9]}, {
      Rational[295, 9], 10}}, {{32.77777777777778, 10.88888888888889}, {
      32.77777777777778, 10}}]], 
   LineBox[NCache[{{Rational[101, 3], 18}, {
      Rational[101, 3], Rational[154, 9]}}, {{33.666666666666664`, 18}, {
      33.666666666666664`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[154, 9]}, {
      Rational[101, 3], Rational[146, 9]}}, {{33.666666666666664`, 
     17.11111111111111}, {33.666666666666664`, 16.22222222222222}}]], 
   LineBox[
    NCache[{{Rational[101, 3], Rational[146, 9]}, {
      Rational[101, 3], Rational[46, 3]}}, {{33.666666666666664`, 
     16.22222222222222}, {33.666666666666664`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[46, 3]}, {
      Rational[101, 3], Rational[130, 9]}}, {{33.666666666666664`, 
     15.333333333333334`}, {33.666666666666664`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[130, 9]}, {
      Rational[101, 3], Rational[122, 9]}}, {{33.666666666666664`, 
     14.444444444444445`}, {33.666666666666664`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[122, 9]}, {
      Rational[101, 3], Rational[38, 3]}}, {{33.666666666666664`, 
     13.555555555555555`}, {33.666666666666664`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[38, 3]}, {
      Rational[101, 3], Rational[106, 9]}}, {{33.666666666666664`, 
     12.666666666666666`}, {33.666666666666664`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[106, 9]}, {
      Rational[101, 3], Rational[98, 9]}}, {{33.666666666666664`, 
     11.777777777777779`}, {33.666666666666664`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[101, 3], Rational[98, 9]}, {
      Rational[101, 3], 10}}, {{33.666666666666664`, 10.88888888888889}, {
      33.666666666666664`, 10}}]], 
   LineBox[NCache[{{Rational[311, 9], 18}, {
      Rational[311, 9], Rational[154, 9]}}, {{34.55555555555556, 18}, {
      34.55555555555556, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[154, 9]}, {
      Rational[311, 9], Rational[146, 9]}}, {{34.55555555555556, 
     17.11111111111111}, {34.55555555555556, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[146, 9]}, {
      Rational[311, 9], Rational[46, 3]}}, {{34.55555555555556, 
     16.22222222222222}, {34.55555555555556, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[46, 3]}, {
      Rational[311, 9], Rational[130, 9]}}, {{34.55555555555556, 
     15.333333333333334`}, {34.55555555555556, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[130, 9]}, {
      Rational[311, 9], Rational[122, 9]}}, {{34.55555555555556, 
     14.444444444444445`}, {34.55555555555556, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[122, 9]}, {
      Rational[311, 9], Rational[38, 3]}}, {{34.55555555555556, 
     13.555555555555555`}, {34.55555555555556, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[38, 3]}, {
      Rational[311, 9], Rational[106, 9]}}, {{34.55555555555556, 
     12.666666666666666`}, {34.55555555555556, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[106, 9]}, {
      Rational[311, 9], Rational[98, 9]}}, {{34.55555555555556, 
     11.777777777777779`}, {34.55555555555556, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[311, 9], Rational[98, 9]}, {
      Rational[311, 9], 10}}, {{34.55555555555556, 10.88888888888889}, {
      34.55555555555556, 10}}]], 
   LineBox[NCache[{{Rational[319, 9], 18}, {
      Rational[319, 9], Rational[154, 9]}}, {{35.44444444444444, 18}, {
      35.44444444444444, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[154, 9]}, {
      Rational[319, 9], Rational[146, 9]}}, {{35.44444444444444, 
     17.11111111111111}, {35.44444444444444, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[146, 9]}, {
      Rational[319, 9], Rational[46, 3]}}, {{35.44444444444444, 
     16.22222222222222}, {35.44444444444444, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[46, 3]}, {
      Rational[319, 9], Rational[130, 9]}}, {{35.44444444444444, 
     15.333333333333334`}, {35.44444444444444, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[130, 9]}, {
      Rational[319, 9], Rational[122, 9]}}, {{35.44444444444444, 
     14.444444444444445`}, {35.44444444444444, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[122, 9]}, {
      Rational[319, 9], Rational[38, 3]}}, {{35.44444444444444, 
     13.555555555555555`}, {35.44444444444444, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[38, 3]}, {
      Rational[319, 9], Rational[106, 9]}}, {{35.44444444444444, 
     12.666666666666666`}, {35.44444444444444, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[106, 9]}, {
      Rational[319, 9], Rational[98, 9]}}, {{35.44444444444444, 
     11.777777777777779`}, {35.44444444444444, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[319, 9], Rational[98, 9]}, {
      Rational[319, 9], 10}}, {{35.44444444444444, 10.88888888888889}, {
      35.44444444444444, 10}}]], 
   LineBox[NCache[{{Rational[109, 3], 18}, {
      Rational[109, 3], Rational[154, 9]}}, {{36.333333333333336`, 18}, {
      36.333333333333336`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[154, 9]}, {
      Rational[109, 3], Rational[146, 9]}}, {{36.333333333333336`, 
     17.11111111111111}, {36.333333333333336`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[146, 9]}, {
      Rational[109, 3], Rational[46, 3]}}, {{36.333333333333336`, 
     16.22222222222222}, {36.333333333333336`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[46, 3]}, {
      Rational[109, 3], Rational[130, 9]}}, {{36.333333333333336`, 
     15.333333333333334`}, {36.333333333333336`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[130, 9]}, {
      Rational[109, 3], Rational[122, 9]}}, {{36.333333333333336`, 
     14.444444444444445`}, {36.333333333333336`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[122, 9]}, {
      Rational[109, 3], Rational[38, 3]}}, {{36.333333333333336`, 
     13.555555555555555`}, {36.333333333333336`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[38, 3]}, {
      Rational[109, 3], Rational[106, 9]}}, {{36.333333333333336`, 
     12.666666666666666`}, {36.333333333333336`, 11.777777777777779`}}]], 
   LineBox[
    NCache[{{Rational[109, 3], Rational[106, 9]}, {
      Rational[109, 3], Rational[98, 9]}}, {{36.333333333333336`, 
     11.777777777777779`}, {36.333333333333336`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[109, 3], Rational[98, 9]}, {
      Rational[109, 3], 10}}, {{36.333333333333336`, 10.88888888888889}, {
      36.333333333333336`, 10}}]], 
   LineBox[NCache[{{Rational[335, 9], 18}, {
      Rational[335, 9], Rational[154, 9]}}, {{37.22222222222222, 18}, {
      37.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[154, 9]}, {
      Rational[335, 9], Rational[146, 9]}}, {{37.22222222222222, 
     17.11111111111111}, {37.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[146, 9]}, {
      Rational[335, 9], Rational[46, 3]}}, {{37.22222222222222, 
     16.22222222222222}, {37.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[46, 3]}, {
      Rational[335, 9], Rational[130, 9]}}, {{37.22222222222222, 
     15.333333333333334`}, {37.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[130, 9]}, {
      Rational[335, 9], Rational[122, 9]}}, {{37.22222222222222, 
     14.444444444444445`}, {37.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[122, 9]}, {
      Rational[335, 9], Rational[38, 3]}}, {{37.22222222222222, 
     13.555555555555555`}, {37.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[38, 3]}, {
      Rational[335, 9], Rational[106, 9]}}, {{37.22222222222222, 
     12.666666666666666`}, {37.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[106, 9]}, {
      Rational[335, 9], Rational[98, 9]}}, {{37.22222222222222, 
     11.777777777777779`}, {37.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[335, 9], Rational[98, 9]}, {
      Rational[335, 9], 10}}, {{37.22222222222222, 10.88888888888889}, {
      37.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[343, 9], 18}, {
      Rational[343, 9], Rational[154, 9]}}, {{38.111111111111114`, 18}, {
      38.111111111111114`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[154, 9]}, {
      Rational[343, 9], Rational[146, 9]}}, {{38.111111111111114`, 
     17.11111111111111}, {38.111111111111114`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[146, 9]}, {
      Rational[343, 9], Rational[46, 3]}}, {{38.111111111111114`, 
     16.22222222222222}, {38.111111111111114`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[46, 3]}, {
      Rational[343, 9], Rational[130, 9]}}, {{38.111111111111114`, 
     15.333333333333334`}, {38.111111111111114`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[130, 9]}, {
      Rational[343, 9], Rational[122, 9]}}, {{38.111111111111114`, 
     14.444444444444445`}, {38.111111111111114`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[122, 9]}, {
      Rational[343, 9], Rational[38, 3]}}, {{38.111111111111114`, 
     13.555555555555555`}, {38.111111111111114`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[38, 3]}, {
      Rational[343, 9], Rational[106, 9]}}, {{38.111111111111114`, 
     12.666666666666666`}, {38.111111111111114`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[106, 9]}, {
      Rational[343, 9], Rational[98, 9]}}, {{38.111111111111114`, 
     11.777777777777779`}, {38.111111111111114`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[343, 9], Rational[98, 9]}, {
      Rational[343, 9], 10}}, {{38.111111111111114`, 10.88888888888889}, {
      38.111111111111114`, 10}}]], 
   LineBox[NCache[{{39, 18}, {39, Rational[154, 9]}}, {{39, 18}, {
      39, 17.11111111111111}}]], 
   LineBox[NCache[{{39, Rational[154, 9]}, {39, Rational[146, 9]}}, {{
      39, 17.11111111111111}, {39, 16.22222222222222}}]], 
   LineBox[NCache[{{39, Rational[146, 9]}, {39, Rational[46, 3]}}, {{
      39, 16.22222222222222}, {39, 15.333333333333334`}}]], 
   LineBox[NCache[{{39, Rational[46, 3]}, {39, Rational[130, 9]}}, {{
      39, 15.333333333333334`}, {39, 14.444444444444445`}}]], 
   LineBox[NCache[{{39, Rational[130, 9]}, {39, Rational[122, 9]}}, {{
      39, 14.444444444444445`}, {39, 13.555555555555555`}}]], 
   LineBox[NCache[{{39, Rational[122, 9]}, {39, Rational[38, 3]}}, {{
      39, 13.555555555555555`}, {39, 12.666666666666666`}}]], 
   LineBox[NCache[{{39, Rational[38, 3]}, {39, Rational[106, 9]}}, {{
      39, 12.666666666666666`}, {39, 11.777777777777779`}}]], 
   LineBox[NCache[{{39, Rational[106, 9]}, {39, Rational[98, 9]}}, {{
      39, 11.777777777777779`}, {39, 10.88888888888889}}]], 
   LineBox[NCache[{{39, Rational[98, 9]}, {39, 10}}, {{
      39, 10.88888888888889}, {39, 10}}]], 
   LineBox[NCache[{{11, 8}, {Rational[107, 9], 8}}, {{11, 8}, {
      11.88888888888889, 8}}]], 
   LineBox[NCache[{{11, Rational[64, 9]}, {
      Rational[107, 9], Rational[64, 9]}}, {{11, 7.111111111111111}, {
      11.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{11, Rational[56, 9]}, {
      Rational[107, 9], Rational[56, 9]}}, {{11, 6.222222222222222}, {
      11.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{11, Rational[16, 3]}, {
      Rational[107, 9], Rational[16, 3]}}, {{11, 5.333333333333333}, {
      11.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{11, Rational[40, 9]}, {
      Rational[107, 9], Rational[40, 9]}}, {{11, 4.444444444444445}, {
      11.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{11, Rational[32, 9]}, {
      Rational[107, 9], Rational[32, 9]}}, {{11, 3.5555555555555554`}, {
      11.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{11, Rational[8, 3]}, {
      Rational[107, 9], Rational[8, 3]}}, {{11, 2.6666666666666665`}, {
      11.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{11, Rational[16, 9]}, {
      Rational[107, 9], Rational[16, 9]}}, {{11, 1.7777777777777777`}, {
      11.88888888888889, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{11, Rational[8, 9]}, {Rational[107, 9], Rational[8, 9]}}, {{
      11, 0.8888888888888888}, {11.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{11, 0}, {Rational[107, 9], 0}}, {{11, 0}, {
      11.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[107, 9], 8}, {Rational[115, 9], 8}}, {{
      11.88888888888889, 8}, {12.777777777777779`, 8}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[64, 9]}, {
      Rational[115, 9], Rational[64, 9]}}, {{11.88888888888889, 
     7.111111111111111}, {12.777777777777779`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[56, 9]}, {
      Rational[115, 9], Rational[56, 9]}}, {{11.88888888888889, 
     6.222222222222222}, {12.777777777777779`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 3]}, {
      Rational[115, 9], Rational[16, 3]}}, {{11.88888888888889, 
     5.333333333333333}, {12.777777777777779`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[40, 9]}, {
      Rational[115, 9], Rational[40, 9]}}, {{11.88888888888889, 
     4.444444444444445}, {12.777777777777779`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[32, 9]}, {
      Rational[115, 9], Rational[32, 9]}}, {{11.88888888888889, 
     3.5555555555555554`}, {12.777777777777779`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 3]}, {
      Rational[115, 9], Rational[8, 3]}}, {{11.88888888888889, 
     2.6666666666666665`}, {12.777777777777779`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 9]}, {
      Rational[115, 9], Rational[16, 9]}}, {{11.88888888888889, 
     1.7777777777777777`}, {12.777777777777779`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 9]}, {
      Rational[115, 9], Rational[8, 9]}}, {{11.88888888888889, 
     0.8888888888888888}, {12.777777777777779`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[107, 9], 0}, {Rational[115, 9], 0}}, {{
      11.88888888888889, 0}, {12.777777777777779`, 0}}]], 
   LineBox[
    NCache[{{Rational[115, 9], 8}, {Rational[41, 3], 8}}, {{
      12.777777777777779`, 8}, {13.666666666666666`, 8}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[64, 9]}, {
      Rational[41, 3], Rational[64, 9]}}, {{12.777777777777779`, 
     7.111111111111111}, {13.666666666666666`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[56, 9]}, {
      Rational[41, 3], Rational[56, 9]}}, {{12.777777777777779`, 
     6.222222222222222}, {13.666666666666666`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 3]}, {
      Rational[41, 3], Rational[16, 3]}}, {{12.777777777777779`, 
     5.333333333333333}, {13.666666666666666`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[40, 9]}, {
      Rational[41, 3], Rational[40, 9]}}, {{12.777777777777779`, 
     4.444444444444445}, {13.666666666666666`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[32, 9]}, {
      Rational[41, 3], Rational[32, 9]}}, {{12.777777777777779`, 
     3.5555555555555554`}, {13.666666666666666`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 3]}, {
      Rational[41, 3], Rational[8, 3]}}, {{12.777777777777779`, 
     2.6666666666666665`}, {13.666666666666666`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 9]}, {
      Rational[41, 3], Rational[16, 9]}}, {{12.777777777777779`, 
     1.7777777777777777`}, {13.666666666666666`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 9]}, {
      Rational[41, 3], Rational[8, 9]}}, {{12.777777777777779`, 
     0.8888888888888888}, {13.666666666666666`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[115, 9], 0}, {Rational[41, 3], 0}}, {{
      12.777777777777779`, 0}, {13.666666666666666`, 0}}]], 
   LineBox[NCache[{{Rational[41, 3], 8}, {Rational[131, 9], 8}}, {{
      13.666666666666666`, 8}, {14.555555555555555`, 8}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[64, 9]}, {
      Rational[131, 9], Rational[64, 9]}}, {{13.666666666666666`, 
     7.111111111111111}, {14.555555555555555`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[56, 9]}, {
      Rational[131, 9], Rational[56, 9]}}, {{13.666666666666666`, 
     6.222222222222222}, {14.555555555555555`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 3]}, {
      Rational[131, 9], Rational[16, 3]}}, {{13.666666666666666`, 
     5.333333333333333}, {14.555555555555555`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[40, 9]}, {
      Rational[131, 9], Rational[40, 9]}}, {{13.666666666666666`, 
     4.444444444444445}, {14.555555555555555`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[32, 9]}, {
      Rational[131, 9], Rational[32, 9]}}, {{13.666666666666666`, 
     3.5555555555555554`}, {14.555555555555555`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 3]}, {
      Rational[131, 9], Rational[8, 3]}}, {{13.666666666666666`, 
     2.6666666666666665`}, {14.555555555555555`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 9]}, {
      Rational[131, 9], Rational[16, 9]}}, {{13.666666666666666`, 
     1.7777777777777777`}, {14.555555555555555`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 9]}, {
      Rational[131, 9], Rational[8, 9]}}, {{13.666666666666666`, 
     0.8888888888888888}, {14.555555555555555`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[41, 3], 0}, {Rational[131, 9], 0}}, {{
      13.666666666666666`, 0}, {14.555555555555555`, 0}}]], 
   LineBox[NCache[{{Rational[131, 9], 8}, {Rational[139, 9], 8}}, {{
      14.555555555555555`, 8}, {15.444444444444445`, 8}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[64, 9]}, {
      Rational[139, 9], Rational[64, 9]}}, {{14.555555555555555`, 
     7.111111111111111}, {15.444444444444445`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[56, 9]}, {
      Rational[139, 9], Rational[56, 9]}}, {{14.555555555555555`, 
     6.222222222222222}, {15.444444444444445`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 3]}, {
      Rational[139, 9], Rational[16, 3]}}, {{14.555555555555555`, 
     5.333333333333333}, {15.444444444444445`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[40, 9]}, {
      Rational[139, 9], Rational[40, 9]}}, {{14.555555555555555`, 
     4.444444444444445}, {15.444444444444445`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[32, 9]}, {
      Rational[139, 9], Rational[32, 9]}}, {{14.555555555555555`, 
     3.5555555555555554`}, {15.444444444444445`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 3]}, {
      Rational[139, 9], Rational[8, 3]}}, {{14.555555555555555`, 
     2.6666666666666665`}, {15.444444444444445`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 9]}, {
      Rational[139, 9], Rational[16, 9]}}, {{14.555555555555555`, 
     1.7777777777777777`}, {15.444444444444445`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 9]}, {
      Rational[139, 9], Rational[8, 9]}}, {{14.555555555555555`, 
     0.8888888888888888}, {15.444444444444445`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[131, 9], 0}, {Rational[139, 9], 0}}, {{
      14.555555555555555`, 0}, {15.444444444444445`, 0}}]], 
   LineBox[NCache[{{Rational[139, 9], 8}, {Rational[49, 3], 8}}, {{
      15.444444444444445`, 8}, {16.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[64, 9]}, {
      Rational[49, 3], Rational[64, 9]}}, {{15.444444444444445`, 
     7.111111111111111}, {16.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[56, 9]}, {
      Rational[49, 3], Rational[56, 9]}}, {{15.444444444444445`, 
     6.222222222222222}, {16.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 3]}, {
      Rational[49, 3], Rational[16, 3]}}, {{15.444444444444445`, 
     5.333333333333333}, {16.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[40, 9]}, {
      Rational[49, 3], Rational[40, 9]}}, {{15.444444444444445`, 
     4.444444444444445}, {16.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[32, 9]}, {
      Rational[49, 3], Rational[32, 9]}}, {{15.444444444444445`, 
     3.5555555555555554`}, {16.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 3]}, {
      Rational[49, 3], Rational[8, 3]}}, {{15.444444444444445`, 
     2.6666666666666665`}, {16.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 9]}, {
      Rational[49, 3], Rational[16, 9]}}, {{15.444444444444445`, 
     1.7777777777777777`}, {16.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 9]}, {
      Rational[49, 3], Rational[8, 9]}}, {{15.444444444444445`, 
     0.8888888888888888}, {16.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[139, 9], 0}, {Rational[49, 3], 0}}, {{
      15.444444444444445`, 0}, {16.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[49, 3], 8}, {Rational[155, 9], 8}}, {{
      16.333333333333332`, 8}, {17.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[64, 9]}, {
      Rational[155, 9], Rational[64, 9]}}, {{16.333333333333332`, 
     7.111111111111111}, {17.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[56, 9]}, {
      Rational[155, 9], Rational[56, 9]}}, {{16.333333333333332`, 
     6.222222222222222}, {17.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 3]}, {
      Rational[155, 9], Rational[16, 3]}}, {{16.333333333333332`, 
     5.333333333333333}, {17.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[40, 9]}, {
      Rational[155, 9], Rational[40, 9]}}, {{16.333333333333332`, 
     4.444444444444445}, {17.22222222222222, 4.444444444444445}}]], 
   LineBox[
    NCache[{{Rational[49, 3], Rational[32, 9]}, {
      Rational[155, 9], Rational[32, 9]}}, {{16.333333333333332`, 
     3.5555555555555554`}, {17.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 3]}, {
      Rational[155, 9], Rational[8, 3]}}, {{16.333333333333332`, 
     2.6666666666666665`}, {17.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 9]}, {
      Rational[155, 9], Rational[16, 9]}}, {{16.333333333333332`, 
     1.7777777777777777`}, {17.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 9]}, {
      Rational[155, 9], Rational[8, 9]}}, {{16.333333333333332`, 
     0.8888888888888888}, {17.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[49, 3], 0}, {Rational[155, 9], 0}}, {{
      16.333333333333332`, 0}, {17.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[155, 9], 8}, {Rational[163, 9], 8}}, {{
      17.22222222222222, 8}, {18.11111111111111, 8}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[64, 9]}, {
      Rational[163, 9], Rational[64, 9]}}, {{17.22222222222222, 
     7.111111111111111}, {18.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[56, 9]}, {
      Rational[163, 9], Rational[56, 9]}}, {{17.22222222222222, 
     6.222222222222222}, {18.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 3]}, {
      Rational[163, 9], Rational[16, 3]}}, {{17.22222222222222, 
     5.333333333333333}, {18.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[40, 9]}, {
      Rational[163, 9], Rational[40, 9]}}, {{17.22222222222222, 
     4.444444444444445}, {18.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[32, 9]}, {
      Rational[163, 9], Rational[32, 9]}}, {{17.22222222222222, 
     3.5555555555555554`}, {18.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 3]}, {
      Rational[163, 9], Rational[8, 3]}}, {{17.22222222222222, 
     2.6666666666666665`}, {18.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 9]}, {
      Rational[163, 9], Rational[16, 9]}}, {{17.22222222222222, 
     1.7777777777777777`}, {18.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 9]}, {
      Rational[163, 9], Rational[8, 9]}}, {{17.22222222222222, 
     0.8888888888888888}, {18.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[155, 9], 0}, {Rational[163, 9], 0}}, {{
      17.22222222222222, 0}, {18.11111111111111, 0}}]], 
   LineBox[NCache[{{Rational[163, 9], 8}, {19, 8}}, {{18.11111111111111, 8}, {
      19, 8}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[64, 9]}, {
      19, Rational[64, 9]}}, {{18.11111111111111, 7.111111111111111}, {
      19, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[56, 9]}, {
      19, Rational[56, 9]}}, {{18.11111111111111, 6.222222222222222}, {
      19, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 3]}, {
      19, Rational[16, 3]}}, {{18.11111111111111, 5.333333333333333}, {
      19, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[40, 9]}, {
      19, Rational[40, 9]}}, {{18.11111111111111, 4.444444444444445}, {
      19, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[32, 9]}, {
      19, Rational[32, 9]}}, {{18.11111111111111, 3.5555555555555554`}, {
      19, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 3]}, {
      19, Rational[8, 3]}}, {{18.11111111111111, 2.6666666666666665`}, {
      19, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 9]}, {
      19, Rational[16, 9]}}, {{18.11111111111111, 1.7777777777777777`}, {
      19, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 9]}, {
      19, Rational[8, 9]}}, {{18.11111111111111, 0.8888888888888888}, {
      19, 0.8888888888888888}}]], 
   LineBox[
    NCache[{{Rational[163, 9], 0}, {19, 0}}, {{18.11111111111111, 0}, {19, 
      0}}]], LineBox[
    NCache[{{11, 8}, {11, Rational[64, 9]}}, {{11, 8}, {
      11, 7.111111111111111}}]], 
   LineBox[NCache[{{11, Rational[64, 9]}, {11, Rational[56, 9]}}, {{
      11, 7.111111111111111}, {11, 6.222222222222222}}]], 
   LineBox[NCache[{{11, Rational[56, 9]}, {11, Rational[16, 3]}}, {{
      11, 6.222222222222222}, {11, 5.333333333333333}}]], 
   LineBox[NCache[{{11, Rational[16, 3]}, {11, Rational[40, 9]}}, {{
      11, 5.333333333333333}, {11, 4.444444444444445}}]], 
   LineBox[NCache[{{11, Rational[40, 9]}, {11, Rational[32, 9]}}, {{
      11, 4.444444444444445}, {11, 3.5555555555555554`}}]], 
   LineBox[NCache[{{11, Rational[32, 9]}, {11, Rational[8, 3]}}, {{
      11, 3.5555555555555554`}, {11, 2.6666666666666665`}}]], 
   LineBox[NCache[{{11, Rational[8, 3]}, {11, Rational[16, 9]}}, {{
      11, 2.6666666666666665`}, {11, 1.7777777777777777`}}]], 
   LineBox[NCache[{{11, Rational[16, 9]}, {11, Rational[8, 9]}}, {{
      11, 1.7777777777777777`}, {11, 0.8888888888888888}}]], 
   LineBox[NCache[{{11, Rational[8, 9]}, {11, 0}}, {{
      11, 0.8888888888888888}, {11, 0}}]], 
   LineBox[NCache[{{Rational[107, 9], 8}, {
      Rational[107, 9], Rational[64, 9]}}, {{11.88888888888889, 8}, {
      11.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[64, 9]}, {
      Rational[107, 9], Rational[56, 9]}}, {{11.88888888888889, 
     7.111111111111111}, {11.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[56, 9]}, {
      Rational[107, 9], Rational[16, 3]}}, {{11.88888888888889, 
     6.222222222222222}, {11.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 3]}, {
      Rational[107, 9], Rational[40, 9]}}, {{11.88888888888889, 
     5.333333333333333}, {11.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[40, 9]}, {
      Rational[107, 9], Rational[32, 9]}}, {{11.88888888888889, 
     4.444444444444445}, {11.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[32, 9]}, {
      Rational[107, 9], Rational[8, 3]}}, {{11.88888888888889, 
     3.5555555555555554`}, {11.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 3]}, {
      Rational[107, 9], Rational[16, 9]}}, {{11.88888888888889, 
     2.6666666666666665`}, {11.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[16, 9]}, {
      Rational[107, 9], Rational[8, 9]}}, {{11.88888888888889, 
     1.7777777777777777`}, {11.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[8, 9]}, {
      Rational[107, 9], 0}}, {{11.88888888888889, 0.8888888888888888}, {
      11.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[115, 9], 8}, {
      Rational[115, 9], Rational[64, 9]}}, {{12.777777777777779`, 8}, {
      12.777777777777779`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[64, 9]}, {
      Rational[115, 9], Rational[56, 9]}}, {{12.777777777777779`, 
     7.111111111111111}, {12.777777777777779`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[56, 9]}, {
      Rational[115, 9], Rational[16, 3]}}, {{12.777777777777779`, 
     6.222222222222222}, {12.777777777777779`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 3]}, {
      Rational[115, 9], Rational[40, 9]}}, {{12.777777777777779`, 
     5.333333333333333}, {12.777777777777779`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[40, 9]}, {
      Rational[115, 9], Rational[32, 9]}}, {{12.777777777777779`, 
     4.444444444444445}, {12.777777777777779`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[32, 9]}, {
      Rational[115, 9], Rational[8, 3]}}, {{12.777777777777779`, 
     3.5555555555555554`}, {12.777777777777779`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 3]}, {
      Rational[115, 9], Rational[16, 9]}}, {{12.777777777777779`, 
     2.6666666666666665`}, {12.777777777777779`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[16, 9]}, {
      Rational[115, 9], Rational[8, 9]}}, {{12.777777777777779`, 
     1.7777777777777777`}, {12.777777777777779`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[8, 9]}, {
      Rational[115, 9], 0}}, {{12.777777777777779`, 0.8888888888888888}, {
      12.777777777777779`, 0}}]], 
   LineBox[NCache[{{Rational[41, 3], 8}, {
      Rational[41, 3], Rational[64, 9]}}, {{13.666666666666666`, 8}, {
      13.666666666666666`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[64, 9]}, {
      Rational[41, 3], Rational[56, 9]}}, {{13.666666666666666`, 
     7.111111111111111}, {13.666666666666666`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[56, 9]}, {
      Rational[41, 3], Rational[16, 3]}}, {{13.666666666666666`, 
     6.222222222222222}, {13.666666666666666`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 3]}, {
      Rational[41, 3], Rational[40, 9]}}, {{13.666666666666666`, 
     5.333333333333333}, {13.666666666666666`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[40, 9]}, {
      Rational[41, 3], Rational[32, 9]}}, {{13.666666666666666`, 
     4.444444444444445}, {13.666666666666666`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[32, 9]}, {
      Rational[41, 3], Rational[8, 3]}}, {{13.666666666666666`, 
     3.5555555555555554`}, {13.666666666666666`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 3]}, {
      Rational[41, 3], Rational[16, 9]}}, {{13.666666666666666`, 
     2.6666666666666665`}, {13.666666666666666`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[16, 9]}, {
      Rational[41, 3], Rational[8, 9]}}, {{13.666666666666666`, 
     1.7777777777777777`}, {13.666666666666666`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[8, 9]}, {
      Rational[41, 3], 0}}, {{13.666666666666666`, 0.8888888888888888}, {
      13.666666666666666`, 0}}]], 
   LineBox[NCache[{{Rational[131, 9], 8}, {
      Rational[131, 9], Rational[64, 9]}}, {{14.555555555555555`, 8}, {
      14.555555555555555`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[64, 9]}, {
      Rational[131, 9], Rational[56, 9]}}, {{14.555555555555555`, 
     7.111111111111111}, {14.555555555555555`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[56, 9]}, {
      Rational[131, 9], Rational[16, 3]}}, {{14.555555555555555`, 
     6.222222222222222}, {14.555555555555555`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 3]}, {
      Rational[131, 9], Rational[40, 9]}}, {{14.555555555555555`, 
     5.333333333333333}, {14.555555555555555`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[40, 9]}, {
      Rational[131, 9], Rational[32, 9]}}, {{14.555555555555555`, 
     4.444444444444445}, {14.555555555555555`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[32, 9]}, {
      Rational[131, 9], Rational[8, 3]}}, {{14.555555555555555`, 
     3.5555555555555554`}, {14.555555555555555`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 3]}, {
      Rational[131, 9], Rational[16, 9]}}, {{14.555555555555555`, 
     2.6666666666666665`}, {14.555555555555555`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[16, 9]}, {
      Rational[131, 9], Rational[8, 9]}}, {{14.555555555555555`, 
     1.7777777777777777`}, {14.555555555555555`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[8, 9]}, {
      Rational[131, 9], 0}}, {{14.555555555555555`, 0.8888888888888888}, {
      14.555555555555555`, 0}}]], 
   LineBox[NCache[{{Rational[139, 9], 8}, {
      Rational[139, 9], Rational[64, 9]}}, {{15.444444444444445`, 8}, {
      15.444444444444445`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[64, 9]}, {
      Rational[139, 9], Rational[56, 9]}}, {{15.444444444444445`, 
     7.111111111111111}, {15.444444444444445`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[56, 9]}, {
      Rational[139, 9], Rational[16, 3]}}, {{15.444444444444445`, 
     6.222222222222222}, {15.444444444444445`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 3]}, {
      Rational[139, 9], Rational[40, 9]}}, {{15.444444444444445`, 
     5.333333333333333}, {15.444444444444445`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[40, 9]}, {
      Rational[139, 9], Rational[32, 9]}}, {{15.444444444444445`, 
     4.444444444444445}, {15.444444444444445`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[32, 9]}, {
      Rational[139, 9], Rational[8, 3]}}, {{15.444444444444445`, 
     3.5555555555555554`}, {15.444444444444445`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 3]}, {
      Rational[139, 9], Rational[16, 9]}}, {{15.444444444444445`, 
     2.6666666666666665`}, {15.444444444444445`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[16, 9]}, {
      Rational[139, 9], Rational[8, 9]}}, {{15.444444444444445`, 
     1.7777777777777777`}, {15.444444444444445`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[8, 9]}, {
      Rational[139, 9], 0}}, {{15.444444444444445`, 0.8888888888888888}, {
      15.444444444444445`, 0}}]], 
   LineBox[NCache[{{Rational[49, 3], 8}, {
      Rational[49, 3], Rational[64, 9]}}, {{16.333333333333332`, 8}, {
      16.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[64, 9]}, {
      Rational[49, 3], Rational[56, 9]}}, {{16.333333333333332`, 
     7.111111111111111}, {16.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[56, 9]}, {
      Rational[49, 3], Rational[16, 3]}}, {{16.333333333333332`, 
     6.222222222222222}, {16.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 3]}, {
      Rational[49, 3], Rational[40, 9]}}, {{16.333333333333332`, 
     5.333333333333333}, {16.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[40, 9]}, {
      Rational[49, 3], Rational[32, 9]}}, {{16.333333333333332`, 
     4.444444444444445}, {16.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[32, 9]}, {
      Rational[49, 3], Rational[8, 3]}}, {{16.333333333333332`, 
     3.5555555555555554`}, {16.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 3]}, {
      Rational[49, 3], Rational[16, 9]}}, {{16.333333333333332`, 
     2.6666666666666665`}, {16.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[16, 9]}, {
      Rational[49, 3], Rational[8, 9]}}, {{16.333333333333332`, 
     1.7777777777777777`}, {16.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[8, 9]}, {
      Rational[49, 3], 0}}, {{16.333333333333332`, 0.8888888888888888}, {
      16.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[155, 9], 8}, {
      Rational[155, 9], Rational[64, 9]}}, {{17.22222222222222, 8}, {
      17.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[64, 9]}, {
      Rational[155, 9], Rational[56, 9]}}, {{17.22222222222222, 
     7.111111111111111}, {17.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[56, 9]}, {
      Rational[155, 9], Rational[16, 3]}}, {{17.22222222222222, 
     6.222222222222222}, {17.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 3]}, {
      Rational[155, 9], Rational[40, 9]}}, {{17.22222222222222, 
     5.333333333333333}, {17.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[40, 9]}, {
      Rational[155, 9], Rational[32, 9]}}, {{17.22222222222222, 
     4.444444444444445}, {17.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[32, 9]}, {
      Rational[155, 9], Rational[8, 3]}}, {{17.22222222222222, 
     3.5555555555555554`}, {17.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 3]}, {
      Rational[155, 9], Rational[16, 9]}}, {{17.22222222222222, 
     2.6666666666666665`}, {17.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[16, 9]}, {
      Rational[155, 9], Rational[8, 9]}}, {{17.22222222222222, 
     1.7777777777777777`}, {17.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[8, 9]}, {
      Rational[155, 9], 0}}, {{17.22222222222222, 0.8888888888888888}, {
      17.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[163, 9], 8}, {
      Rational[163, 9], Rational[64, 9]}}, {{18.11111111111111, 8}, {
      18.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[64, 9]}, {
      Rational[163, 9], Rational[56, 9]}}, {{18.11111111111111, 
     7.111111111111111}, {18.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[56, 9]}, {
      Rational[163, 9], Rational[16, 3]}}, {{18.11111111111111, 
     6.222222222222222}, {18.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 3]}, {
      Rational[163, 9], Rational[40, 9]}}, {{18.11111111111111, 
     5.333333333333333}, {18.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[40, 9]}, {
      Rational[163, 9], Rational[32, 9]}}, {{18.11111111111111, 
     4.444444444444445}, {18.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[32, 9]}, {
      Rational[163, 9], Rational[8, 3]}}, {{18.11111111111111, 
     3.5555555555555554`}, {18.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 3]}, {
      Rational[163, 9], Rational[16, 9]}}, {{18.11111111111111, 
     2.6666666666666665`}, {18.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[16, 9]}, {
      Rational[163, 9], Rational[8, 9]}}, {{18.11111111111111, 
     1.7777777777777777`}, {18.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[8, 9]}, {
      Rational[163, 9], 0}}, {{18.11111111111111, 0.8888888888888888}, {
      18.11111111111111, 0}}]], 
   LineBox[NCache[{{19, 8}, {19, Rational[64, 9]}}, {{19, 8}, {
      19, 7.111111111111111}}]], 
   LineBox[NCache[{{19, Rational[64, 9]}, {19, Rational[56, 9]}}, {{
      19, 7.111111111111111}, {19, 6.222222222222222}}]], 
   LineBox[NCache[{{19, Rational[56, 9]}, {19, Rational[16, 3]}}, {{
      19, 6.222222222222222}, {19, 5.333333333333333}}]], 
   LineBox[NCache[{{19, Rational[16, 3]}, {19, Rational[40, 9]}}, {{
      19, 5.333333333333333}, {19, 4.444444444444445}}]], 
   LineBox[NCache[{{19, Rational[40, 9]}, {19, Rational[32, 9]}}, {{
      19, 4.444444444444445}, {19, 3.5555555555555554`}}]], 
   LineBox[NCache[{{19, Rational[32, 9]}, {19, Rational[8, 3]}}, {{
      19, 3.5555555555555554`}, {19, 2.6666666666666665`}}]], 
   LineBox[NCache[{{19, Rational[8, 3]}, {19, Rational[16, 9]}}, {{
      19, 2.6666666666666665`}, {19, 1.7777777777777777`}}]], 
   LineBox[NCache[{{19, Rational[16, 9]}, {19, Rational[8, 9]}}, {{
      19, 1.7777777777777777`}, {19, 0.8888888888888888}}]], 
   LineBox[NCache[{{19, Rational[8, 9]}, {19, 0}}, {{
      19, 0.8888888888888888}, {19, 0}}]], LineBox[{{21, 8}, {23, 8}}], 
   LineBox[{{21, 6}, {23, 6}}], LineBox[{{21, 4}, {23, 4}}], 
   LineBox[{{21, 2}, {23, 2}}], LineBox[{{21, 0}, {23, 0}}], 
   LineBox[{{23, 8}, {25, 8}}], LineBox[{{23, 6}, {25, 6}}], 
   LineBox[{{23, 4}, {25, 4}}], LineBox[{{23, 2}, {25, 2}}], 
   LineBox[{{23, 0}, {25, 0}}], LineBox[{{25, 8}, {27, 8}}], 
   LineBox[{{25, 6}, {27, 6}}], LineBox[{{25, 4}, {27, 4}}], 
   LineBox[{{25, 2}, {27, 2}}], LineBox[{{25, 0}, {27, 0}}], 
   LineBox[{{27, 8}, {29, 8}}], LineBox[{{27, 6}, {29, 6}}], 
   LineBox[{{27, 4}, {29, 4}}], LineBox[{{27, 2}, {29, 2}}], 
   LineBox[{{27, 0}, {29, 0}}], LineBox[{{21, 8}, {21, 6}}], 
   LineBox[{{21, 6}, {21, 4}}], LineBox[{{21, 4}, {21, 2}}], 
   LineBox[{{21, 2}, {21, 0}}], LineBox[{{23, 8}, {23, 6}}], 
   LineBox[{{23, 6}, {23, 4}}], LineBox[{{23, 4}, {23, 2}}], 
   LineBox[{{23, 2}, {23, 0}}], LineBox[{{25, 8}, {25, 6}}], 
   LineBox[{{25, 6}, {25, 4}}], LineBox[{{25, 4}, {25, 2}}], 
   LineBox[{{25, 2}, {25, 0}}], LineBox[{{27, 8}, {27, 6}}], 
   LineBox[{{27, 6}, {27, 4}}], LineBox[{{27, 4}, {27, 2}}], 
   LineBox[{{27, 2}, {27, 0}}], LineBox[{{29, 8}, {29, 6}}], 
   LineBox[{{29, 6}, {29, 4}}], LineBox[{{29, 4}, {29, 2}}], 
   LineBox[{{29, 2}, {29, 0}}], LineBox[{{31, 8}, {35, 8}}], 
   LineBox[{{31, 4}, {35, 4}}], LineBox[{{31, 0}, {35, 0}}], 
   LineBox[{{35, 8}, {39, 8}}], LineBox[{{35, 4}, {39, 4}}], 
   LineBox[{{35, 0}, {39, 0}}], LineBox[{{31, 8}, {31, 4}}], 
   LineBox[{{31, 4}, {31, 0}}], LineBox[{{35, 8}, {35, 4}}], 
   LineBox[{{35, 4}, {35, 0}}], LineBox[{{39, 8}, {39, 4}}], 
   LineBox[{{39, 4}, {39, 0}}], LineBox[{{19, 18}, {21, 18}}], 
   LineBox[{{19, 18}, {21, 16}}], LineBox[{{19, 14}, {21, 14}}], 
   LineBox[{{19, 14}, {21, 12}}], LineBox[{{19, 10}, {21, 10}}], 
   LineBox[{{19, 8}, {21, 8}}], 
   LineBox[NCache[{{19, Rational[64, 9]}, {21, 8}}, {{
      19, 7.111111111111111}, {21, 8}}]], 
   LineBox[NCache[{{19, Rational[56, 9]}, {21, 6}}, {{
      19, 6.222222222222222}, {21, 6}}]], 
   LineBox[NCache[{{19, Rational[16, 3]}, {21, 6}}, {{
      19, 5.333333333333333}, {21, 6}}]], 
   LineBox[NCache[{{19, Rational[40, 9]}, {21, 4}}, {{
      19, 4.444444444444445}, {21, 4}}]], 
   LineBox[NCache[{{19, Rational[32, 9]}, {21, 4}}, {{
      19, 3.5555555555555554`}, {21, 4}}]], 
   LineBox[NCache[{{19, Rational[8, 3]}, {21, 2}}, {{
      19, 2.6666666666666665`}, {21, 2}}]], 
   LineBox[NCache[{{19, Rational[16, 9]}, {21, 2}}, {{
      19, 1.7777777777777777`}, {21, 2}}]], 
   LineBox[NCache[{{19, Rational[8, 9]}, {21, 0}}, {{
      19, 0.8888888888888888}, {21, 0}}]], LineBox[{{19, 0}, {21, 0}}], 
   LineBox[{{29, 18}, {31, 18}}], 
   LineBox[NCache[{{29, 18}, {31, Rational[154, 9]}}, {{29, 18}, {
      31, 17.11111111111111}}]], 
   LineBox[NCache[{{29, 16}, {31, Rational[146, 9]}}, {{29, 16}, {
      31, 16.22222222222222}}]], 
   LineBox[NCache[{{29, 16}, {31, Rational[46, 3]}}, {{29, 16}, {
      31, 15.333333333333334`}}]], 
   LineBox[NCache[{{29, 14}, {31, Rational[130, 9]}}, {{29, 14}, {
      31, 14.444444444444445`}}]], 
   LineBox[NCache[{{29, 14}, {31, Rational[122, 9]}}, {{29, 14}, {
      31, 13.555555555555555`}}]], 
   LineBox[NCache[{{29, 12}, {31, Rational[38, 3]}}, {{29, 12}, {
      31, 12.666666666666666`}}]], 
   LineBox[NCache[{{29, 12}, {31, Rational[106, 9]}}, {{29, 12}, {
      31, 11.777777777777779`}}]], 
   LineBox[NCache[{{29, 10}, {31, Rational[98, 9]}}, {{29, 10}, {
      31, 10.88888888888889}}]], LineBox[{{29, 10}, {31, 10}}], 
   LineBox[{{29, 8}, {31, 8}}], LineBox[{{29, 6}, {31, 8}}], 
   LineBox[{{29, 4}, {31, 4}}], LineBox[{{29, 2}, {31, 4}}], 
   LineBox[{{29, 0}, {31, 0}}], LineBox[{{11, 10}, {11, 8}}], 
   LineBox[NCache[{{11, 10}, {Rational[107, 9], 8}}, {{11, 10}, {
      11.88888888888889, 8}}]], 
   LineBox[NCache[{{11, 10}, {Rational[115, 9], 8}}, {{11, 10}, {
      12.777777777777779`, 8}}]], 
   LineBox[NCache[{{11, 10}, {Rational[41, 3], 8}}, {{11, 10}, {
      13.666666666666666`, 8}}]], 
   LineBox[NCache[{{15, 10}, {Rational[131, 9], 8}}, {{15, 10}, {
      14.555555555555555`, 8}}]], 
   LineBox[NCache[{{15, 10}, {Rational[139, 9], 8}}, {{15, 10}, {
      15.444444444444445`, 8}}]], 
   LineBox[NCache[{{15, 10}, {Rational[49, 3], 8}}, {{15, 10}, {
      16.333333333333332`, 8}}]], 
   LineBox[NCache[{{19, 10}, {Rational[155, 9], 8}}, {{19, 10}, {
      17.22222222222222, 8}}]], 
   LineBox[NCache[{{19, 10}, {Rational[163, 9], 8}}, {{19, 10}, {
      18.11111111111111, 8}}]], LineBox[{{19, 10}, {19, 8}}], 
   LineBox[{{21, 10}, {21, 8}}], LineBox[{{23, 10}, {23, 8}}], 
   LineBox[{{25, 10}, {25, 8}}], LineBox[{{27, 10}, {27, 8}}], 
   LineBox[{{29, 10}, {29, 8}}], LineBox[{{31, 10}, {31, 8}}], 
   LineBox[NCache[{{Rational[287, 9], 10}, {31, 8}}, {{
      31.88888888888889, 10}, {31, 8}}]], 
   LineBox[
    NCache[{{Rational[295, 9], 10}, {31, 8}}, {{32.77777777777778, 10}, {31, 
      8}}]], LineBox[
    NCache[{{Rational[101, 3], 10}, {31, 8}}, {{33.666666666666664`, 10}, {31,
       8}}]], LineBox[
    NCache[{{Rational[311, 9], 10}, {35, 8}}, {{34.55555555555556, 10}, {35, 
      8}}]], LineBox[
    NCache[{{Rational[319, 9], 10}, {35, 8}}, {{35.44444444444444, 10}, {35, 
      8}}]], LineBox[
    NCache[{{Rational[109, 3], 10}, {35, 8}}, {{36.333333333333336`, 10}, {35,
       8}}]], LineBox[
    NCache[{{Rational[335, 9], 10}, {39, 8}}, {{37.22222222222222, 10}, {39, 
      8}}]], LineBox[
    NCache[{{Rational[343, 9], 10}, {39, 8}}, {{38.111111111111114`, 10}, {39,
       8}}]], LineBox[{{39, 10}, {39, 8}}]},
  ImageSize->400]], "Output",
 CellChangeTimes->{{3.470839828677406*^9, 3.470839846310652*^9}, 
   3.47084301437155*^9, 3.470846063345973*^9, 3.470846153166815*^9, 
   3.470846443675823*^9, 3.470849685982281*^9, {3.470850737803256*^9, 
   3.470850754516849*^9}, 3.470867723594604*^9, 3.470867805855131*^9, 
   3.47087448068851*^9, 3.470878272305736*^9, 3.470881814361014*^9, 
   3.470912103198689*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.7", ",", "0.3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.3", ",", "0.7"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.470840494224575*^9, 3.470840501822014*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], 
   LineBox[NCache[{{11, 18}, {Rational[37, 3], 18}}, {{11, 18}, {
      12.333333333333334`, 18}}]], 
   LineBox[NCache[{{11, Rational[50, 3]}, {
      Rational[37, 3], Rational[50, 3]}}, {{11, 16.666666666666668`}, {
      12.333333333333334`, 16.666666666666668`}}]], 
   LineBox[NCache[{{11, Rational[46, 3]}, {
      Rational[37, 3], Rational[46, 3]}}, {{11, 15.333333333333334`}, {
      12.333333333333334`, 15.333333333333334`}}]], 
   LineBox[NCache[{{11, 14}, {Rational[37, 3], 14}}, {{11, 14}, {
      12.333333333333334`, 14}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {
      Rational[37, 3], Rational[38, 3]}}, {{11, 12.666666666666666`}, {
      12.333333333333334`, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[34, 3]}, {
      Rational[37, 3], Rational[34, 3]}}, {{11, 11.333333333333334`}, {
      12.333333333333334`, 11.333333333333334`}}]], 
   LineBox[NCache[{{11, 10}, {Rational[37, 3], 10}}, {{11, 10}, {
      12.333333333333334`, 10}}]], 
   LineBox[NCache[{{Rational[37, 3], 18}, {Rational[41, 3], 18}}, {{
      12.333333333333334`, 18}, {13.666666666666666`, 18}}]], 
   LineBox[NCache[{{Rational[37, 3], Rational[50, 3]}, {
      Rational[41, 3], Rational[50, 3]}}, {{12.333333333333334`, 
     16.666666666666668`}, {13.666666666666666`, 16.666666666666668`}}]], 
   LineBox[NCache[{{Rational[37, 3], Rational[46, 3]}, {
      Rational[41, 3], Rational[46, 3]}}, {{12.333333333333334`, 
     15.333333333333334`}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[37, 3], 14}, {Rational[41, 3], 14}}, {{
      12.333333333333334`, 14}, {13.666666666666666`, 14}}]], 
   LineBox[NCache[{{Rational[37, 3], Rational[38, 3]}, {
      Rational[41, 3], Rational[38, 3]}}, {{12.333333333333334`, 
     12.666666666666666`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[37, 3], Rational[34, 3]}, {
      Rational[41, 3], Rational[34, 3]}}, {{12.333333333333334`, 
     11.333333333333334`}, {13.666666666666666`, 11.333333333333334`}}]], 
   LineBox[
    NCache[{{Rational[37, 3], 10}, {Rational[41, 3], 10}}, {{
      12.333333333333334`, 10}, {13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {15, 18}}, {{
      13.666666666666666`, 18}, {15, 18}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[50, 3]}, {
      15, Rational[50, 3]}}, {{13.666666666666666`, 16.666666666666668`}, {
      15, 16.666666666666668`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      15, Rational[46, 3]}}, {{13.666666666666666`, 15.333333333333334`}, {
      15, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], 14}, {15, 14}}, {{
      13.666666666666666`, 14}, {15, 14}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      15, Rational[38, 3]}}, {{13.666666666666666`, 12.666666666666666`}, {
      15, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[34, 3]}, {
      15, Rational[34, 3]}}, {{13.666666666666666`, 11.333333333333334`}, {
      15, 11.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], 10}, {15, 10}}, {{
      13.666666666666666`, 10}, {15, 10}}]], 
   LineBox[NCache[{{15, 18}, {Rational[49, 3], 18}}, {{15, 18}, {
      16.333333333333332`, 18}}]], 
   LineBox[NCache[{{15, Rational[50, 3]}, {
      Rational[49, 3], Rational[50, 3]}}, {{15, 16.666666666666668`}, {
      16.333333333333332`, 16.666666666666668`}}]], 
   LineBox[NCache[{{15, Rational[46, 3]}, {
      Rational[49, 3], Rational[46, 3]}}, {{15, 15.333333333333334`}, {
      16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{15, 14}, {Rational[49, 3], 14}}, {{15, 14}, {
      16.333333333333332`, 14}}]], 
   LineBox[NCache[{{15, Rational[38, 3]}, {
      Rational[49, 3], Rational[38, 3]}}, {{15, 12.666666666666666`}, {
      16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{15, Rational[34, 3]}, {
      Rational[49, 3], Rational[34, 3]}}, {{15, 11.333333333333334`}, {
      16.333333333333332`, 11.333333333333334`}}]], 
   LineBox[NCache[{{15, 10}, {Rational[49, 3], 10}}, {{15, 10}, {
      16.333333333333332`, 10}}]], 
   LineBox[
    NCache[{{Rational[49, 3], 18}, {Rational[53, 3], 18}}, {{
      16.333333333333332`, 18}, {17.666666666666668`, 18}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[50, 3]}, {
      Rational[53, 3], Rational[50, 3]}}, {{16.333333333333332`, 
     16.666666666666668`}, {17.666666666666668`, 16.666666666666668`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[53, 3], Rational[46, 3]}}, {{16.333333333333332`, 
     15.333333333333334`}, {17.666666666666668`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], 14}, {Rational[53, 3], 14}}, {{
      16.333333333333332`, 14}, {17.666666666666668`, 14}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[53, 3], Rational[38, 3]}}, {{16.333333333333332`, 
     12.666666666666666`}, {17.666666666666668`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[34, 3]}, {
      Rational[53, 3], Rational[34, 3]}}, {{16.333333333333332`, 
     11.333333333333334`}, {17.666666666666668`, 11.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], 10}, {Rational[53, 3], 10}}, {{
      16.333333333333332`, 10}, {17.666666666666668`, 10}}]], 
   LineBox[NCache[{{Rational[53, 3], 18}, {19, 18}}, {{
      17.666666666666668`, 18}, {19, 18}}]], 
   LineBox[NCache[{{Rational[53, 3], Rational[50, 3]}, {
      19, Rational[50, 3]}}, {{17.666666666666668`, 16.666666666666668`}, {
      19, 16.666666666666668`}}]], 
   LineBox[NCache[{{Rational[53, 3], Rational[46, 3]}, {
      19, Rational[46, 3]}}, {{17.666666666666668`, 15.333333333333334`}, {
      19, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[53, 3], 14}, {19, 14}}, {{
      17.666666666666668`, 14}, {19, 14}}]], 
   LineBox[NCache[{{Rational[53, 3], Rational[38, 3]}, {
      19, Rational[38, 3]}}, {{17.666666666666668`, 12.666666666666666`}, {
      19, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[53, 3], Rational[34, 3]}, {
      19, Rational[34, 3]}}, {{17.666666666666668`, 11.333333333333334`}, {
      19, 11.333333333333334`}}]], 
   LineBox[
    NCache[{{Rational[53, 3], 10}, {19, 10}}, {{17.666666666666668`, 10}, {19,
       10}}]], LineBox[
    NCache[{{11, 18}, {11, Rational[50, 3]}}, {{11, 18}, {
      11, 16.666666666666668`}}]], 
   LineBox[NCache[{{11, Rational[50, 3]}, {11, Rational[46, 3]}}, {{
      11, 16.666666666666668`}, {11, 15.333333333333334`}}]], 
   LineBox[NCache[{{11, Rational[46, 3]}, {11, 14}}, {{
      11, 15.333333333333334`}, {11, 14}}]], 
   LineBox[NCache[{{11, 14}, {11, Rational[38, 3]}}, {{11, 14}, {
      11, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {11, Rational[34, 3]}}, {{
      11, 12.666666666666666`}, {11, 11.333333333333334`}}]], 
   LineBox[NCache[{{11, Rational[34, 3]}, {11, 10}}, {{
      11, 11.333333333333334`}, {11, 10}}]], 
   LineBox[NCache[{{Rational[37, 3], 18}, {
      Rational[37, 3], Rational[50, 3]}}, {{12.333333333333334`, 18}, {
      12.333333333333334`, 16.666666666666668`}}]], 
   LineBox[NCache[{{Rational[37, 3], Rational[50, 3]}, {
      Rational[37, 3], Rational[46, 3]}}, {{12.333333333333334`, 
     16.666666666666668`}, {12.333333333333334`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[37, 3], Rational[46, 3]}, {
      Rational[37, 3], 14}}, {{12.333333333333334`, 15.333333333333334`}, {
      12.333333333333334`, 14}}]], 
   LineBox[NCache[{{Rational[37, 3], 14}, {
      Rational[37, 3], Rational[38, 3]}}, {{12.333333333333334`, 14}, {
      12.333333333333334`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[37, 3], Rational[38, 3]}, {
      Rational[37, 3], Rational[34, 3]}}, {{12.333333333333334`, 
     12.666666666666666`}, {12.333333333333334`, 11.333333333333334`}}]], 
   LineBox[NCache[{{Rational[37, 3], Rational[34, 3]}, {
      Rational[37, 3], 10}}, {{12.333333333333334`, 11.333333333333334`}, {
      12.333333333333334`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {
      Rational[41, 3], Rational[50, 3]}}, {{13.666666666666666`, 18}, {
      13.666666666666666`, 16.666666666666668`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[50, 3]}, {
      Rational[41, 3], Rational[46, 3]}}, {{13.666666666666666`, 
     16.666666666666668`}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[41, 3], 14}}, {{13.666666666666666`, 15.333333333333334`}, {
      13.666666666666666`, 14}}]], 
   LineBox[NCache[{{Rational[41, 3], 14}, {
      Rational[41, 3], Rational[38, 3]}}, {{13.666666666666666`, 14}, {
      13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[41, 3], Rational[34, 3]}}, {{13.666666666666666`, 
     12.666666666666666`}, {13.666666666666666`, 11.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[34, 3]}, {
      Rational[41, 3], 10}}, {{13.666666666666666`, 11.333333333333334`}, {
      13.666666666666666`, 10}}]], 
   LineBox[NCache[{{15, 18}, {15, Rational[50, 3]}}, {{15, 18}, {
      15, 16.666666666666668`}}]], 
   LineBox[NCache[{{15, Rational[50, 3]}, {15, Rational[46, 3]}}, {{
      15, 16.666666666666668`}, {15, 15.333333333333334`}}]], 
   LineBox[NCache[{{15, Rational[46, 3]}, {15, 14}}, {{
      15, 15.333333333333334`}, {15, 14}}]], 
   LineBox[NCache[{{15, 14}, {15, Rational[38, 3]}}, {{15, 14}, {
      15, 12.666666666666666`}}]], 
   LineBox[NCache[{{15, Rational[38, 3]}, {15, Rational[34, 3]}}, {{
      15, 12.666666666666666`}, {15, 11.333333333333334`}}]], 
   LineBox[NCache[{{15, Rational[34, 3]}, {15, 10}}, {{
      15, 11.333333333333334`}, {15, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {
      Rational[49, 3], Rational[50, 3]}}, {{16.333333333333332`, 18}, {
      16.333333333333332`, 16.666666666666668`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[50, 3]}, {
      Rational[49, 3], Rational[46, 3]}}, {{16.333333333333332`, 
     16.666666666666668`}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[49, 3], 14}}, {{16.333333333333332`, 15.333333333333334`}, {
      16.333333333333332`, 14}}]], 
   LineBox[
    NCache[{{Rational[49, 3], 14}, {Rational[49, 3], Rational[38, 3]}}, {{
      16.333333333333332`, 14}, {16.333333333333332`, 12.666666666666666`}}]],
    LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[49, 3], Rational[34, 3]}}, {{16.333333333333332`, 
     12.666666666666666`}, {16.333333333333332`, 11.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[34, 3]}, {
      Rational[49, 3], 10}}, {{16.333333333333332`, 11.333333333333334`}, {
      16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[53, 3], 18}, {
      Rational[53, 3], Rational[50, 3]}}, {{17.666666666666668`, 18}, {
      17.666666666666668`, 16.666666666666668`}}]], 
   LineBox[NCache[{{Rational[53, 3], Rational[50, 3]}, {
      Rational[53, 3], Rational[46, 3]}}, {{17.666666666666668`, 
     16.666666666666668`}, {17.666666666666668`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[53, 3], Rational[46, 3]}, {
      Rational[53, 3], 14}}, {{17.666666666666668`, 15.333333333333334`}, {
      17.666666666666668`, 14}}]], 
   LineBox[NCache[{{Rational[53, 3], 14}, {
      Rational[53, 3], Rational[38, 3]}}, {{17.666666666666668`, 14}, {
      17.666666666666668`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[53, 3], Rational[38, 3]}, {
      Rational[53, 3], Rational[34, 3]}}, {{17.666666666666668`, 
     12.666666666666666`}, {17.666666666666668`, 11.333333333333334`}}]], 
   LineBox[NCache[{{Rational[53, 3], Rational[34, 3]}, {
      Rational[53, 3], 10}}, {{17.666666666666668`, 11.333333333333334`}, {
      17.666666666666668`, 10}}]], 
   LineBox[NCache[{{19, 18}, {19, Rational[50, 3]}}, {{19, 18}, {
      19, 16.666666666666668`}}]], 
   LineBox[NCache[{{19, Rational[50, 3]}, {19, Rational[46, 3]}}, {{
      19, 16.666666666666668`}, {19, 15.333333333333334`}}]], 
   LineBox[NCache[{{19, Rational[46, 3]}, {19, 14}}, {{
      19, 15.333333333333334`}, {19, 14}}]], 
   LineBox[NCache[{{19, 14}, {19, Rational[38, 3]}}, {{19, 14}, {
      19, 12.666666666666666`}}]], 
   LineBox[NCache[{{19, Rational[38, 3]}, {19, Rational[34, 3]}}, {{
      19, 12.666666666666666`}, {19, 11.333333333333334`}}]], 
   LineBox[NCache[{{19, Rational[34, 3]}, {19, 10}}, {{
      19, 11.333333333333334`}, {19, 10}}]], LineBox[{{21, 18}, {25, 18}}], 
   LineBox[{{21, 14}, {25, 14}}], LineBox[{{21, 10}, {25, 10}}], 
   LineBox[{{25, 18}, {29, 18}}], LineBox[{{25, 14}, {29, 14}}], 
   LineBox[{{25, 10}, {29, 10}}], LineBox[{{21, 18}, {21, 14}}], 
   LineBox[{{21, 14}, {21, 10}}], LineBox[{{25, 18}, {25, 14}}], 
   LineBox[{{25, 14}, {25, 10}}], LineBox[{{29, 18}, {29, 14}}], 
   LineBox[{{29, 14}, {29, 10}}], LineBox[{{11, 8}, {15, 8}}], 
   LineBox[{{11, 4}, {15, 4}}], LineBox[{{11, 0}, {15, 0}}], 
   LineBox[{{15, 8}, {19, 8}}], LineBox[{{15, 4}, {19, 4}}], 
   LineBox[{{15, 0}, {19, 0}}], LineBox[{{11, 8}, {11, 4}}], 
   LineBox[{{11, 4}, {11, 0}}], LineBox[{{15, 8}, {15, 4}}], 
   LineBox[{{15, 4}, {15, 0}}], LineBox[{{19, 8}, {19, 4}}], 
   LineBox[{{19, 4}, {19, 0}}], 
   LineBox[NCache[{{21, 8}, {Rational[67, 3], 8}}, {{21, 8}, {
      22.333333333333332`, 8}}]], 
   LineBox[NCache[{{21, Rational[20, 3]}, {
      Rational[67, 3], Rational[20, 3]}}, {{21, 6.666666666666667}, {
      22.333333333333332`, 6.666666666666667}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {
      Rational[67, 3], Rational[16, 3]}}, {{21, 5.333333333333333}, {
      22.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{21, 4}, {Rational[67, 3], 4}}, {{21, 4}, {
      22.333333333333332`, 4}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {
      Rational[67, 3], Rational[8, 3]}}, {{21, 2.6666666666666665`}, {
      22.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[4, 3]}, {
      Rational[67, 3], Rational[4, 3]}}, {{21, 1.3333333333333333`}, {
      22.333333333333332`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{21, 0}, {Rational[67, 3], 0}}, {{21, 0}, {
      22.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[67, 3], 8}, {Rational[71, 3], 8}}, {{
      22.333333333333332`, 8}, {23.666666666666668`, 8}}]], 
   LineBox[NCache[{{Rational[67, 3], Rational[20, 3]}, {
      Rational[71, 3], Rational[20, 3]}}, {{22.333333333333332`, 
     6.666666666666667}, {23.666666666666668`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[67, 3], Rational[16, 3]}, {
      Rational[71, 3], Rational[16, 3]}}, {{22.333333333333332`, 
     5.333333333333333}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[67, 3], 4}, {Rational[71, 3], 4}}, {{
      22.333333333333332`, 4}, {23.666666666666668`, 4}}]], 
   LineBox[NCache[{{Rational[67, 3], Rational[8, 3]}, {
      Rational[71, 3], Rational[8, 3]}}, {{22.333333333333332`, 
     2.6666666666666665`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[67, 3], Rational[4, 3]}, {
      Rational[71, 3], Rational[4, 3]}}, {{22.333333333333332`, 
     1.3333333333333333`}, {23.666666666666668`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[67, 3], 0}, {Rational[71, 3], 0}}, {{
      22.333333333333332`, 0}, {23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {25, 8}}, {{
      23.666666666666668`, 8}, {25, 8}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[20, 3]}, {
      25, Rational[20, 3]}}, {{23.666666666666668`, 6.666666666666667}, {
      25, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      25, Rational[16, 3]}}, {{23.666666666666668`, 5.333333333333333}, {
      25, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], 4}, {25, 4}}, {{
      23.666666666666668`, 4}, {25, 4}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      25, Rational[8, 3]}}, {{23.666666666666668`, 2.6666666666666665`}, {
      25, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[4, 3]}, {
      25, Rational[4, 3]}}, {{23.666666666666668`, 1.3333333333333333`}, {
      25, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[71, 3], 0}, {25, 0}}, {{
      23.666666666666668`, 0}, {25, 0}}]], 
   LineBox[NCache[{{25, 8}, {Rational[79, 3], 8}}, {{25, 8}, {
      26.333333333333332`, 8}}]], 
   LineBox[NCache[{{25, Rational[20, 3]}, {
      Rational[79, 3], Rational[20, 3]}}, {{25, 6.666666666666667}, {
      26.333333333333332`, 6.666666666666667}}]], 
   LineBox[NCache[{{25, Rational[16, 3]}, {
      Rational[79, 3], Rational[16, 3]}}, {{25, 5.333333333333333}, {
      26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{25, 4}, {Rational[79, 3], 4}}, {{25, 4}, {
      26.333333333333332`, 4}}]], 
   LineBox[NCache[{{25, Rational[8, 3]}, {
      Rational[79, 3], Rational[8, 3]}}, {{25, 2.6666666666666665`}, {
      26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{25, Rational[4, 3]}, {
      Rational[79, 3], Rational[4, 3]}}, {{25, 1.3333333333333333`}, {
      26.333333333333332`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{25, 0}, {Rational[79, 3], 0}}, {{25, 0}, {
      26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {Rational[83, 3], 8}}, {{
      26.333333333333332`, 8}, {27.666666666666668`, 8}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[20, 3]}, {
      Rational[83, 3], Rational[20, 3]}}, {{26.333333333333332`, 
     6.666666666666667}, {27.666666666666668`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[83, 3], Rational[16, 3]}}, {{26.333333333333332`, 
     5.333333333333333}, {27.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], 4}, {Rational[83, 3], 4}}, {{
      26.333333333333332`, 4}, {27.666666666666668`, 4}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[83, 3], Rational[8, 3]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {27.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[4, 3]}, {
      Rational[83, 3], Rational[4, 3]}}, {{26.333333333333332`, 
     1.3333333333333333`}, {27.666666666666668`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[79, 3], 0}, {Rational[83, 3], 0}}, {{
      26.333333333333332`, 0}, {27.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[83, 3], 8}, {29, 8}}, {{
      27.666666666666668`, 8}, {29, 8}}]], 
   LineBox[
    NCache[{{Rational[83, 3], Rational[20, 3]}, {29, Rational[20, 3]}}, {{
      27.666666666666668`, 6.666666666666667}, {29, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[83, 3], Rational[16, 3]}, {
      29, Rational[16, 3]}}, {{27.666666666666668`, 5.333333333333333}, {
      29, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[83, 3], 4}, {29, 4}}, {{
      27.666666666666668`, 4}, {29, 4}}]], 
   LineBox[NCache[{{Rational[83, 3], Rational[8, 3]}, {
      29, Rational[8, 3]}}, {{27.666666666666668`, 2.6666666666666665`}, {
      29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[83, 3], Rational[4, 3]}, {
      29, Rational[4, 3]}}, {{27.666666666666668`, 1.3333333333333333`}, {
      29, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[83, 3], 0}, {29, 0}}, {{
      27.666666666666668`, 0}, {29, 0}}]], 
   LineBox[NCache[{{21, 8}, {21, Rational[20, 3]}}, {{21, 8}, {
      21, 6.666666666666667}}]], 
   LineBox[NCache[{{21, Rational[20, 3]}, {21, Rational[16, 3]}}, {{
      21, 6.666666666666667}, {21, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {21, 4}}, {{
      21, 5.333333333333333}, {21, 4}}]], 
   LineBox[NCache[{{21, 4}, {21, Rational[8, 3]}}, {{21, 4}, {
      21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {21, Rational[4, 3]}}, {{
      21, 2.6666666666666665`}, {21, 1.3333333333333333`}}]], 
   LineBox[NCache[{{21, Rational[4, 3]}, {21, 0}}, {{
      21, 1.3333333333333333`}, {21, 0}}]], 
   LineBox[NCache[{{Rational[67, 3], 8}, {
      Rational[67, 3], Rational[20, 3]}}, {{22.333333333333332`, 8}, {
      22.333333333333332`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[67, 3], Rational[20, 3]}, {
      Rational[67, 3], Rational[16, 3]}}, {{22.333333333333332`, 
     6.666666666666667}, {22.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[67, 3], Rational[16, 3]}, {
      Rational[67, 3], 4}}, {{22.333333333333332`, 5.333333333333333}, {
      22.333333333333332`, 4}}]], 
   LineBox[NCache[{{Rational[67, 3], 4}, {
      Rational[67, 3], Rational[8, 3]}}, {{22.333333333333332`, 4}, {
      22.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[67, 3], Rational[8, 3]}, {
      Rational[67, 3], Rational[4, 3]}}, {{22.333333333333332`, 
     2.6666666666666665`}, {22.333333333333332`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[67, 3], Rational[4, 3]}, {
      Rational[67, 3], 0}}, {{22.333333333333332`, 1.3333333333333333`}, {
      22.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {
      Rational[71, 3], Rational[20, 3]}}, {{23.666666666666668`, 8}, {
      23.666666666666668`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[20, 3]}, {
      Rational[71, 3], Rational[16, 3]}}, {{23.666666666666668`, 
     6.666666666666667}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[71, 3], 4}}, {{23.666666666666668`, 5.333333333333333}, {
      23.666666666666668`, 4}}]], 
   LineBox[NCache[{{Rational[71, 3], 4}, {
      Rational[71, 3], Rational[8, 3]}}, {{23.666666666666668`, 4}, {
      23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[71, 3], Rational[4, 3]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {23.666666666666668`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[4, 3]}, {
      Rational[71, 3], 0}}, {{23.666666666666668`, 1.3333333333333333`}, {
      23.666666666666668`, 0}}]], 
   LineBox[NCache[{{25, 8}, {25, Rational[20, 3]}}, {{25, 8}, {
      25, 6.666666666666667}}]], 
   LineBox[NCache[{{25, Rational[20, 3]}, {25, Rational[16, 3]}}, {{
      25, 6.666666666666667}, {25, 5.333333333333333}}]], 
   LineBox[NCache[{{25, Rational[16, 3]}, {25, 4}}, {{
      25, 5.333333333333333}, {25, 4}}]], 
   LineBox[NCache[{{25, 4}, {25, Rational[8, 3]}}, {{25, 4}, {
      25, 2.6666666666666665`}}]], 
   LineBox[NCache[{{25, Rational[8, 3]}, {25, Rational[4, 3]}}, {{
      25, 2.6666666666666665`}, {25, 1.3333333333333333`}}]], 
   LineBox[
    NCache[{{25, Rational[4, 3]}, {25, 0}}, {{25, 1.3333333333333333`}, {25, 
      0}}]], LineBox[
    NCache[{{Rational[79, 3], 8}, {Rational[79, 3], Rational[20, 3]}}, {{
      26.333333333333332`, 8}, {26.333333333333332`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[20, 3]}, {
      Rational[79, 3], Rational[16, 3]}}, {{26.333333333333332`, 
     6.666666666666667}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[79, 3], 4}}, {{26.333333333333332`, 5.333333333333333}, {
      26.333333333333332`, 4}}]], 
   LineBox[NCache[{{Rational[79, 3], 4}, {
      Rational[79, 3], Rational[8, 3]}}, {{26.333333333333332`, 4}, {
      26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[79, 3], Rational[4, 3]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {26.333333333333332`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[4, 3]}, {
      Rational[79, 3], 0}}, {{26.333333333333332`, 1.3333333333333333`}, {
      26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[83, 3], 8}, {
      Rational[83, 3], Rational[20, 3]}}, {{27.666666666666668`, 8}, {
      27.666666666666668`, 6.666666666666667}}]], 
   LineBox[NCache[{{Rational[83, 3], Rational[20, 3]}, {
      Rational[83, 3], Rational[16, 3]}}, {{27.666666666666668`, 
     6.666666666666667}, {27.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[83, 3], Rational[16, 3]}, {
      Rational[83, 3], 4}}, {{27.666666666666668`, 5.333333333333333}, {
      27.666666666666668`, 4}}]], 
   LineBox[NCache[{{Rational[83, 3], 4}, {
      Rational[83, 3], Rational[8, 3]}}, {{27.666666666666668`, 4}, {
      27.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[83, 3], Rational[8, 3]}, {
      Rational[83, 3], Rational[4, 3]}}, {{27.666666666666668`, 
     2.6666666666666665`}, {27.666666666666668`, 1.3333333333333333`}}]], 
   LineBox[NCache[{{Rational[83, 3], Rational[4, 3]}, {
      Rational[83, 3], 0}}, {{27.666666666666668`, 1.3333333333333333`}, {
      27.666666666666668`, 0}}]], 
   LineBox[NCache[{{29, 8}, {29, Rational[20, 3]}}, {{29, 8}, {
      29, 6.666666666666667}}]], 
   LineBox[NCache[{{29, Rational[20, 3]}, {29, Rational[16, 3]}}, {{
      29, 6.666666666666667}, {29, 5.333333333333333}}]], 
   LineBox[NCache[{{29, Rational[16, 3]}, {29, 4}}, {{
      29, 5.333333333333333}, {29, 4}}]], 
   LineBox[NCache[{{29, 4}, {29, Rational[8, 3]}}, {{29, 4}, {
      29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{29, Rational[8, 3]}, {29, Rational[4, 3]}}, {{
      29, 2.6666666666666665`}, {29, 1.3333333333333333`}}]], 
   LineBox[NCache[{{29, Rational[4, 3]}, {29, 0}}, {{
      29, 1.3333333333333333`}, {29, 0}}]], LineBox[{{19, 18}, {21, 18}}], 
   LineBox[NCache[{{19, Rational[50, 3]}, {21, 18}}, {{
      19, 16.666666666666668`}, {21, 18}}]], 
   LineBox[NCache[{{19, Rational[46, 3]}, {21, 18}}, {{
      19, 15.333333333333334`}, {21, 18}}]], LineBox[{{19, 14}, {21, 14}}], 
   LineBox[NCache[{{19, Rational[38, 3]}, {21, 14}}, {{
      19, 12.666666666666666`}, {21, 14}}]], 
   LineBox[NCache[{{19, Rational[34, 3]}, {21, 10}}, {{
      19, 11.333333333333334`}, {21, 10}}]], LineBox[{{19, 10}, {21, 10}}], 
   LineBox[{{19, 8}, {21, 8}}], 
   LineBox[NCache[{{19, 8}, {21, Rational[20, 3]}}, {{19, 8}, {
      21, 6.666666666666667}}]], 
   LineBox[NCache[{{19, 8}, {21, Rational[16, 3]}}, {{19, 8}, {
      21, 5.333333333333333}}]], LineBox[{{19, 4}, {21, 4}}], 
   LineBox[NCache[{{19, 4}, {21, Rational[8, 3]}}, {{19, 4}, {
      21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{19, 0}, {21, Rational[4, 3]}}, {{19, 0}, {
      21, 1.3333333333333333`}}]], LineBox[{{19, 0}, {21, 0}}], 
   LineBox[{{11, 10}, {11, 8}}], 
   LineBox[NCache[{{Rational[37, 3], 10}, {11, 8}}, {{
      12.333333333333334`, 10}, {11, 8}}]], 
   LineBox[NCache[{{Rational[41, 3], 10}, {11, 8}}, {{
      13.666666666666666`, 10}, {11, 8}}]], LineBox[{{15, 10}, {15, 8}}], 
   LineBox[NCache[{{Rational[49, 3], 10}, {15, 8}}, {{
      16.333333333333332`, 10}, {15, 8}}]], 
   LineBox[NCache[{{Rational[53, 3], 10}, {19, 8}}, {{
      17.666666666666668`, 10}, {19, 8}}]], LineBox[{{19, 10}, {19, 8}}], 
   LineBox[{{21, 10}, {21, 8}}], 
   LineBox[NCache[{{21, 10}, {Rational[67, 3], 8}}, {{21, 10}, {
      22.333333333333332`, 8}}]], 
   LineBox[NCache[{{21, 10}, {Rational[71, 3], 8}}, {{21, 10}, {
      23.666666666666668`, 8}}]], LineBox[{{25, 10}, {25, 8}}], 
   LineBox[NCache[{{25, 10}, {Rational[79, 3], 8}}, {{25, 10}, {
      26.333333333333332`, 8}}]], 
   LineBox[NCache[{{29, 10}, {Rational[83, 3], 8}}, {{29, 10}, {
      27.666666666666668`, 8}}]], LineBox[{{29, 10}, {29, 8}}]},
  ImageSize->400]], "Output",
 CellChangeTimes->{
  3.470843014858365*^9, 3.470846063583105*^9, 3.470846153313167*^9, 
   3.47084644386559*^9, 3.470849686145641*^9, {3.47085073793406*^9, 
   3.470850754855917*^9}, 3.470867723942694*^9, 3.470867806016205*^9, 
   3.470874480849374*^9, 3.470878272491747*^9, 3.470881814530947*^9, 
   3.47091210356983*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0.3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.3", ",", "1"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.470839680051248*^9, 3.470839684909661*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], 
   LineBox[NCache[{{11, 18}, {Rational[107, 9], 18}}, {{11, 18}, {
      11.88888888888889, 18}}]], 
   LineBox[NCache[{{11, Rational[154, 9]}, {
      Rational[107, 9], Rational[154, 9]}}, {{11, 17.11111111111111}, {
      11.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{11, Rational[146, 9]}, {
      Rational[107, 9], Rational[146, 9]}}, {{11, 16.22222222222222}, {
      11.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{11, Rational[46, 3]}, {
      Rational[107, 9], Rational[46, 3]}}, {{11, 15.333333333333334`}, {
      11.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{11, Rational[130, 9]}, {
      Rational[107, 9], Rational[130, 9]}}, {{11, 14.444444444444445`}, {
      11.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{11, Rational[122, 9]}, {
      Rational[107, 9], Rational[122, 9]}}, {{11, 13.555555555555555`}, {
      11.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {
      Rational[107, 9], Rational[38, 3]}}, {{11, 12.666666666666666`}, {
      11.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[106, 9]}, {
      Rational[107, 9], Rational[106, 9]}}, {{11, 11.777777777777779`}, {
      11.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{11, Rational[98, 9]}, {
      Rational[107, 9], Rational[98, 9]}}, {{11, 10.88888888888889}, {
      11.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{11, 10}, {Rational[107, 9], 10}}, {{11, 10}, {
      11.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[107, 9], 18}, {Rational[115, 9], 18}}, {{
      11.88888888888889, 18}, {12.777777777777779`, 18}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[154, 9]}, {
      Rational[115, 9], Rational[154, 9]}}, {{11.88888888888889, 
     17.11111111111111}, {12.777777777777779`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[146, 9]}, {
      Rational[115, 9], Rational[146, 9]}}, {{11.88888888888889, 
     16.22222222222222}, {12.777777777777779`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[46, 3]}, {
      Rational[115, 9], Rational[46, 3]}}, {{11.88888888888889, 
     15.333333333333334`}, {12.777777777777779`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[130, 9]}, {
      Rational[115, 9], Rational[130, 9]}}, {{11.88888888888889, 
     14.444444444444445`}, {12.777777777777779`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[122, 9]}, {
      Rational[115, 9], Rational[122, 9]}}, {{11.88888888888889, 
     13.555555555555555`}, {12.777777777777779`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[38, 3]}, {
      Rational[115, 9], Rational[38, 3]}}, {{11.88888888888889, 
     12.666666666666666`}, {12.777777777777779`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[106, 9]}, {
      Rational[115, 9], Rational[106, 9]}}, {{11.88888888888889, 
     11.777777777777779`}, {12.777777777777779`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[98, 9]}, {
      Rational[115, 9], Rational[98, 9]}}, {{11.88888888888889, 
     10.88888888888889}, {12.777777777777779`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[107, 9], 10}, {Rational[115, 9], 10}}, {{
      11.88888888888889, 10}, {12.777777777777779`, 10}}]], 
   LineBox[NCache[{{Rational[115, 9], 18}, {Rational[41, 3], 18}}, {{
      12.777777777777779`, 18}, {13.666666666666666`, 18}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[154, 9]}, {
      Rational[41, 3], Rational[154, 9]}}, {{12.777777777777779`, 
     17.11111111111111}, {13.666666666666666`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[146, 9]}, {
      Rational[41, 3], Rational[146, 9]}}, {{12.777777777777779`, 
     16.22222222222222}, {13.666666666666666`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[46, 3]}, {
      Rational[41, 3], Rational[46, 3]}}, {{12.777777777777779`, 
     15.333333333333334`}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[130, 9]}, {
      Rational[41, 3], Rational[130, 9]}}, {{12.777777777777779`, 
     14.444444444444445`}, {13.666666666666666`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[122, 9]}, {
      Rational[41, 3], Rational[122, 9]}}, {{12.777777777777779`, 
     13.555555555555555`}, {13.666666666666666`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[38, 3]}, {
      Rational[41, 3], Rational[38, 3]}}, {{12.777777777777779`, 
     12.666666666666666`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[106, 9]}, {
      Rational[41, 3], Rational[106, 9]}}, {{12.777777777777779`, 
     11.777777777777779`}, {13.666666666666666`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[98, 9]}, {
      Rational[41, 3], Rational[98, 9]}}, {{12.777777777777779`, 
     10.88888888888889}, {13.666666666666666`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[115, 9], 10}, {Rational[41, 3], 10}}, {{
      12.777777777777779`, 10}, {13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {Rational[131, 9], 18}}, {{
      13.666666666666666`, 18}, {14.555555555555555`, 18}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[154, 9]}, {
      Rational[131, 9], Rational[154, 9]}}, {{13.666666666666666`, 
     17.11111111111111}, {14.555555555555555`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[146, 9]}, {
      Rational[131, 9], Rational[146, 9]}}, {{13.666666666666666`, 
     16.22222222222222}, {14.555555555555555`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[131, 9], Rational[46, 3]}}, {{13.666666666666666`, 
     15.333333333333334`}, {14.555555555555555`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[130, 9]}, {
      Rational[131, 9], Rational[130, 9]}}, {{13.666666666666666`, 
     14.444444444444445`}, {14.555555555555555`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[122, 9]}, {
      Rational[131, 9], Rational[122, 9]}}, {{13.666666666666666`, 
     13.555555555555555`}, {14.555555555555555`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[131, 9], Rational[38, 3]}}, {{13.666666666666666`, 
     12.666666666666666`}, {14.555555555555555`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[106, 9]}, {
      Rational[131, 9], Rational[106, 9]}}, {{13.666666666666666`, 
     11.777777777777779`}, {14.555555555555555`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[98, 9]}, {
      Rational[131, 9], Rational[98, 9]}}, {{13.666666666666666`, 
     10.88888888888889}, {14.555555555555555`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[41, 3], 10}, {Rational[131, 9], 10}}, {{
      13.666666666666666`, 10}, {14.555555555555555`, 10}}]], 
   LineBox[NCache[{{Rational[131, 9], 18}, {Rational[139, 9], 18}}, {{
      14.555555555555555`, 18}, {15.444444444444445`, 18}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[154, 9]}, {
      Rational[139, 9], Rational[154, 9]}}, {{14.555555555555555`, 
     17.11111111111111}, {15.444444444444445`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[146, 9]}, {
      Rational[139, 9], Rational[146, 9]}}, {{14.555555555555555`, 
     16.22222222222222}, {15.444444444444445`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[46, 3]}, {
      Rational[139, 9], Rational[46, 3]}}, {{14.555555555555555`, 
     15.333333333333334`}, {15.444444444444445`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[130, 9]}, {
      Rational[139, 9], Rational[130, 9]}}, {{14.555555555555555`, 
     14.444444444444445`}, {15.444444444444445`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[122, 9]}, {
      Rational[139, 9], Rational[122, 9]}}, {{14.555555555555555`, 
     13.555555555555555`}, {15.444444444444445`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[38, 3]}, {
      Rational[139, 9], Rational[38, 3]}}, {{14.555555555555555`, 
     12.666666666666666`}, {15.444444444444445`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[106, 9]}, {
      Rational[139, 9], Rational[106, 9]}}, {{14.555555555555555`, 
     11.777777777777779`}, {15.444444444444445`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[98, 9]}, {
      Rational[139, 9], Rational[98, 9]}}, {{14.555555555555555`, 
     10.88888888888889}, {15.444444444444445`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[131, 9], 10}, {Rational[139, 9], 10}}, {{
      14.555555555555555`, 10}, {15.444444444444445`, 10}}]], 
   LineBox[NCache[{{Rational[139, 9], 18}, {Rational[49, 3], 18}}, {{
      15.444444444444445`, 18}, {16.333333333333332`, 18}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[154, 9]}, {
      Rational[49, 3], Rational[154, 9]}}, {{15.444444444444445`, 
     17.11111111111111}, {16.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[146, 9]}, {
      Rational[49, 3], Rational[146, 9]}}, {{15.444444444444445`, 
     16.22222222222222}, {16.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[46, 3]}, {
      Rational[49, 3], Rational[46, 3]}}, {{15.444444444444445`, 
     15.333333333333334`}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[130, 9]}, {
      Rational[49, 3], Rational[130, 9]}}, {{15.444444444444445`, 
     14.444444444444445`}, {16.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[122, 9]}, {
      Rational[49, 3], Rational[122, 9]}}, {{15.444444444444445`, 
     13.555555555555555`}, {16.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[38, 3]}, {
      Rational[49, 3], Rational[38, 3]}}, {{15.444444444444445`, 
     12.666666666666666`}, {16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[106, 9]}, {
      Rational[49, 3], Rational[106, 9]}}, {{15.444444444444445`, 
     11.777777777777779`}, {16.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[98, 9]}, {
      Rational[49, 3], Rational[98, 9]}}, {{15.444444444444445`, 
     10.88888888888889}, {16.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[139, 9], 10}, {Rational[49, 3], 10}}, {{
      15.444444444444445`, 10}, {16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {Rational[155, 9], 18}}, {{
      16.333333333333332`, 18}, {17.22222222222222, 18}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[154, 9]}, {
      Rational[155, 9], Rational[154, 9]}}, {{16.333333333333332`, 
     17.11111111111111}, {17.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[146, 9]}, {
      Rational[155, 9], Rational[146, 9]}}, {{16.333333333333332`, 
     16.22222222222222}, {17.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[155, 9], Rational[46, 3]}}, {{16.333333333333332`, 
     15.333333333333334`}, {17.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[130, 9]}, {
      Rational[155, 9], Rational[130, 9]}}, {{16.333333333333332`, 
     14.444444444444445`}, {17.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[122, 9]}, {
      Rational[155, 9], Rational[122, 9]}}, {{16.333333333333332`, 
     13.555555555555555`}, {17.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[155, 9], Rational[38, 3]}}, {{16.333333333333332`, 
     12.666666666666666`}, {17.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[106, 9]}, {
      Rational[155, 9], Rational[106, 9]}}, {{16.333333333333332`, 
     11.777777777777779`}, {17.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[98, 9]}, {
      Rational[155, 9], Rational[98, 9]}}, {{16.333333333333332`, 
     10.88888888888889}, {17.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[49, 3], 10}, {Rational[155, 9], 10}}, {{
      16.333333333333332`, 10}, {17.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[155, 9], 18}, {Rational[163, 9], 18}}, {{
      17.22222222222222, 18}, {18.11111111111111, 18}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[154, 9]}, {
      Rational[163, 9], Rational[154, 9]}}, {{17.22222222222222, 
     17.11111111111111}, {18.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[146, 9]}, {
      Rational[163, 9], Rational[146, 9]}}, {{17.22222222222222, 
     16.22222222222222}, {18.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[46, 3]}, {
      Rational[163, 9], Rational[46, 3]}}, {{17.22222222222222, 
     15.333333333333334`}, {18.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[130, 9]}, {
      Rational[163, 9], Rational[130, 9]}}, {{17.22222222222222, 
     14.444444444444445`}, {18.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[122, 9]}, {
      Rational[163, 9], Rational[122, 9]}}, {{17.22222222222222, 
     13.555555555555555`}, {18.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[38, 3]}, {
      Rational[163, 9], Rational[38, 3]}}, {{17.22222222222222, 
     12.666666666666666`}, {18.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[106, 9]}, {
      Rational[163, 9], Rational[106, 9]}}, {{17.22222222222222, 
     11.777777777777779`}, {18.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[98, 9]}, {
      Rational[163, 9], Rational[98, 9]}}, {{17.22222222222222, 
     10.88888888888889}, {18.11111111111111, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[155, 9], 10}, {Rational[163, 9], 10}}, {{
      17.22222222222222, 10}, {18.11111111111111, 10}}]], 
   LineBox[NCache[{{Rational[163, 9], 18}, {19, 18}}, {{
      18.11111111111111, 18}, {19, 18}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[154, 9]}, {
      19, Rational[154, 9]}}, {{18.11111111111111, 17.11111111111111}, {
      19, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[146, 9]}, {
      19, Rational[146, 9]}}, {{18.11111111111111, 16.22222222222222}, {
      19, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[46, 3]}, {
      19, Rational[46, 3]}}, {{18.11111111111111, 15.333333333333334`}, {
      19, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[130, 9]}, {
      19, Rational[130, 9]}}, {{18.11111111111111, 14.444444444444445`}, {
      19, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[122, 9]}, {
      19, Rational[122, 9]}}, {{18.11111111111111, 13.555555555555555`}, {
      19, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[38, 3]}, {
      19, Rational[38, 3]}}, {{18.11111111111111, 12.666666666666666`}, {
      19, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[106, 9]}, {
      19, Rational[106, 9]}}, {{18.11111111111111, 11.777777777777779`}, {
      19, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[98, 9]}, {
      19, Rational[98, 9]}}, {{18.11111111111111, 10.88888888888889}, {
      19, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[163, 9], 10}, {19, 10}}, {{
      18.11111111111111, 10}, {19, 10}}]], 
   LineBox[NCache[{{11, 18}, {11, Rational[154, 9]}}, {{11, 18}, {
      11, 17.11111111111111}}]], 
   LineBox[NCache[{{11, Rational[154, 9]}, {11, Rational[146, 9]}}, {{
      11, 17.11111111111111}, {11, 16.22222222222222}}]], 
   LineBox[NCache[{{11, Rational[146, 9]}, {11, Rational[46, 3]}}, {{
      11, 16.22222222222222}, {11, 15.333333333333334`}}]], 
   LineBox[
    NCache[{{11, Rational[46, 3]}, {11, Rational[130, 9]}}, {{
      11, 15.333333333333334`}, {11, 14.444444444444445`}}]], 
   LineBox[NCache[{{11, Rational[130, 9]}, {11, Rational[122, 9]}}, {{
      11, 14.444444444444445`}, {11, 13.555555555555555`}}]], 
   LineBox[NCache[{{11, Rational[122, 9]}, {11, Rational[38, 3]}}, {{
      11, 13.555555555555555`}, {11, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {11, Rational[106, 9]}}, {{
      11, 12.666666666666666`}, {11, 11.777777777777779`}}]], 
   LineBox[NCache[{{11, Rational[106, 9]}, {11, Rational[98, 9]}}, {{
      11, 11.777777777777779`}, {11, 10.88888888888889}}]], 
   LineBox[NCache[{{11, Rational[98, 9]}, {11, 10}}, {{
      11, 10.88888888888889}, {11, 10}}]], 
   LineBox[NCache[{{Rational[107, 9], 18}, {
      Rational[107, 9], Rational[154, 9]}}, {{11.88888888888889, 18}, {
      11.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[154, 9]}, {
      Rational[107, 9], Rational[146, 9]}}, {{11.88888888888889, 
     17.11111111111111}, {11.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[146, 9]}, {
      Rational[107, 9], Rational[46, 3]}}, {{11.88888888888889, 
     16.22222222222222}, {11.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[46, 3]}, {
      Rational[107, 9], Rational[130, 9]}}, {{11.88888888888889, 
     15.333333333333334`}, {11.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[130, 9]}, {
      Rational[107, 9], Rational[122, 9]}}, {{11.88888888888889, 
     14.444444444444445`}, {11.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[122, 9]}, {
      Rational[107, 9], Rational[38, 3]}}, {{11.88888888888889, 
     13.555555555555555`}, {11.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[38, 3]}, {
      Rational[107, 9], Rational[106, 9]}}, {{11.88888888888889, 
     12.666666666666666`}, {11.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[106, 9]}, {
      Rational[107, 9], Rational[98, 9]}}, {{11.88888888888889, 
     11.777777777777779`}, {11.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[98, 9]}, {
      Rational[107, 9], 10}}, {{11.88888888888889, 10.88888888888889}, {
      11.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[115, 9], 18}, {
      Rational[115, 9], Rational[154, 9]}}, {{12.777777777777779`, 18}, {
      12.777777777777779`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[154, 9]}, {
      Rational[115, 9], Rational[146, 9]}}, {{12.777777777777779`, 
     17.11111111111111}, {12.777777777777779`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[146, 9]}, {
      Rational[115, 9], Rational[46, 3]}}, {{12.777777777777779`, 
     16.22222222222222}, {12.777777777777779`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[46, 3]}, {
      Rational[115, 9], Rational[130, 9]}}, {{12.777777777777779`, 
     15.333333333333334`}, {12.777777777777779`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[130, 9]}, {
      Rational[115, 9], Rational[122, 9]}}, {{12.777777777777779`, 
     14.444444444444445`}, {12.777777777777779`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[122, 9]}, {
      Rational[115, 9], Rational[38, 3]}}, {{12.777777777777779`, 
     13.555555555555555`}, {12.777777777777779`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[38, 3]}, {
      Rational[115, 9], Rational[106, 9]}}, {{12.777777777777779`, 
     12.666666666666666`}, {12.777777777777779`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[106, 9]}, {
      Rational[115, 9], Rational[98, 9]}}, {{12.777777777777779`, 
     11.777777777777779`}, {12.777777777777779`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[98, 9]}, {
      Rational[115, 9], 10}}, {{12.777777777777779`, 10.88888888888889}, {
      12.777777777777779`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {
      Rational[41, 3], Rational[154, 9]}}, {{13.666666666666666`, 18}, {
      13.666666666666666`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[154, 9]}, {
      Rational[41, 3], Rational[146, 9]}}, {{13.666666666666666`, 
     17.11111111111111}, {13.666666666666666`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[146, 9]}, {
      Rational[41, 3], Rational[46, 3]}}, {{13.666666666666666`, 
     16.22222222222222}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[41, 3], Rational[130, 9]}}, {{13.666666666666666`, 
     15.333333333333334`}, {13.666666666666666`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[130, 9]}, {
      Rational[41, 3], Rational[122, 9]}}, {{13.666666666666666`, 
     14.444444444444445`}, {13.666666666666666`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[122, 9]}, {
      Rational[41, 3], Rational[38, 3]}}, {{13.666666666666666`, 
     13.555555555555555`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[41, 3], Rational[106, 9]}}, {{13.666666666666666`, 
     12.666666666666666`}, {13.666666666666666`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[106, 9]}, {
      Rational[41, 3], Rational[98, 9]}}, {{13.666666666666666`, 
     11.777777777777779`}, {13.666666666666666`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[98, 9]}, {
      Rational[41, 3], 10}}, {{13.666666666666666`, 10.88888888888889}, {
      13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[131, 9], 18}, {
      Rational[131, 9], Rational[154, 9]}}, {{14.555555555555555`, 18}, {
      14.555555555555555`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[154, 9]}, {
      Rational[131, 9], Rational[146, 9]}}, {{14.555555555555555`, 
     17.11111111111111}, {14.555555555555555`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[146, 9]}, {
      Rational[131, 9], Rational[46, 3]}}, {{14.555555555555555`, 
     16.22222222222222}, {14.555555555555555`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[46, 3]}, {
      Rational[131, 9], Rational[130, 9]}}, {{14.555555555555555`, 
     15.333333333333334`}, {14.555555555555555`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[130, 9]}, {
      Rational[131, 9], Rational[122, 9]}}, {{14.555555555555555`, 
     14.444444444444445`}, {14.555555555555555`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[122, 9]}, {
      Rational[131, 9], Rational[38, 3]}}, {{14.555555555555555`, 
     13.555555555555555`}, {14.555555555555555`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[38, 3]}, {
      Rational[131, 9], Rational[106, 9]}}, {{14.555555555555555`, 
     12.666666666666666`}, {14.555555555555555`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[106, 9]}, {
      Rational[131, 9], Rational[98, 9]}}, {{14.555555555555555`, 
     11.777777777777779`}, {14.555555555555555`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[98, 9]}, {
      Rational[131, 9], 10}}, {{14.555555555555555`, 10.88888888888889}, {
      14.555555555555555`, 10}}]], 
   LineBox[NCache[{{Rational[139, 9], 18}, {
      Rational[139, 9], Rational[154, 9]}}, {{15.444444444444445`, 18}, {
      15.444444444444445`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[154, 9]}, {
      Rational[139, 9], Rational[146, 9]}}, {{15.444444444444445`, 
     17.11111111111111}, {15.444444444444445`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[146, 9]}, {
      Rational[139, 9], Rational[46, 3]}}, {{15.444444444444445`, 
     16.22222222222222}, {15.444444444444445`, 15.333333333333334`}}]], 
   LineBox[
    NCache[{{Rational[139, 9], Rational[46, 3]}, {
      Rational[139, 9], Rational[130, 9]}}, {{15.444444444444445`, 
     15.333333333333334`}, {15.444444444444445`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[130, 9]}, {
      Rational[139, 9], Rational[122, 9]}}, {{15.444444444444445`, 
     14.444444444444445`}, {15.444444444444445`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[122, 9]}, {
      Rational[139, 9], Rational[38, 3]}}, {{15.444444444444445`, 
     13.555555555555555`}, {15.444444444444445`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[38, 3]}, {
      Rational[139, 9], Rational[106, 9]}}, {{15.444444444444445`, 
     12.666666666666666`}, {15.444444444444445`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[106, 9]}, {
      Rational[139, 9], Rational[98, 9]}}, {{15.444444444444445`, 
     11.777777777777779`}, {15.444444444444445`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[98, 9]}, {
      Rational[139, 9], 10}}, {{15.444444444444445`, 10.88888888888889}, {
      15.444444444444445`, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {
      Rational[49, 3], Rational[154, 9]}}, {{16.333333333333332`, 18}, {
      16.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[154, 9]}, {
      Rational[49, 3], Rational[146, 9]}}, {{16.333333333333332`, 
     17.11111111111111}, {16.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[146, 9]}, {
      Rational[49, 3], Rational[46, 3]}}, {{16.333333333333332`, 
     16.22222222222222}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[49, 3], Rational[130, 9]}}, {{16.333333333333332`, 
     15.333333333333334`}, {16.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[130, 9]}, {
      Rational[49, 3], Rational[122, 9]}}, {{16.333333333333332`, 
     14.444444444444445`}, {16.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[122, 9]}, {
      Rational[49, 3], Rational[38, 3]}}, {{16.333333333333332`, 
     13.555555555555555`}, {16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[49, 3], Rational[106, 9]}}, {{16.333333333333332`, 
     12.666666666666666`}, {16.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[106, 9]}, {
      Rational[49, 3], Rational[98, 9]}}, {{16.333333333333332`, 
     11.777777777777779`}, {16.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[98, 9]}, {
      Rational[49, 3], 10}}, {{16.333333333333332`, 10.88888888888889}, {
      16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[155, 9], 18}, {
      Rational[155, 9], Rational[154, 9]}}, {{17.22222222222222, 18}, {
      17.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[154, 9]}, {
      Rational[155, 9], Rational[146, 9]}}, {{17.22222222222222, 
     17.11111111111111}, {17.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[146, 9]}, {
      Rational[155, 9], Rational[46, 3]}}, {{17.22222222222222, 
     16.22222222222222}, {17.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[46, 3]}, {
      Rational[155, 9], Rational[130, 9]}}, {{17.22222222222222, 
     15.333333333333334`}, {17.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[130, 9]}, {
      Rational[155, 9], Rational[122, 9]}}, {{17.22222222222222, 
     14.444444444444445`}, {17.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[122, 9]}, {
      Rational[155, 9], Rational[38, 3]}}, {{17.22222222222222, 
     13.555555555555555`}, {17.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[38, 3]}, {
      Rational[155, 9], Rational[106, 9]}}, {{17.22222222222222, 
     12.666666666666666`}, {17.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[106, 9]}, {
      Rational[155, 9], Rational[98, 9]}}, {{17.22222222222222, 
     11.777777777777779`}, {17.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[98, 9]}, {
      Rational[155, 9], 10}}, {{17.22222222222222, 10.88888888888889}, {
      17.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[163, 9], 18}, {
      Rational[163, 9], Rational[154, 9]}}, {{18.11111111111111, 18}, {
      18.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[154, 9]}, {
      Rational[163, 9], Rational[146, 9]}}, {{18.11111111111111, 
     17.11111111111111}, {18.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[146, 9]}, {
      Rational[163, 9], Rational[46, 3]}}, {{18.11111111111111, 
     16.22222222222222}, {18.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[46, 3]}, {
      Rational[163, 9], Rational[130, 9]}}, {{18.11111111111111, 
     15.333333333333334`}, {18.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[130, 9]}, {
      Rational[163, 9], Rational[122, 9]}}, {{18.11111111111111, 
     14.444444444444445`}, {18.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[122, 9]}, {
      Rational[163, 9], Rational[38, 3]}}, {{18.11111111111111, 
     13.555555555555555`}, {18.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[38, 3]}, {
      Rational[163, 9], Rational[106, 9]}}, {{18.11111111111111, 
     12.666666666666666`}, {18.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[106, 9]}, {
      Rational[163, 9], Rational[98, 9]}}, {{18.11111111111111, 
     11.777777777777779`}, {18.11111111111111, 10.88888888888889}}]], 
   LineBox[
    NCache[{{Rational[163, 9], Rational[98, 9]}, {Rational[163, 9], 10}}, {{
      18.11111111111111, 10.88888888888889}, {18.11111111111111, 10}}]], 
   LineBox[NCache[{{19, 18}, {19, Rational[154, 9]}}, {{19, 18}, {
      19, 17.11111111111111}}]], 
   LineBox[NCache[{{19, Rational[154, 9]}, {19, Rational[146, 9]}}, {{
      19, 17.11111111111111}, {19, 16.22222222222222}}]], 
   LineBox[NCache[{{19, Rational[146, 9]}, {19, Rational[46, 3]}}, {{
      19, 16.22222222222222}, {19, 15.333333333333334`}}]], 
   LineBox[NCache[{{19, Rational[46, 3]}, {19, Rational[130, 9]}}, {{
      19, 15.333333333333334`}, {19, 14.444444444444445`}}]], 
   LineBox[NCache[{{19, Rational[130, 9]}, {19, Rational[122, 9]}}, {{
      19, 14.444444444444445`}, {19, 13.555555555555555`}}]], 
   LineBox[NCache[{{19, Rational[122, 9]}, {19, Rational[38, 3]}}, {{
      19, 13.555555555555555`}, {19, 12.666666666666666`}}]], 
   LineBox[NCache[{{19, Rational[38, 3]}, {19, Rational[106, 9]}}, {{
      19, 12.666666666666666`}, {19, 11.777777777777779`}}]], 
   LineBox[NCache[{{19, Rational[106, 9]}, {19, Rational[98, 9]}}, {{
      19, 11.777777777777779`}, {19, 10.88888888888889}}]], 
   LineBox[NCache[{{19, Rational[98, 9]}, {19, 10}}, {{
      19, 10.88888888888889}, {19, 10}}]], LineBox[{{21, 18}, {25, 18}}], 
   LineBox[{{21, 14}, {25, 14}}], LineBox[{{21, 10}, {25, 10}}], 
   LineBox[{{25, 18}, {29, 18}}], LineBox[{{25, 14}, {29, 14}}], 
   LineBox[{{25, 10}, {29, 10}}], LineBox[{{21, 18}, {21, 14}}], 
   LineBox[{{21, 14}, {21, 10}}], LineBox[{{25, 18}, {25, 14}}], 
   LineBox[{{25, 14}, {25, 10}}], LineBox[{{29, 18}, {29, 14}}], 
   LineBox[{{29, 14}, {29, 10}}], LineBox[{{11, 8}, {15, 8}}], 
   LineBox[{{11, 4}, {15, 4}}], LineBox[{{11, 0}, {15, 0}}], 
   LineBox[{{15, 8}, {19, 8}}], LineBox[{{15, 4}, {19, 4}}], 
   LineBox[{{15, 0}, {19, 0}}], LineBox[{{11, 8}, {11, 4}}], 
   LineBox[{{11, 4}, {11, 0}}], LineBox[{{15, 8}, {15, 4}}], 
   LineBox[{{15, 4}, {15, 0}}], LineBox[{{19, 8}, {19, 4}}], 
   LineBox[{{19, 4}, {19, 0}}], 
   LineBox[NCache[{{21, 8}, {Rational[197, 9], 8}}, {{21, 8}, {
      21.88888888888889, 8}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {
      Rational[197, 9], Rational[64, 9]}}, {{21, 7.111111111111111}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21, 6.222222222222222}, {
      21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21, 5.333333333333333}, {
      21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21, 4.444444444444445}, {
      21.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21, 3.5555555555555554`}, {
      21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21, 2.6666666666666665`}, {
      21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21, 1.7777777777777777`}, {
      21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21, 0.8888888888888888}, {
      21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, 0}, {Rational[197, 9], 0}}, {{21, 0}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {Rational[205, 9], 8}}, {{
      21.88888888888889, 8}, {22.77777777777778, 8}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[64, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{21.88888888888889, 
     6.222222222222222}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[16, 3]}}, {{21.88888888888889, 
     5.333333333333333}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[40, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{21.88888888888889, 
     3.5555555555555554`}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[8, 3]}}, {{21.88888888888889, 
     2.6666666666666665`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[16, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{21.88888888888889, 
     0.8888888888888888}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], 0}, {Rational[205, 9], 0}}, {{
      21.88888888888889, 0}, {22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {Rational[71, 3], 8}}, {{
      22.77777777777778, 8}, {23.666666666666668`, 8}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[71, 3], Rational[64, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{22.77777777777778, 
     6.222222222222222}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[71, 3], Rational[16, 3]}}, {{22.77777777777778, 
     5.333333333333333}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[71, 3], Rational[40, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{22.77777777777778, 
     3.5555555555555554`}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[71, 3], Rational[8, 3]}}, {{22.77777777777778, 
     2.6666666666666665`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[71, 3], Rational[16, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{22.77777777777778, 
     0.8888888888888888}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], 0}, {Rational[71, 3], 0}}, {{
      22.77777777777778, 0}, {23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {Rational[221, 9], 8}}, {{
      23.666666666666668`, 8}, {24.555555555555557`, 8}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[221, 9], Rational[64, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{23.666666666666668`, 
     6.222222222222222}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[221, 9], Rational[16, 3]}}, {{23.666666666666668`, 
     5.333333333333333}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[221, 9], Rational[40, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[221, 9], Rational[8, 3]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[221, 9], Rational[16, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{23.666666666666668`, 
     0.8888888888888888}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[71, 3], 0}, {Rational[221, 9], 0}}, {{
      23.666666666666668`, 0}, {24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {Rational[229, 9], 8}}, {{
      24.555555555555557`, 8}, {25.444444444444443`, 8}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[64, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {25.444444444444443`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     6.222222222222222}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     5.333333333333333}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[
    NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     0.8888888888888888}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], 0}, {Rational[229, 9], 0}}, {{
      24.555555555555557`, 0}, {25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {Rational[79, 3], 8}}, {{
      25.444444444444443`, 8}, {26.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[79, 3], Rational[64, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{25.444444444444443`, 
     6.222222222222222}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[79, 3], Rational[16, 3]}}, {{25.444444444444443`, 
     5.333333333333333}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[79, 3], Rational[40, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[79, 3], Rational[8, 3]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[79, 3], Rational[16, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{25.444444444444443`, 
     0.8888888888888888}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], 0}, {Rational[79, 3], 0}}, {{
      25.444444444444443`, 0}, {26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {Rational[245, 9], 8}}, {{
      26.333333333333332`, 8}, {27.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[245, 9], Rational[64, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{26.333333333333332`, 
     6.222222222222222}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[245, 9], Rational[16, 3]}}, {{26.333333333333332`, 
     5.333333333333333}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[245, 9], Rational[40, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[245, 9], Rational[8, 3]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[245, 9], Rational[16, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{26.333333333333332`, 
     0.8888888888888888}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[79, 3], 0}, {Rational[245, 9], 0}}, {{
      26.333333333333332`, 0}, {27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {Rational[253, 9], 8}}, {{
      27.22222222222222, 8}, {28.11111111111111, 8}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[64, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{27.22222222222222, 
     6.222222222222222}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[16, 3]}}, {{27.22222222222222, 
     5.333333333333333}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[40, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{27.22222222222222, 
     3.5555555555555554`}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[8, 3]}}, {{27.22222222222222, 
     2.6666666666666665`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[16, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{27.22222222222222, 
     0.8888888888888888}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], 0}, {Rational[253, 9], 0}}, {{
      27.22222222222222, 0}, {28.11111111111111, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {29, 8}}, {{28.11111111111111, 8}, {
      29, 8}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      29, Rational[64, 9]}}, {{28.11111111111111, 7.111111111111111}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      29, Rational[56, 9]}}, {{28.11111111111111, 6.222222222222222}, {
      29, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      29, Rational[16, 3]}}, {{28.11111111111111, 5.333333333333333}, {
      29, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      29, Rational[40, 9]}}, {{28.11111111111111, 4.444444444444445}, {
      29, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      29, Rational[32, 9]}}, {{28.11111111111111, 3.5555555555555554`}, {
      29, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      29, Rational[8, 3]}}, {{28.11111111111111, 2.6666666666666665`}, {
      29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 9]}, {
      29, Rational[16, 9]}}, {{28.11111111111111, 1.7777777777777777`}, {
      29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      29, Rational[8, 9]}}, {{28.11111111111111, 0.8888888888888888}, {
      29, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], 0}, {29, 0}}, {{28.11111111111111, 0}, {
      29, 0}}]], 
   LineBox[NCache[{{21, 8}, {21, Rational[64, 9]}}, {{21, 8}, {
      21, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {21, Rational[56, 9]}}, {{
      21, 7.111111111111111}, {21, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {21, Rational[16, 3]}}, {{
      21, 6.222222222222222}, {21, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {21, Rational[40, 9]}}, {{
      21, 5.333333333333333}, {21, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {21, Rational[32, 9]}}, {{
      21, 4.444444444444445}, {21, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {21, Rational[8, 3]}}, {{
      21, 3.5555555555555554`}, {21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {21, Rational[16, 9]}}, {{
      21, 2.6666666666666665`}, {21, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {21, Rational[8, 9]}}, {{
      21, 1.7777777777777777`}, {21, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {21, 0}}, {{
      21, 0.8888888888888888}, {21, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {
      Rational[197, 9], Rational[64, 9]}}, {{21.88888888888889, 8}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21.88888888888889, 
     6.222222222222222}, {21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21.88888888888889, 
     5.333333333333333}, {21.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21.88888888888889, 
     3.5555555555555554`}, {21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21.88888888888889, 
     2.6666666666666665`}, {21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[197, 9], 0}}, {{21.88888888888889, 0.8888888888888888}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {
      Rational[205, 9], Rational[64, 9]}}, {{22.77777777777778, 8}, {
      22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[16, 3]}}, {{22.77777777777778, 
     6.222222222222222}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[40, 9]}}, {{22.77777777777778, 
     5.333333333333333}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[8, 3]}}, {{22.77777777777778, 
     3.5555555555555554`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[16, 9]}}, {{22.77777777777778, 
     2.6666666666666665`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[205, 9], 0}}, {{22.77777777777778, 0.8888888888888888}, {
      22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {
      Rational[71, 3], Rational[64, 9]}}, {{23.666666666666668`, 8}, {
      23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[71, 3], Rational[16, 3]}}, {{23.666666666666668`, 
     6.222222222222222}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[71, 3], Rational[40, 9]}}, {{23.666666666666668`, 
     5.333333333333333}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[71, 3], Rational[8, 3]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[71, 3], Rational[16, 9]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 9]}, {
      Rational[71, 3], 0}}, {{23.666666666666668`, 0.8888888888888888}, {
      23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {
      Rational[221, 9], Rational[64, 9]}}, {{24.555555555555557`, 8}, {
      24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[221, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     6.222222222222222}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[221, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     5.333333333333333}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[221, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[221, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[221, 9], 0}}, {{24.555555555555557`, 0.8888888888888888}, {
      24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {
      Rational[229, 9], Rational[64, 9]}}, {{25.444444444444443`, 8}, {
      25.444444444444443`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[16, 3]}}, {{25.444444444444443`, 
     6.222222222222222}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[40, 9]}}, {{25.444444444444443`, 
     5.333333333333333}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[8, 3]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[16, 9]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[229, 9], 0}}, {{25.444444444444443`, 0.8888888888888888}, {
      25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {
      Rational[79, 3], Rational[64, 9]}}, {{26.333333333333332`, 8}, {
      26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[79, 3], Rational[16, 3]}}, {{26.333333333333332`, 
     6.222222222222222}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[79, 3], Rational[40, 9]}}, {{26.333333333333332`, 
     5.333333333333333}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[79, 3], Rational[8, 3]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[79, 3], Rational[16, 9]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[
    NCache[{{Rational[79, 3], Rational[8, 9]}, {Rational[79, 3], 0}}, {{
      26.333333333333332`, 0.8888888888888888}, {26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {
      Rational[245, 9], Rational[64, 9]}}, {{27.22222222222222, 8}, {
      27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[245, 9], Rational[16, 3]}}, {{27.22222222222222, 
     6.222222222222222}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[245, 9], Rational[40, 9]}}, {{27.22222222222222, 
     5.333333333333333}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[245, 9], Rational[8, 3]}}, {{27.22222222222222, 
     3.5555555555555554`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[245, 9], Rational[16, 9]}}, {{27.22222222222222, 
     2.6666666666666665`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[245, 9], 0}}, {{27.22222222222222, 0.8888888888888888}, {
      27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {
      Rational[253, 9], Rational[64, 9]}}, {{28.11111111111111, 8}, {
      28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{28.11111111111111, 
     7.111111111111111}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[16, 3]}}, {{28.11111111111111, 
     6.222222222222222}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[40, 9]}}, {{28.11111111111111, 
     5.333333333333333}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{28.11111111111111, 
     4.444444444444445}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[8, 3]}}, {{28.11111111111111, 
     3.5555555555555554`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[16, 9]}}, {{28.11111111111111, 
     2.6666666666666665`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{28.11111111111111, 
     1.7777777777777777`}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      Rational[253, 9], 0}}, {{28.11111111111111, 0.8888888888888888}, {
      28.11111111111111, 0}}]], 
   LineBox[NCache[{{29, 8}, {29, Rational[64, 9]}}, {{29, 8}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{29, Rational[64, 9]}, {29, Rational[56, 9]}}, {{
      29, 7.111111111111111}, {29, 6.222222222222222}}]], 
   LineBox[NCache[{{29, Rational[56, 9]}, {29, Rational[16, 3]}}, {{
      29, 6.222222222222222}, {29, 5.333333333333333}}]], 
   LineBox[NCache[{{29, Rational[16, 3]}, {29, Rational[40, 9]}}, {{
      29, 5.333333333333333}, {29, 4.444444444444445}}]], 
   LineBox[NCache[{{29, Rational[40, 9]}, {29, Rational[32, 9]}}, {{
      29, 4.444444444444445}, {29, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{29, Rational[32, 9]}, {29, Rational[8, 3]}}, {{
      29, 3.5555555555555554`}, {29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{29, Rational[8, 3]}, {29, Rational[16, 9]}}, {{
      29, 2.6666666666666665`}, {29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{29, Rational[16, 9]}, {29, Rational[8, 9]}}, {{
      29, 1.7777777777777777`}, {29, 0.8888888888888888}}]], 
   LineBox[NCache[{{29, Rational[8, 9]}, {29, 0}}, {{
      29, 0.8888888888888888}, {29, 0}}]], LineBox[{{19, 18}, {21, 18}}], 
   LineBox[NCache[{{19, Rational[154, 9]}, {21, 18}}, {{
      19, 17.11111111111111}, {21, 18}}]], 
   LineBox[NCache[{{19, Rational[146, 9]}, {21, 18}}, {{
      19, 16.22222222222222}, {21, 18}}]], 
   LineBox[NCache[{{19, Rational[46, 3]}, {21, 18}}, {{
      19, 15.333333333333334`}, {21, 18}}]], 
   LineBox[NCache[{{19, Rational[130, 9]}, {21, 14}}, {{
      19, 14.444444444444445`}, {21, 14}}]], 
   LineBox[NCache[{{19, Rational[122, 9]}, {21, 14}}, {{
      19, 13.555555555555555`}, {21, 14}}]], 
   LineBox[NCache[{{19, Rational[38, 3]}, {21, 14}}, {{
      19, 12.666666666666666`}, {21, 14}}]], 
   LineBox[NCache[{{19, Rational[106, 9]}, {21, 10}}, {{
      19, 11.777777777777779`}, {21, 10}}]], 
   LineBox[NCache[{{19, Rational[98, 9]}, {21, 10}}, {{
      19, 10.88888888888889}, {21, 10}}]], LineBox[{{19, 10}, {21, 10}}], 
   LineBox[{{19, 8}, {21, 8}}], 
   LineBox[NCache[{{19, 8}, {21, Rational[64, 9]}}, {{19, 8}, {
      21, 7.111111111111111}}]], 
   LineBox[NCache[{{19, 8}, {21, Rational[56, 9]}}, {{19, 8}, {
      21, 6.222222222222222}}]], 
   LineBox[NCache[{{19, 8}, {21, Rational[16, 3]}}, {{19, 8}, {
      21, 5.333333333333333}}]], 
   LineBox[NCache[{{19, 4}, {21, Rational[40, 9]}}, {{19, 4}, {
      21, 4.444444444444445}}]], 
   LineBox[NCache[{{19, 4}, {21, Rational[32, 9]}}, {{19, 4}, {
      21, 3.5555555555555554`}}]], 
   LineBox[NCache[{{19, 4}, {21, Rational[8, 3]}}, {{19, 4}, {
      21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{19, 0}, {21, Rational[16, 9]}}, {{19, 0}, {
      21, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{19, 0}, {21, Rational[8, 9]}}, {{19, 0}, {
      21, 0.8888888888888888}}]], LineBox[{{19, 0}, {21, 0}}], 
   LineBox[{{11, 10}, {11, 8}}], 
   LineBox[NCache[{{Rational[107, 9], 10}, {11, 8}}, {{
      11.88888888888889, 10}, {11, 8}}]], 
   LineBox[NCache[{{Rational[115, 9], 10}, {11, 8}}, {{
      12.777777777777779`, 10}, {11, 8}}]], 
   LineBox[NCache[{{Rational[41, 3], 10}, {11, 8}}, {{
      13.666666666666666`, 10}, {11, 8}}]], 
   LineBox[NCache[{{Rational[131, 9], 10}, {15, 8}}, {{
      14.555555555555555`, 10}, {15, 8}}]], 
   LineBox[NCache[{{Rational[139, 9], 10}, {15, 8}}, {{
      15.444444444444445`, 10}, {15, 8}}]], 
   LineBox[NCache[{{Rational[49, 3], 10}, {15, 8}}, {{
      16.333333333333332`, 10}, {15, 8}}]], 
   LineBox[NCache[{{Rational[155, 9], 10}, {19, 8}}, {{
      17.22222222222222, 10}, {19, 8}}]], 
   LineBox[NCache[{{Rational[163, 9], 10}, {19, 8}}, {{
      18.11111111111111, 10}, {19, 8}}]], LineBox[{{19, 10}, {19, 8}}], 
   LineBox[{{21, 10}, {21, 8}}], 
   LineBox[NCache[{{21, 10}, {Rational[197, 9], 8}}, {{21, 10}, {
      21.88888888888889, 8}}]], 
   LineBox[NCache[{{21, 10}, {Rational[205, 9], 8}}, {{21, 10}, {
      22.77777777777778, 8}}]], 
   LineBox[NCache[{{21, 10}, {Rational[71, 3], 8}}, {{21, 10}, {
      23.666666666666668`, 8}}]], 
   LineBox[NCache[{{25, 10}, {Rational[221, 9], 8}}, {{25, 10}, {
      24.555555555555557`, 8}}]], 
   LineBox[NCache[{{25, 10}, {Rational[229, 9], 8}}, {{25, 10}, {
      25.444444444444443`, 8}}]], 
   LineBox[NCache[{{25, 10}, {Rational[79, 3], 8}}, {{25, 10}, {
      26.333333333333332`, 8}}]], 
   LineBox[NCache[{{29, 10}, {Rational[245, 9], 8}}, {{29, 10}, {
      27.22222222222222, 8}}]], 
   LineBox[NCache[{{29, 10}, {Rational[253, 9], 8}}, {{29, 10}, {
      28.11111111111111, 8}}]], LineBox[{{29, 10}, {29, 8}}]},
  ImageSize->400]], "Output",
 CellChangeTimes->{
  3.470839685735463*^9, 3.470843014657029*^9, 3.470846063939701*^9, 
   3.470846153588977*^9, 3.470846444268429*^9, 3.470849686436659*^9, {
   3.470850738227799*^9, 3.470850755187439*^9}, 3.4708677242764*^9, 
   3.470867806325304*^9, 3.470874481184552*^9, 3.470878272855733*^9, 
   3.470881814854392*^9, 3.470912103882588*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateGraphicFromResolutionGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0.3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "1"}], "}"}]}], "}"}], ",", "False"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.470850782954733*^9, 3.470850788620906*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], AbsoluteThickness[5], 
   LineBox[NCache[{{11, 18}, {Rational[107, 9], 18}}, {{11, 18}, {
      11.88888888888889, 18}}]], 
   LineBox[NCache[{{11, Rational[154, 9]}, {
      Rational[107, 9], Rational[154, 9]}}, {{11, 17.11111111111111}, {
      11.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{11, Rational[146, 9]}, {
      Rational[107, 9], Rational[146, 9]}}, {{11, 16.22222222222222}, {
      11.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{11, Rational[46, 3]}, {
      Rational[107, 9], Rational[46, 3]}}, {{11, 15.333333333333334`}, {
      11.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{11, Rational[130, 9]}, {
      Rational[107, 9], Rational[130, 9]}}, {{11, 14.444444444444445`}, {
      11.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{11, Rational[122, 9]}, {
      Rational[107, 9], Rational[122, 9]}}, {{11, 13.555555555555555`}, {
      11.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {
      Rational[107, 9], Rational[38, 3]}}, {{11, 12.666666666666666`}, {
      11.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[106, 9]}, {
      Rational[107, 9], Rational[106, 9]}}, {{11, 11.777777777777779`}, {
      11.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{11, Rational[98, 9]}, {
      Rational[107, 9], Rational[98, 9]}}, {{11, 10.88888888888889}, {
      11.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{11, 10}, {Rational[107, 9], 10}}, {{11, 10}, {
      11.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[107, 9], 18}, {Rational[115, 9], 18}}, {{
      11.88888888888889, 18}, {12.777777777777779`, 18}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[154, 9]}, {
      Rational[115, 9], Rational[154, 9]}}, {{11.88888888888889, 
     17.11111111111111}, {12.777777777777779`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[146, 9]}, {
      Rational[115, 9], Rational[146, 9]}}, {{11.88888888888889, 
     16.22222222222222}, {12.777777777777779`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[46, 3]}, {
      Rational[115, 9], Rational[46, 3]}}, {{11.88888888888889, 
     15.333333333333334`}, {12.777777777777779`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[130, 9]}, {
      Rational[115, 9], Rational[130, 9]}}, {{11.88888888888889, 
     14.444444444444445`}, {12.777777777777779`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[122, 9]}, {
      Rational[115, 9], Rational[122, 9]}}, {{11.88888888888889, 
     13.555555555555555`}, {12.777777777777779`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[38, 3]}, {
      Rational[115, 9], Rational[38, 3]}}, {{11.88888888888889, 
     12.666666666666666`}, {12.777777777777779`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[106, 9]}, {
      Rational[115, 9], Rational[106, 9]}}, {{11.88888888888889, 
     11.777777777777779`}, {12.777777777777779`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[98, 9]}, {
      Rational[115, 9], Rational[98, 9]}}, {{11.88888888888889, 
     10.88888888888889}, {12.777777777777779`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[107, 9], 10}, {Rational[115, 9], 10}}, {{
      11.88888888888889, 10}, {12.777777777777779`, 10}}]], 
   LineBox[NCache[{{Rational[115, 9], 18}, {Rational[41, 3], 18}}, {{
      12.777777777777779`, 18}, {13.666666666666666`, 18}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[154, 9]}, {
      Rational[41, 3], Rational[154, 9]}}, {{12.777777777777779`, 
     17.11111111111111}, {13.666666666666666`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[146, 9]}, {
      Rational[41, 3], Rational[146, 9]}}, {{12.777777777777779`, 
     16.22222222222222}, {13.666666666666666`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[46, 3]}, {
      Rational[41, 3], Rational[46, 3]}}, {{12.777777777777779`, 
     15.333333333333334`}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[130, 9]}, {
      Rational[41, 3], Rational[130, 9]}}, {{12.777777777777779`, 
     14.444444444444445`}, {13.666666666666666`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[122, 9]}, {
      Rational[41, 3], Rational[122, 9]}}, {{12.777777777777779`, 
     13.555555555555555`}, {13.666666666666666`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[38, 3]}, {
      Rational[41, 3], Rational[38, 3]}}, {{12.777777777777779`, 
     12.666666666666666`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[106, 9]}, {
      Rational[41, 3], Rational[106, 9]}}, {{12.777777777777779`, 
     11.777777777777779`}, {13.666666666666666`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[98, 9]}, {
      Rational[41, 3], Rational[98, 9]}}, {{12.777777777777779`, 
     10.88888888888889}, {13.666666666666666`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[115, 9], 10}, {Rational[41, 3], 10}}, {{
      12.777777777777779`, 10}, {13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {Rational[131, 9], 18}}, {{
      13.666666666666666`, 18}, {14.555555555555555`, 18}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[154, 9]}, {
      Rational[131, 9], Rational[154, 9]}}, {{13.666666666666666`, 
     17.11111111111111}, {14.555555555555555`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[146, 9]}, {
      Rational[131, 9], Rational[146, 9]}}, {{13.666666666666666`, 
     16.22222222222222}, {14.555555555555555`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[131, 9], Rational[46, 3]}}, {{13.666666666666666`, 
     15.333333333333334`}, {14.555555555555555`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[130, 9]}, {
      Rational[131, 9], Rational[130, 9]}}, {{13.666666666666666`, 
     14.444444444444445`}, {14.555555555555555`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[122, 9]}, {
      Rational[131, 9], Rational[122, 9]}}, {{13.666666666666666`, 
     13.555555555555555`}, {14.555555555555555`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[131, 9], Rational[38, 3]}}, {{13.666666666666666`, 
     12.666666666666666`}, {14.555555555555555`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[106, 9]}, {
      Rational[131, 9], Rational[106, 9]}}, {{13.666666666666666`, 
     11.777777777777779`}, {14.555555555555555`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[98, 9]}, {
      Rational[131, 9], Rational[98, 9]}}, {{13.666666666666666`, 
     10.88888888888889}, {14.555555555555555`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[41, 3], 10}, {Rational[131, 9], 10}}, {{
      13.666666666666666`, 10}, {14.555555555555555`, 10}}]], 
   LineBox[NCache[{{Rational[131, 9], 18}, {Rational[139, 9], 18}}, {{
      14.555555555555555`, 18}, {15.444444444444445`, 18}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[154, 9]}, {
      Rational[139, 9], Rational[154, 9]}}, {{14.555555555555555`, 
     17.11111111111111}, {15.444444444444445`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[146, 9]}, {
      Rational[139, 9], Rational[146, 9]}}, {{14.555555555555555`, 
     16.22222222222222}, {15.444444444444445`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[46, 3]}, {
      Rational[139, 9], Rational[46, 3]}}, {{14.555555555555555`, 
     15.333333333333334`}, {15.444444444444445`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[130, 9]}, {
      Rational[139, 9], Rational[130, 9]}}, {{14.555555555555555`, 
     14.444444444444445`}, {15.444444444444445`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[122, 9]}, {
      Rational[139, 9], Rational[122, 9]}}, {{14.555555555555555`, 
     13.555555555555555`}, {15.444444444444445`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[38, 3]}, {
      Rational[139, 9], Rational[38, 3]}}, {{14.555555555555555`, 
     12.666666666666666`}, {15.444444444444445`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[106, 9]}, {
      Rational[139, 9], Rational[106, 9]}}, {{14.555555555555555`, 
     11.777777777777779`}, {15.444444444444445`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[98, 9]}, {
      Rational[139, 9], Rational[98, 9]}}, {{14.555555555555555`, 
     10.88888888888889}, {15.444444444444445`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[131, 9], 10}, {Rational[139, 9], 10}}, {{
      14.555555555555555`, 10}, {15.444444444444445`, 10}}]], 
   LineBox[NCache[{{Rational[139, 9], 18}, {Rational[49, 3], 18}}, {{
      15.444444444444445`, 18}, {16.333333333333332`, 18}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[154, 9]}, {
      Rational[49, 3], Rational[154, 9]}}, {{15.444444444444445`, 
     17.11111111111111}, {16.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[146, 9]}, {
      Rational[49, 3], Rational[146, 9]}}, {{15.444444444444445`, 
     16.22222222222222}, {16.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[46, 3]}, {
      Rational[49, 3], Rational[46, 3]}}, {{15.444444444444445`, 
     15.333333333333334`}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[130, 9]}, {
      Rational[49, 3], Rational[130, 9]}}, {{15.444444444444445`, 
     14.444444444444445`}, {16.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[122, 9]}, {
      Rational[49, 3], Rational[122, 9]}}, {{15.444444444444445`, 
     13.555555555555555`}, {16.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[38, 3]}, {
      Rational[49, 3], Rational[38, 3]}}, {{15.444444444444445`, 
     12.666666666666666`}, {16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[106, 9]}, {
      Rational[49, 3], Rational[106, 9]}}, {{15.444444444444445`, 
     11.777777777777779`}, {16.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[98, 9]}, {
      Rational[49, 3], Rational[98, 9]}}, {{15.444444444444445`, 
     10.88888888888889}, {16.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[139, 9], 10}, {Rational[49, 3], 10}}, {{
      15.444444444444445`, 10}, {16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {Rational[155, 9], 18}}, {{
      16.333333333333332`, 18}, {17.22222222222222, 18}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[154, 9]}, {
      Rational[155, 9], Rational[154, 9]}}, {{16.333333333333332`, 
     17.11111111111111}, {17.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[146, 9]}, {
      Rational[155, 9], Rational[146, 9]}}, {{16.333333333333332`, 
     16.22222222222222}, {17.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[155, 9], Rational[46, 3]}}, {{16.333333333333332`, 
     15.333333333333334`}, {17.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[130, 9]}, {
      Rational[155, 9], Rational[130, 9]}}, {{16.333333333333332`, 
     14.444444444444445`}, {17.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[122, 9]}, {
      Rational[155, 9], Rational[122, 9]}}, {{16.333333333333332`, 
     13.555555555555555`}, {17.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[155, 9], Rational[38, 3]}}, {{16.333333333333332`, 
     12.666666666666666`}, {17.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[106, 9]}, {
      Rational[155, 9], Rational[106, 9]}}, {{16.333333333333332`, 
     11.777777777777779`}, {17.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[98, 9]}, {
      Rational[155, 9], Rational[98, 9]}}, {{16.333333333333332`, 
     10.88888888888889}, {17.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[49, 3], 10}, {Rational[155, 9], 10}}, {{
      16.333333333333332`, 10}, {17.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[155, 9], 18}, {Rational[163, 9], 18}}, {{
      17.22222222222222, 18}, {18.11111111111111, 18}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[154, 9]}, {
      Rational[163, 9], Rational[154, 9]}}, {{17.22222222222222, 
     17.11111111111111}, {18.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[146, 9]}, {
      Rational[163, 9], Rational[146, 9]}}, {{17.22222222222222, 
     16.22222222222222}, {18.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[46, 3]}, {
      Rational[163, 9], Rational[46, 3]}}, {{17.22222222222222, 
     15.333333333333334`}, {18.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[130, 9]}, {
      Rational[163, 9], Rational[130, 9]}}, {{17.22222222222222, 
     14.444444444444445`}, {18.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[122, 9]}, {
      Rational[163, 9], Rational[122, 9]}}, {{17.22222222222222, 
     13.555555555555555`}, {18.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[38, 3]}, {
      Rational[163, 9], Rational[38, 3]}}, {{17.22222222222222, 
     12.666666666666666`}, {18.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[106, 9]}, {
      Rational[163, 9], Rational[106, 9]}}, {{17.22222222222222, 
     11.777777777777779`}, {18.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[98, 9]}, {
      Rational[163, 9], Rational[98, 9]}}, {{17.22222222222222, 
     10.88888888888889}, {18.11111111111111, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[155, 9], 10}, {Rational[163, 9], 10}}, {{
      17.22222222222222, 10}, {18.11111111111111, 10}}]], 
   LineBox[NCache[{{Rational[163, 9], 18}, {19, 18}}, {{
      18.11111111111111, 18}, {19, 18}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[154, 9]}, {
      19, Rational[154, 9]}}, {{18.11111111111111, 17.11111111111111}, {
      19, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[146, 9]}, {
      19, Rational[146, 9]}}, {{18.11111111111111, 16.22222222222222}, {
      19, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[46, 3]}, {
      19, Rational[46, 3]}}, {{18.11111111111111, 15.333333333333334`}, {
      19, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[130, 9]}, {
      19, Rational[130, 9]}}, {{18.11111111111111, 14.444444444444445`}, {
      19, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[122, 9]}, {
      19, Rational[122, 9]}}, {{18.11111111111111, 13.555555555555555`}, {
      19, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[38, 3]}, {
      19, Rational[38, 3]}}, {{18.11111111111111, 12.666666666666666`}, {
      19, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[106, 9]}, {
      19, Rational[106, 9]}}, {{18.11111111111111, 11.777777777777779`}, {
      19, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[98, 9]}, {
      19, Rational[98, 9]}}, {{18.11111111111111, 10.88888888888889}, {
      19, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[163, 9], 10}, {19, 10}}, {{
      18.11111111111111, 10}, {19, 10}}]], 
   LineBox[NCache[{{11, 18}, {11, Rational[154, 9]}}, {{11, 18}, {
      11, 17.11111111111111}}]], 
   LineBox[NCache[{{11, Rational[154, 9]}, {11, Rational[146, 9]}}, {{
      11, 17.11111111111111}, {11, 16.22222222222222}}]], 
   LineBox[NCache[{{11, Rational[146, 9]}, {11, Rational[46, 3]}}, {{
      11, 16.22222222222222}, {11, 15.333333333333334`}}]], 
   LineBox[
    NCache[{{11, Rational[46, 3]}, {11, Rational[130, 9]}}, {{
      11, 15.333333333333334`}, {11, 14.444444444444445`}}]], 
   LineBox[NCache[{{11, Rational[130, 9]}, {11, Rational[122, 9]}}, {{
      11, 14.444444444444445`}, {11, 13.555555555555555`}}]], 
   LineBox[NCache[{{11, Rational[122, 9]}, {11, Rational[38, 3]}}, {{
      11, 13.555555555555555`}, {11, 12.666666666666666`}}]], 
   LineBox[NCache[{{11, Rational[38, 3]}, {11, Rational[106, 9]}}, {{
      11, 12.666666666666666`}, {11, 11.777777777777779`}}]], 
   LineBox[NCache[{{11, Rational[106, 9]}, {11, Rational[98, 9]}}, {{
      11, 11.777777777777779`}, {11, 10.88888888888889}}]], 
   LineBox[NCache[{{11, Rational[98, 9]}, {11, 10}}, {{
      11, 10.88888888888889}, {11, 10}}]], 
   LineBox[NCache[{{Rational[107, 9], 18}, {
      Rational[107, 9], Rational[154, 9]}}, {{11.88888888888889, 18}, {
      11.88888888888889, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[154, 9]}, {
      Rational[107, 9], Rational[146, 9]}}, {{11.88888888888889, 
     17.11111111111111}, {11.88888888888889, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[146, 9]}, {
      Rational[107, 9], Rational[46, 3]}}, {{11.88888888888889, 
     16.22222222222222}, {11.88888888888889, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[46, 3]}, {
      Rational[107, 9], Rational[130, 9]}}, {{11.88888888888889, 
     15.333333333333334`}, {11.88888888888889, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[130, 9]}, {
      Rational[107, 9], Rational[122, 9]}}, {{11.88888888888889, 
     14.444444444444445`}, {11.88888888888889, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[122, 9]}, {
      Rational[107, 9], Rational[38, 3]}}, {{11.88888888888889, 
     13.555555555555555`}, {11.88888888888889, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[38, 3]}, {
      Rational[107, 9], Rational[106, 9]}}, {{11.88888888888889, 
     12.666666666666666`}, {11.88888888888889, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[106, 9]}, {
      Rational[107, 9], Rational[98, 9]}}, {{11.88888888888889, 
     11.777777777777779`}, {11.88888888888889, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[107, 9], Rational[98, 9]}, {
      Rational[107, 9], 10}}, {{11.88888888888889, 10.88888888888889}, {
      11.88888888888889, 10}}]], 
   LineBox[NCache[{{Rational[115, 9], 18}, {
      Rational[115, 9], Rational[154, 9]}}, {{12.777777777777779`, 18}, {
      12.777777777777779`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[154, 9]}, {
      Rational[115, 9], Rational[146, 9]}}, {{12.777777777777779`, 
     17.11111111111111}, {12.777777777777779`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[146, 9]}, {
      Rational[115, 9], Rational[46, 3]}}, {{12.777777777777779`, 
     16.22222222222222}, {12.777777777777779`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[46, 3]}, {
      Rational[115, 9], Rational[130, 9]}}, {{12.777777777777779`, 
     15.333333333333334`}, {12.777777777777779`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[130, 9]}, {
      Rational[115, 9], Rational[122, 9]}}, {{12.777777777777779`, 
     14.444444444444445`}, {12.777777777777779`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[122, 9]}, {
      Rational[115, 9], Rational[38, 3]}}, {{12.777777777777779`, 
     13.555555555555555`}, {12.777777777777779`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[38, 3]}, {
      Rational[115, 9], Rational[106, 9]}}, {{12.777777777777779`, 
     12.666666666666666`}, {12.777777777777779`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[106, 9]}, {
      Rational[115, 9], Rational[98, 9]}}, {{12.777777777777779`, 
     11.777777777777779`}, {12.777777777777779`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[115, 9], Rational[98, 9]}, {
      Rational[115, 9], 10}}, {{12.777777777777779`, 10.88888888888889}, {
      12.777777777777779`, 10}}]], 
   LineBox[NCache[{{Rational[41, 3], 18}, {
      Rational[41, 3], Rational[154, 9]}}, {{13.666666666666666`, 18}, {
      13.666666666666666`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[154, 9]}, {
      Rational[41, 3], Rational[146, 9]}}, {{13.666666666666666`, 
     17.11111111111111}, {13.666666666666666`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[146, 9]}, {
      Rational[41, 3], Rational[46, 3]}}, {{13.666666666666666`, 
     16.22222222222222}, {13.666666666666666`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[46, 3]}, {
      Rational[41, 3], Rational[130, 9]}}, {{13.666666666666666`, 
     15.333333333333334`}, {13.666666666666666`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[130, 9]}, {
      Rational[41, 3], Rational[122, 9]}}, {{13.666666666666666`, 
     14.444444444444445`}, {13.666666666666666`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[122, 9]}, {
      Rational[41, 3], Rational[38, 3]}}, {{13.666666666666666`, 
     13.555555555555555`}, {13.666666666666666`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[38, 3]}, {
      Rational[41, 3], Rational[106, 9]}}, {{13.666666666666666`, 
     12.666666666666666`}, {13.666666666666666`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[106, 9]}, {
      Rational[41, 3], Rational[98, 9]}}, {{13.666666666666666`, 
     11.777777777777779`}, {13.666666666666666`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[41, 3], Rational[98, 9]}, {
      Rational[41, 3], 10}}, {{13.666666666666666`, 10.88888888888889}, {
      13.666666666666666`, 10}}]], 
   LineBox[NCache[{{Rational[131, 9], 18}, {
      Rational[131, 9], Rational[154, 9]}}, {{14.555555555555555`, 18}, {
      14.555555555555555`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[154, 9]}, {
      Rational[131, 9], Rational[146, 9]}}, {{14.555555555555555`, 
     17.11111111111111}, {14.555555555555555`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[146, 9]}, {
      Rational[131, 9], Rational[46, 3]}}, {{14.555555555555555`, 
     16.22222222222222}, {14.555555555555555`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[46, 3]}, {
      Rational[131, 9], Rational[130, 9]}}, {{14.555555555555555`, 
     15.333333333333334`}, {14.555555555555555`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[130, 9]}, {
      Rational[131, 9], Rational[122, 9]}}, {{14.555555555555555`, 
     14.444444444444445`}, {14.555555555555555`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[122, 9]}, {
      Rational[131, 9], Rational[38, 3]}}, {{14.555555555555555`, 
     13.555555555555555`}, {14.555555555555555`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[38, 3]}, {
      Rational[131, 9], Rational[106, 9]}}, {{14.555555555555555`, 
     12.666666666666666`}, {14.555555555555555`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[106, 9]}, {
      Rational[131, 9], Rational[98, 9]}}, {{14.555555555555555`, 
     11.777777777777779`}, {14.555555555555555`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[131, 9], Rational[98, 9]}, {
      Rational[131, 9], 10}}, {{14.555555555555555`, 10.88888888888889}, {
      14.555555555555555`, 10}}]], 
   LineBox[NCache[{{Rational[139, 9], 18}, {
      Rational[139, 9], Rational[154, 9]}}, {{15.444444444444445`, 18}, {
      15.444444444444445`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[154, 9]}, {
      Rational[139, 9], Rational[146, 9]}}, {{15.444444444444445`, 
     17.11111111111111}, {15.444444444444445`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[146, 9]}, {
      Rational[139, 9], Rational[46, 3]}}, {{15.444444444444445`, 
     16.22222222222222}, {15.444444444444445`, 15.333333333333334`}}]], 
   LineBox[
    NCache[{{Rational[139, 9], Rational[46, 3]}, {
      Rational[139, 9], Rational[130, 9]}}, {{15.444444444444445`, 
     15.333333333333334`}, {15.444444444444445`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[130, 9]}, {
      Rational[139, 9], Rational[122, 9]}}, {{15.444444444444445`, 
     14.444444444444445`}, {15.444444444444445`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[122, 9]}, {
      Rational[139, 9], Rational[38, 3]}}, {{15.444444444444445`, 
     13.555555555555555`}, {15.444444444444445`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[38, 3]}, {
      Rational[139, 9], Rational[106, 9]}}, {{15.444444444444445`, 
     12.666666666666666`}, {15.444444444444445`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[106, 9]}, {
      Rational[139, 9], Rational[98, 9]}}, {{15.444444444444445`, 
     11.777777777777779`}, {15.444444444444445`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[139, 9], Rational[98, 9]}, {
      Rational[139, 9], 10}}, {{15.444444444444445`, 10.88888888888889}, {
      15.444444444444445`, 10}}]], 
   LineBox[NCache[{{Rational[49, 3], 18}, {
      Rational[49, 3], Rational[154, 9]}}, {{16.333333333333332`, 18}, {
      16.333333333333332`, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[154, 9]}, {
      Rational[49, 3], Rational[146, 9]}}, {{16.333333333333332`, 
     17.11111111111111}, {16.333333333333332`, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[146, 9]}, {
      Rational[49, 3], Rational[46, 3]}}, {{16.333333333333332`, 
     16.22222222222222}, {16.333333333333332`, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[46, 3]}, {
      Rational[49, 3], Rational[130, 9]}}, {{16.333333333333332`, 
     15.333333333333334`}, {16.333333333333332`, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[130, 9]}, {
      Rational[49, 3], Rational[122, 9]}}, {{16.333333333333332`, 
     14.444444444444445`}, {16.333333333333332`, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[122, 9]}, {
      Rational[49, 3], Rational[38, 3]}}, {{16.333333333333332`, 
     13.555555555555555`}, {16.333333333333332`, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[38, 3]}, {
      Rational[49, 3], Rational[106, 9]}}, {{16.333333333333332`, 
     12.666666666666666`}, {16.333333333333332`, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[106, 9]}, {
      Rational[49, 3], Rational[98, 9]}}, {{16.333333333333332`, 
     11.777777777777779`}, {16.333333333333332`, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[49, 3], Rational[98, 9]}, {
      Rational[49, 3], 10}}, {{16.333333333333332`, 10.88888888888889}, {
      16.333333333333332`, 10}}]], 
   LineBox[NCache[{{Rational[155, 9], 18}, {
      Rational[155, 9], Rational[154, 9]}}, {{17.22222222222222, 18}, {
      17.22222222222222, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[154, 9]}, {
      Rational[155, 9], Rational[146, 9]}}, {{17.22222222222222, 
     17.11111111111111}, {17.22222222222222, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[146, 9]}, {
      Rational[155, 9], Rational[46, 3]}}, {{17.22222222222222, 
     16.22222222222222}, {17.22222222222222, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[46, 3]}, {
      Rational[155, 9], Rational[130, 9]}}, {{17.22222222222222, 
     15.333333333333334`}, {17.22222222222222, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[130, 9]}, {
      Rational[155, 9], Rational[122, 9]}}, {{17.22222222222222, 
     14.444444444444445`}, {17.22222222222222, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[122, 9]}, {
      Rational[155, 9], Rational[38, 3]}}, {{17.22222222222222, 
     13.555555555555555`}, {17.22222222222222, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[38, 3]}, {
      Rational[155, 9], Rational[106, 9]}}, {{17.22222222222222, 
     12.666666666666666`}, {17.22222222222222, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[106, 9]}, {
      Rational[155, 9], Rational[98, 9]}}, {{17.22222222222222, 
     11.777777777777779`}, {17.22222222222222, 10.88888888888889}}]], 
   LineBox[NCache[{{Rational[155, 9], Rational[98, 9]}, {
      Rational[155, 9], 10}}, {{17.22222222222222, 10.88888888888889}, {
      17.22222222222222, 10}}]], 
   LineBox[NCache[{{Rational[163, 9], 18}, {
      Rational[163, 9], Rational[154, 9]}}, {{18.11111111111111, 18}, {
      18.11111111111111, 17.11111111111111}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[154, 9]}, {
      Rational[163, 9], Rational[146, 9]}}, {{18.11111111111111, 
     17.11111111111111}, {18.11111111111111, 16.22222222222222}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[146, 9]}, {
      Rational[163, 9], Rational[46, 3]}}, {{18.11111111111111, 
     16.22222222222222}, {18.11111111111111, 15.333333333333334`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[46, 3]}, {
      Rational[163, 9], Rational[130, 9]}}, {{18.11111111111111, 
     15.333333333333334`}, {18.11111111111111, 14.444444444444445`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[130, 9]}, {
      Rational[163, 9], Rational[122, 9]}}, {{18.11111111111111, 
     14.444444444444445`}, {18.11111111111111, 13.555555555555555`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[122, 9]}, {
      Rational[163, 9], Rational[38, 3]}}, {{18.11111111111111, 
     13.555555555555555`}, {18.11111111111111, 12.666666666666666`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[38, 3]}, {
      Rational[163, 9], Rational[106, 9]}}, {{18.11111111111111, 
     12.666666666666666`}, {18.11111111111111, 11.777777777777779`}}]], 
   LineBox[NCache[{{Rational[163, 9], Rational[106, 9]}, {
      Rational[163, 9], Rational[98, 9]}}, {{18.11111111111111, 
     11.777777777777779`}, {18.11111111111111, 10.88888888888889}}]], 
   LineBox[
    NCache[{{Rational[163, 9], Rational[98, 9]}, {Rational[163, 9], 10}}, {{
      18.11111111111111, 10.88888888888889}, {18.11111111111111, 10}}]], 
   LineBox[NCache[{{19, 18}, {19, Rational[154, 9]}}, {{19, 18}, {
      19, 17.11111111111111}}]], 
   LineBox[NCache[{{19, Rational[154, 9]}, {19, Rational[146, 9]}}, {{
      19, 17.11111111111111}, {19, 16.22222222222222}}]], 
   LineBox[NCache[{{19, Rational[146, 9]}, {19, Rational[46, 3]}}, {{
      19, 16.22222222222222}, {19, 15.333333333333334`}}]], 
   LineBox[NCache[{{19, Rational[46, 3]}, {19, Rational[130, 9]}}, {{
      19, 15.333333333333334`}, {19, 14.444444444444445`}}]], 
   LineBox[NCache[{{19, Rational[130, 9]}, {19, Rational[122, 9]}}, {{
      19, 14.444444444444445`}, {19, 13.555555555555555`}}]], 
   LineBox[NCache[{{19, Rational[122, 9]}, {19, Rational[38, 3]}}, {{
      19, 13.555555555555555`}, {19, 12.666666666666666`}}]], 
   LineBox[NCache[{{19, Rational[38, 3]}, {19, Rational[106, 9]}}, {{
      19, 12.666666666666666`}, {19, 11.777777777777779`}}]], 
   LineBox[NCache[{{19, Rational[106, 9]}, {19, Rational[98, 9]}}, {{
      19, 11.777777777777779`}, {19, 10.88888888888889}}]], 
   LineBox[NCache[{{19, Rational[98, 9]}, {19, 10}}, {{
      19, 10.88888888888889}, {19, 10}}]], LineBox[{{21, 18}, {25, 18}}], 
   LineBox[{{21, 14}, {25, 14}}], LineBox[{{21, 10}, {25, 10}}], 
   LineBox[{{25, 18}, {29, 18}}], LineBox[{{25, 14}, {29, 14}}], 
   LineBox[{{25, 10}, {29, 10}}], LineBox[{{21, 18}, {21, 14}}], 
   LineBox[{{21, 14}, {21, 10}}], LineBox[{{25, 18}, {25, 14}}], 
   LineBox[{{25, 14}, {25, 10}}], LineBox[{{29, 18}, {29, 14}}], 
   LineBox[{{29, 14}, {29, 10}}], LineBox[{{11, 8}, {15, 8}}], 
   LineBox[{{11, 4}, {15, 4}}], LineBox[{{11, 0}, {15, 0}}], 
   LineBox[{{15, 8}, {19, 8}}], LineBox[{{15, 4}, {19, 4}}], 
   LineBox[{{15, 0}, {19, 0}}], LineBox[{{11, 8}, {11, 4}}], 
   LineBox[{{11, 4}, {11, 0}}], LineBox[{{15, 8}, {15, 4}}], 
   LineBox[{{15, 4}, {15, 0}}], LineBox[{{19, 8}, {19, 4}}], 
   LineBox[{{19, 4}, {19, 0}}], 
   LineBox[NCache[{{21, 8}, {Rational[197, 9], 8}}, {{21, 8}, {
      21.88888888888889, 8}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {
      Rational[197, 9], Rational[64, 9]}}, {{21, 7.111111111111111}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21, 6.222222222222222}, {
      21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21, 5.333333333333333}, {
      21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21, 4.444444444444445}, {
      21.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21, 3.5555555555555554`}, {
      21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21, 2.6666666666666665`}, {
      21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21, 1.7777777777777777`}, {
      21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21, 0.8888888888888888}, {
      21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, 0}, {Rational[197, 9], 0}}, {{21, 0}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {Rational[205, 9], 8}}, {{
      21.88888888888889, 8}, {22.77777777777778, 8}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[64, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{21.88888888888889, 
     6.222222222222222}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[16, 3]}}, {{21.88888888888889, 
     5.333333333333333}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[40, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{21.88888888888889, 
     3.5555555555555554`}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[8, 3]}}, {{21.88888888888889, 
     2.6666666666666665`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[16, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{21.88888888888889, 
     0.8888888888888888}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], 0}, {Rational[205, 9], 0}}, {{
      21.88888888888889, 0}, {22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {Rational[71, 3], 8}}, {{
      22.77777777777778, 8}, {23.666666666666668`, 8}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[71, 3], Rational[64, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{22.77777777777778, 
     6.222222222222222}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[71, 3], Rational[16, 3]}}, {{22.77777777777778, 
     5.333333333333333}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[71, 3], Rational[40, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{22.77777777777778, 
     3.5555555555555554`}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[71, 3], Rational[8, 3]}}, {{22.77777777777778, 
     2.6666666666666665`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[71, 3], Rational[16, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{22.77777777777778, 
     0.8888888888888888}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], 0}, {Rational[71, 3], 0}}, {{
      22.77777777777778, 0}, {23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {Rational[221, 9], 8}}, {{
      23.666666666666668`, 8}, {24.555555555555557`, 8}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[221, 9], Rational[64, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{23.666666666666668`, 
     6.222222222222222}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[221, 9], Rational[16, 3]}}, {{23.666666666666668`, 
     5.333333333333333}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[221, 9], Rational[40, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[221, 9], Rational[8, 3]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[221, 9], Rational[16, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{23.666666666666668`, 
     0.8888888888888888}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[71, 3], 0}, {Rational[221, 9], 0}}, {{
      23.666666666666668`, 0}, {24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {Rational[229, 9], 8}}, {{
      24.555555555555557`, 8}, {25.444444444444443`, 8}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[64, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {25.444444444444443`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     6.222222222222222}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     5.333333333333333}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[
    NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     0.8888888888888888}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], 0}, {Rational[229, 9], 0}}, {{
      24.555555555555557`, 0}, {25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {Rational[79, 3], 8}}, {{
      25.444444444444443`, 8}, {26.333333333333332`, 8}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[79, 3], Rational[64, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{25.444444444444443`, 
     6.222222222222222}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[79, 3], Rational[16, 3]}}, {{25.444444444444443`, 
     5.333333333333333}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[79, 3], Rational[40, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[79, 3], Rational[8, 3]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[79, 3], Rational[16, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[
    NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{25.444444444444443`, 
     0.8888888888888888}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], 0}, {Rational[79, 3], 0}}, {{
      25.444444444444443`, 0}, {26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {Rational[245, 9], 8}}, {{
      26.333333333333332`, 8}, {27.22222222222222, 8}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[245, 9], Rational[64, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{26.333333333333332`, 
     6.222222222222222}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[245, 9], Rational[16, 3]}}, {{26.333333333333332`, 
     5.333333333333333}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[245, 9], Rational[40, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[245, 9], Rational[8, 3]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[245, 9], Rational[16, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{26.333333333333332`, 
     0.8888888888888888}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[79, 3], 0}, {Rational[245, 9], 0}}, {{
      26.333333333333332`, 0}, {27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {Rational[253, 9], 8}}, {{
      27.22222222222222, 8}, {28.11111111111111, 8}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[64, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{27.22222222222222, 
     6.222222222222222}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[16, 3]}}, {{27.22222222222222, 
     5.333333333333333}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[40, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{27.22222222222222, 
     3.5555555555555554`}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[8, 3]}}, {{27.22222222222222, 
     2.6666666666666665`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[16, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{27.22222222222222, 
     0.8888888888888888}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], 0}, {Rational[253, 9], 0}}, {{
      27.22222222222222, 0}, {28.11111111111111, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {29, 8}}, {{28.11111111111111, 8}, {
      29, 8}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      29, Rational[64, 9]}}, {{28.11111111111111, 7.111111111111111}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      29, Rational[56, 9]}}, {{28.11111111111111, 6.222222222222222}, {
      29, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      29, Rational[16, 3]}}, {{28.11111111111111, 5.333333333333333}, {
      29, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      29, Rational[40, 9]}}, {{28.11111111111111, 4.444444444444445}, {
      29, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      29, Rational[32, 9]}}, {{28.11111111111111, 3.5555555555555554`}, {
      29, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      29, Rational[8, 3]}}, {{28.11111111111111, 2.6666666666666665`}, {
      29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 9]}, {
      29, Rational[16, 9]}}, {{28.11111111111111, 1.7777777777777777`}, {
      29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      29, Rational[8, 9]}}, {{28.11111111111111, 0.8888888888888888}, {
      29, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], 0}, {29, 0}}, {{28.11111111111111, 0}, {
      29, 0}}]], 
   LineBox[NCache[{{21, 8}, {21, Rational[64, 9]}}, {{21, 8}, {
      21, 7.111111111111111}}]], 
   LineBox[NCache[{{21, Rational[64, 9]}, {21, Rational[56, 9]}}, {{
      21, 7.111111111111111}, {21, 6.222222222222222}}]], 
   LineBox[NCache[{{21, Rational[56, 9]}, {21, Rational[16, 3]}}, {{
      21, 6.222222222222222}, {21, 5.333333333333333}}]], 
   LineBox[NCache[{{21, Rational[16, 3]}, {21, Rational[40, 9]}}, {{
      21, 5.333333333333333}, {21, 4.444444444444445}}]], 
   LineBox[NCache[{{21, Rational[40, 9]}, {21, Rational[32, 9]}}, {{
      21, 4.444444444444445}, {21, 3.5555555555555554`}}]], 
   LineBox[NCache[{{21, Rational[32, 9]}, {21, Rational[8, 3]}}, {{
      21, 3.5555555555555554`}, {21, 2.6666666666666665`}}]], 
   LineBox[NCache[{{21, Rational[8, 3]}, {21, Rational[16, 9]}}, {{
      21, 2.6666666666666665`}, {21, 1.7777777777777777`}}]], 
   LineBox[NCache[{{21, Rational[16, 9]}, {21, Rational[8, 9]}}, {{
      21, 1.7777777777777777`}, {21, 0.8888888888888888}}]], 
   LineBox[NCache[{{21, Rational[8, 9]}, {21, 0}}, {{
      21, 0.8888888888888888}, {21, 0}}]], 
   LineBox[NCache[{{Rational[197, 9], 8}, {
      Rational[197, 9], Rational[64, 9]}}, {{21.88888888888889, 8}, {
      21.88888888888889, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[64, 9]}, {
      Rational[197, 9], Rational[56, 9]}}, {{21.88888888888889, 
     7.111111111111111}, {21.88888888888889, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[56, 9]}, {
      Rational[197, 9], Rational[16, 3]}}, {{21.88888888888889, 
     6.222222222222222}, {21.88888888888889, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 3]}, {
      Rational[197, 9], Rational[40, 9]}}, {{21.88888888888889, 
     5.333333333333333}, {21.88888888888889, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[40, 9]}, {
      Rational[197, 9], Rational[32, 9]}}, {{21.88888888888889, 
     4.444444444444445}, {21.88888888888889, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[32, 9]}, {
      Rational[197, 9], Rational[8, 3]}}, {{21.88888888888889, 
     3.5555555555555554`}, {21.88888888888889, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 3]}, {
      Rational[197, 9], Rational[16, 9]}}, {{21.88888888888889, 
     2.6666666666666665`}, {21.88888888888889, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[16, 9]}, {
      Rational[197, 9], Rational[8, 9]}}, {{21.88888888888889, 
     1.7777777777777777`}, {21.88888888888889, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[197, 9], Rational[8, 9]}, {
      Rational[197, 9], 0}}, {{21.88888888888889, 0.8888888888888888}, {
      21.88888888888889, 0}}]], 
   LineBox[NCache[{{Rational[205, 9], 8}, {
      Rational[205, 9], Rational[64, 9]}}, {{22.77777777777778, 8}, {
      22.77777777777778, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[64, 9]}, {
      Rational[205, 9], Rational[56, 9]}}, {{22.77777777777778, 
     7.111111111111111}, {22.77777777777778, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[56, 9]}, {
      Rational[205, 9], Rational[16, 3]}}, {{22.77777777777778, 
     6.222222222222222}, {22.77777777777778, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 3]}, {
      Rational[205, 9], Rational[40, 9]}}, {{22.77777777777778, 
     5.333333333333333}, {22.77777777777778, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[40, 9]}, {
      Rational[205, 9], Rational[32, 9]}}, {{22.77777777777778, 
     4.444444444444445}, {22.77777777777778, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[32, 9]}, {
      Rational[205, 9], Rational[8, 3]}}, {{22.77777777777778, 
     3.5555555555555554`}, {22.77777777777778, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 3]}, {
      Rational[205, 9], Rational[16, 9]}}, {{22.77777777777778, 
     2.6666666666666665`}, {22.77777777777778, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[16, 9]}, {
      Rational[205, 9], Rational[8, 9]}}, {{22.77777777777778, 
     1.7777777777777777`}, {22.77777777777778, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[205, 9], Rational[8, 9]}, {
      Rational[205, 9], 0}}, {{22.77777777777778, 0.8888888888888888}, {
      22.77777777777778, 0}}]], 
   LineBox[NCache[{{Rational[71, 3], 8}, {
      Rational[71, 3], Rational[64, 9]}}, {{23.666666666666668`, 8}, {
      23.666666666666668`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[64, 9]}, {
      Rational[71, 3], Rational[56, 9]}}, {{23.666666666666668`, 
     7.111111111111111}, {23.666666666666668`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[56, 9]}, {
      Rational[71, 3], Rational[16, 3]}}, {{23.666666666666668`, 
     6.222222222222222}, {23.666666666666668`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 3]}, {
      Rational[71, 3], Rational[40, 9]}}, {{23.666666666666668`, 
     5.333333333333333}, {23.666666666666668`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[40, 9]}, {
      Rational[71, 3], Rational[32, 9]}}, {{23.666666666666668`, 
     4.444444444444445}, {23.666666666666668`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[32, 9]}, {
      Rational[71, 3], Rational[8, 3]}}, {{23.666666666666668`, 
     3.5555555555555554`}, {23.666666666666668`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 3]}, {
      Rational[71, 3], Rational[16, 9]}}, {{23.666666666666668`, 
     2.6666666666666665`}, {23.666666666666668`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[16, 9]}, {
      Rational[71, 3], Rational[8, 9]}}, {{23.666666666666668`, 
     1.7777777777777777`}, {23.666666666666668`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[71, 3], Rational[8, 9]}, {
      Rational[71, 3], 0}}, {{23.666666666666668`, 0.8888888888888888}, {
      23.666666666666668`, 0}}]], 
   LineBox[NCache[{{Rational[221, 9], 8}, {
      Rational[221, 9], Rational[64, 9]}}, {{24.555555555555557`, 8}, {
      24.555555555555557`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[64, 9]}, {
      Rational[221, 9], Rational[56, 9]}}, {{24.555555555555557`, 
     7.111111111111111}, {24.555555555555557`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[56, 9]}, {
      Rational[221, 9], Rational[16, 3]}}, {{24.555555555555557`, 
     6.222222222222222}, {24.555555555555557`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 3]}, {
      Rational[221, 9], Rational[40, 9]}}, {{24.555555555555557`, 
     5.333333333333333}, {24.555555555555557`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[40, 9]}, {
      Rational[221, 9], Rational[32, 9]}}, {{24.555555555555557`, 
     4.444444444444445}, {24.555555555555557`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[32, 9]}, {
      Rational[221, 9], Rational[8, 3]}}, {{24.555555555555557`, 
     3.5555555555555554`}, {24.555555555555557`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 3]}, {
      Rational[221, 9], Rational[16, 9]}}, {{24.555555555555557`, 
     2.6666666666666665`}, {24.555555555555557`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[16, 9]}, {
      Rational[221, 9], Rational[8, 9]}}, {{24.555555555555557`, 
     1.7777777777777777`}, {24.555555555555557`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[221, 9], Rational[8, 9]}, {
      Rational[221, 9], 0}}, {{24.555555555555557`, 0.8888888888888888}, {
      24.555555555555557`, 0}}]], 
   LineBox[NCache[{{Rational[229, 9], 8}, {
      Rational[229, 9], Rational[64, 9]}}, {{25.444444444444443`, 8}, {
      25.444444444444443`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[64, 9]}, {
      Rational[229, 9], Rational[56, 9]}}, {{25.444444444444443`, 
     7.111111111111111}, {25.444444444444443`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[56, 9]}, {
      Rational[229, 9], Rational[16, 3]}}, {{25.444444444444443`, 
     6.222222222222222}, {25.444444444444443`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 3]}, {
      Rational[229, 9], Rational[40, 9]}}, {{25.444444444444443`, 
     5.333333333333333}, {25.444444444444443`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[40, 9]}, {
      Rational[229, 9], Rational[32, 9]}}, {{25.444444444444443`, 
     4.444444444444445}, {25.444444444444443`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[32, 9]}, {
      Rational[229, 9], Rational[8, 3]}}, {{25.444444444444443`, 
     3.5555555555555554`}, {25.444444444444443`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 3]}, {
      Rational[229, 9], Rational[16, 9]}}, {{25.444444444444443`, 
     2.6666666666666665`}, {25.444444444444443`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[16, 9]}, {
      Rational[229, 9], Rational[8, 9]}}, {{25.444444444444443`, 
     1.7777777777777777`}, {25.444444444444443`, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[229, 9], Rational[8, 9]}, {
      Rational[229, 9], 0}}, {{25.444444444444443`, 0.8888888888888888}, {
      25.444444444444443`, 0}}]], 
   LineBox[NCache[{{Rational[79, 3], 8}, {
      Rational[79, 3], Rational[64, 9]}}, {{26.333333333333332`, 8}, {
      26.333333333333332`, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[64, 9]}, {
      Rational[79, 3], Rational[56, 9]}}, {{26.333333333333332`, 
     7.111111111111111}, {26.333333333333332`, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[56, 9]}, {
      Rational[79, 3], Rational[16, 3]}}, {{26.333333333333332`, 
     6.222222222222222}, {26.333333333333332`, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 3]}, {
      Rational[79, 3], Rational[40, 9]}}, {{26.333333333333332`, 
     5.333333333333333}, {26.333333333333332`, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[40, 9]}, {
      Rational[79, 3], Rational[32, 9]}}, {{26.333333333333332`, 
     4.444444444444445}, {26.333333333333332`, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[32, 9]}, {
      Rational[79, 3], Rational[8, 3]}}, {{26.333333333333332`, 
     3.5555555555555554`}, {26.333333333333332`, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[8, 3]}, {
      Rational[79, 3], Rational[16, 9]}}, {{26.333333333333332`, 
     2.6666666666666665`}, {26.333333333333332`, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[79, 3], Rational[16, 9]}, {
      Rational[79, 3], Rational[8, 9]}}, {{26.333333333333332`, 
     1.7777777777777777`}, {26.333333333333332`, 0.8888888888888888}}]], 
   LineBox[
    NCache[{{Rational[79, 3], Rational[8, 9]}, {Rational[79, 3], 0}}, {{
      26.333333333333332`, 0.8888888888888888}, {26.333333333333332`, 0}}]], 
   LineBox[NCache[{{Rational[245, 9], 8}, {
      Rational[245, 9], Rational[64, 9]}}, {{27.22222222222222, 8}, {
      27.22222222222222, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[64, 9]}, {
      Rational[245, 9], Rational[56, 9]}}, {{27.22222222222222, 
     7.111111111111111}, {27.22222222222222, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[56, 9]}, {
      Rational[245, 9], Rational[16, 3]}}, {{27.22222222222222, 
     6.222222222222222}, {27.22222222222222, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 3]}, {
      Rational[245, 9], Rational[40, 9]}}, {{27.22222222222222, 
     5.333333333333333}, {27.22222222222222, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[40, 9]}, {
      Rational[245, 9], Rational[32, 9]}}, {{27.22222222222222, 
     4.444444444444445}, {27.22222222222222, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[32, 9]}, {
      Rational[245, 9], Rational[8, 3]}}, {{27.22222222222222, 
     3.5555555555555554`}, {27.22222222222222, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 3]}, {
      Rational[245, 9], Rational[16, 9]}}, {{27.22222222222222, 
     2.6666666666666665`}, {27.22222222222222, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[16, 9]}, {
      Rational[245, 9], Rational[8, 9]}}, {{27.22222222222222, 
     1.7777777777777777`}, {27.22222222222222, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[245, 9], Rational[8, 9]}, {
      Rational[245, 9], 0}}, {{27.22222222222222, 0.8888888888888888}, {
      27.22222222222222, 0}}]], 
   LineBox[NCache[{{Rational[253, 9], 8}, {
      Rational[253, 9], Rational[64, 9]}}, {{28.11111111111111, 8}, {
      28.11111111111111, 7.111111111111111}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[64, 9]}, {
      Rational[253, 9], Rational[56, 9]}}, {{28.11111111111111, 
     7.111111111111111}, {28.11111111111111, 6.222222222222222}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[56, 9]}, {
      Rational[253, 9], Rational[16, 3]}}, {{28.11111111111111, 
     6.222222222222222}, {28.11111111111111, 5.333333333333333}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 3]}, {
      Rational[253, 9], Rational[40, 9]}}, {{28.11111111111111, 
     5.333333333333333}, {28.11111111111111, 4.444444444444445}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[40, 9]}, {
      Rational[253, 9], Rational[32, 9]}}, {{28.11111111111111, 
     4.444444444444445}, {28.11111111111111, 3.5555555555555554`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[32, 9]}, {
      Rational[253, 9], Rational[8, 3]}}, {{28.11111111111111, 
     3.5555555555555554`}, {28.11111111111111, 2.6666666666666665`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 3]}, {
      Rational[253, 9], Rational[16, 9]}}, {{28.11111111111111, 
     2.6666666666666665`}, {28.11111111111111, 1.7777777777777777`}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[16, 9]}, {
      Rational[253, 9], Rational[8, 9]}}, {{28.11111111111111, 
     1.7777777777777777`}, {28.11111111111111, 0.8888888888888888}}]], 
   LineBox[NCache[{{Rational[253, 9], Rational[8, 9]}, {
      Rational[253, 9], 0}}, {{28.11111111111111, 0.8888888888888888}, {
      28.11111111111111, 0}}]], 
   LineBox[NCache[{{29, 8}, {29, Rational[64, 9]}}, {{29, 8}, {
      29, 7.111111111111111}}]], 
   LineBox[NCache[{{29, Rational[64, 9]}, {29, Rational[56, 9]}}, {{
      29, 7.111111111111111}, {29, 6.222222222222222}}]], 
   LineBox[NCache[{{29, Rational[56, 9]}, {29, Rational[16, 3]}}, {{
      29, 6.222222222222222}, {29, 5.333333333333333}}]], 
   LineBox[NCache[{{29, Rational[16, 3]}, {29, Rational[40, 9]}}, {{
      29, 5.333333333333333}, {29, 4.444444444444445}}]], 
   LineBox[NCache[{{29, Rational[40, 9]}, {29, Rational[32, 9]}}, {{
      29, 4.444444444444445}, {29, 3.5555555555555554`}}]], 
   LineBox[
    NCache[{{29, Rational[32, 9]}, {29, Rational[8, 3]}}, {{
      29, 3.5555555555555554`}, {29, 2.6666666666666665`}}]], 
   LineBox[NCache[{{29, Rational[8, 3]}, {29, Rational[16, 9]}}, {{
      29, 2.6666666666666665`}, {29, 1.7777777777777777`}}]], 
   LineBox[NCache[{{29, Rational[16, 9]}, {29, Rational[8, 9]}}, {{
      29, 1.7777777777777777`}, {29, 0.8888888888888888}}]], 
   LineBox[NCache[{{29, Rational[8, 9]}, {29, 0}}, {{
      29, 0.8888888888888888}, {29, 0}}]]},
  ImageSize->400]], "Output",
 CellChangeTimes->{3.470850791000624*^9, 3.470867724592778*^9, 
  3.470867806709803*^9, 3.470874481462757*^9, 3.470878273143089*^9, 
  3.470881815098432*^9, 3.470912104200487*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1360, 692},
WindowMargins->{{0, Automatic}, {Automatic, 25}},
FrontEndVersion->"7.0 for Linux x86 (32-bit) (November 27, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 102, 1, 39, "Subsection"],
Cell[672, 25, 1023, 27, 55, "Input"],
Cell[1698, 54, 2869, 75, 231, "Input"],
Cell[4570, 131, 2636, 72, 275, "Input"],
Cell[7209, 205, 164, 4, 32, "Input"],
Cell[7376, 211, 166, 4, 32, "Input"],
Cell[7545, 217, 162, 4, 32, "Input"],
Cell[7710, 223, 168, 4, 32, "Input"],
Cell[7881, 229, 1611, 45, 187, "Input"],
Cell[9495, 276, 4248, 105, 297, "Input"],
Cell[13746, 383, 614, 19, 55, "Input"],
Cell[14363, 404, 2557, 67, 231, "Input"],
Cell[16923, 473, 3475, 87, 275, "Input"],
Cell[20401, 562, 6073, 137, 561, "Input"],
Cell[26477, 701, 6487, 151, 539, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33001, 857, 112, 1, 39, "Subsection"],
Cell[33116, 860, 189, 4, 32, "Input"],
Cell[33308, 866, 493, 14, 32, "Input"],
Cell[33804, 882, 60149, 995, 93, "Input"],
Cell[CellGroupData[{
Cell[93978, 1881, 233, 6, 32, "Input"],
Cell[94214, 1889, 843, 14, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95094, 1908, 704, 15, 77, "Input"],
Cell[95801, 1925, 943, 15, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96781, 1945, 436, 9, 32, "Input"],
Cell[97220, 1956, 1929, 35, 45, "Output"]
}, Open  ]],
Cell[99164, 1994, 1362, 22, 32, "Input"],
Cell[100529, 2018, 153, 3, 32, "Input"],
Cell[100685, 2023, 173, 4, 32, "Input"],
Cell[100861, 2029, 341, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[101227, 2040, 433, 8, 32, "Input"],
Cell[101663, 2050, 446292, 7321, 473, 214181, 3516, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[547970, 9374, 202, 5, 32, "Input"],
Cell[CellGroupData[{
Cell[548197, 9383, 235, 5, 32, "Input"],
Cell[548435, 9390, 21417, 356, 134, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[569889, 9751, 211, 4, 32, "Input"],
Cell[570103, 9757, 2253, 42, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[572405, 9805, 160, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[572590, 9811, 111, 1, 29, "Subsubsection"],
Cell[CellGroupData[{
Cell[572726, 9816, 416, 11, 77, "Input"],
Cell[573145, 9829, 374, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[573556, 9841, 355, 7, 32, "Input"],
Cell[573914, 9850, 260580, 4340, 762, 203985, 3410, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834531, 14195, 332, 6, 32, "Input"],
Cell[834866, 14203, 292843, 4786, 756, 209278, 3414, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1127746, 18994, 367, 6, 32, "Input"],
Cell[1128116, 19002, 159046, 2595, 756, 106667, 1735, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1287211, 21603, 107, 1, 29, "Subsubsection"],
Cell[CellGroupData[{
Cell[1287343, 21608, 272, 8, 32, "Input"],
Cell[1287618, 21618, 518, 12, 31, "Output"]
}, Open  ]],
Cell[1288151, 21633, 4251, 104, 407, "Input"],
Cell[1292405, 21739, 377, 10, 32, "Input"],
Cell[CellGroupData[{
Cell[1292807, 21753, 296, 8, 32, "Input"],
Cell[1293106, 21763, 140887, 2258, 414, 131700, 2106, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1434030, 24026, 336, 10, 32, "Input"],
Cell[1434369, 24038, 136528, 2191, 414, 127280, 2038, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1570934, 26234, 221, 5, 32, "Input"],
Cell[1571158, 26241, 33168, 538, 202, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1604363, 26784, 233, 5, 32, "Input"],
Cell[1604599, 26791, 34568, 562, 141, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1639204, 27358, 249, 6, 32, "Input"],
Cell[1639456, 27366, 47739, 793, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1687232, 28164, 324, 8, 32, "Input"],
Cell[1687559, 28174, 71312, 1149, 278, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1758908, 29328, 304, 8, 32, "Input"],
Cell[1759215, 29338, 28106, 491, 414, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1787358, 29834, 300, 8, 32, "Input"],
Cell[1787661, 29844, 68245, 1103, 414, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1855943, 30952, 341, 10, 32, "Input"],
Cell[1856287, 30964, 64619, 1032, 414, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
